Class: Aws::MediaConvert::Types::AacSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::AacSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
When making an API call, you may pass AacSettings data as a hash:
{
audio_description_broadcaster_mix: "BROADCASTER_MIXED_AD", # accepts BROADCASTER_MIXED_AD, NORMAL
bitrate: 1,
codec_profile: "LC", # accepts LC, HEV1, HEV2
coding_mode: "AD_RECEIVER_MIX", # accepts AD_RECEIVER_MIX, CODING_MODE_1_0, CODING_MODE_1_1, CODING_MODE_2_0, CODING_MODE_5_1
rate_control_mode: "CBR", # accepts CBR, VBR
raw_format: "LATM_LOAS", # accepts LATM_LOAS, NONE
sample_rate: 1,
specification: "MPEG2", # accepts MPEG2, MPEG4
vbr_quality: "LOW", # accepts LOW, MEDIUM_LOW, MEDIUM_HIGH, HIGH
}
Required when you set (Codec) under (AudioDescriptions)>(CodecSettings) to the value AAC. The service accepts one of two mutually exclusive groups of AAC settings–VBR and CBR. To select one of these modes, set the value of Bitrate control mode (rateControlMode) to “VBR” or “CBR”. In VBR mode, you control the audio quality with the setting VBR quality (vbrQuality). In CBR mode, you use the setting Bitrate (bitrate). Defaults and valid values depend on the rate control mode.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#audio_description_broadcaster_mix ⇒ String
Choose BROADCASTER_MIXED_AD when the input contains pre-mixed main audio + audio description (AD) as a stereo pair.
-
#bitrate ⇒ Integer
Specify the average bitrate in bits per second.
-
#codec_profile ⇒ String
AAC Profile.
-
#coding_mode ⇒ String
Mono (Audio Description), Mono, Stereo, or 5.1 channel layout.
-
#rate_control_mode ⇒ String
Rate Control Mode.
-
#raw_format ⇒ String
Enables LATM/LOAS AAC output.
-
#sample_rate ⇒ Integer
Sample rate in Hz.
-
#specification ⇒ String
Use MPEG-2 AAC instead of MPEG-4 AAC audio for raw or MPEG-2 Transport Stream containers.
-
#vbr_quality ⇒ String
VBR Quality Level - Only used if rate_control_mode is VBR.
Instance Attribute Details
#audio_description_broadcaster_mix ⇒ String
Choose BROADCASTER_MIXED_AD when the input contains pre-mixed main audio + audio description (AD) as a stereo pair. The value for AudioType will be set to 3, which signals to downstream systems that this stream contains “broadcaster mixed AD”. Note that the input received by the encoder must contain pre-mixed audio; the encoder does not perform the mixing. When you choose BROADCASTER_MIXED_AD, the encoder ignores any values you provide in AudioType and FollowInputAudioType. Choose NORMAL when the input does not contain pre-mixed audio + audio description (AD). In this case, the encoder will use any values you provide for AudioType and FollowInputAudioType.
102 103 104 105 106 107 108 109 110 111 112 113 114 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 102 class AacSettings < Struct.new( :audio_description_broadcaster_mix, :bitrate, :codec_profile, :coding_mode, :rate_control_mode, :raw_format, :sample_rate, :specification, :vbr_quality) SENSITIVE = [] include Aws::Structure end |
#bitrate ⇒ Integer
Specify the average bitrate in bits per second. The set of valid values for this setting is: 6000, 8000, 10000, 12000, 14000, 16000, 20000, 24000, 28000, 32000, 40000, 48000, 56000, 64000, 80000, 96000, 112000, 128000, 160000, 192000, 224000, 256000, 288000, 320000, 384000, 448000, 512000, 576000, 640000, 768000, 896000,
-
The value you set is also constrained by the values that
you choose for Profile (codecProfile), Bitrate control mode (codingMode), and Sample rate (sampleRate). Default values depend on Bitrate control mode and Profile.
102 103 104 105 106 107 108 109 110 111 112 113 114 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 102 class AacSettings < Struct.new( :audio_description_broadcaster_mix, :bitrate, :codec_profile, :coding_mode, :rate_control_mode, :raw_format, :sample_rate, :specification, :vbr_quality) SENSITIVE = [] include Aws::Structure end |
#codec_profile ⇒ String
AAC Profile.
102 103 104 105 106 107 108 109 110 111 112 113 114 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 102 class AacSettings < Struct.new( :audio_description_broadcaster_mix, :bitrate, :codec_profile, :coding_mode, :rate_control_mode, :raw_format, :sample_rate, :specification, :vbr_quality) SENSITIVE = [] include Aws::Structure end |
#coding_mode ⇒ String
Mono (Audio Description), Mono, Stereo, or 5.1 channel layout. Valid values depend on rate control mode and profile. “1.0 - Audio Description (Receiver Mix)” setting receives a stereo description plus control track and emits a mono AAC encode of the description track, with control data emitted in the PES header as per ETSI TS 101 154 Annex E.
102 103 104 105 106 107 108 109 110 111 112 113 114 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 102 class AacSettings < Struct.new( :audio_description_broadcaster_mix, :bitrate, :codec_profile, :coding_mode, :rate_control_mode, :raw_format, :sample_rate, :specification, :vbr_quality) SENSITIVE = [] include Aws::Structure end |
#rate_control_mode ⇒ String
Rate Control Mode.
102 103 104 105 106 107 108 109 110 111 112 113 114 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 102 class AacSettings < Struct.new( :audio_description_broadcaster_mix, :bitrate, :codec_profile, :coding_mode, :rate_control_mode, :raw_format, :sample_rate, :specification, :vbr_quality) SENSITIVE = [] include Aws::Structure end |
#raw_format ⇒ String
Enables LATM/LOAS AAC output. Note that if you use LATM/LOAS AAC in an output, you must choose “No container” for the output container.
102 103 104 105 106 107 108 109 110 111 112 113 114 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 102 class AacSettings < Struct.new( :audio_description_broadcaster_mix, :bitrate, :codec_profile, :coding_mode, :rate_control_mode, :raw_format, :sample_rate, :specification, :vbr_quality) SENSITIVE = [] include Aws::Structure end |
#sample_rate ⇒ Integer
Sample rate in Hz. Valid values depend on rate control mode and profile.
102 103 104 105 106 107 108 109 110 111 112 113 114 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 102 class AacSettings < Struct.new( :audio_description_broadcaster_mix, :bitrate, :codec_profile, :coding_mode, :rate_control_mode, :raw_format, :sample_rate, :specification, :vbr_quality) SENSITIVE = [] include Aws::Structure end |
#specification ⇒ String
Use MPEG-2 AAC instead of MPEG-4 AAC audio for raw or MPEG-2 Transport Stream containers.
102 103 104 105 106 107 108 109 110 111 112 113 114 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 102 class AacSettings < Struct.new( :audio_description_broadcaster_mix, :bitrate, :codec_profile, :coding_mode, :rate_control_mode, :raw_format, :sample_rate, :specification, :vbr_quality) SENSITIVE = [] include Aws::Structure end |
#vbr_quality ⇒ String
VBR Quality Level - Only used if rate_control_mode is VBR.
102 103 104 105 106 107 108 109 110 111 112 113 114 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 102 class AacSettings < Struct.new( :audio_description_broadcaster_mix, :bitrate, :codec_profile, :coding_mode, :rate_control_mode, :raw_format, :sample_rate, :specification, :vbr_quality) SENSITIVE = [] include Aws::Structure end |