Class: Aws::MediaConvert::Types::Ac4Settings
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::Ac4Settings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
Required when you set Codec to the value AC4.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bitrate ⇒ Integer
Specify the average bitrate in bits per second.
-
#bitstream_mode ⇒ String
Specify the bitstream mode for the AC-4 stream that the encoder emits.
-
#coding_mode ⇒ String
Dolby AC-4 coding mode.
-
#dynamic_range_compression_flat_panel_tv ⇒ String
Choose the Dolby AC-4 dynamic range control (DRC) profile that MediaConvert uses when encoding the metadata in the Dolby AC-4 stream for the specified decoder mode.
-
#dynamic_range_compression_home_theater ⇒ String
Choose the Dolby AC-4 dynamic range control (DRC) profile that MediaConvert uses when encoding the metadata in the Dolby AC-4 stream for the specified decoder mode.
-
#dynamic_range_compression_portable_headphones ⇒ String
Choose the Dolby AC-4 dynamic range control (DRC) profile that MediaConvert uses when encoding the metadata in the Dolby AC-4 stream for the specified decoder mode.
-
#dynamic_range_compression_portable_speakers ⇒ String
Choose the Dolby AC-4 dynamic range control (DRC) profile that MediaConvert uses when encoding the metadata in the Dolby AC-4 stream for the specified decoder mode.
-
#lo_ro_center_mix_level ⇒ Float
Specify a value for the following Dolby AC-4 setting: Left only/Right only center mix.
-
#lo_ro_surround_mix_level ⇒ Float
Specify a value for the following Dolby AC-4 setting: Left only/Right only surround mix.
-
#lt_rt_center_mix_level ⇒ Float
Specify a value for the following Dolby AC-4 setting: Left total/Right total center mix.
-
#lt_rt_surround_mix_level ⇒ Float
Specify a value for the following Dolby AC-4 setting: Left total/Right total surround mix.
-
#sample_rate ⇒ Integer
This value is always 48000.
-
#stereo_downmix ⇒ String
Choose the preferred stereo downmix method.
Instance Attribute Details
#bitrate ⇒ Integer
Specify the average bitrate in bits per second. Leave blank to use the default bitrate for the coding mode you select according to ETSI TS 103 190. Valid bitrates for coding mode 2.0 (stereo): 48000, 64000, 96000, 128000, 144000, 192000, 256000, 288000, 320000, 384000, 448000, 512000, or 768000. Valid bitrates for coding mode 5.1 (3/2 with LFE): 96000, 128000, 144000, 192000, 256000, 288000, 320000, 384000, 448000, 512000, or 768000. Valid bitrates for coding mode 5.1.4 (immersive): 192000, 256000, 288000, 320000, 384000, 448000, 512000, or 768000.
367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 367 class Ac4Settings < Struct.new( :bitrate, :bitstream_mode, :coding_mode, :dynamic_range_compression_flat_panel_tv, :dynamic_range_compression_home_theater, :dynamic_range_compression_portable_headphones, :dynamic_range_compression_portable_speakers, :lo_ro_center_mix_level, :lo_ro_surround_mix_level, :lt_rt_center_mix_level, :lt_rt_surround_mix_level, :sample_rate, :stereo_downmix) SENSITIVE = [] include Aws::Structure end |
#bitstream_mode ⇒ String
Specify the bitstream mode for the AC-4 stream that the encoder emits. For more information about the AC-4 bitstream mode, see ETSI TS 103 190. Maps to dlb_paec_ac4_bed_classifier in the encoder implementation. - COMPLETE_MAIN: Complete Main (standard mix) - EMERGENCY: Stereo Emergency content
367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 367 class Ac4Settings < Struct.new( :bitrate, :bitstream_mode, :coding_mode, :dynamic_range_compression_flat_panel_tv, :dynamic_range_compression_home_theater, :dynamic_range_compression_portable_headphones, :dynamic_range_compression_portable_speakers, :lo_ro_center_mix_level, :lo_ro_surround_mix_level, :lt_rt_center_mix_level, :lt_rt_surround_mix_level, :sample_rate, :stereo_downmix) SENSITIVE = [] include Aws::Structure end |
#coding_mode ⇒ String
Dolby AC-4 coding mode. Determines number of channels. Maps to dlb_paec_ac4_bed_channel_config in the encoder implementation.
-
CODING_MODE_2_0: 2.0 (stereo) - maps to
DLB_PAEC_AC4_BED_CHANNEL_CONFIG_20 - CODING_MODE_3_2_LFE: 5.1 surround - maps to DLB_PAEC_AC4_BED_CHANNEL_CONFIG_51 - CODING_MODE_5_1_4: 5.1.4 immersive - maps to DLB_PAEC_AC4_BED_CHANNEL_CONFIG_514
367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 367 class Ac4Settings < Struct.new( :bitrate, :bitstream_mode, :coding_mode, :dynamic_range_compression_flat_panel_tv, :dynamic_range_compression_home_theater, :dynamic_range_compression_portable_headphones, :dynamic_range_compression_portable_speakers, :lo_ro_center_mix_level, :lo_ro_surround_mix_level, :lt_rt_center_mix_level, :lt_rt_surround_mix_level, :sample_rate, :stereo_downmix) SENSITIVE = [] include Aws::Structure end |
#dynamic_range_compression_flat_panel_tv ⇒ String
Choose the Dolby AC-4 dynamic range control (DRC) profile that MediaConvert uses when encoding the metadata in the Dolby AC-4 stream for the specified decoder mode. For information about the Dolby AC-4 DRC profiles, see the Dolby AC-4 specification.
367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 367 class Ac4Settings < Struct.new( :bitrate, :bitstream_mode, :coding_mode, :dynamic_range_compression_flat_panel_tv, :dynamic_range_compression_home_theater, :dynamic_range_compression_portable_headphones, :dynamic_range_compression_portable_speakers, :lo_ro_center_mix_level, :lo_ro_surround_mix_level, :lt_rt_center_mix_level, :lt_rt_surround_mix_level, :sample_rate, :stereo_downmix) SENSITIVE = [] include Aws::Structure end |
#dynamic_range_compression_home_theater ⇒ String
Choose the Dolby AC-4 dynamic range control (DRC) profile that MediaConvert uses when encoding the metadata in the Dolby AC-4 stream for the specified decoder mode. For information about the Dolby AC-4 DRC profiles, see the Dolby AC-4 specification.
367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 367 class Ac4Settings < Struct.new( :bitrate, :bitstream_mode, :coding_mode, :dynamic_range_compression_flat_panel_tv, :dynamic_range_compression_home_theater, :dynamic_range_compression_portable_headphones, :dynamic_range_compression_portable_speakers, :lo_ro_center_mix_level, :lo_ro_surround_mix_level, :lt_rt_center_mix_level, :lt_rt_surround_mix_level, :sample_rate, :stereo_downmix) SENSITIVE = [] include Aws::Structure end |
#dynamic_range_compression_portable_headphones ⇒ String
Choose the Dolby AC-4 dynamic range control (DRC) profile that MediaConvert uses when encoding the metadata in the Dolby AC-4 stream for the specified decoder mode. For information about the Dolby AC-4 DRC profiles, see the Dolby AC-4 specification.
367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 367 class Ac4Settings < Struct.new( :bitrate, :bitstream_mode, :coding_mode, :dynamic_range_compression_flat_panel_tv, :dynamic_range_compression_home_theater, :dynamic_range_compression_portable_headphones, :dynamic_range_compression_portable_speakers, :lo_ro_center_mix_level, :lo_ro_surround_mix_level, :lt_rt_center_mix_level, :lt_rt_surround_mix_level, :sample_rate, :stereo_downmix) SENSITIVE = [] include Aws::Structure end |
#dynamic_range_compression_portable_speakers ⇒ String
Choose the Dolby AC-4 dynamic range control (DRC) profile that MediaConvert uses when encoding the metadata in the Dolby AC-4 stream for the specified decoder mode. For information about the Dolby AC-4 DRC profiles, see the Dolby AC-4 specification.
367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 367 class Ac4Settings < Struct.new( :bitrate, :bitstream_mode, :coding_mode, :dynamic_range_compression_flat_panel_tv, :dynamic_range_compression_home_theater, :dynamic_range_compression_portable_headphones, :dynamic_range_compression_portable_speakers, :lo_ro_center_mix_level, :lo_ro_surround_mix_level, :lt_rt_center_mix_level, :lt_rt_surround_mix_level, :sample_rate, :stereo_downmix) SENSITIVE = [] include Aws::Structure end |
#lo_ro_center_mix_level ⇒ Float
Specify a value for the following Dolby AC-4 setting: Left only/Right only center mix. MediaConvert uses this value for downmixing. How the service uses this value depends on the value that you choose for Stereo downmix. Valid values: 3.0, 1.5, 0.0, -1.5, -3.0, -4.5, -6.0, and -infinity. The value -infinity mutes the channel. This setting applies only if you keep the default value of 3/2 - L, R, C, Ls, Rs for the setting Coding mode. If you choose a different value for Coding mode, the service ignores Left only/Right only center.
367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 367 class Ac4Settings < Struct.new( :bitrate, :bitstream_mode, :coding_mode, :dynamic_range_compression_flat_panel_tv, :dynamic_range_compression_home_theater, :dynamic_range_compression_portable_headphones, :dynamic_range_compression_portable_speakers, :lo_ro_center_mix_level, :lo_ro_surround_mix_level, :lt_rt_center_mix_level, :lt_rt_surround_mix_level, :sample_rate, :stereo_downmix) SENSITIVE = [] include Aws::Structure end |
#lo_ro_surround_mix_level ⇒ Float
Specify a value for the following Dolby AC-4 setting: Left only/Right only surround mix. MediaConvert uses this value for downmixing. How the service uses this value depends on the value that you choose for Stereo downmix. Valid values: -1.5, -3.0, -4.5, -6.0, and -infinity. The value -infinity mutes the channel. This setting applies only if you keep the default value of 3/2 - L, R, C, Ls, Rs for the setting Coding mode. If you choose a different value for Coding mode, the service ignores Left only/Right only surround.
367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 367 class Ac4Settings < Struct.new( :bitrate, :bitstream_mode, :coding_mode, :dynamic_range_compression_flat_panel_tv, :dynamic_range_compression_home_theater, :dynamic_range_compression_portable_headphones, :dynamic_range_compression_portable_speakers, :lo_ro_center_mix_level, :lo_ro_surround_mix_level, :lt_rt_center_mix_level, :lt_rt_surround_mix_level, :sample_rate, :stereo_downmix) SENSITIVE = [] include Aws::Structure end |
#lt_rt_center_mix_level ⇒ Float
Specify a value for the following Dolby AC-4 setting: Left total/Right total center mix. MediaConvert uses this value for downmixing. How the service uses this value depends on the value that you choose for Stereo downmix. Valid values: 3.0, 1.5, 0.0, -1.5, -3.0, -4.5, -6.0, and -infinity. The value -infinity mutes the channel. This setting applies only if you keep the default value of 3/2 - L, R, C, Ls, Rs for the setting Coding mode. If you choose a different value for Coding mode, the service ignores Left total/Right total center.
367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 367 class Ac4Settings < Struct.new( :bitrate, :bitstream_mode, :coding_mode, :dynamic_range_compression_flat_panel_tv, :dynamic_range_compression_home_theater, :dynamic_range_compression_portable_headphones, :dynamic_range_compression_portable_speakers, :lo_ro_center_mix_level, :lo_ro_surround_mix_level, :lt_rt_center_mix_level, :lt_rt_surround_mix_level, :sample_rate, :stereo_downmix) SENSITIVE = [] include Aws::Structure end |
#lt_rt_surround_mix_level ⇒ Float
Specify a value for the following Dolby AC-4 setting: Left total/Right total surround mix. MediaConvert uses this value for downmixing. How the service uses this value depends on the value that you choose for Stereo downmix. Valid values: -1.5, -3.0, -4.5, -6.0, and -infinity. The value -infinity mutes the channel. This setting applies only if you keep the default value of 3/2 - L, R, C, Ls, Rs for the setting Coding mode. If you choose a different value for Coding mode, the service ignores Left total/Right total surround.
367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 367 class Ac4Settings < Struct.new( :bitrate, :bitstream_mode, :coding_mode, :dynamic_range_compression_flat_panel_tv, :dynamic_range_compression_home_theater, :dynamic_range_compression_portable_headphones, :dynamic_range_compression_portable_speakers, :lo_ro_center_mix_level, :lo_ro_surround_mix_level, :lt_rt_center_mix_level, :lt_rt_surround_mix_level, :sample_rate, :stereo_downmix) SENSITIVE = [] include Aws::Structure end |
#sample_rate ⇒ Integer
This value is always 48000. It represents the sample rate in Hz.
367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 367 class Ac4Settings < Struct.new( :bitrate, :bitstream_mode, :coding_mode, :dynamic_range_compression_flat_panel_tv, :dynamic_range_compression_home_theater, :dynamic_range_compression_portable_headphones, :dynamic_range_compression_portable_speakers, :lo_ro_center_mix_level, :lo_ro_surround_mix_level, :lt_rt_center_mix_level, :lt_rt_surround_mix_level, :sample_rate, :stereo_downmix) SENSITIVE = [] include Aws::Structure end |
#stereo_downmix ⇒ String
Choose the preferred stereo downmix method. This setting tells the decoder how to downmix multi-channel audio to stereo during playback.
367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 367 class Ac4Settings < Struct.new( :bitrate, :bitstream_mode, :coding_mode, :dynamic_range_compression_flat_panel_tv, :dynamic_range_compression_home_theater, :dynamic_range_compression_portable_headphones, :dynamic_range_compression_portable_speakers, :lo_ro_center_mix_level, :lo_ro_surround_mix_level, :lt_rt_center_mix_level, :lt_rt_surround_mix_level, :sample_rate, :stereo_downmix) SENSITIVE = [] include Aws::Structure end |