Class: Aws::MediaConvert::Types::AudioNormalizationSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::AudioNormalizationSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
Advanced audio normalization settings. Ignore these settings unless you need to comply with a loudness standard.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#algorithm ⇒ String
Choose one of the following audio normalization algorithms: ITU-R BS.1770-1: Ungated loudness.
-
#algorithm_control ⇒ String
When enabled the output audio is corrected using the chosen algorithm.
-
#correction_gate_level ⇒ Integer
Content measuring above this level will be corrected to the target level.
-
#loudness_logging ⇒ String
If set to LOG, log each output's audio track loudness to a CSV file.
-
#peak_calculation ⇒ String
If set to TRUE_PEAK, calculate and log the TruePeak for each output's audio track loudness.
-
#target_lkfs ⇒ Float
When you use Audio normalization (AudioNormalizationSettings), optionally use this setting to specify a target loudness.
Instance Attribute Details
#algorithm ⇒ String
Choose one of the following audio normalization algorithms: ITU-R BS.1770-1: Ungated loudness. A measurement of ungated average loudness for an entire piece of content, suitable for measurement of short-form content under ATSC recommendation A/85. Supports up to 5.1 audio channels. ITU-R BS.1770-2: Gated loudness. A measurement of gated average loudness compliant with the requirements of EBU-R128. Supports up to 5.1 audio channels. ITU-R BS.1770-3: Modified peak. The same loudness measurement algorithm as 1770-2, with an updated true peak measurement. ITU-R BS.1770-4: Higher channel count. Allows for more audio channels than the other algorithms, including configurations such as 7.1.
633 634 635 636 637 638 639 640 641 642 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 633 class AudioNormalizationSettings < Struct.new( :algorithm, :algorithm_control, :correction_gate_level, :loudness_logging, :peak_calculation, :target_lkfs) SENSITIVE = [] include Aws::Structure end |
#algorithm_control ⇒ String
When enabled the output audio is corrected using the chosen algorithm. If disabled, the audio will be measured but not adjusted.
633 634 635 636 637 638 639 640 641 642 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 633 class AudioNormalizationSettings < Struct.new( :algorithm, :algorithm_control, :correction_gate_level, :loudness_logging, :peak_calculation, :target_lkfs) SENSITIVE = [] include Aws::Structure end |
#correction_gate_level ⇒ Integer
Content measuring above this level will be corrected to the target level. Content measuring below this level will not be corrected.
633 634 635 636 637 638 639 640 641 642 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 633 class AudioNormalizationSettings < Struct.new( :algorithm, :algorithm_control, :correction_gate_level, :loudness_logging, :peak_calculation, :target_lkfs) SENSITIVE = [] include Aws::Structure end |
#loudness_logging ⇒ String
If set to LOG, log each output's audio track loudness to a CSV file.
633 634 635 636 637 638 639 640 641 642 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 633 class AudioNormalizationSettings < Struct.new( :algorithm, :algorithm_control, :correction_gate_level, :loudness_logging, :peak_calculation, :target_lkfs) SENSITIVE = [] include Aws::Structure end |
#peak_calculation ⇒ String
If set to TRUE_PEAK, calculate and log the TruePeak for each output's audio track loudness.
633 634 635 636 637 638 639 640 641 642 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 633 class AudioNormalizationSettings < Struct.new( :algorithm, :algorithm_control, :correction_gate_level, :loudness_logging, :peak_calculation, :target_lkfs) SENSITIVE = [] include Aws::Structure end |
#target_lkfs ⇒ Float
When you use Audio normalization (AudioNormalizationSettings), optionally use this setting to specify a target loudness. If you don't specify a value here, the encoder chooses a value for you, based on the algorithm that you choose for Algorithm (algorithm). If you choose algorithm 1770-1, the encoder will choose -24 LKFS; otherwise, the encoder will choose -23 LKFS.
633 634 635 636 637 638 639 640 641 642 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 633 class AudioNormalizationSettings < Struct.new( :algorithm, :algorithm_control, :correction_gate_level, :loudness_logging, :peak_calculation, :target_lkfs) SENSITIVE = [] include Aws::Structure end |