Class: Aws::MediaConvert::Types::AudioProperties

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediaconvert/types.rb

Overview

Details about the media file's audio track.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bit_depthInteger

The bit depth of the audio track.

Returns:

  • (Integer)


976
977
978
979
980
981
982
983
984
985
986
987
# File 'lib/aws-sdk-mediaconvert/types.rb', line 976

class AudioProperties < Struct.new(
  :bit_depth,
  :bit_rate,
  :channel_layout,
  :channels,
  :frame_rate,
  :language_code,
  :object_count,
  :sample_rate)
  SENSITIVE = []
  include Aws::Structure
end

#bit_rateInteger

The bit rate of the audio track, in bits per second.

Returns:

  • (Integer)


976
977
978
979
980
981
982
983
984
985
986
987
# File 'lib/aws-sdk-mediaconvert/types.rb', line 976

class AudioProperties < Struct.new(
  :bit_depth,
  :bit_rate,
  :channel_layout,
  :channels,
  :frame_rate,
  :language_code,
  :object_count,
  :sample_rate)
  SENSITIVE = []
  include Aws::Structure
end

#channel_layoutString

The audio channel layout of the track, such as "mono", "stereo", "5.1", or "7.1". Object-based or immersive audio is reported as "5.1.4" or "7.1.4".

Returns:

  • (String)


976
977
978
979
980
981
982
983
984
985
986
987
# File 'lib/aws-sdk-mediaconvert/types.rb', line 976

class AudioProperties < Struct.new(
  :bit_depth,
  :bit_rate,
  :channel_layout,
  :channels,
  :frame_rate,
  :language_code,
  :object_count,
  :sample_rate)
  SENSITIVE = []
  include Aws::Structure
end

#channelsInteger

The number of audio channels in the audio track.

Returns:

  • (Integer)


976
977
978
979
980
981
982
983
984
985
986
987
# File 'lib/aws-sdk-mediaconvert/types.rb', line 976

class AudioProperties < Struct.new(
  :bit_depth,
  :bit_rate,
  :channel_layout,
  :channels,
  :frame_rate,
  :language_code,
  :object_count,
  :sample_rate)
  SENSITIVE = []
  include Aws::Structure
end

#frame_rateTypes::FrameRate

The frame rate of the video or audio track, expressed as a fraction with numerator and denominator values.

Returns:



976
977
978
979
980
981
982
983
984
985
986
987
# File 'lib/aws-sdk-mediaconvert/types.rb', line 976

class AudioProperties < Struct.new(
  :bit_depth,
  :bit_rate,
  :channel_layout,
  :channels,
  :frame_rate,
  :language_code,
  :object_count,
  :sample_rate)
  SENSITIVE = []
  include Aws::Structure
end

#language_codeString

The language code of the audio track, in three character ISO 639-3 format.

Returns:

  • (String)


976
977
978
979
980
981
982
983
984
985
986
987
# File 'lib/aws-sdk-mediaconvert/types.rb', line 976

class AudioProperties < Struct.new(
  :bit_depth,
  :bit_rate,
  :channel_layout,
  :channels,
  :frame_rate,
  :language_code,
  :object_count,
  :sample_rate)
  SENSITIVE = []
  include Aws::Structure
end

#object_countInteger

The number of audio objects in an object-based or immersive audio track. This field is present for codecs that support object-based audio, such as E-AC-3 with Joint Object Coding (JOC) or IAMF. This field is null when the audio track does not contain object-based audio metadata.

Returns:

  • (Integer)


976
977
978
979
980
981
982
983
984
985
986
987
# File 'lib/aws-sdk-mediaconvert/types.rb', line 976

class AudioProperties < Struct.new(
  :bit_depth,
  :bit_rate,
  :channel_layout,
  :channels,
  :frame_rate,
  :language_code,
  :object_count,
  :sample_rate)
  SENSITIVE = []
  include Aws::Structure
end

#sample_rateInteger

The sample rate of the audio track.

Returns:

  • (Integer)


976
977
978
979
980
981
982
983
984
985
986
987
# File 'lib/aws-sdk-mediaconvert/types.rb', line 976

class AudioProperties < Struct.new(
  :bit_depth,
  :bit_rate,
  :channel_layout,
  :channels,
  :frame_rate,
  :language_code,
  :object_count,
  :sample_rate)
  SENSITIVE = []
  include Aws::Structure
end