Class: Aws::MediaConvert::Types::AutomatedAbrSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::AutomatedAbrSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
Use automated ABR to have MediaConvert set up the renditions in your ABR package for you automatically, based on characteristics of your input video. This feature optimizes video quality while minimizing the overall size of your ABR package.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_abr_bitrate ⇒ Integer
Optional.
-
#max_renditions ⇒ Integer
Optional.
-
#min_abr_bitrate ⇒ Integer
Optional.
-
#rules ⇒ Array<Types::AutomatedAbrRule>
Optional.
Instance Attribute Details
#max_abr_bitrate ⇒ Integer
Optional. The maximum target bit rate used in your automated ABR stack. Use this value to set an upper limit on the bandwidth consumed by the highest-quality rendition. This is the rendition that is delivered to viewers with the fastest internet connections. If you don't specify a value, MediaConvert uses 8,000,000 (8 mb/s) by default.
923 924 925 926 927 928 929 930 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 923 class AutomatedAbrSettings < Struct.new( :max_abr_bitrate, :max_renditions, :min_abr_bitrate, :rules) SENSITIVE = [] include Aws::Structure end |
#max_renditions ⇒ Integer
Optional. The maximum number of renditions that MediaConvert will create in your automated ABR stack. The number of renditions is determined automatically, based on analysis of each job, but will never exceed this limit. When you set this to Auto in the console, which is equivalent to excluding it from your JSON job specification, MediaConvert defaults to a limit of 15.
923 924 925 926 927 928 929 930 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 923 class AutomatedAbrSettings < Struct.new( :max_abr_bitrate, :max_renditions, :min_abr_bitrate, :rules) SENSITIVE = [] include Aws::Structure end |
#min_abr_bitrate ⇒ Integer
Optional. The minimum target bitrate used in your automated ABR stack. Use this value to set a lower limit on the bitrate of video delivered to viewers with slow internet connections. If you don't specify a value, MediaConvert uses 600,000 (600 kb/s) by default.
923 924 925 926 927 928 929 930 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 923 class AutomatedAbrSettings < Struct.new( :max_abr_bitrate, :max_renditions, :min_abr_bitrate, :rules) SENSITIVE = [] include Aws::Structure end |
#rules ⇒ Array<Types::AutomatedAbrRule>
Optional. Use Automated ABR rules to specify restrictions for the rendition sizes MediaConvert will create in your ABR stack. You can use these rules if your ABR workflow has specific rendition size requirements, but you still want MediaConvert to optimize for video quality and overall file size.
923 924 925 926 927 928 929 930 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 923 class AutomatedAbrSettings < Struct.new( :max_abr_bitrate, :max_renditions, :min_abr_bitrate, :rules) SENSITIVE = [] include Aws::Structure end |