Class: Aws::MediaConvert::Types::AutomatedEncodingSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::AutomatedEncodingSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
Use automated encoding to have MediaConvert choose your encoding settings for you, based on characteristics of your input video.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#abr_settings ⇒ Types::AutomatedAbrSettings
Use automated ABR to have MediaConvert set up the renditions in your ABR package for you automatically, based on characteristics of your input video.
Instance Attribute Details
#abr_settings ⇒ Types::AutomatedAbrSettings
Use automated ABR to have MediaConvert set up the renditions in your ABR package for you automatically, based on characteristics of your input video. This feature optimizes video quality while minimizing the overall size of your ABR package.
1293 1294 1295 1296 1297 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 1293 class AutomatedEncodingSettings < Struct.new( :abr_settings) SENSITIVE = [] include Aws::Structure end |