Class: Aws::MediaConvert::Types::AvailBlanking

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediaconvert/types.rb

Overview

Use ad avail blanking settings to specify your output content during SCTE-35 triggered ad avails. You can blank your video or overlay it with an image. MediaConvert also removes any audio and embedded captions during the ad avail. For more information, see docs.aws.amazon.com/mediaconvert/latest/ug/ad-avail-blanking.html.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#avail_blanking_imageString

Blanking image to be used. Leave empty for solid black. Only bmp and png images are supported.

Returns:

  • (String)


1148
1149
1150
1151
1152
# File 'lib/aws-sdk-mediaconvert/types.rb', line 1148

class AvailBlanking < Struct.new(
  :avail_blanking_image)
  SENSITIVE = []
  include Aws::Structure
end