Class: Aws::MediaConvert::Types::AvcIntraUhdSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::AvcIntraUhdSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
Optional when you set AVC-Intra class to Class 4K/2K. When you set AVC-Intra class to a different value, this object isn’t allowed.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#quality_tuning_level ⇒ String
Optional.
Instance Attribute Details
#quality_tuning_level ⇒ String
Optional. Use Quality tuning level to choose how many transcoding passes MediaConvert does with your video. When you choose Multi-pass, your video quality is better and your output bitrate is more accurate. That is, the actual bitrate of your output is closer to the target bitrate defined in the specification. When you choose Single-pass, your encoding time is faster. The default behavior is Single-pass.
1704 1705 1706 1707 1708 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 1704 class AvcIntraUhdSettings < Struct.new( :quality_tuning_level) SENSITIVE = [] include Aws::Structure end |