Class: Aws::MediaConvert::Types::CaptionDescriptionPreset
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::CaptionDescriptionPreset
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
Caption Description for preset
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#custom_language_code ⇒ String
Specify the language for this captions output track.
-
#destination_settings ⇒ Types::CaptionDestinationSettings
Settings related to one captions tab on the MediaConvert console.
-
#language_code ⇒ String
Specify the language of this captions output track.
-
#language_description ⇒ String
Specify a label for this set of output captions.
Instance Attribute Details
#custom_language_code ⇒ String
Specify the language for this captions output track. For most captions output formats, the encoder puts this language information in the output captions metadata. If your output captions format is DVB-Sub or Burn in, the encoder uses this language information when automatically selecting the font script for rendering the captions text. For all outputs, you can use an ISO 639-2 or ISO 639-3 code. For streaming outputs, you can also use any other code in the full RFC-5646 specification. Streaming outputs are those that are in one of the following output groups: CMAF, DASH ISO, Apple HLS, or Microsoft Smooth Streaming.
1654 1655 1656 1657 1658 1659 1660 1661 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 1654 class CaptionDescriptionPreset < Struct.new( :custom_language_code, :destination_settings, :language_code, :language_description) SENSITIVE = [] include Aws::Structure end |
#destination_settings ⇒ Types::CaptionDestinationSettings
Settings related to one captions tab on the MediaConvert console. In your job JSON, an instance of captions DestinationSettings is equivalent to one captions tab in the console. Usually, one captions tab corresponds to one output captions track. Depending on your output captions format, one tab might correspond to a set of output captions tracks. For more information, see docs.aws.amazon.com/mediaconvert/latest/ug/including-captions.html.
1654 1655 1656 1657 1658 1659 1660 1661 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 1654 class CaptionDescriptionPreset < Struct.new( :custom_language_code, :destination_settings, :language_code, :language_description) SENSITIVE = [] include Aws::Structure end |
#language_code ⇒ String
Specify the language of this captions output track. For most captions output formats, the encoder puts this language information in the output captions metadata. If your output captions format is DVB-Sub or Burn in, the encoder uses this language information to choose the font language for rendering the captions text.
1654 1655 1656 1657 1658 1659 1660 1661 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 1654 class CaptionDescriptionPreset < Struct.new( :custom_language_code, :destination_settings, :language_code, :language_description) SENSITIVE = [] include Aws::Structure end |
#language_description ⇒ String
Specify a label for this set of output captions. For example, “English”, “Director commentary”, or “track_2”. For streaming outputs, MediaConvert passes this information into destination manifests for display on the end-viewer's player device. For outputs in other output groups, the service ignores this setting.
1654 1655 1656 1657 1658 1659 1660 1661 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 1654 class CaptionDescriptionPreset < Struct.new( :custom_language_code, :destination_settings, :language_code, :language_description) SENSITIVE = [] include Aws::Structure end |