Class: Aws::MediaConvert::Types::CaptionSelector
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::CaptionSelector
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
When making an API call, you may pass CaptionSelector data as a hash:
{
custom_language_code: "__stringMin3Max3PatternAZaZ3",
language_code: "ENG", # accepts ENG, SPA, FRA, DEU, GER, ZHO, ARA, HIN, JPN, RUS, POR, ITA, URD, VIE, KOR, PAN, ABK, AAR, AFR, AKA, SQI, AMH, ARG, HYE, ASM, AVA, AVE, AYM, AZE, BAM, BAK, EUS, BEL, BEN, BIH, BIS, BOS, BRE, BUL, MYA, CAT, KHM, CHA, CHE, NYA, CHU, CHV, COR, COS, CRE, HRV, CES, DAN, DIV, NLD, DZO, ENM, EPO, EST, EWE, FAO, FIJ, FIN, FRM, FUL, GLA, GLG, LUG, KAT, ELL, GRN, GUJ, HAT, HAU, HEB, HER, HMO, HUN, ISL, IDO, IBO, IND, INA, ILE, IKU, IPK, GLE, JAV, KAL, KAN, KAU, KAS, KAZ, KIK, KIN, KIR, KOM, KON, KUA, KUR, LAO, LAT, LAV, LIM, LIN, LIT, LUB, LTZ, MKD, MLG, MSA, MAL, MLT, GLV, MRI, MAR, MAH, MON, NAU, NAV, NDE, NBL, NDO, NEP, SME, NOR, NOB, NNO, OCI, OJI, ORI, ORM, OSS, PLI, FAS, POL, PUS, QUE, QAA, RON, ROH, RUN, SMO, SAG, SAN, SRD, SRB, SNA, III, SND, SIN, SLK, SLV, SOM, SOT, SUN, SWA, SSW, SWE, TGL, TAH, TGK, TAM, TAT, TEL, THA, BOD, TIR, TON, TSO, TSN, TUR, TUK, TWI, UIG, UKR, UZB, VEN, VOL, WLN, CYM, FRY, WOL, XHO, YID, YOR, ZHA, ZUL, ORJ, QPC, TNG, SRP
source_settings: {
ancillary_source_settings: {
convert_608_to_708: "UPCONVERT", # accepts UPCONVERT, DISABLED
source_ancillary_channel_number: 1,
terminate_captions: "END_OF_INPUT", # accepts END_OF_INPUT, DISABLED
},
dvb_sub_source_settings: {
pid: 1,
},
embedded_source_settings: {
convert_608_to_708: "UPCONVERT", # accepts UPCONVERT, DISABLED
source_608_channel_number: 1,
source_608_track_number: 1,
terminate_captions: "END_OF_INPUT", # accepts END_OF_INPUT, DISABLED
},
file_source_settings: {
convert_608_to_708: "UPCONVERT", # accepts UPCONVERT, DISABLED
framerate: {
framerate_denominator: 1,
framerate_numerator: 1,
},
source_file: "__stringMin14PatternS3SccSCCTtmlTTMLDfxpDFXPStlSTLSrtSRTXmlXMLSmiSMIVttVTTWebvttWEBVTTHttpsSccSCCTtmlTTMLDfxpDFXPStlSTLSrtSRTXmlXMLSmiSMIVttVTTWebvttWEBVTT",
time_delta: 1,
time_delta_units: "SECONDS", # accepts SECONDS, MILLISECONDS
},
source_type: "ANCILLARY", # accepts ANCILLARY, DVB_SUB, EMBEDDED, SCTE20, SCC, TTML, STL, SRT, SMI, SMPTE_TT, TELETEXT, NULL_SOURCE, IMSC, WEBVTT
teletext_source_settings: {
page_number: "__stringMin3Max3Pattern1809aFAF09aEAE",
},
track_source_settings: {
track_number: 1,
},
webvtt_hls_source_settings: {
rendition_group_id: "__string",
rendition_language_code: "ENG", # accepts ENG, SPA, FRA, DEU, GER, ZHO, ARA, HIN, JPN, RUS, POR, ITA, URD, VIE, KOR, PAN, ABK, AAR, AFR, AKA, SQI, AMH, ARG, HYE, ASM, AVA, AVE, AYM, AZE, BAM, BAK, EUS, BEL, BEN, BIH, BIS, BOS, BRE, BUL, MYA, CAT, KHM, CHA, CHE, NYA, CHU, CHV, COR, COS, CRE, HRV, CES, DAN, DIV, NLD, DZO, ENM, EPO, EST, EWE, FAO, FIJ, FIN, FRM, FUL, GLA, GLG, LUG, KAT, ELL, GRN, GUJ, HAT, HAU, HEB, HER, HMO, HUN, ISL, IDO, IBO, IND, INA, ILE, IKU, IPK, GLE, JAV, KAL, KAN, KAU, KAS, KAZ, KIK, KIN, KIR, KOM, KON, KUA, KUR, LAO, LAT, LAV, LIM, LIN, LIT, LUB, LTZ, MKD, MLG, MSA, MAL, MLT, GLV, MRI, MAR, MAH, MON, NAU, NAV, NDE, NBL, NDO, NEP, SME, NOR, NOB, NNO, OCI, OJI, ORI, ORM, OSS, PLI, FAS, POL, PUS, QUE, QAA, RON, ROH, RUN, SMO, SAG, SAN, SRD, SRB, SNA, III, SND, SIN, SLK, SLV, SOM, SOT, SUN, SWA, SSW, SWE, TGL, TAH, TGK, TAM, TAT, TEL, THA, BOD, TIR, TON, TSO, TSN, TUR, TUK, TWI, UIG, UKR, UZB, VEN, VOL, WLN, CYM, FRY, WOL, XHO, YID, YOR, ZHA, ZUL, ORJ, QPC, TNG, SRP
rendition_name: "__string",
},
},
}
Use captions selectors to specify the captions data from your input that you use in your outputs. You can use up to 20 captions selectors per input.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#custom_language_code ⇒ String
The specific language to extract from source, using the ISO 639-2 or ISO 639-3 three-letter language code.
-
#language_code ⇒ String
The specific language to extract from source.
-
#source_settings ⇒ Types::CaptionSourceSettings
If your input captions are SCC, TTML, STL, SMI, SRT, or IMSC in an xml file, specify the URI of the input captions source file.
Instance Attribute Details
#custom_language_code ⇒ String
The specific language to extract from source, using the ISO 639-2 or ISO 639-3 three-letter language code. If input is SCTE-27, complete this field and/or PID to select the caption language to extract. If input is DVB-Sub and output is Burn-in or SMPTE-TT, complete this field and/or PID to select the caption language to extract. If input is DVB-Sub that is being passed through, omit this field (and PID field); there is no way to extract a specific language with pass-through captions.
2695 2696 2697 2698 2699 2700 2701 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 2695 class CaptionSelector < Struct.new( :custom_language_code, :language_code, :source_settings) SENSITIVE = [] include Aws::Structure end |
#language_code ⇒ String
The specific language to extract from source. If input is SCTE-27, complete this field and/or PID to select the caption language to extract. If input is DVB-Sub and output is Burn-in or SMPTE-TT, complete this field and/or PID to select the caption language to extract. If input is DVB-Sub that is being passed through, omit this field (and PID field); there is no way to extract a specific language with pass-through captions.
2695 2696 2697 2698 2699 2700 2701 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 2695 class CaptionSelector < Struct.new( :custom_language_code, :language_code, :source_settings) SENSITIVE = [] include Aws::Structure end |
#source_settings ⇒ Types::CaptionSourceSettings
If your input captions are SCC, TTML, STL, SMI, SRT, or IMSC in an xml file, specify the URI of the input captions source file. If your input captions are IMSC in an IMF package, use TrackSourceSettings instead of FileSoureSettings.
2695 2696 2697 2698 2699 2700 2701 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 2695 class CaptionSelector < Struct.new( :custom_language_code, :language_code, :source_settings) SENSITIVE = [] include Aws::Structure end |