Class: Aws::MediaConvert::Types::CaptionSourceFramerate
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::CaptionSourceFramerate
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
Ignore this setting unless your input captions format is SCC. To have the service compensate for differing frame rates between your input captions and input video, specify the frame rate of the captions file. Specify this value as a fraction. For example, you might specify 24 / 1 for 24 fps, 25 / 1 for 25 fps, 24000 / 1001 for 23.976 fps, or 30000 / 1001 for 29.97 fps.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#framerate_denominator ⇒ Integer
Specify the denominator of the fraction that represents the frame rate for the setting Caption source frame rate.
-
#framerate_numerator ⇒ Integer
Specify the numerator of the fraction that represents the frame rate for the setting Caption source frame rate.
Instance Attribute Details
#framerate_denominator ⇒ Integer
Specify the denominator of the fraction that represents the frame rate for the setting Caption source frame rate. Use this setting along with the setting Framerate numerator.
1871 1872 1873 1874 1875 1876 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 1871 class CaptionSourceFramerate < Struct.new( :framerate_denominator, :framerate_numerator) SENSITIVE = [] include Aws::Structure end |
#framerate_numerator ⇒ Integer
Specify the numerator of the fraction that represents the frame rate for the setting Caption source frame rate. Use this setting along with the setting Framerate denominator.
1871 1872 1873 1874 1875 1876 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 1871 class CaptionSourceFramerate < Struct.new( :framerate_denominator, :framerate_numerator) SENSITIVE = [] include Aws::Structure end |