Class: Aws::MediaConvert::Types::CaptionSourceSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::CaptionSourceSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
When making an API call, you may pass CaptionSourceSettings data as a hash:
{
ancillary_source_settings: {
convert_608_to_708: "UPCONVERT", # accepts UPCONVERT, DISABLED
source_ancillary_channel_number: 1,
terminate_captions: "END_OF_INPUT", # accepts END_OF_INPUT, DISABLED
},
dvb_sub_source_settings: {
pid: 1,
},
embedded_source_settings: {
convert_608_to_708: "UPCONVERT", # accepts UPCONVERT, DISABLED
source_608_channel_number: 1,
source_608_track_number: 1,
terminate_captions: "END_OF_INPUT", # accepts END_OF_INPUT, DISABLED
},
file_source_settings: {
convert_608_to_708: "UPCONVERT", # accepts UPCONVERT, DISABLED
framerate: {
framerate_denominator: 1,
framerate_numerator: 1,
},
source_file: "__stringMin14PatternS3SccSCCTtmlTTMLDfxpDFXPStlSTLSrtSRTXmlXMLSmiSMIVttVTTWebvttWEBVTTHttpsSccSCCTtmlTTMLDfxpDFXPStlSTLSrtSRTXmlXMLSmiSMIVttVTTWebvttWEBVTT",
time_delta: 1,
time_delta_units: "SECONDS", # accepts SECONDS, MILLISECONDS
},
source_type: "ANCILLARY", # accepts ANCILLARY, DVB_SUB, EMBEDDED, SCTE20, SCC, TTML, STL, SRT, SMI, SMPTE_TT, TELETEXT, NULL_SOURCE, IMSC, WEBVTT
teletext_source_settings: {
page_number: "__stringMin3Max3Pattern1809aFAF09aEAE",
},
track_source_settings: {
track_number: 1,
},
webvtt_hls_source_settings: {
rendition_group_id: "__string",
rendition_language_code: "ENG", # accepts ENG, SPA, FRA, DEU, GER, ZHO, ARA, HIN, JPN, RUS, POR, ITA, URD, VIE, KOR, PAN, ABK, AAR, AFR, AKA, SQI, AMH, ARG, HYE, ASM, AVA, AVE, AYM, AZE, BAM, BAK, EUS, BEL, BEN, BIH, BIS, BOS, BRE, BUL, MYA, CAT, KHM, CHA, CHE, NYA, CHU, CHV, COR, COS, CRE, HRV, CES, DAN, DIV, NLD, DZO, ENM, EPO, EST, EWE, FAO, FIJ, FIN, FRM, FUL, GLA, GLG, LUG, KAT, ELL, GRN, GUJ, HAT, HAU, HEB, HER, HMO, HUN, ISL, IDO, IBO, IND, INA, ILE, IKU, IPK, GLE, JAV, KAL, KAN, KAU, KAS, KAZ, KIK, KIN, KIR, KOM, KON, KUA, KUR, LAO, LAT, LAV, LIM, LIN, LIT, LUB, LTZ, MKD, MLG, MSA, MAL, MLT, GLV, MRI, MAR, MAH, MON, NAU, NAV, NDE, NBL, NDO, NEP, SME, NOR, NOB, NNO, OCI, OJI, ORI, ORM, OSS, PLI, FAS, POL, PUS, QUE, QAA, RON, ROH, RUN, SMO, SAG, SAN, SRD, SRB, SNA, III, SND, SIN, SLK, SLV, SOM, SOT, SUN, SWA, SSW, SWE, TGL, TAH, TGK, TAM, TAT, TEL, THA, BOD, TIR, TON, TSO, TSN, TUR, TUK, TWI, UIG, UKR, UZB, VEN, VOL, WLN, CYM, FRY, WOL, XHO, YID, YOR, ZHA, ZUL, ORJ, QPC, TNG, SRP
rendition_name: "__string",
},
}
If your input captions are SCC, TTML, STL, SMI, SRT, or IMSC in an xml file, specify the URI of the input captions source file. If your input captions are IMSC in an IMF package, use TrackSourceSettings instead of FileSoureSettings.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#ancillary_source_settings ⇒ Types::AncillarySourceSettings
Settings for ancillary captions source.
-
#dvb_sub_source_settings ⇒ Types::DvbSubSourceSettings
DVB Sub Source Settings.
-
#embedded_source_settings ⇒ Types::EmbeddedSourceSettings
Settings for embedded captions Source.
-
#file_source_settings ⇒ Types::FileSourceSettings
If your input captions are SCC, SMI, SRT, STL, TTML, WebVTT, or IMSC 1.1 in an xml file, specify the URI of the input caption source file.
-
#source_type ⇒ String
Use Source (SourceType) to identify the format of your input captions.
-
#teletext_source_settings ⇒ Types::TeletextSourceSettings
Settings specific to Teletext caption sources, including Page number.
-
#track_source_settings ⇒ Types::TrackSourceSettings
Settings specific to caption sources that are specified by track number.
-
#webvtt_hls_source_settings ⇒ Types::WebvttHlsSourceSettings
Settings specific to WebVTT sources in HLS alternative rendition group.
Instance Attribute Details
#ancillary_source_settings ⇒ Types::AncillarySourceSettings
Settings for ancillary captions source.
2589 2590 2591 2592 2593 2594 2595 2596 2597 2598 2599 2600 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 2589 class CaptionSourceSettings < Struct.new( :ancillary_source_settings, :dvb_sub_source_settings, :embedded_source_settings, :file_source_settings, :source_type, :teletext_source_settings, :track_source_settings, :webvtt_hls_source_settings) SENSITIVE = [] include Aws::Structure end |
#dvb_sub_source_settings ⇒ Types::DvbSubSourceSettings
DVB Sub Source Settings
2589 2590 2591 2592 2593 2594 2595 2596 2597 2598 2599 2600 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 2589 class CaptionSourceSettings < Struct.new( :ancillary_source_settings, :dvb_sub_source_settings, :embedded_source_settings, :file_source_settings, :source_type, :teletext_source_settings, :track_source_settings, :webvtt_hls_source_settings) SENSITIVE = [] include Aws::Structure end |
#embedded_source_settings ⇒ Types::EmbeddedSourceSettings
Settings for embedded captions Source
2589 2590 2591 2592 2593 2594 2595 2596 2597 2598 2599 2600 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 2589 class CaptionSourceSettings < Struct.new( :ancillary_source_settings, :dvb_sub_source_settings, :embedded_source_settings, :file_source_settings, :source_type, :teletext_source_settings, :track_source_settings, :webvtt_hls_source_settings) SENSITIVE = [] include Aws::Structure end |
#file_source_settings ⇒ Types::FileSourceSettings
If your input captions are SCC, SMI, SRT, STL, TTML, WebVTT, or IMSC 1.1 in an xml file, specify the URI of the input caption source file. If your caption source is IMSC in an IMF package, use TrackSourceSettings instead of FileSoureSettings.
2589 2590 2591 2592 2593 2594 2595 2596 2597 2598 2599 2600 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 2589 class CaptionSourceSettings < Struct.new( :ancillary_source_settings, :dvb_sub_source_settings, :embedded_source_settings, :file_source_settings, :source_type, :teletext_source_settings, :track_source_settings, :webvtt_hls_source_settings) SENSITIVE = [] include Aws::Structure end |
#source_type ⇒ String
Use Source (SourceType) to identify the format of your input captions. The service cannot auto-detect caption format.
2589 2590 2591 2592 2593 2594 2595 2596 2597 2598 2599 2600 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 2589 class CaptionSourceSettings < Struct.new( :ancillary_source_settings, :dvb_sub_source_settings, :embedded_source_settings, :file_source_settings, :source_type, :teletext_source_settings, :track_source_settings, :webvtt_hls_source_settings) SENSITIVE = [] include Aws::Structure end |
#teletext_source_settings ⇒ Types::TeletextSourceSettings
Settings specific to Teletext caption sources, including Page number.
2589 2590 2591 2592 2593 2594 2595 2596 2597 2598 2599 2600 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 2589 class CaptionSourceSettings < Struct.new( :ancillary_source_settings, :dvb_sub_source_settings, :embedded_source_settings, :file_source_settings, :source_type, :teletext_source_settings, :track_source_settings, :webvtt_hls_source_settings) SENSITIVE = [] include Aws::Structure end |
#track_source_settings ⇒ Types::TrackSourceSettings
Settings specific to caption sources that are specified by track number. Currently, this is only IMSC captions in an IMF package. If your caption source is IMSC 1.1 in a separate xml file, use FileSourceSettings instead of TrackSourceSettings.
2589 2590 2591 2592 2593 2594 2595 2596 2597 2598 2599 2600 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 2589 class CaptionSourceSettings < Struct.new( :ancillary_source_settings, :dvb_sub_source_settings, :embedded_source_settings, :file_source_settings, :source_type, :teletext_source_settings, :track_source_settings, :webvtt_hls_source_settings) SENSITIVE = [] include Aws::Structure end |
#webvtt_hls_source_settings ⇒ Types::WebvttHlsSourceSettings
Settings specific to WebVTT sources in HLS alternative rendition group. Specify the properties (renditionGroupId, renditionName or renditionLanguageCode) to identify the unique subtitle track among the alternative rendition groups present in the HLS manifest. If no unique track is found, or multiple tracks match the specified properties, the job fails. If there is only one subtitle track in the rendition group, the settings can be left empty and the default subtitle track will be chosen. If your caption source is a sidecar file, use FileSourceSettings instead of WebvttHlsSourceSettings.
2589 2590 2591 2592 2593 2594 2595 2596 2597 2598 2599 2600 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 2589 class CaptionSourceSettings < Struct.new( :ancillary_source_settings, :dvb_sub_source_settings, :embedded_source_settings, :file_source_settings, :source_type, :teletext_source_settings, :track_source_settings, :webvtt_hls_source_settings) SENSITIVE = [] include Aws::Structure end |