Class: Aws::MediaConvert::Types::CmafImageBasedTrickPlaySettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::CmafImageBasedTrickPlaySettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
Tile and thumbnail settings applicable when imageBasedTrickPlay is ADVANCED
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#interval_cadence ⇒ String
The cadence MediaConvert follows for generating thumbnails.
-
#thumbnail_height ⇒ Integer
Height of each thumbnail within each tile image, in pixels.
-
#thumbnail_interval ⇒ Float
Enter the interval, in seconds, that MediaConvert uses to generate thumbnails.
-
#thumbnail_width ⇒ Integer
Width of each thumbnail within each tile image, in pixels.
-
#tile_height ⇒ Integer
Number of thumbnails in each column of a tile image.
-
#tile_width ⇒ Integer
Number of thumbnails in each row of a tile image.
Instance Attribute Details
#interval_cadence ⇒ String
The cadence MediaConvert follows for generating thumbnails. If set to FOLLOW_IFRAME, MediaConvert generates thumbnails for each IDR frame in the output (matching the GOP cadence). If set to FOLLOW_CUSTOM, MediaConvert generates thumbnails according to the interval you specify in thumbnailInterval. If set to FOLLOW_SEGMENTATION, MediaConvert generates thumbnail playlist entries that align exactly with video segment boundaries. FOLLOW_SEGMENTATION requires 1x1 tiling.
2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 2889 class CmafImageBasedTrickPlaySettings < Struct.new( :interval_cadence, :thumbnail_height, :thumbnail_interval, :thumbnail_width, :tile_height, :tile_width) SENSITIVE = [] include Aws::Structure end |
#thumbnail_height ⇒ Integer
Height of each thumbnail within each tile image, in pixels. Leave blank to maintain aspect ratio with thumbnail width. If following the aspect ratio would lead to a total tile height greater than 4096, then the job will be rejected. Must be divisible by 2.
2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 2889 class CmafImageBasedTrickPlaySettings < Struct.new( :interval_cadence, :thumbnail_height, :thumbnail_interval, :thumbnail_width, :tile_height, :tile_width) SENSITIVE = [] include Aws::Structure end |
#thumbnail_interval ⇒ Float
Enter the interval, in seconds, that MediaConvert uses to generate thumbnails. If the interval you enter doesn’t align with the output frame rate, MediaConvert automatically rounds the interval to align with the output frame rate. For example, if the output frame rate is 29.97 frames per second and you enter 5, MediaConvert uses a 150 frame interval to generate thumbnails.
2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 2889 class CmafImageBasedTrickPlaySettings < Struct.new( :interval_cadence, :thumbnail_height, :thumbnail_interval, :thumbnail_width, :tile_height, :tile_width) SENSITIVE = [] include Aws::Structure end |
#thumbnail_width ⇒ Integer
Width of each thumbnail within each tile image, in pixels. Default is 312. Must be divisible by 8.
2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 2889 class CmafImageBasedTrickPlaySettings < Struct.new( :interval_cadence, :thumbnail_height, :thumbnail_interval, :thumbnail_width, :tile_height, :tile_width) SENSITIVE = [] include Aws::Structure end |
#tile_height ⇒ Integer
Number of thumbnails in each column of a tile image. Set a value between 2 and 2048. Must be divisible by 2.
2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 2889 class CmafImageBasedTrickPlaySettings < Struct.new( :interval_cadence, :thumbnail_height, :thumbnail_interval, :thumbnail_width, :tile_height, :tile_width) SENSITIVE = [] include Aws::Structure end |
#tile_width ⇒ Integer
Number of thumbnails in each row of a tile image. Set a value between 1 and 512.
2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 2889 class CmafImageBasedTrickPlaySettings < Struct.new( :interval_cadence, :thumbnail_height, :thumbnail_interval, :thumbnail_width, :tile_height, :tile_width) SENSITIVE = [] include Aws::Structure end |