Class: Aws::MediaConvert::Types::CmfcSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::CmfcSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
When making an API call, you may pass CmfcSettings data as a hash:
{
audio_duration: "DEFAULT_CODEC_DURATION", # accepts DEFAULT_CODEC_DURATION, MATCH_VIDEO_DURATION
audio_group_id: "__string",
audio_rendition_sets: "__string",
audio_track_type: "ALTERNATE_AUDIO_AUTO_SELECT_DEFAULT", # accepts ALTERNATE_AUDIO_AUTO_SELECT_DEFAULT, ALTERNATE_AUDIO_AUTO_SELECT, ALTERNATE_AUDIO_NOT_AUTO_SELECT
descriptive_video_service_flag: "DONT_FLAG", # accepts DONT_FLAG, FLAG
i_frame_only_manifest: "INCLUDE", # accepts INCLUDE, EXCLUDE
klv_metadata: "PASSTHROUGH", # accepts PASSTHROUGH, NONE
scte_35_esam: "INSERT", # accepts INSERT, NONE
scte_35_source: "PASSTHROUGH", # accepts PASSTHROUGH, NONE
timed_metadata: "PASSTHROUGH", # accepts PASSTHROUGH, NONE
}
These settings relate to the fragmented MP4 container for the segments in your CMAF outputs.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#audio_duration ⇒ String
Specify this setting only when your output will be consumed by a downstream repackaging workflow that is sensitive to very small duration differences between video and audio.
-
#audio_group_id ⇒ String
Specify the audio rendition group for this audio rendition.
-
#audio_rendition_sets ⇒ String
List the audio rendition groups that you want included with this video rendition.
-
#audio_track_type ⇒ String
Use this setting to control the values that MediaConvert puts in your HLS parent playlist to control how the client player selects which audio track to play.
-
#descriptive_video_service_flag ⇒ String
Specify whether to flag this audio track as descriptive video service (DVS) in your HLS parent manifest.
-
#i_frame_only_manifest ⇒ String
Choose Include (INCLUDE) to have MediaConvert generate an HLS child manifest that lists only the I-frames for this rendition, in addition to your regular manifest for this rendition.
-
#klv_metadata ⇒ String
To include key-length-value metadata in this output: Set KLV metadata insertion to Passthrough.
-
#scte_35_esam ⇒ String
Use this setting only when you specify SCTE-35 markers from ESAM.
-
#scte_35_source ⇒ String
Ignore this setting unless you have SCTE-35 markers in your input video file.
-
#timed_metadata ⇒ String
To include ID3 metadata in this output: Set ID3 metadata (timedMetadata) to Passthrough (PASSTHROUGH).
Instance Attribute Details
#audio_duration ⇒ String
Specify this setting only when your output will be consumed by a downstream repackaging workflow that is sensitive to very small duration differences between video and audio. For this situation, choose Match video duration (MATCH_VIDEO_DURATION). In all other cases, keep the default value, Default codec duration (DEFAULT_CODEC_DURATION). When you choose Match video duration, MediaConvert pads the output audio streams with silence or trims them to ensure that the total duration of each audio stream is at least as long as the total duration of the video stream. After padding or trimming, the audio stream duration is no more than one frame longer than the video stream. MediaConvert applies audio padding or trimming only to the end of the last segment of the output. For unsegmented outputs, MediaConvert adds padding only to the end of the file. When you keep the default value, any minor discrepancies between audio and video duration will depend on your output audio codec.
3529 3530 3531 3532 3533 3534 3535 3536 3537 3538 3539 3540 3541 3542 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 3529 class CmfcSettings < Struct.new( :audio_duration, :audio_group_id, :audio_rendition_sets, :audio_track_type, :descriptive_video_service_flag, :i_frame_only_manifest, :klv_metadata, :scte_35_esam, :scte_35_source, :timed_metadata) SENSITIVE = [] include Aws::Structure end |
#audio_group_id ⇒ String
Specify the audio rendition group for this audio rendition. Specify up to one value for each audio output in your output group. This value appears in your HLS parent manifest in the EXT-X-MEDIA tag of TYPE=AUDIO, as the value for the GROUP-ID attribute. For example, if you specify “audio_aac_1” for Audio group ID, it appears in your manifest like this: #EXT-X-MEDIA:TYPE=AUDIO,GROUP-ID=“audio_aac_1”. Related setting: To associate the rendition group that this audio track belongs to with a video rendition, include the same value that you provide here for that video output's setting Audio rendition sets (audioRenditionSets).
3529 3530 3531 3532 3533 3534 3535 3536 3537 3538 3539 3540 3541 3542 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 3529 class CmfcSettings < Struct.new( :audio_duration, :audio_group_id, :audio_rendition_sets, :audio_track_type, :descriptive_video_service_flag, :i_frame_only_manifest, :klv_metadata, :scte_35_esam, :scte_35_source, :timed_metadata) SENSITIVE = [] include Aws::Structure end |
#audio_rendition_sets ⇒ String
List the audio rendition groups that you want included with this video rendition. Use a comma-separated list. For example, say you want to include the audio rendition groups that have the audio group IDs “audio_aac_1” and “audio_dolby”. Then you would specify this value: “audio_aac_1,audio_dolby”. Related setting: The rendition groups that you include in your comma-separated list should all match values that you specify in the setting Audio group ID (AudioGroupId) for audio renditions in the same output group as this video rendition. Default behavior: If you don't specify anything here and for Audio group ID, MediaConvert puts each audio variant in its own audio rendition group and associates it with every video variant. Each value in your list appears in your HLS parent manifest in the EXT-X-STREAM-INF tag as the value for the AUDIO attribute. To continue the previous example, say that the file name for the child manifest for your video rendition is “amazing_video_1.m3u8”. Then, in your parent manifest, each value will appear on separate lines, like this: #EXT-X-STREAM-INF:AUDIO=“audio_aac_1”… amazing_video_1.m3u8 #EXT-X-STREAM-INF:AUDIO=“audio_dolby”… amazing_video_1.m3u8
3529 3530 3531 3532 3533 3534 3535 3536 3537 3538 3539 3540 3541 3542 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 3529 class CmfcSettings < Struct.new( :audio_duration, :audio_group_id, :audio_rendition_sets, :audio_track_type, :descriptive_video_service_flag, :i_frame_only_manifest, :klv_metadata, :scte_35_esam, :scte_35_source, :timed_metadata) SENSITIVE = [] include Aws::Structure end |
#audio_track_type ⇒ String
Use this setting to control the values that MediaConvert puts in your HLS parent playlist to control how the client player selects which audio track to play. The other options for this setting determine the values that MediaConvert writes for the DEFAULT and AUTOSELECT attributes of the EXT-X-MEDIA entry for the audio variant. For more information about these attributes, see the Apple documentation article developer.apple.com/documentation/http_live_streaming/example_playlists_for_http_live_streaming/adding_alternate_media_to_a_playlist. Choose Alternate audio, auto select, default (ALTERNATE_AUDIO_AUTO_SELECT_DEFAULT) to set DEFAULT=YES and AUTOSELECT=YES. Choose this value for only one variant in your output group. Choose Alternate audio, auto select, not default (ALTERNATE_AUDIO_AUTO_SELECT) to set DEFAULT=NO and AUTOSELECT=YES. Choose Alternate Audio, Not Auto Select to set DEFAULT=NO and AUTOSELECT=NO. When you don't specify a value for this setting, MediaConvert defaults to Alternate audio, auto select, default. When there is more than one variant in your output group, you must explicitly choose a value for this setting.
3529 3530 3531 3532 3533 3534 3535 3536 3537 3538 3539 3540 3541 3542 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 3529 class CmfcSettings < Struct.new( :audio_duration, :audio_group_id, :audio_rendition_sets, :audio_track_type, :descriptive_video_service_flag, :i_frame_only_manifest, :klv_metadata, :scte_35_esam, :scte_35_source, :timed_metadata) SENSITIVE = [] include Aws::Structure end |
#descriptive_video_service_flag ⇒ String
Specify whether to flag this audio track as descriptive video service (DVS) in your HLS parent manifest. When you choose Flag (FLAG), MediaConvert includes the parameter CHARACTERISTICS=“public.accessibility.describes-video” in the EXT-X-MEDIA entry for this track. When you keep the default choice, Don't flag (DONT_FLAG), MediaConvert leaves this parameter out. The DVS flag can help with accessibility on Apple devices. For more information, see the Apple documentation.
3529 3530 3531 3532 3533 3534 3535 3536 3537 3538 3539 3540 3541 3542 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 3529 class CmfcSettings < Struct.new( :audio_duration, :audio_group_id, :audio_rendition_sets, :audio_track_type, :descriptive_video_service_flag, :i_frame_only_manifest, :klv_metadata, :scte_35_esam, :scte_35_source, :timed_metadata) SENSITIVE = [] include Aws::Structure end |
#i_frame_only_manifest ⇒ String
Choose Include (INCLUDE) to have MediaConvert generate an HLS child manifest that lists only the I-frames for this rendition, in addition to your regular manifest for this rendition. You might use this manifest as part of a workflow that creates preview functions for your video. MediaConvert adds both the I-frame only child manifest and the regular child manifest to the parent manifest. When you don't need the I-frame only child manifest, keep the default value Exclude (EXCLUDE).
3529 3530 3531 3532 3533 3534 3535 3536 3537 3538 3539 3540 3541 3542 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 3529 class CmfcSettings < Struct.new( :audio_duration, :audio_group_id, :audio_rendition_sets, :audio_track_type, :descriptive_video_service_flag, :i_frame_only_manifest, :klv_metadata, :scte_35_esam, :scte_35_source, :timed_metadata) SENSITIVE = [] include Aws::Structure end |
#klv_metadata ⇒ String
To include key-length-value metadata in this output: Set KLV metadata insertion to Passthrough. MediaConvert reads KLV metadata present in your input and writes each instance to a separate event message box in the output, according to MISB ST1910.1. To exclude this KLV metadata: Set KLV metadata insertion to None or leave blank.
3529 3530 3531 3532 3533 3534 3535 3536 3537 3538 3539 3540 3541 3542 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 3529 class CmfcSettings < Struct.new( :audio_duration, :audio_group_id, :audio_rendition_sets, :audio_track_type, :descriptive_video_service_flag, :i_frame_only_manifest, :klv_metadata, :scte_35_esam, :scte_35_source, :timed_metadata) SENSITIVE = [] include Aws::Structure end |
#scte_35_esam ⇒ String
Use this setting only when you specify SCTE-35 markers from ESAM. Choose INSERT to put SCTE-35 markers in this output at the insertion points that you specify in an ESAM XML document. Provide the document in the setting SCC XML (sccXml).
3529 3530 3531 3532 3533 3534 3535 3536 3537 3538 3539 3540 3541 3542 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 3529 class CmfcSettings < Struct.new( :audio_duration, :audio_group_id, :audio_rendition_sets, :audio_track_type, :descriptive_video_service_flag, :i_frame_only_manifest, :klv_metadata, :scte_35_esam, :scte_35_source, :timed_metadata) SENSITIVE = [] include Aws::Structure end |
#scte_35_source ⇒ String
Ignore this setting unless you have SCTE-35 markers in your input video file. Choose Passthrough (PASSTHROUGH) if you want SCTE-35 markers that appear in your input to also appear in this output. Choose None (NONE) if you don't want those SCTE-35 markers in this output.
3529 3530 3531 3532 3533 3534 3535 3536 3537 3538 3539 3540 3541 3542 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 3529 class CmfcSettings < Struct.new( :audio_duration, :audio_group_id, :audio_rendition_sets, :audio_track_type, :descriptive_video_service_flag, :i_frame_only_manifest, :klv_metadata, :scte_35_esam, :scte_35_source, :timed_metadata) SENSITIVE = [] include Aws::Structure end |
#timed_metadata ⇒ String
To include ID3 metadata in this output: Set ID3 metadata (timedMetadata) to Passthrough (PASSTHROUGH). Specify this ID3 metadata in Custom ID3 metadata inserter (timedMetadataInsertion). MediaConvert writes each instance of ID3 metadata in a separate Event Message (eMSG) box. To exclude this ID3 metadata: Set ID3 metadata to None (NONE) or leave blank.
3529 3530 3531 3532 3533 3534 3535 3536 3537 3538 3539 3540 3541 3542 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 3529 class CmfcSettings < Struct.new( :audio_duration, :audio_group_id, :audio_rendition_sets, :audio_track_type, :descriptive_video_service_flag, :i_frame_only_manifest, :klv_metadata, :scte_35_esam, :scte_35_source, :timed_metadata) SENSITIVE = [] include Aws::Structure end |