Class: Aws::MediaConvert::Types::ContainerSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::ContainerSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
When making an API call, you may pass ContainerSettings data as a hash:
{
cmfc_settings: {
audio_duration: "DEFAULT_CODEC_DURATION", # accepts DEFAULT_CODEC_DURATION, MATCH_VIDEO_DURATION
audio_group_id: "__string",
audio_rendition_sets: "__string",
audio_track_type: "ALTERNATE_AUDIO_AUTO_SELECT_DEFAULT", # accepts ALTERNATE_AUDIO_AUTO_SELECT_DEFAULT, ALTERNATE_AUDIO_AUTO_SELECT, ALTERNATE_AUDIO_NOT_AUTO_SELECT
descriptive_video_service_flag: "DONT_FLAG", # accepts DONT_FLAG, FLAG
i_frame_only_manifest: "INCLUDE", # accepts INCLUDE, EXCLUDE
klv_metadata: "PASSTHROUGH", # accepts PASSTHROUGH, NONE
scte_35_esam: "INSERT", # accepts INSERT, NONE
scte_35_source: "PASSTHROUGH", # accepts PASSTHROUGH, NONE
timed_metadata: "PASSTHROUGH", # accepts PASSTHROUGH, NONE
},
container: "F4V", # accepts F4V, ISMV, M2TS, M3U8, CMFC, MOV, MP4, MPD, MXF, WEBM, RAW
f4v_settings: {
moov_placement: "PROGRESSIVE_DOWNLOAD", # accepts PROGRESSIVE_DOWNLOAD, NORMAL
},
m2ts_settings: {
audio_buffer_model: "DVB", # accepts DVB, ATSC
audio_duration: "DEFAULT_CODEC_DURATION", # accepts DEFAULT_CODEC_DURATION, MATCH_VIDEO_DURATION
audio_frames_per_pes: 1,
audio_pids: [1],
bitrate: 1,
buffer_model: "MULTIPLEX", # accepts MULTIPLEX, NONE
data_pts_control: "AUTO", # accepts AUTO, ALIGN_TO_VIDEO
dvb_nit_settings: {
network_id: 1,
network_name: "__stringMin1Max256",
nit_interval: 1,
},
dvb_sdt_settings: {
output_sdt: "SDT_FOLLOW", # accepts SDT_FOLLOW, SDT_FOLLOW_IF_PRESENT, SDT_MANUAL, SDT_NONE
sdt_interval: 1,
service_name: "__stringMin1Max256",
service_provider_name: "__stringMin1Max256",
},
dvb_sub_pids: [1],
dvb_tdt_settings: {
tdt_interval: 1,
},
dvb_teletext_pid: 1,
ebp_audio_interval: "VIDEO_AND_FIXED_INTERVALS", # accepts VIDEO_AND_FIXED_INTERVALS, VIDEO_INTERVAL
ebp_placement: "VIDEO_AND_AUDIO_PIDS", # accepts VIDEO_AND_AUDIO_PIDS, VIDEO_PID
es_rate_in_pes: "INCLUDE", # accepts INCLUDE, EXCLUDE
force_ts_video_ebp_order: "FORCE", # accepts FORCE, DEFAULT
fragment_time: 1.0,
klv_metadata: "PASSTHROUGH", # accepts PASSTHROUGH, NONE
max_pcr_interval: 1,
min_ebp_interval: 1,
nielsen_id_3: "INSERT", # accepts INSERT, NONE
null_packet_bitrate: 1.0,
pat_interval: 1,
pcr_control: "PCR_EVERY_PES_PACKET", # accepts PCR_EVERY_PES_PACKET, CONFIGURED_PCR_PERIOD
pcr_pid: 1,
pmt_interval: 1,
pmt_pid: 1,
private_metadata_pid: 1,
program_number: 1,
rate_mode: "VBR", # accepts VBR, CBR
scte_35_esam: {
scte_35_esam_pid: 1,
},
scte_35_pid: 1,
scte_35_source: "PASSTHROUGH", # accepts PASSTHROUGH, NONE
segmentation_markers: "NONE", # accepts NONE, RAI_SEGSTART, RAI_ADAPT, PSI_SEGSTART, EBP, EBP_LEGACY
segmentation_style: "MAINTAIN_CADENCE", # accepts MAINTAIN_CADENCE, RESET_CADENCE
segmentation_time: 1.0,
timed_metadata_pid: 1,
transport_stream_id: 1,
video_pid: 1,
},
m3u_8_settings: {
audio_duration: "DEFAULT_CODEC_DURATION", # accepts DEFAULT_CODEC_DURATION, MATCH_VIDEO_DURATION
audio_frames_per_pes: 1,
audio_pids: [1],
data_pts_control: "AUTO", # accepts AUTO, ALIGN_TO_VIDEO
max_pcr_interval: 1,
nielsen_id_3: "INSERT", # accepts INSERT, NONE
pat_interval: 1,
pcr_control: "PCR_EVERY_PES_PACKET", # accepts PCR_EVERY_PES_PACKET, CONFIGURED_PCR_PERIOD
pcr_pid: 1,
pmt_interval: 1,
pmt_pid: 1,
private_metadata_pid: 1,
program_number: 1,
scte_35_pid: 1,
scte_35_source: "PASSTHROUGH", # accepts PASSTHROUGH, NONE
timed_metadata: "PASSTHROUGH", # accepts PASSTHROUGH, NONE
timed_metadata_pid: 1,
transport_stream_id: 1,
video_pid: 1,
},
mov_settings: {
clap_atom: "INCLUDE", # accepts INCLUDE, EXCLUDE
cslg_atom: "INCLUDE", # accepts INCLUDE, EXCLUDE
mpeg_2_four_cc_control: "XDCAM", # accepts XDCAM, MPEG
padding_control: "OMNEON", # accepts OMNEON, NONE
reference: "SELF_CONTAINED", # accepts SELF_CONTAINED, EXTERNAL
},
mp_4_settings: {
audio_duration: "DEFAULT_CODEC_DURATION", # accepts DEFAULT_CODEC_DURATION, MATCH_VIDEO_DURATION
cslg_atom: "INCLUDE", # accepts INCLUDE, EXCLUDE
ctts_version: 1,
free_space_box: "INCLUDE", # accepts INCLUDE, EXCLUDE
moov_placement: "PROGRESSIVE_DOWNLOAD", # accepts PROGRESSIVE_DOWNLOAD, NORMAL
mp_4_major_brand: "__string",
},
mpd_settings: {
accessibility_caption_hints: "INCLUDE", # accepts INCLUDE, EXCLUDE
audio_duration: "DEFAULT_CODEC_DURATION", # accepts DEFAULT_CODEC_DURATION, MATCH_VIDEO_DURATION
caption_container_type: "RAW", # accepts RAW, FRAGMENTED_MP4
klv_metadata: "NONE", # accepts NONE, PASSTHROUGH
scte_35_esam: "INSERT", # accepts INSERT, NONE
scte_35_source: "PASSTHROUGH", # accepts PASSTHROUGH, NONE
timed_metadata: "PASSTHROUGH", # accepts PASSTHROUGH, NONE
},
mxf_settings: {
afd_signaling: "NO_COPY", # accepts NO_COPY, COPY_FROM_VIDEO
profile: "D_10", # accepts D_10, XDCAM, OP1A, XAVC
xavc_profile_settings: {
duration_mode: "ALLOW_ANY_DURATION", # accepts ALLOW_ANY_DURATION, DROP_FRAMES_FOR_COMPLIANCE
max_anc_data_size: 1,
},
},
}
Container specific settings.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cmfc_settings ⇒ Types::CmfcSettings
These settings relate to the fragmented MP4 container for the segments in your CMAF outputs.
-
#container ⇒ String
Container for this output.
-
#f4v_settings ⇒ Types::F4vSettings
Settings for F4v container.
-
#m2ts_settings ⇒ Types::M2tsSettings
MPEG-2 TS container settings.
-
#m3u_8_settings ⇒ Types::M3u8Settings
These settings relate to the MPEG-2 transport stream (MPEG2-TS) container for the MPEG2-TS segments in your HLS outputs.
-
#mov_settings ⇒ Types::MovSettings
These settings relate to your QuickTime MOV output container.
-
#mp_4_settings ⇒ Types::Mp4Settings
These settings relate to your MP4 output container.
-
#mpd_settings ⇒ Types::MpdSettings
These settings relate to the fragmented MP4 container for the segments in your DASH outputs.
-
#mxf_settings ⇒ Types::MxfSettings
These settings relate to your MXF output container.
Instance Attribute Details
#cmfc_settings ⇒ Types::CmfcSettings
These settings relate to the fragmented MP4 container for the segments in your CMAF outputs.
3859 3860 3861 3862 3863 3864 3865 3866 3867 3868 3869 3870 3871 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 3859 class ContainerSettings < Struct.new( :cmfc_settings, :container, :f4v_settings, :m2ts_settings, :m3u_8_settings, :mov_settings, :mp_4_settings, :mpd_settings, :mxf_settings) SENSITIVE = [] include Aws::Structure end |
#container ⇒ String
Container for this output. Some containers require a container settings object. If not specified, the default object will be created.
3859 3860 3861 3862 3863 3864 3865 3866 3867 3868 3869 3870 3871 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 3859 class ContainerSettings < Struct.new( :cmfc_settings, :container, :f4v_settings, :m2ts_settings, :m3u_8_settings, :mov_settings, :mp_4_settings, :mpd_settings, :mxf_settings) SENSITIVE = [] include Aws::Structure end |
#f4v_settings ⇒ Types::F4vSettings
Settings for F4v container
3859 3860 3861 3862 3863 3864 3865 3866 3867 3868 3869 3870 3871 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 3859 class ContainerSettings < Struct.new( :cmfc_settings, :container, :f4v_settings, :m2ts_settings, :m3u_8_settings, :mov_settings, :mp_4_settings, :mpd_settings, :mxf_settings) SENSITIVE = [] include Aws::Structure end |
#m2ts_settings ⇒ Types::M2tsSettings
MPEG-2 TS container settings. These apply to outputs in a File output group when the output's container (ContainerType) is MPEG-2 Transport Stream (M2TS). In these assets, data is organized by the program map table (PMT). Each transport stream program contains subsets of data, including audio, video, and metadata. Each of these subsets of data has a numerical label called a packet identifier (PID). Each transport stream program corresponds to one MediaConvert output. The PMT lists the types of data in a program along with their PID. Downstream systems and players use the program map table to look up the PID for each type of data it accesses and then uses the PIDs to locate specific data within the asset.
3859 3860 3861 3862 3863 3864 3865 3866 3867 3868 3869 3870 3871 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 3859 class ContainerSettings < Struct.new( :cmfc_settings, :container, :f4v_settings, :m2ts_settings, :m3u_8_settings, :mov_settings, :mp_4_settings, :mpd_settings, :mxf_settings) SENSITIVE = [] include Aws::Structure end |
#m3u_8_settings ⇒ Types::M3u8Settings
These settings relate to the MPEG-2 transport stream (MPEG2-TS) container for the MPEG2-TS segments in your HLS outputs.
3859 3860 3861 3862 3863 3864 3865 3866 3867 3868 3869 3870 3871 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 3859 class ContainerSettings < Struct.new( :cmfc_settings, :container, :f4v_settings, :m2ts_settings, :m3u_8_settings, :mov_settings, :mp_4_settings, :mpd_settings, :mxf_settings) SENSITIVE = [] include Aws::Structure end |
#mov_settings ⇒ Types::MovSettings
These settings relate to your QuickTime MOV output container.
3859 3860 3861 3862 3863 3864 3865 3866 3867 3868 3869 3870 3871 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 3859 class ContainerSettings < Struct.new( :cmfc_settings, :container, :f4v_settings, :m2ts_settings, :m3u_8_settings, :mov_settings, :mp_4_settings, :mpd_settings, :mxf_settings) SENSITIVE = [] include Aws::Structure end |
#mp_4_settings ⇒ Types::Mp4Settings
These settings relate to your MP4 output container. You can create audio only outputs with this container. For more information, see docs.aws.amazon.com/mediaconvert/latest/ug/supported-codecs-containers-audio-only.html#output-codecs-and-containers-supported-for-audio-only.
3859 3860 3861 3862 3863 3864 3865 3866 3867 3868 3869 3870 3871 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 3859 class ContainerSettings < Struct.new( :cmfc_settings, :container, :f4v_settings, :m2ts_settings, :m3u_8_settings, :mov_settings, :mp_4_settings, :mpd_settings, :mxf_settings) SENSITIVE = [] include Aws::Structure end |
#mpd_settings ⇒ Types::MpdSettings
These settings relate to the fragmented MP4 container for the segments in your DASH outputs.
3859 3860 3861 3862 3863 3864 3865 3866 3867 3868 3869 3870 3871 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 3859 class ContainerSettings < Struct.new( :cmfc_settings, :container, :f4v_settings, :m2ts_settings, :m3u_8_settings, :mov_settings, :mp_4_settings, :mpd_settings, :mxf_settings) SENSITIVE = [] include Aws::Structure end |
#mxf_settings ⇒ Types::MxfSettings
These settings relate to your MXF output container.
3859 3860 3861 3862 3863 3864 3865 3866 3867 3868 3869 3870 3871 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 3859 class ContainerSettings < Struct.new( :cmfc_settings, :container, :f4v_settings, :m2ts_settings, :m3u_8_settings, :mov_settings, :mp_4_settings, :mpd_settings, :mxf_settings) SENSITIVE = [] include Aws::Structure end |