Class: Aws::MediaConvert::Types::CreateJobTemplateRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::CreateJobTemplateRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
Send your create job template request with the name of the template and the JSON for the template. The template JSON should include everything in a valid job, except for input location and filename, IAM role, and user metadata.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#acceleration_settings ⇒ Types::AccelerationSettings
Accelerated transcoding can significantly speed up jobs with long, visually complex content.
-
#category ⇒ String
Optional.
-
#description ⇒ String
Optional.
-
#hop_destinations ⇒ Array<Types::HopDestination>
Optional.
-
#name ⇒ String
The name of the job template you are creating.
-
#priority ⇒ Integer
Specify the relative priority for this job.
-
#queue ⇒ String
Optional.
-
#settings ⇒ Types::JobTemplateSettings
JobTemplateSettings contains all the transcode settings saved in the template that will be applied to jobs created from it.
-
#status_update_interval ⇒ String
Specify how often MediaConvert sends STATUS_UPDATE events to Amazon CloudWatch Events.
-
#tags ⇒ Hash<String,String>
The tags that you want to add to the resource.
Instance Attribute Details
#acceleration_settings ⇒ Types::AccelerationSettings
Accelerated transcoding can significantly speed up jobs with long, visually complex content. Outputs that use this feature incur pro-tier pricing. For information about feature limitations, see the AWS Elemental MediaConvert User Guide.
3070 3071 3072 3073 3074 3075 3076 3077 3078 3079 3080 3081 3082 3083 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 3070 class CreateJobTemplateRequest < Struct.new( :acceleration_settings, :category, :description, :hop_destinations, :name, :priority, :queue, :settings, :status_update_interval, :tags) SENSITIVE = [] include Aws::Structure end |
#category ⇒ String
Optional. A category for the job template you are creating
3070 3071 3072 3073 3074 3075 3076 3077 3078 3079 3080 3081 3082 3083 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 3070 class CreateJobTemplateRequest < Struct.new( :acceleration_settings, :category, :description, :hop_destinations, :name, :priority, :queue, :settings, :status_update_interval, :tags) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
Optional. A description of the job template you are creating.
3070 3071 3072 3073 3074 3075 3076 3077 3078 3079 3080 3081 3082 3083 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 3070 class CreateJobTemplateRequest < Struct.new( :acceleration_settings, :category, :description, :hop_destinations, :name, :priority, :queue, :settings, :status_update_interval, :tags) SENSITIVE = [] include Aws::Structure end |
#hop_destinations ⇒ Array<Types::HopDestination>
Optional. Use queue hopping to avoid overly long waits in the backlog of the queue that you submit your job to. Specify an alternate queue and the maximum time that your job will wait in the initial queue before hopping. For more information about this feature, see the AWS Elemental MediaConvert User Guide.
3070 3071 3072 3073 3074 3075 3076 3077 3078 3079 3080 3081 3082 3083 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 3070 class CreateJobTemplateRequest < Struct.new( :acceleration_settings, :category, :description, :hop_destinations, :name, :priority, :queue, :settings, :status_update_interval, :tags) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the job template you are creating.
3070 3071 3072 3073 3074 3075 3076 3077 3078 3079 3080 3081 3082 3083 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 3070 class CreateJobTemplateRequest < Struct.new( :acceleration_settings, :category, :description, :hop_destinations, :name, :priority, :queue, :settings, :status_update_interval, :tags) SENSITIVE = [] include Aws::Structure end |
#priority ⇒ Integer
Specify the relative priority for this job. In any given queue, the service begins processing the job with the highest value first. When more than one job has the same priority, the service begins processing the job that you submitted first. If you don’t specify a priority, the service uses the default value 0.
3070 3071 3072 3073 3074 3075 3076 3077 3078 3079 3080 3081 3082 3083 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 3070 class CreateJobTemplateRequest < Struct.new( :acceleration_settings, :category, :description, :hop_destinations, :name, :priority, :queue, :settings, :status_update_interval, :tags) SENSITIVE = [] include Aws::Structure end |
#queue ⇒ String
Optional. The queue that jobs created from this template are assigned to. If you don’t specify this, jobs will go to the default queue.
3070 3071 3072 3073 3074 3075 3076 3077 3078 3079 3080 3081 3082 3083 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 3070 class CreateJobTemplateRequest < Struct.new( :acceleration_settings, :category, :description, :hop_destinations, :name, :priority, :queue, :settings, :status_update_interval, :tags) SENSITIVE = [] include Aws::Structure end |
#settings ⇒ Types::JobTemplateSettings
JobTemplateSettings contains all the transcode settings saved in the template that will be applied to jobs created from it.
3070 3071 3072 3073 3074 3075 3076 3077 3078 3079 3080 3081 3082 3083 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 3070 class CreateJobTemplateRequest < Struct.new( :acceleration_settings, :category, :description, :hop_destinations, :name, :priority, :queue, :settings, :status_update_interval, :tags) SENSITIVE = [] include Aws::Structure end |
#status_update_interval ⇒ String
Specify how often MediaConvert sends STATUS_UPDATE events to Amazon CloudWatch Events. Set the interval, in seconds, between status updates. MediaConvert sends an update at this interval from the time the service begins processing your job to the time it completes the transcode or encounters an error.
3070 3071 3072 3073 3074 3075 3076 3077 3078 3079 3080 3081 3082 3083 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 3070 class CreateJobTemplateRequest < Struct.new( :acceleration_settings, :category, :description, :hop_destinations, :name, :priority, :queue, :settings, :status_update_interval, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags that you want to add to the resource. You can tag resources with a key-value pair or with only a key.
3070 3071 3072 3073 3074 3075 3076 3077 3078 3079 3080 3081 3082 3083 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 3070 class CreateJobTemplateRequest < Struct.new( :acceleration_settings, :category, :description, :hop_destinations, :name, :priority, :queue, :settings, :status_update_interval, :tags) SENSITIVE = [] include Aws::Structure end |