Class: Aws::MediaConvert::Types::CreateQueueRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediaconvert/types.rb

Overview

Create an on-demand queue by sending a CreateQueue request with the name of the queue. Create a reserved queue by sending a CreateQueue request with the pricing plan set to RESERVED and with values specified for the settings under reservationPlanSettings. When you create a reserved queue, you enter into a 12-month commitment to purchase the RTS that you specify. You can’t cancel this commitment.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#concurrent_jobsInteger

Specify the maximum number of jobs your queue can process concurrently. For on-demand queues, the value you enter is constrained by your service quotas for Maximum concurrent jobs, per on-demand queue and Maximum concurrent jobs, per account. For reserved queues, specify the number of jobs you can process concurrently in your reservation plan instead.

Returns:

  • (Integer)


3955
3956
3957
3958
3959
3960
3961
3962
3963
3964
3965
3966
# File 'lib/aws-sdk-mediaconvert/types.rb', line 3955

class CreateQueueRequest < Struct.new(
  :concurrent_jobs,
  :description,
  :maximum_concurrent_feeds,
  :name,
  :pricing_plan,
  :reservation_plan_settings,
  :status,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

Optional. A description of the queue that you are creating.

Returns:

  • (String)


3955
3956
3957
3958
3959
3960
3961
3962
3963
3964
3965
3966
# File 'lib/aws-sdk-mediaconvert/types.rb', line 3955

class CreateQueueRequest < Struct.new(
  :concurrent_jobs,
  :description,
  :maximum_concurrent_feeds,
  :name,
  :pricing_plan,
  :reservation_plan_settings,
  :status,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#maximum_concurrent_feedsInteger

Specify the maximum number of Elemental Inference feeds MediaConvert can process concurrently.

Returns:

  • (Integer)


3955
3956
3957
3958
3959
3960
3961
3962
3963
3964
3965
3966
# File 'lib/aws-sdk-mediaconvert/types.rb', line 3955

class CreateQueueRequest < Struct.new(
  :concurrent_jobs,
  :description,
  :maximum_concurrent_feeds,
  :name,
  :pricing_plan,
  :reservation_plan_settings,
  :status,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the queue that you are creating.

Returns:

  • (String)


3955
3956
3957
3958
3959
3960
3961
3962
3963
3964
3965
3966
# File 'lib/aws-sdk-mediaconvert/types.rb', line 3955

class CreateQueueRequest < Struct.new(
  :concurrent_jobs,
  :description,
  :maximum_concurrent_feeds,
  :name,
  :pricing_plan,
  :reservation_plan_settings,
  :status,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#pricing_planString

Specifies whether the pricing plan for the queue is on-demand or reserved. For on-demand, you pay per minute, billed in increments of .01 minute. For reserved, you pay for the transcoding capacity of the entire queue, regardless of how much or how little you use it. Reserved pricing requires a 12-month commitment. When you use the API to create a queue, the default is on-demand.

Returns:

  • (String)


3955
3956
3957
3958
3959
3960
3961
3962
3963
3964
3965
3966
# File 'lib/aws-sdk-mediaconvert/types.rb', line 3955

class CreateQueueRequest < Struct.new(
  :concurrent_jobs,
  :description,
  :maximum_concurrent_feeds,
  :name,
  :pricing_plan,
  :reservation_plan_settings,
  :status,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#reservation_plan_settingsTypes::ReservationPlanSettings

Details about the pricing plan for your reserved queue. Required for reserved queues and not applicable to on-demand queues.



3955
3956
3957
3958
3959
3960
3961
3962
3963
3964
3965
3966
# File 'lib/aws-sdk-mediaconvert/types.rb', line 3955

class CreateQueueRequest < Struct.new(
  :concurrent_jobs,
  :description,
  :maximum_concurrent_feeds,
  :name,
  :pricing_plan,
  :reservation_plan_settings,
  :status,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

Initial state of the queue. If you create a paused queue, then jobs in that queue won’t begin.

Returns:

  • (String)


3955
3956
3957
3958
3959
3960
3961
3962
3963
3964
3965
3966
# File 'lib/aws-sdk-mediaconvert/types.rb', line 3955

class CreateQueueRequest < Struct.new(
  :concurrent_jobs,
  :description,
  :maximum_concurrent_feeds,
  :name,
  :pricing_plan,
  :reservation_plan_settings,
  :status,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The tags that you want to add to the resource. You can tag resources with a key-value pair or with only a key.

Returns:

  • (Hash<String,String>)


3955
3956
3957
3958
3959
3960
3961
3962
3963
3964
3965
3966
# File 'lib/aws-sdk-mediaconvert/types.rb', line 3955

class CreateQueueRequest < Struct.new(
  :concurrent_jobs,
  :description,
  :maximum_concurrent_feeds,
  :name,
  :pricing_plan,
  :reservation_plan_settings,
  :status,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end