Class: Aws::MediaConvert::Types::Deinterlacer

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediaconvert/types.rb

Overview

Settings for deinterlacer

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#algorithmString

Only applies when you set Deinterlacer (DeinterlaceMode) to Deinterlace (DEINTERLACE) or Adaptive (ADAPTIVE). Motion adaptive interpolate (INTERPOLATE) produces sharper pictures, while blend (BLEND) produces smoother motion. Use (INTERPOLATE_TICKER) OR (BLEND_TICKER) if your source file includes a ticker, such as a scrolling headline at the bottom of the frame.

Returns:

  • (String)


3425
3426
3427
3428
3429
3430
3431
# File 'lib/aws-sdk-mediaconvert/types.rb', line 3425

class Deinterlacer < Struct.new(
  :algorithm,
  :control,
  :mode)
  SENSITIVE = []
  include Aws::Structure
end

#controlString

- When set to NORMAL (default), the deinterlacer does not convert frames that are tagged in metadata as progressive. It will only convert those that are tagged as some other type. - When set to FORCE_ALL_FRAMES, the deinterlacer converts every frame to progressive - even those that are already tagged as progressive. Turn Force mode on only if there is a good chance that the metadata has tagged frames as progressive when they are not progressive. Do not turn on otherwise; processing frames that are already progressive into progressive will probably result in lower quality video.

Returns:

  • (String)


3425
3426
3427
3428
3429
3430
3431
# File 'lib/aws-sdk-mediaconvert/types.rb', line 3425

class Deinterlacer < Struct.new(
  :algorithm,
  :control,
  :mode)
  SENSITIVE = []
  include Aws::Structure
end

#modeString

Use Deinterlacer (DeinterlaceMode) to choose how the service will do deinterlacing. Default is Deinterlace. - Deinterlace converts interlaced to progressive. - Inverse telecine converts Hard Telecine 29.97i to progressive 23.976p. - Adaptive auto-detects and converts to progressive.

Returns:

  • (String)


3425
3426
3427
3428
3429
3430
3431
# File 'lib/aws-sdk-mediaconvert/types.rb', line 3425

class Deinterlacer < Struct.new(
  :algorithm,
  :control,
  :mode)
  SENSITIVE = []
  include Aws::Structure
end