Class: Aws::MediaConvert::Types::DeleteQueueRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::DeleteQueueRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
Note:
When making an API call, you may pass DeleteQueueRequest data as a hash:
{
name: "__string", # required
}
Delete a queue by sending a request with the queue name. You can't delete a queue with an active pricing plan or one that has unprocessed jobs in it.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#name ⇒ String
The name of the queue that you want to delete.
Instance Attribute Details
#name ⇒ String
The name of the queue that you want to delete.
7757 7758 7759 7760 7761 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 7757 class DeleteQueueRequest < Struct.new( :name) SENSITIVE = [] include Aws::Structure end |