Class: Aws::MediaConvert::Types::DescribeEndpointsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::DescribeEndpointsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
Send a request with an empty body to the regional API endpoint to get your account API endpoint. Note that DescribeEndpoints is no longer required. We recommend that you send your requests directly to the regional endpoint instead.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
Optional.
-
#mode ⇒ String
Optional field, defaults to DEFAULT.
-
#next_token ⇒ String
Use this string, provided with the response to a previous request, to request the next batch of endpoints.
Instance Attribute Details
#max_results ⇒ Integer
Optional. Max number of endpoints, up to twenty, that will be returned at one time.
3755 3756 3757 3758 3759 3760 3761 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 3755 class DescribeEndpointsRequest < Struct.new( :max_results, :mode, :next_token) SENSITIVE = [] include Aws::Structure end |
#mode ⇒ String
Optional field, defaults to DEFAULT. Specify DEFAULT for this operation to return your endpoints if any exist, or to create an endpoint for you and return it if one doesn’t already exist. Specify GET_ONLY to return your endpoints if any exist, or an empty list if none exist.
3755 3756 3757 3758 3759 3760 3761 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 3755 class DescribeEndpointsRequest < Struct.new( :max_results, :mode, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
Use this string, provided with the response to a previous request, to request the next batch of endpoints.
3755 3756 3757 3758 3759 3760 3761 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 3755 class DescribeEndpointsRequest < Struct.new( :max_results, :mode, :next_token) SENSITIVE = [] include Aws::Structure end |