Class: Aws::MediaConvert::Types::DescribeEndpointsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::DescribeEndpointsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
Successful describe endpoints requests will return your account API endpoint.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#endpoints ⇒ Array<Types::Endpoint>
List of endpoints.
-
#next_token ⇒ String
Use this string to request the next batch of endpoints.
Instance Attribute Details
#endpoints ⇒ Array<Types::Endpoint>
List of endpoints
4430 4431 4432 4433 4434 4435 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 4430 class DescribeEndpointsResponse < Struct.new( :endpoints, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
Use this string to request the next batch of endpoints.
4430 4431 4432 4433 4434 4435 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 4430 class DescribeEndpointsResponse < Struct.new( :endpoints, :next_token) SENSITIVE = [] include Aws::Structure end |