Class: Aws::MediaConvert::Types::DolbyVision
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::DolbyVision
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
When making an API call, you may pass DolbyVision data as a hash:
{
l6_metadata: {
max_cll: 1,
max_fall: 1,
},
l6_mode: "PASSTHROUGH", # accepts PASSTHROUGH, RECALCULATE, SPECIFY
profile: "PROFILE_5", # accepts PROFILE_5
}
With AWS Elemental MediaConvert, you can create profile 5 Dolby Vision outputs from MXF and IMF sources that contain mastering information as frame-interleaved Dolby Vision metadata.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#l6_metadata ⇒ Types::DolbyVisionLevel6Metadata
Use these settings when you set DolbyVisionLevel6Mode to SPECIFY to override the MaxCLL and MaxFALL values in your input with new values.
-
#l6_mode ⇒ String
Use Dolby Vision Mode to choose how the service will handle Dolby Vision MaxCLL and MaxFALL properies.
-
#profile ⇒ String
In the current MediaConvert implementation, the Dolby Vision profile is always 5 (PROFILE_5).
Instance Attribute Details
#l6_metadata ⇒ Types::DolbyVisionLevel6Metadata
Use these settings when you set DolbyVisionLevel6Mode to SPECIFY to override the MaxCLL and MaxFALL values in your input with new values.
7920 7921 7922 7923 7924 7925 7926 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 7920 class DolbyVision < Struct.new( :l6_metadata, :l6_mode, :profile) SENSITIVE = [] include Aws::Structure end |
#l6_mode ⇒ String
Use Dolby Vision Mode to choose how the service will handle Dolby Vision MaxCLL and MaxFALL properies.
7920 7921 7922 7923 7924 7925 7926 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 7920 class DolbyVision < Struct.new( :l6_metadata, :l6_mode, :profile) SENSITIVE = [] include Aws::Structure end |
#profile ⇒ String
In the current MediaConvert implementation, the Dolby Vision profile is always 5 (PROFILE_5). Therefore, all of your inputs must contain Dolby Vision frame interleaved data.
7920 7921 7922 7923 7924 7925 7926 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 7920 class DolbyVision < Struct.new( :l6_metadata, :l6_mode, :profile) SENSITIVE = [] include Aws::Structure end |