Class: Aws::MediaConvert::Types::DolbyVisionMetadata

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediaconvert/types.rb

Overview

Dolby Vision characteristics of the video track: the profile and level, and whether the RPU (dynamic metadata), base layer, and enhancement layer are present. Use this to distinguish Dolby Vision content from standard HEVC and to choose your encoding or passthrough settings. Omitted when the content is not Dolby Vision.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#base_layerString

Whether a Dolby Vision component is present in the track.

Returns:

  • (String)


4904
4905
4906
4907
4908
4909
4910
4911
4912
# File 'lib/aws-sdk-mediaconvert/types.rb', line 4904

class  < Struct.new(
  :base_layer,
  :enhancement_layer,
  :level,
  :profile,
  :rpu)
  SENSITIVE = []
  include Aws::Structure
end

#enhancement_layerString

Whether a Dolby Vision component is present in the track.

Returns:

  • (String)


4904
4905
4906
4907
4908
4909
4910
4911
4912
# File 'lib/aws-sdk-mediaconvert/types.rb', line 4904

class  < Struct.new(
  :base_layer,
  :enhancement_layer,
  :level,
  :profile,
  :rpu)
  SENSITIVE = []
  include Aws::Structure
end

#levelInteger

The Dolby Vision level, which indicates the maximum resolution and frame rate.

Returns:

  • (Integer)


4904
4905
4906
4907
4908
4909
4910
4911
4912
# File 'lib/aws-sdk-mediaconvert/types.rb', line 4904

class  < Struct.new(
  :base_layer,
  :enhancement_layer,
  :level,
  :profile,
  :rpu)
  SENSITIVE = []
  include Aws::Structure
end

#profileInteger

The Dolby Vision profile, for example 5, 7, or 8. The profile determines the layer structure and playback compatibility of the content.

Returns:

  • (Integer)


4904
4905
4906
4907
4908
4909
4910
4911
4912
# File 'lib/aws-sdk-mediaconvert/types.rb', line 4904

class  < Struct.new(
  :base_layer,
  :enhancement_layer,
  :level,
  :profile,
  :rpu)
  SENSITIVE = []
  include Aws::Structure
end

#rpuString

Whether a Dolby Vision component is present in the track.

Returns:

  • (String)


4904
4905
4906
4907
4908
4909
4910
4911
4912
# File 'lib/aws-sdk-mediaconvert/types.rb', line 4904

class  < Struct.new(
  :base_layer,
  :enhancement_layer,
  :level,
  :profile,
  :rpu)
  SENSITIVE = []
  include Aws::Structure
end