Class: Aws::MediaConvert::Types::DvbNitSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::DvbNitSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
When making an API call, you may pass DvbNitSettings data as a hash:
{
network_id: 1,
network_name: "__stringMin1Max256",
nit_interval: 1,
}
Use these settings to insert a DVB Network Information Table (NIT) in the transport stream of this output. When you work directly in your JSON job specification, include this object only when your job has a transport stream output and the container settings contain the object M2tsSettings.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#network_id ⇒ Integer
The numeric value placed in the Network Information Table (NIT).
-
#network_name ⇒ String
The network name text placed in the network_name_descriptor inside the Network Information Table.
-
#nit_interval ⇒ Integer
The number of milliseconds between instances of this table in the output transport stream.
Instance Attribute Details
#network_id ⇒ Integer
The numeric value placed in the Network Information Table (NIT).
8317 8318 8319 8320 8321 8322 8323 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 8317 class DvbNitSettings < Struct.new( :network_id, :network_name, :nit_interval) SENSITIVE = [] include Aws::Structure end |
#network_name ⇒ String
The network name text placed in the network_name_descriptor inside the Network Information Table. Maximum length is 256 characters.
8317 8318 8319 8320 8321 8322 8323 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 8317 class DvbNitSettings < Struct.new( :network_id, :network_name, :nit_interval) SENSITIVE = [] include Aws::Structure end |
#nit_interval ⇒ Integer
The number of milliseconds between instances of this table in the output transport stream.
8317 8318 8319 8320 8321 8322 8323 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 8317 class DvbNitSettings < Struct.new( :network_id, :network_name, :nit_interval) SENSITIVE = [] include Aws::Structure end |