Class: Aws::MediaConvert::Types::DvbTdtSettings

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediaconvert/types.rb

Overview

Use these settings to insert a DVB Time and Date Table (TDT) in the transport stream of this output. When you work directly in your JSON job specification, include this object only when your job has a transport stream output and the container settings contain the object M2tsSettings.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#tdt_intervalInteger

The number of milliseconds between instances of this table in the output transport stream.

Returns:

  • (Integer)


4071
4072
4073
4074
4075
# File 'lib/aws-sdk-mediaconvert/types.rb', line 4071

class DvbTdtSettings < Struct.new(
  :tdt_interval)
  SENSITIVE = []
  include Aws::Structure
end