Class: Aws::MediaConvert::Types::EsamSettings

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediaconvert/types.rb

Overview

Note:

When making an API call, you may pass EsamSettings data as a hash:

{
  manifest_confirm_condition_notification: {
    mcc_xml: "__stringPatternSNManifestConfirmConditionNotificationNS",
  },
  response_signal_preroll: 1,
  signal_processing_notification: {
    scc_xml: "__stringPatternSNSignalProcessingNotificationNS",
  },
}

Settings for Event Signaling And Messaging (ESAM). If you don't do ad insertion, you can ignore these settings.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#manifest_confirm_condition_notificationTypes::EsamManifestConfirmConditionNotification

Specifies an ESAM ManifestConfirmConditionNotification XML as per OC-SP-ESAM-API-I03-131025. The transcoder uses the manifest conditioning instructions that you provide in the setting MCC XML (mccXml).



9061
9062
9063
9064
9065
9066
9067
# File 'lib/aws-sdk-mediaconvert/types.rb', line 9061

class EsamSettings < Struct.new(
  :manifest_confirm_condition_notification,
  :response_signal_preroll,
  :signal_processing_notification)
  SENSITIVE = []
  include Aws::Structure
end

#response_signal_prerollInteger

Specifies the stream distance, in milliseconds, between the SCTE 35 messages that the transcoder places and the splice points that they refer to. If the time between the start of the asset and the SCTE-35 message is less than this value, then the transcoder places the SCTE-35 marker at the beginning of the stream.

Returns:

  • (Integer)


9061
9062
9063
9064
9065
9066
9067
# File 'lib/aws-sdk-mediaconvert/types.rb', line 9061

class EsamSettings < Struct.new(
  :manifest_confirm_condition_notification,
  :response_signal_preroll,
  :signal_processing_notification)
  SENSITIVE = []
  include Aws::Structure
end

#signal_processing_notificationTypes::EsamSignalProcessingNotification

Specifies an ESAM SignalProcessingNotification XML as per OC-SP-ESAM-API-I03-131025. The transcoder uses the signal processing instructions that you provide in the setting SCC XML (sccXml).



9061
9062
9063
9064
9065
9066
9067
# File 'lib/aws-sdk-mediaconvert/types.rb', line 9061

class EsamSettings < Struct.new(
  :manifest_confirm_condition_notification,
  :response_signal_preroll,
  :signal_processing_notification)
  SENSITIVE = []
  include Aws::Structure
end