Class: Aws::MediaConvert::Types::FileGroupSettings

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediaconvert/types.rb

Overview

Settings related to your File output group. MediaConvert uses this group of settings to generate a single standalone file, rather than a streaming package.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#destinationString

Use Destination to specify the S3 output location and the output filename base. Destination accepts format identifiers. If you do not specify the base filename in the URI, the service will use the filename of the input file. If your job has multiple inputs, the service uses the filename of the first input file.

Returns:

  • (String)


5731
5732
5733
5734
5735
5736
# File 'lib/aws-sdk-mediaconvert/types.rb', line 5731

class FileGroupSettings < Struct.new(
  :destination,
  :destination_settings)
  SENSITIVE = []
  include Aws::Structure
end

#destination_settingsTypes::DestinationSettings

Settings associated with the destination. Will vary based on the type of destination



5731
5732
5733
5734
5735
5736
# File 'lib/aws-sdk-mediaconvert/types.rb', line 5731

class FileGroupSettings < Struct.new(
  :destination,
  :destination_settings)
  SENSITIVE = []
  include Aws::Structure
end