Class: Aws::MediaConvert::Types::FrameCaptureSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::FrameCaptureSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
When making an API call, you may pass FrameCaptureSettings data as a hash:
{
framerate_denominator: 1,
framerate_numerator: 1,
max_captures: 1,
quality: 1,
}
Required when you set (Codec) under (VideoDescription)>(CodecSettings) to the value FRAME_CAPTURE.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#framerate_denominator ⇒ Integer
Frame capture will encode the first frame of the output stream, then one frame every framerateDenominator/framerateNumerator seconds.
-
#framerate_numerator ⇒ Integer
Frame capture will encode the first frame of the output stream, then one frame every framerateDenominator/framerateNumerator seconds.
-
#max_captures ⇒ Integer
Maximum number of captures (encoded jpg output files).
-
#quality ⇒ Integer
JPEG Quality - a higher value equals higher quality.
Instance Attribute Details
#framerate_denominator ⇒ Integer
Frame capture will encode the first frame of the output stream, then one frame every framerateDenominator/framerateNumerator seconds. For example, settings of framerateNumerator = 1 and framerateDenominator
3 (a rate of 1/3 frame per second) will capture the first frame,
then 1 frame every 3s. Files will be named as filename.n.jpg where n is the 0-based sequence number of each Capture.
9351 9352 9353 9354 9355 9356 9357 9358 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 9351 class FrameCaptureSettings < Struct.new( :framerate_denominator, :framerate_numerator, :max_captures, :quality) SENSITIVE = [] include Aws::Structure end |
#framerate_numerator ⇒ Integer
Frame capture will encode the first frame of the output stream, then one frame every framerateDenominator/framerateNumerator seconds. For example, settings of framerateNumerator = 1 and framerateDenominator
3 (a rate of 1/3 frame per second) will capture the first frame,
then 1 frame every 3s. Files will be named as filename.NNNNNNN.jpg where N is the 0-based frame sequence number zero padded to 7 decimal places.
9351 9352 9353 9354 9355 9356 9357 9358 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 9351 class FrameCaptureSettings < Struct.new( :framerate_denominator, :framerate_numerator, :max_captures, :quality) SENSITIVE = [] include Aws::Structure end |
#max_captures ⇒ Integer
Maximum number of captures (encoded jpg output files).
9351 9352 9353 9354 9355 9356 9357 9358 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 9351 class FrameCaptureSettings < Struct.new( :framerate_denominator, :framerate_numerator, :max_captures, :quality) SENSITIVE = [] include Aws::Structure end |
#quality ⇒ Integer
JPEG Quality - a higher value equals higher quality.
9351 9352 9353 9354 9355 9356 9357 9358 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 9351 class FrameCaptureSettings < Struct.new( :framerate_denominator, :framerate_numerator, :max_captures, :quality) SENSITIVE = [] include Aws::Structure end |