Class: Aws::MediaConvert::Types::GetJobsQueryResultsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediaconvert/types.rb

Overview

If the jobs query completed successfully, then a JSON array of jobs will be included in this response. To retrieve the twenty next most recent jobs matched by your jobs query, call the StartJobsQuery using the nextToken string returned in this response.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#jobsArray<Types::Job>

List of jobs.

Returns:



6447
6448
6449
6450
6451
6452
6453
# File 'lib/aws-sdk-mediaconvert/types.rb', line 6447

class GetJobsQueryResultsResponse < Struct.new(
  :jobs,
  :next_token,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

Use this string to request the next batch of jobs via the StartJobsQuery API.

Returns:

  • (String)


6447
6448
6449
6450
6451
6452
6453
# File 'lib/aws-sdk-mediaconvert/types.rb', line 6447

class GetJobsQueryResultsResponse < Struct.new(
  :jobs,
  :next_token,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the jobs query.

Returns:

  • (String)


6447
6448
6449
6450
6451
6452
6453
# File 'lib/aws-sdk-mediaconvert/types.rb', line 6447

class GetJobsQueryResultsResponse < Struct.new(
  :jobs,
  :next_token,
  :status)
  SENSITIVE = []
  include Aws::Structure
end