Class: Aws::MediaConvert::Types::GetQueueRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::GetQueueRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
Note:
When making an API call, you may pass GetQueueRequest data as a hash:
{
name: "__string", # required
}
Get information about a queue by sending a request with the queue name.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#name ⇒ String
The name of the queue that you want information about.
Instance Attribute Details
#name ⇒ String
The name of the queue that you want information about.
9495 9496 9497 9498 9499 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 9495 class GetQueueRequest < Struct.new( :name) SENSITIVE = [] include Aws::Structure end |