Class: Aws::MediaConvert::Types::Hdr10Plus
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::Hdr10Plus
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
Note:
When making an API call, you may pass Hdr10Plus data as a hash:
{
mastering_monitor_nits: 1,
target_monitor_nits: 1,
}
Setting for HDR10+ metadata insertion
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#mastering_monitor_nits ⇒ Integer
Specify the HDR10+ mastering display normalized peak luminance, in nits.
-
#target_monitor_nits ⇒ Integer
Specify the HDR10+ target display nominal peak luminance, in nits.
Instance Attribute Details
#mastering_monitor_nits ⇒ Integer
Specify the HDR10+ mastering display normalized peak luminance, in nits. This is the normalized actual peak luminance of the mastering display, as defined by ST 2094-40.
11271 11272 11273 11274 11275 11276 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 11271 class Hdr10Plus < Struct.new( :mastering_monitor_nits, :target_monitor_nits) SENSITIVE = [] include Aws::Structure end |
#target_monitor_nits ⇒ Integer
Specify the HDR10+ target display nominal peak luminance, in nits. This is the nominal maximum luminance of the target display as defined by ST 2094-40.
11271 11272 11273 11274 11275 11276 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 11271 class Hdr10Plus < Struct.new( :mastering_monitor_nits, :target_monitor_nits) SENSITIVE = [] include Aws::Structure end |