Class: Aws::MediaConvert::Types::HlsEncryptionSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::HlsEncryptionSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
When making an API call, you may pass HlsEncryptionSettings data as a hash:
{
constant_initialization_vector: "__stringMin32Max32Pattern09aFAF32",
encryption_method: "AES128", # accepts AES128, SAMPLE_AES
initialization_vector_in_manifest: "INCLUDE", # accepts INCLUDE, EXCLUDE
offline_encrypted: "ENABLED", # accepts ENABLED, DISABLED
speke_key_provider: {
certificate_arn: "__stringPatternArnAwsUsGovAcm",
resource_id: "__string",
system_ids: ["__stringPattern09aFAF809aFAF409aFAF409aFAF409aFAF12"],
url: "__stringPatternHttps",
},
static_key_provider: {
key_format: "__stringPatternIdentityAZaZ26AZaZ09163",
key_format_versions: "__stringPatternDD",
static_key_value: "__stringPatternAZaZ0932",
url: "__string",
},
type: "SPEKE", # accepts SPEKE, STATIC_KEY
}
Settings for HLS encryption
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#constant_initialization_vector ⇒ String
This is a 128-bit, 16-byte hex value represented by a 32-character text string.
-
#encryption_method ⇒ String
Encrypts the segments with the given encryption scheme.
-
#initialization_vector_in_manifest ⇒ String
The Initialization Vector is a 128-bit number used in conjunction with the key for encrypting blocks.
-
#offline_encrypted ⇒ String
Enable this setting to insert the EXT-X-SESSION-KEY element into the master playlist.
-
#speke_key_provider ⇒ Types::SpekeKeyProvider
If your output group type is HLS, DASH, or Microsoft Smooth, use these settings when doing DRM encryption with a SPEKE-compliant key provider.
-
#static_key_provider ⇒ Types::StaticKeyProvider
Use these settings to set up encryption with a static key provider.
-
#type ⇒ String
Specify whether your DRM encryption key is static or from a key provider that follows the SPEKE standard.
Instance Attribute Details
#constant_initialization_vector ⇒ String
This is a 128-bit, 16-byte hex value represented by a 32-character text string. If this parameter is not set then the Initialization Vector will follow the segment number by default.
11021 11022 11023 11024 11025 11026 11027 11028 11029 11030 11031 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 11021 class HlsEncryptionSettings < Struct.new( :constant_initialization_vector, :encryption_method, :initialization_vector_in_manifest, :offline_encrypted, :speke_key_provider, :static_key_provider, :type) SENSITIVE = [] include Aws::Structure end |
#encryption_method ⇒ String
Encrypts the segments with the given encryption scheme. Leave blank to disable. Selecting 'Disabled' in the web interface also disables encryption.
11021 11022 11023 11024 11025 11026 11027 11028 11029 11030 11031 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 11021 class HlsEncryptionSettings < Struct.new( :constant_initialization_vector, :encryption_method, :initialization_vector_in_manifest, :offline_encrypted, :speke_key_provider, :static_key_provider, :type) SENSITIVE = [] include Aws::Structure end |
#initialization_vector_in_manifest ⇒ String
The Initialization Vector is a 128-bit number used in conjunction with the key for encrypting blocks. If set to INCLUDE, Initialization Vector is listed in the manifest. Otherwise Initialization Vector is not in the manifest.
11021 11022 11023 11024 11025 11026 11027 11028 11029 11030 11031 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 11021 class HlsEncryptionSettings < Struct.new( :constant_initialization_vector, :encryption_method, :initialization_vector_in_manifest, :offline_encrypted, :speke_key_provider, :static_key_provider, :type) SENSITIVE = [] include Aws::Structure end |
#offline_encrypted ⇒ String
Enable this setting to insert the EXT-X-SESSION-KEY element into the master playlist. This allows for offline Apple HLS FairPlay content protection.
11021 11022 11023 11024 11025 11026 11027 11028 11029 11030 11031 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 11021 class HlsEncryptionSettings < Struct.new( :constant_initialization_vector, :encryption_method, :initialization_vector_in_manifest, :offline_encrypted, :speke_key_provider, :static_key_provider, :type) SENSITIVE = [] include Aws::Structure end |
#speke_key_provider ⇒ Types::SpekeKeyProvider
If your output group type is HLS, DASH, or Microsoft Smooth, use these settings when doing DRM encryption with a SPEKE-compliant key provider. If your output group type is CMAF, use the SpekeKeyProviderCmaf settings instead.
11021 11022 11023 11024 11025 11026 11027 11028 11029 11030 11031 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 11021 class HlsEncryptionSettings < Struct.new( :constant_initialization_vector, :encryption_method, :initialization_vector_in_manifest, :offline_encrypted, :speke_key_provider, :static_key_provider, :type) SENSITIVE = [] include Aws::Structure end |
#static_key_provider ⇒ Types::StaticKeyProvider
Use these settings to set up encryption with a static key provider.
11021 11022 11023 11024 11025 11026 11027 11028 11029 11030 11031 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 11021 class HlsEncryptionSettings < Struct.new( :constant_initialization_vector, :encryption_method, :initialization_vector_in_manifest, :offline_encrypted, :speke_key_provider, :static_key_provider, :type) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
Specify whether your DRM encryption key is static or from a key provider that follows the SPEKE standard. For more information about SPEKE, see docs.aws.amazon.com/speke/latest/documentation/what-is-speke.html.
11021 11022 11023 11024 11025 11026 11027 11028 11029 11030 11031 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 11021 class HlsEncryptionSettings < Struct.new( :constant_initialization_vector, :encryption_method, :initialization_vector_in_manifest, :offline_encrypted, :speke_key_provider, :static_key_provider, :type) SENSITIVE = [] include Aws::Structure end |