Class: Aws::MediaConvert::Types::HlsGroupSettings

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediaconvert/types.rb

Overview

Settings related to your HLS output package. For more information, see docs.aws.amazon.com/mediaconvert/latest/ug/outputs-file-ABR.html. When you work directly in your JSON job specification, include this object and any required children when you set Type, under OutputGroupSettings, to HLS_GROUP_SETTINGS.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#ad_markersArray<String>

Choose one or more ad marker types to decorate your Apple HLS manifest. This setting does not determine whether SCTE-35 markers appear in the outputs themselves.

Returns:

  • (Array<String>)


6803
6804
6805
6806
6807
6808
6809
6810
6811
6812
6813
6814
6815
6816
6817
6818
6819
6820
6821
6822
6823
6824
6825
6826
6827
6828
6829
6830
6831
6832
6833
6834
6835
6836
6837
6838
# File 'lib/aws-sdk-mediaconvert/types.rb', line 6803

class HlsGroupSettings < Struct.new(
  :ad_markers,
  :additional_manifests,
  :audio_only_header,
  :base_url,
  :caption_language_mappings,
  :caption_language_setting,
  :caption_segment_length_control,
  :client_cache,
  :codec_specification,
  :destination,
  :destination_settings,
  :directory_structure,
  :encryption,
  :image_based_trick_play,
  :image_based_trick_play_settings,
  :manifest_compression,
  :manifest_duration_format,
  :min_final_segment_length,
  :min_segment_length,
  :output_selection,
  :program_date_time,
  :program_date_time_period,
  :progressive_write_hls_manifest,
  :segment_control,
  :segment_length,
  :segment_length_control,
  :segments_per_subdirectory,
  :stream_inf_resolution,
  :target_duration_compatibility_mode,
  :timed_metadata_id_3_frame,
  :timed_metadata_id_3_period,
  :timestamp_delta_milliseconds)
  SENSITIVE = []
  include Aws::Structure
end

#additional_manifestsArray<Types::HlsAdditionalManifest>

By default, the service creates one top-level .m3u8 HLS manifest for each HLS output group in your job. This default manifest references every output in the output group. To create additional top-level manifests that reference a subset of the outputs in the output group, specify a list of them here.

Returns:



6803
6804
6805
6806
6807
6808
6809
6810
6811
6812
6813
6814
6815
6816
6817
6818
6819
6820
6821
6822
6823
6824
6825
6826
6827
6828
6829
6830
6831
6832
6833
6834
6835
6836
6837
6838
# File 'lib/aws-sdk-mediaconvert/types.rb', line 6803

class HlsGroupSettings < Struct.new(
  :ad_markers,
  :additional_manifests,
  :audio_only_header,
  :base_url,
  :caption_language_mappings,
  :caption_language_setting,
  :caption_segment_length_control,
  :client_cache,
  :codec_specification,
  :destination,
  :destination_settings,
  :directory_structure,
  :encryption,
  :image_based_trick_play,
  :image_based_trick_play_settings,
  :manifest_compression,
  :manifest_duration_format,
  :min_final_segment_length,
  :min_segment_length,
  :output_selection,
  :program_date_time,
  :program_date_time_period,
  :progressive_write_hls_manifest,
  :segment_control,
  :segment_length,
  :segment_length_control,
  :segments_per_subdirectory,
  :stream_inf_resolution,
  :target_duration_compatibility_mode,
  :timed_metadata_id_3_frame,
  :timed_metadata_id_3_period,
  :timestamp_delta_milliseconds)
  SENSITIVE = []
  include Aws::Structure
end

#audio_only_headerString

Ignore this setting unless you are using FairPlay DRM with Verimatrix and you encounter playback issues. Keep the default value, Include (INCLUDE), to output audio-only headers. Choose Exclude (EXCLUDE) to remove the audio-only headers from your audio segments.

Returns:

  • (String)


6803
6804
6805
6806
6807
6808
6809
6810
6811
6812
6813
6814
6815
6816
6817
6818
6819
6820
6821
6822
6823
6824
6825
6826
6827
6828
6829
6830
6831
6832
6833
6834
6835
6836
6837
6838
# File 'lib/aws-sdk-mediaconvert/types.rb', line 6803

class HlsGroupSettings < Struct.new(
  :ad_markers,
  :additional_manifests,
  :audio_only_header,
  :base_url,
  :caption_language_mappings,
  :caption_language_setting,
  :caption_segment_length_control,
  :client_cache,
  :codec_specification,
  :destination,
  :destination_settings,
  :directory_structure,
  :encryption,
  :image_based_trick_play,
  :image_based_trick_play_settings,
  :manifest_compression,
  :manifest_duration_format,
  :min_final_segment_length,
  :min_segment_length,
  :output_selection,
  :program_date_time,
  :program_date_time_period,
  :progressive_write_hls_manifest,
  :segment_control,
  :segment_length,
  :segment_length_control,
  :segments_per_subdirectory,
  :stream_inf_resolution,
  :target_duration_compatibility_mode,
  :timed_metadata_id_3_frame,
  :timed_metadata_id_3_period,
  :timestamp_delta_milliseconds)
  SENSITIVE = []
  include Aws::Structure
end

#base_urlString

A partial URI prefix that will be prepended to each output in the media .m3u8 file. Can be used if base manifest is delivered from a different URL than the main .m3u8 file.

Returns:

  • (String)


6803
6804
6805
6806
6807
6808
6809
6810
6811
6812
6813
6814
6815
6816
6817
6818
6819
6820
6821
6822
6823
6824
6825
6826
6827
6828
6829
6830
6831
6832
6833
6834
6835
6836
6837
6838
# File 'lib/aws-sdk-mediaconvert/types.rb', line 6803

class HlsGroupSettings < Struct.new(
  :ad_markers,
  :additional_manifests,
  :audio_only_header,
  :base_url,
  :caption_language_mappings,
  :caption_language_setting,
  :caption_segment_length_control,
  :client_cache,
  :codec_specification,
  :destination,
  :destination_settings,
  :directory_structure,
  :encryption,
  :image_based_trick_play,
  :image_based_trick_play_settings,
  :manifest_compression,
  :manifest_duration_format,
  :min_final_segment_length,
  :min_segment_length,
  :output_selection,
  :program_date_time,
  :program_date_time_period,
  :progressive_write_hls_manifest,
  :segment_control,
  :segment_length,
  :segment_length_control,
  :segments_per_subdirectory,
  :stream_inf_resolution,
  :target_duration_compatibility_mode,
  :timed_metadata_id_3_frame,
  :timed_metadata_id_3_period,
  :timestamp_delta_milliseconds)
  SENSITIVE = []
  include Aws::Structure
end

#caption_language_mappingsArray<Types::HlsCaptionLanguageMapping>

Language to be used on Caption outputs



6803
6804
6805
6806
6807
6808
6809
6810
6811
6812
6813
6814
6815
6816
6817
6818
6819
6820
6821
6822
6823
6824
6825
6826
6827
6828
6829
6830
6831
6832
6833
6834
6835
6836
6837
6838
# File 'lib/aws-sdk-mediaconvert/types.rb', line 6803

class HlsGroupSettings < Struct.new(
  :ad_markers,
  :additional_manifests,
  :audio_only_header,
  :base_url,
  :caption_language_mappings,
  :caption_language_setting,
  :caption_segment_length_control,
  :client_cache,
  :codec_specification,
  :destination,
  :destination_settings,
  :directory_structure,
  :encryption,
  :image_based_trick_play,
  :image_based_trick_play_settings,
  :manifest_compression,
  :manifest_duration_format,
  :min_final_segment_length,
  :min_segment_length,
  :output_selection,
  :program_date_time,
  :program_date_time_period,
  :progressive_write_hls_manifest,
  :segment_control,
  :segment_length,
  :segment_length_control,
  :segments_per_subdirectory,
  :stream_inf_resolution,
  :target_duration_compatibility_mode,
  :timed_metadata_id_3_frame,
  :timed_metadata_id_3_period,
  :timestamp_delta_milliseconds)
  SENSITIVE = []
  include Aws::Structure
end

#caption_language_settingString

Applies only to 608 Embedded output captions. Insert: Include CLOSED-CAPTIONS lines in the manifest. Specify at least one language in the CC1 Language Code field. One CLOSED-CAPTION line is added for each Language Code you specify. Make sure to specify the languages in the order in which they appear in the original source (if the source is embedded format) or the order of the caption selectors (if the source is other than embedded). Otherwise, languages in the manifest will not match up properly with the output captions. None: Include CLOSED-CAPTIONS=NONE line in the manifest. Omit: Omit any CLOSED-CAPTIONS line from the manifest.

Returns:

  • (String)


6803
6804
6805
6806
6807
6808
6809
6810
6811
6812
6813
6814
6815
6816
6817
6818
6819
6820
6821
6822
6823
6824
6825
6826
6827
6828
6829
6830
6831
6832
6833
6834
6835
6836
6837
6838
# File 'lib/aws-sdk-mediaconvert/types.rb', line 6803

class HlsGroupSettings < Struct.new(
  :ad_markers,
  :additional_manifests,
  :audio_only_header,
  :base_url,
  :caption_language_mappings,
  :caption_language_setting,
  :caption_segment_length_control,
  :client_cache,
  :codec_specification,
  :destination,
  :destination_settings,
  :directory_structure,
  :encryption,
  :image_based_trick_play,
  :image_based_trick_play_settings,
  :manifest_compression,
  :manifest_duration_format,
  :min_final_segment_length,
  :min_segment_length,
  :output_selection,
  :program_date_time,
  :program_date_time_period,
  :progressive_write_hls_manifest,
  :segment_control,
  :segment_length,
  :segment_length_control,
  :segments_per_subdirectory,
  :stream_inf_resolution,
  :target_duration_compatibility_mode,
  :timed_metadata_id_3_frame,
  :timed_metadata_id_3_period,
  :timestamp_delta_milliseconds)
  SENSITIVE = []
  include Aws::Structure
end

#caption_segment_length_controlString

Set Caption segment length control (CaptionSegmentLengthControl) to Match video (MATCH_VIDEO) to create caption segments that align with the video segments from the first video output in this output group. For example, if the video segments are 2 seconds long, your WebVTT segments will also be 2 seconds long. Keep the default setting, Large segments (LARGE_SEGMENTS) to create caption segments that are 300 seconds long.

Returns:

  • (String)


6803
6804
6805
6806
6807
6808
6809
6810
6811
6812
6813
6814
6815
6816
6817
6818
6819
6820
6821
6822
6823
6824
6825
6826
6827
6828
6829
6830
6831
6832
6833
6834
6835
6836
6837
6838
# File 'lib/aws-sdk-mediaconvert/types.rb', line 6803

class HlsGroupSettings < Struct.new(
  :ad_markers,
  :additional_manifests,
  :audio_only_header,
  :base_url,
  :caption_language_mappings,
  :caption_language_setting,
  :caption_segment_length_control,
  :client_cache,
  :codec_specification,
  :destination,
  :destination_settings,
  :directory_structure,
  :encryption,
  :image_based_trick_play,
  :image_based_trick_play_settings,
  :manifest_compression,
  :manifest_duration_format,
  :min_final_segment_length,
  :min_segment_length,
  :output_selection,
  :program_date_time,
  :program_date_time_period,
  :progressive_write_hls_manifest,
  :segment_control,
  :segment_length,
  :segment_length_control,
  :segments_per_subdirectory,
  :stream_inf_resolution,
  :target_duration_compatibility_mode,
  :timed_metadata_id_3_frame,
  :timed_metadata_id_3_period,
  :timestamp_delta_milliseconds)
  SENSITIVE = []
  include Aws::Structure
end

#client_cacheString

Disable this setting only when your workflow requires the #EXT-X-ALLOW-CACHE:no tag. Otherwise, keep the default value Enabled (ENABLED) and control caching in your video distribution set up. For example, use the Cache-Control http header.

Returns:

  • (String)


6803
6804
6805
6806
6807
6808
6809
6810
6811
6812
6813
6814
6815
6816
6817
6818
6819
6820
6821
6822
6823
6824
6825
6826
6827
6828
6829
6830
6831
6832
6833
6834
6835
6836
6837
6838
# File 'lib/aws-sdk-mediaconvert/types.rb', line 6803

class HlsGroupSettings < Struct.new(
  :ad_markers,
  :additional_manifests,
  :audio_only_header,
  :base_url,
  :caption_language_mappings,
  :caption_language_setting,
  :caption_segment_length_control,
  :client_cache,
  :codec_specification,
  :destination,
  :destination_settings,
  :directory_structure,
  :encryption,
  :image_based_trick_play,
  :image_based_trick_play_settings,
  :manifest_compression,
  :manifest_duration_format,
  :min_final_segment_length,
  :min_segment_length,
  :output_selection,
  :program_date_time,
  :program_date_time_period,
  :progressive_write_hls_manifest,
  :segment_control,
  :segment_length,
  :segment_length_control,
  :segments_per_subdirectory,
  :stream_inf_resolution,
  :target_duration_compatibility_mode,
  :timed_metadata_id_3_frame,
  :timed_metadata_id_3_period,
  :timestamp_delta_milliseconds)
  SENSITIVE = []
  include Aws::Structure
end

#codec_specificationString

Specification to use (RFC-6381 or the default RFC-4281) during m3u8 playlist generation.

Returns:

  • (String)


6803
6804
6805
6806
6807
6808
6809
6810
6811
6812
6813
6814
6815
6816
6817
6818
6819
6820
6821
6822
6823
6824
6825
6826
6827
6828
6829
6830
6831
6832
6833
6834
6835
6836
6837
6838
# File 'lib/aws-sdk-mediaconvert/types.rb', line 6803

class HlsGroupSettings < Struct.new(
  :ad_markers,
  :additional_manifests,
  :audio_only_header,
  :base_url,
  :caption_language_mappings,
  :caption_language_setting,
  :caption_segment_length_control,
  :client_cache,
  :codec_specification,
  :destination,
  :destination_settings,
  :directory_structure,
  :encryption,
  :image_based_trick_play,
  :image_based_trick_play_settings,
  :manifest_compression,
  :manifest_duration_format,
  :min_final_segment_length,
  :min_segment_length,
  :output_selection,
  :program_date_time,
  :program_date_time_period,
  :progressive_write_hls_manifest,
  :segment_control,
  :segment_length,
  :segment_length_control,
  :segments_per_subdirectory,
  :stream_inf_resolution,
  :target_duration_compatibility_mode,
  :timed_metadata_id_3_frame,
  :timed_metadata_id_3_period,
  :timestamp_delta_milliseconds)
  SENSITIVE = []
  include Aws::Structure
end

#destinationString

Use Destination (Destination) to specify the S3 output location and the output filename base. Destination accepts format identifiers. If you do not specify the base filename in the URI, the service will use the filename of the input file. If your job has multiple inputs, the service uses the filename of the first input file.

Returns:

  • (String)


6803
6804
6805
6806
6807
6808
6809
6810
6811
6812
6813
6814
6815
6816
6817
6818
6819
6820
6821
6822
6823
6824
6825
6826
6827
6828
6829
6830
6831
6832
6833
6834
6835
6836
6837
6838
# File 'lib/aws-sdk-mediaconvert/types.rb', line 6803

class HlsGroupSettings < Struct.new(
  :ad_markers,
  :additional_manifests,
  :audio_only_header,
  :base_url,
  :caption_language_mappings,
  :caption_language_setting,
  :caption_segment_length_control,
  :client_cache,
  :codec_specification,
  :destination,
  :destination_settings,
  :directory_structure,
  :encryption,
  :image_based_trick_play,
  :image_based_trick_play_settings,
  :manifest_compression,
  :manifest_duration_format,
  :min_final_segment_length,
  :min_segment_length,
  :output_selection,
  :program_date_time,
  :program_date_time_period,
  :progressive_write_hls_manifest,
  :segment_control,
  :segment_length,
  :segment_length_control,
  :segments_per_subdirectory,
  :stream_inf_resolution,
  :target_duration_compatibility_mode,
  :timed_metadata_id_3_frame,
  :timed_metadata_id_3_period,
  :timestamp_delta_milliseconds)
  SENSITIVE = []
  include Aws::Structure
end

#destination_settingsTypes::DestinationSettings

Settings associated with the destination. Will vary based on the type of destination



6803
6804
6805
6806
6807
6808
6809
6810
6811
6812
6813
6814
6815
6816
6817
6818
6819
6820
6821
6822
6823
6824
6825
6826
6827
6828
6829
6830
6831
6832
6833
6834
6835
6836
6837
6838
# File 'lib/aws-sdk-mediaconvert/types.rb', line 6803

class HlsGroupSettings < Struct.new(
  :ad_markers,
  :additional_manifests,
  :audio_only_header,
  :base_url,
  :caption_language_mappings,
  :caption_language_setting,
  :caption_segment_length_control,
  :client_cache,
  :codec_specification,
  :destination,
  :destination_settings,
  :directory_structure,
  :encryption,
  :image_based_trick_play,
  :image_based_trick_play_settings,
  :manifest_compression,
  :manifest_duration_format,
  :min_final_segment_length,
  :min_segment_length,
  :output_selection,
  :program_date_time,
  :program_date_time_period,
  :progressive_write_hls_manifest,
  :segment_control,
  :segment_length,
  :segment_length_control,
  :segments_per_subdirectory,
  :stream_inf_resolution,
  :target_duration_compatibility_mode,
  :timed_metadata_id_3_frame,
  :timed_metadata_id_3_period,
  :timestamp_delta_milliseconds)
  SENSITIVE = []
  include Aws::Structure
end

#directory_structureString

Indicates whether segments should be placed in subdirectories.

Returns:

  • (String)


6803
6804
6805
6806
6807
6808
6809
6810
6811
6812
6813
6814
6815
6816
6817
6818
6819
6820
6821
6822
6823
6824
6825
6826
6827
6828
6829
6830
6831
6832
6833
6834
6835
6836
6837
6838
# File 'lib/aws-sdk-mediaconvert/types.rb', line 6803

class HlsGroupSettings < Struct.new(
  :ad_markers,
  :additional_manifests,
  :audio_only_header,
  :base_url,
  :caption_language_mappings,
  :caption_language_setting,
  :caption_segment_length_control,
  :client_cache,
  :codec_specification,
  :destination,
  :destination_settings,
  :directory_structure,
  :encryption,
  :image_based_trick_play,
  :image_based_trick_play_settings,
  :manifest_compression,
  :manifest_duration_format,
  :min_final_segment_length,
  :min_segment_length,
  :output_selection,
  :program_date_time,
  :program_date_time_period,
  :progressive_write_hls_manifest,
  :segment_control,
  :segment_length,
  :segment_length_control,
  :segments_per_subdirectory,
  :stream_inf_resolution,
  :target_duration_compatibility_mode,
  :timed_metadata_id_3_frame,
  :timed_metadata_id_3_period,
  :timestamp_delta_milliseconds)
  SENSITIVE = []
  include Aws::Structure
end

#encryptionTypes::HlsEncryptionSettings

DRM settings.



6803
6804
6805
6806
6807
6808
6809
6810
6811
6812
6813
6814
6815
6816
6817
6818
6819
6820
6821
6822
6823
6824
6825
6826
6827
6828
6829
6830
6831
6832
6833
6834
6835
6836
6837
6838
# File 'lib/aws-sdk-mediaconvert/types.rb', line 6803

class HlsGroupSettings < Struct.new(
  :ad_markers,
  :additional_manifests,
  :audio_only_header,
  :base_url,
  :caption_language_mappings,
  :caption_language_setting,
  :caption_segment_length_control,
  :client_cache,
  :codec_specification,
  :destination,
  :destination_settings,
  :directory_structure,
  :encryption,
  :image_based_trick_play,
  :image_based_trick_play_settings,
  :manifest_compression,
  :manifest_duration_format,
  :min_final_segment_length,
  :min_segment_length,
  :output_selection,
  :program_date_time,
  :program_date_time_period,
  :progressive_write_hls_manifest,
  :segment_control,
  :segment_length,
  :segment_length_control,
  :segments_per_subdirectory,
  :stream_inf_resolution,
  :target_duration_compatibility_mode,
  :timed_metadata_id_3_frame,
  :timed_metadata_id_3_period,
  :timestamp_delta_milliseconds)
  SENSITIVE = []
  include Aws::Structure
end

#image_based_trick_playString

Specify whether MediaConvert generates images for trick play. Keep the default value, None (NONE), to not generate any images. Choose Thumbnail (THUMBNAIL) to generate tiled thumbnails. Choose Thumbnail and full frame (THUMBNAIL_AND_FULLFRAME) to generate tiled thumbnails and full-resolution images of single frames. MediaConvert creates a child manifest for each set of images that you generate and adds corresponding entries to the parent manifest. A common application for these images is Roku trick mode. The thumbnails and full-frame images that MediaConvert creates with this feature are compatible with this Roku specification: developer.roku.com/docs/developer-program/media-playback/trick-mode/hls-and-dash.md

Returns:

  • (String)


6803
6804
6805
6806
6807
6808
6809
6810
6811
6812
6813
6814
6815
6816
6817
6818
6819
6820
6821
6822
6823
6824
6825
6826
6827
6828
6829
6830
6831
6832
6833
6834
6835
6836
6837
6838
# File 'lib/aws-sdk-mediaconvert/types.rb', line 6803

class HlsGroupSettings < Struct.new(
  :ad_markers,
  :additional_manifests,
  :audio_only_header,
  :base_url,
  :caption_language_mappings,
  :caption_language_setting,
  :caption_segment_length_control,
  :client_cache,
  :codec_specification,
  :destination,
  :destination_settings,
  :directory_structure,
  :encryption,
  :image_based_trick_play,
  :image_based_trick_play_settings,
  :manifest_compression,
  :manifest_duration_format,
  :min_final_segment_length,
  :min_segment_length,
  :output_selection,
  :program_date_time,
  :program_date_time_period,
  :progressive_write_hls_manifest,
  :segment_control,
  :segment_length,
  :segment_length_control,
  :segments_per_subdirectory,
  :stream_inf_resolution,
  :target_duration_compatibility_mode,
  :timed_metadata_id_3_frame,
  :timed_metadata_id_3_period,
  :timestamp_delta_milliseconds)
  SENSITIVE = []
  include Aws::Structure
end

#image_based_trick_play_settingsTypes::HlsImageBasedTrickPlaySettings

Tile and thumbnail settings applicable when imageBasedTrickPlay is ADVANCED



6803
6804
6805
6806
6807
6808
6809
6810
6811
6812
6813
6814
6815
6816
6817
6818
6819
6820
6821
6822
6823
6824
6825
6826
6827
6828
6829
6830
6831
6832
6833
6834
6835
6836
6837
6838
# File 'lib/aws-sdk-mediaconvert/types.rb', line 6803

class HlsGroupSettings < Struct.new(
  :ad_markers,
  :additional_manifests,
  :audio_only_header,
  :base_url,
  :caption_language_mappings,
  :caption_language_setting,
  :caption_segment_length_control,
  :client_cache,
  :codec_specification,
  :destination,
  :destination_settings,
  :directory_structure,
  :encryption,
  :image_based_trick_play,
  :image_based_trick_play_settings,
  :manifest_compression,
  :manifest_duration_format,
  :min_final_segment_length,
  :min_segment_length,
  :output_selection,
  :program_date_time,
  :program_date_time_period,
  :progressive_write_hls_manifest,
  :segment_control,
  :segment_length,
  :segment_length_control,
  :segments_per_subdirectory,
  :stream_inf_resolution,
  :target_duration_compatibility_mode,
  :timed_metadata_id_3_frame,
  :timed_metadata_id_3_period,
  :timestamp_delta_milliseconds)
  SENSITIVE = []
  include Aws::Structure
end

#manifest_compressionString

When set to GZIP, compresses HLS playlist.

Returns:

  • (String)


6803
6804
6805
6806
6807
6808
6809
6810
6811
6812
6813
6814
6815
6816
6817
6818
6819
6820
6821
6822
6823
6824
6825
6826
6827
6828
6829
6830
6831
6832
6833
6834
6835
6836
6837
6838
# File 'lib/aws-sdk-mediaconvert/types.rb', line 6803

class HlsGroupSettings < Struct.new(
  :ad_markers,
  :additional_manifests,
  :audio_only_header,
  :base_url,
  :caption_language_mappings,
  :caption_language_setting,
  :caption_segment_length_control,
  :client_cache,
  :codec_specification,
  :destination,
  :destination_settings,
  :directory_structure,
  :encryption,
  :image_based_trick_play,
  :image_based_trick_play_settings,
  :manifest_compression,
  :manifest_duration_format,
  :min_final_segment_length,
  :min_segment_length,
  :output_selection,
  :program_date_time,
  :program_date_time_period,
  :progressive_write_hls_manifest,
  :segment_control,
  :segment_length,
  :segment_length_control,
  :segments_per_subdirectory,
  :stream_inf_resolution,
  :target_duration_compatibility_mode,
  :timed_metadata_id_3_frame,
  :timed_metadata_id_3_period,
  :timestamp_delta_milliseconds)
  SENSITIVE = []
  include Aws::Structure
end

#manifest_duration_formatString

Indicates whether the output manifest should use floating point values for segment duration.

Returns:

  • (String)


6803
6804
6805
6806
6807
6808
6809
6810
6811
6812
6813
6814
6815
6816
6817
6818
6819
6820
6821
6822
6823
6824
6825
6826
6827
6828
6829
6830
6831
6832
6833
6834
6835
6836
6837
6838
# File 'lib/aws-sdk-mediaconvert/types.rb', line 6803

class HlsGroupSettings < Struct.new(
  :ad_markers,
  :additional_manifests,
  :audio_only_header,
  :base_url,
  :caption_language_mappings,
  :caption_language_setting,
  :caption_segment_length_control,
  :client_cache,
  :codec_specification,
  :destination,
  :destination_settings,
  :directory_structure,
  :encryption,
  :image_based_trick_play,
  :image_based_trick_play_settings,
  :manifest_compression,
  :manifest_duration_format,
  :min_final_segment_length,
  :min_segment_length,
  :output_selection,
  :program_date_time,
  :program_date_time_period,
  :progressive_write_hls_manifest,
  :segment_control,
  :segment_length,
  :segment_length_control,
  :segments_per_subdirectory,
  :stream_inf_resolution,
  :target_duration_compatibility_mode,
  :timed_metadata_id_3_frame,
  :timed_metadata_id_3_period,
  :timestamp_delta_milliseconds)
  SENSITIVE = []
  include Aws::Structure
end

#min_final_segment_lengthFloat

Keep this setting at the default value of 0, unless you are troubleshooting a problem with how devices play back the end of your video asset. If you know that player devices are hanging on the final segment of your video because the length of your final segment is too short, use this setting to specify a minimum final segment length, in seconds. Choose a value that is greater than or equal to 1 and less than your segment length. When you specify a value for this setting, the encoder will combine any final segment that is shorter than the length that you specify with the previous segment. For example, your segment length is 3 seconds and your final segment is .5 seconds without a minimum final segment length; when you set the minimum final segment length to 1, your final segment is 3.5 seconds.

Returns:

  • (Float)


6803
6804
6805
6806
6807
6808
6809
6810
6811
6812
6813
6814
6815
6816
6817
6818
6819
6820
6821
6822
6823
6824
6825
6826
6827
6828
6829
6830
6831
6832
6833
6834
6835
6836
6837
6838
# File 'lib/aws-sdk-mediaconvert/types.rb', line 6803

class HlsGroupSettings < Struct.new(
  :ad_markers,
  :additional_manifests,
  :audio_only_header,
  :base_url,
  :caption_language_mappings,
  :caption_language_setting,
  :caption_segment_length_control,
  :client_cache,
  :codec_specification,
  :destination,
  :destination_settings,
  :directory_structure,
  :encryption,
  :image_based_trick_play,
  :image_based_trick_play_settings,
  :manifest_compression,
  :manifest_duration_format,
  :min_final_segment_length,
  :min_segment_length,
  :output_selection,
  :program_date_time,
  :program_date_time_period,
  :progressive_write_hls_manifest,
  :segment_control,
  :segment_length,
  :segment_length_control,
  :segments_per_subdirectory,
  :stream_inf_resolution,
  :target_duration_compatibility_mode,
  :timed_metadata_id_3_frame,
  :timed_metadata_id_3_period,
  :timestamp_delta_milliseconds)
  SENSITIVE = []
  include Aws::Structure
end

#min_segment_lengthInteger

When set, Minimum Segment Size is enforced by looking ahead and back within the specified range for a nearby avail and extending the segment size if needed.

Returns:

  • (Integer)


6803
6804
6805
6806
6807
6808
6809
6810
6811
6812
6813
6814
6815
6816
6817
6818
6819
6820
6821
6822
6823
6824
6825
6826
6827
6828
6829
6830
6831
6832
6833
6834
6835
6836
6837
6838
# File 'lib/aws-sdk-mediaconvert/types.rb', line 6803

class HlsGroupSettings < Struct.new(
  :ad_markers,
  :additional_manifests,
  :audio_only_header,
  :base_url,
  :caption_language_mappings,
  :caption_language_setting,
  :caption_segment_length_control,
  :client_cache,
  :codec_specification,
  :destination,
  :destination_settings,
  :directory_structure,
  :encryption,
  :image_based_trick_play,
  :image_based_trick_play_settings,
  :manifest_compression,
  :manifest_duration_format,
  :min_final_segment_length,
  :min_segment_length,
  :output_selection,
  :program_date_time,
  :program_date_time_period,
  :progressive_write_hls_manifest,
  :segment_control,
  :segment_length,
  :segment_length_control,
  :segments_per_subdirectory,
  :stream_inf_resolution,
  :target_duration_compatibility_mode,
  :timed_metadata_id_3_frame,
  :timed_metadata_id_3_period,
  :timestamp_delta_milliseconds)
  SENSITIVE = []
  include Aws::Structure
end

#output_selectionString

Indicates whether the .m3u8 manifest file should be generated for this HLS output group.

Returns:

  • (String)


6803
6804
6805
6806
6807
6808
6809
6810
6811
6812
6813
6814
6815
6816
6817
6818
6819
6820
6821
6822
6823
6824
6825
6826
6827
6828
6829
6830
6831
6832
6833
6834
6835
6836
6837
6838
# File 'lib/aws-sdk-mediaconvert/types.rb', line 6803

class HlsGroupSettings < Struct.new(
  :ad_markers,
  :additional_manifests,
  :audio_only_header,
  :base_url,
  :caption_language_mappings,
  :caption_language_setting,
  :caption_segment_length_control,
  :client_cache,
  :codec_specification,
  :destination,
  :destination_settings,
  :directory_structure,
  :encryption,
  :image_based_trick_play,
  :image_based_trick_play_settings,
  :manifest_compression,
  :manifest_duration_format,
  :min_final_segment_length,
  :min_segment_length,
  :output_selection,
  :program_date_time,
  :program_date_time_period,
  :progressive_write_hls_manifest,
  :segment_control,
  :segment_length,
  :segment_length_control,
  :segments_per_subdirectory,
  :stream_inf_resolution,
  :target_duration_compatibility_mode,
  :timed_metadata_id_3_frame,
  :timed_metadata_id_3_period,
  :timestamp_delta_milliseconds)
  SENSITIVE = []
  include Aws::Structure
end

#program_date_timeString

Includes or excludes EXT-X-PROGRAM-DATE-TIME tag in .m3u8 manifest files. The value is calculated as follows: either the program date and time are initialized using the input timecode source, or the time is initialized using the input timecode source and the date is initialized using the timestamp_offset.

Returns:

  • (String)


6803
6804
6805
6806
6807
6808
6809
6810
6811
6812
6813
6814
6815
6816
6817
6818
6819
6820
6821
6822
6823
6824
6825
6826
6827
6828
6829
6830
6831
6832
6833
6834
6835
6836
6837
6838
# File 'lib/aws-sdk-mediaconvert/types.rb', line 6803

class HlsGroupSettings < Struct.new(
  :ad_markers,
  :additional_manifests,
  :audio_only_header,
  :base_url,
  :caption_language_mappings,
  :caption_language_setting,
  :caption_segment_length_control,
  :client_cache,
  :codec_specification,
  :destination,
  :destination_settings,
  :directory_structure,
  :encryption,
  :image_based_trick_play,
  :image_based_trick_play_settings,
  :manifest_compression,
  :manifest_duration_format,
  :min_final_segment_length,
  :min_segment_length,
  :output_selection,
  :program_date_time,
  :program_date_time_period,
  :progressive_write_hls_manifest,
  :segment_control,
  :segment_length,
  :segment_length_control,
  :segments_per_subdirectory,
  :stream_inf_resolution,
  :target_duration_compatibility_mode,
  :timed_metadata_id_3_frame,
  :timed_metadata_id_3_period,
  :timestamp_delta_milliseconds)
  SENSITIVE = []
  include Aws::Structure
end

#program_date_time_periodInteger

Period of insertion of EXT-X-PROGRAM-DATE-TIME entry, in seconds.

Returns:

  • (Integer)


6803
6804
6805
6806
6807
6808
6809
6810
6811
6812
6813
6814
6815
6816
6817
6818
6819
6820
6821
6822
6823
6824
6825
6826
6827
6828
6829
6830
6831
6832
6833
6834
6835
6836
6837
6838
# File 'lib/aws-sdk-mediaconvert/types.rb', line 6803

class HlsGroupSettings < Struct.new(
  :ad_markers,
  :additional_manifests,
  :audio_only_header,
  :base_url,
  :caption_language_mappings,
  :caption_language_setting,
  :caption_segment_length_control,
  :client_cache,
  :codec_specification,
  :destination,
  :destination_settings,
  :directory_structure,
  :encryption,
  :image_based_trick_play,
  :image_based_trick_play_settings,
  :manifest_compression,
  :manifest_duration_format,
  :min_final_segment_length,
  :min_segment_length,
  :output_selection,
  :program_date_time,
  :program_date_time_period,
  :progressive_write_hls_manifest,
  :segment_control,
  :segment_length,
  :segment_length_control,
  :segments_per_subdirectory,
  :stream_inf_resolution,
  :target_duration_compatibility_mode,
  :timed_metadata_id_3_frame,
  :timed_metadata_id_3_period,
  :timestamp_delta_milliseconds)
  SENSITIVE = []
  include Aws::Structure
end

#progressive_write_hls_manifestString

Specify whether MediaConvert generates HLS manifests while your job is running or when your job is complete. To generate HLS manifests while your job is running: Choose Enabled. Use if you want to play back your content as soon as it’s available. MediaConvert writes the parent and child manifests after the first three media segments are written to your destination S3 bucket. It then writes new updated manifests after each additional segment is written. The parent manifest includes the latest BANDWIDTH and AVERAGE-BANDWIDTH attributes, and child manifests include the latest available media segment. When your job completes, the final child playlists include an EXT-X-ENDLIST tag. To generate HLS manifests only when your job completes: Choose Disabled.

Returns:

  • (String)


6803
6804
6805
6806
6807
6808
6809
6810
6811
6812
6813
6814
6815
6816
6817
6818
6819
6820
6821
6822
6823
6824
6825
6826
6827
6828
6829
6830
6831
6832
6833
6834
6835
6836
6837
6838
# File 'lib/aws-sdk-mediaconvert/types.rb', line 6803

class HlsGroupSettings < Struct.new(
  :ad_markers,
  :additional_manifests,
  :audio_only_header,
  :base_url,
  :caption_language_mappings,
  :caption_language_setting,
  :caption_segment_length_control,
  :client_cache,
  :codec_specification,
  :destination,
  :destination_settings,
  :directory_structure,
  :encryption,
  :image_based_trick_play,
  :image_based_trick_play_settings,
  :manifest_compression,
  :manifest_duration_format,
  :min_final_segment_length,
  :min_segment_length,
  :output_selection,
  :program_date_time,
  :program_date_time_period,
  :progressive_write_hls_manifest,
  :segment_control,
  :segment_length,
  :segment_length_control,
  :segments_per_subdirectory,
  :stream_inf_resolution,
  :target_duration_compatibility_mode,
  :timed_metadata_id_3_frame,
  :timed_metadata_id_3_period,
  :timestamp_delta_milliseconds)
  SENSITIVE = []
  include Aws::Structure
end

#segment_controlString

When set to SINGLE_FILE, emits program as a single media resource (.ts) file, uses #EXT-X-BYTERANGE tags to index segment for playback.

Returns:

  • (String)


6803
6804
6805
6806
6807
6808
6809
6810
6811
6812
6813
6814
6815
6816
6817
6818
6819
6820
6821
6822
6823
6824
6825
6826
6827
6828
6829
6830
6831
6832
6833
6834
6835
6836
6837
6838
# File 'lib/aws-sdk-mediaconvert/types.rb', line 6803

class HlsGroupSettings < Struct.new(
  :ad_markers,
  :additional_manifests,
  :audio_only_header,
  :base_url,
  :caption_language_mappings,
  :caption_language_setting,
  :caption_segment_length_control,
  :client_cache,
  :codec_specification,
  :destination,
  :destination_settings,
  :directory_structure,
  :encryption,
  :image_based_trick_play,
  :image_based_trick_play_settings,
  :manifest_compression,
  :manifest_duration_format,
  :min_final_segment_length,
  :min_segment_length,
  :output_selection,
  :program_date_time,
  :program_date_time_period,
  :progressive_write_hls_manifest,
  :segment_control,
  :segment_length,
  :segment_length_control,
  :segments_per_subdirectory,
  :stream_inf_resolution,
  :target_duration_compatibility_mode,
  :timed_metadata_id_3_frame,
  :timed_metadata_id_3_period,
  :timestamp_delta_milliseconds)
  SENSITIVE = []
  include Aws::Structure
end

#segment_lengthInteger

Specify the length, in whole seconds, of each segment. When you don’t specify a value, MediaConvert defaults to 10. Related settings: Use Segment length control (SegmentLengthControl) to specify whether the encoder enforces this value strictly. Use Segment control (HlsSegmentControl) to specify whether MediaConvert creates separate segment files or one content file that has metadata to mark the segment boundaries.

Returns:

  • (Integer)


6803
6804
6805
6806
6807
6808
6809
6810
6811
6812
6813
6814
6815
6816
6817
6818
6819
6820
6821
6822
6823
6824
6825
6826
6827
6828
6829
6830
6831
6832
6833
6834
6835
6836
6837
6838
# File 'lib/aws-sdk-mediaconvert/types.rb', line 6803

class HlsGroupSettings < Struct.new(
  :ad_markers,
  :additional_manifests,
  :audio_only_header,
  :base_url,
  :caption_language_mappings,
  :caption_language_setting,
  :caption_segment_length_control,
  :client_cache,
  :codec_specification,
  :destination,
  :destination_settings,
  :directory_structure,
  :encryption,
  :image_based_trick_play,
  :image_based_trick_play_settings,
  :manifest_compression,
  :manifest_duration_format,
  :min_final_segment_length,
  :min_segment_length,
  :output_selection,
  :program_date_time,
  :program_date_time_period,
  :progressive_write_hls_manifest,
  :segment_control,
  :segment_length,
  :segment_length_control,
  :segments_per_subdirectory,
  :stream_inf_resolution,
  :target_duration_compatibility_mode,
  :timed_metadata_id_3_frame,
  :timed_metadata_id_3_period,
  :timestamp_delta_milliseconds)
  SENSITIVE = []
  include Aws::Structure
end

#segment_length_controlString

Specify how you want MediaConvert to determine the segment length. Choose Exact (EXACT) to have the encoder use the exact length that you specify with the setting Segment length (SegmentLength). This might result in extra I-frames. Choose Multiple of GOP (GOP_MULTIPLE) to have the encoder round up the segment lengths to match the next GOP boundary.

Returns:

  • (String)


6803
6804
6805
6806
6807
6808
6809
6810
6811
6812
6813
6814
6815
6816
6817
6818
6819
6820
6821
6822
6823
6824
6825
6826
6827
6828
6829
6830
6831
6832
6833
6834
6835
6836
6837
6838
# File 'lib/aws-sdk-mediaconvert/types.rb', line 6803

class HlsGroupSettings < Struct.new(
  :ad_markers,
  :additional_manifests,
  :audio_only_header,
  :base_url,
  :caption_language_mappings,
  :caption_language_setting,
  :caption_segment_length_control,
  :client_cache,
  :codec_specification,
  :destination,
  :destination_settings,
  :directory_structure,
  :encryption,
  :image_based_trick_play,
  :image_based_trick_play_settings,
  :manifest_compression,
  :manifest_duration_format,
  :min_final_segment_length,
  :min_segment_length,
  :output_selection,
  :program_date_time,
  :program_date_time_period,
  :progressive_write_hls_manifest,
  :segment_control,
  :segment_length,
  :segment_length_control,
  :segments_per_subdirectory,
  :stream_inf_resolution,
  :target_duration_compatibility_mode,
  :timed_metadata_id_3_frame,
  :timed_metadata_id_3_period,
  :timestamp_delta_milliseconds)
  SENSITIVE = []
  include Aws::Structure
end

#segments_per_subdirectoryInteger

Specify the number of segments to write to a subdirectory before starting a new one. You must also set Directory structure to Subdirectory per stream for this setting to have an effect.

Returns:

  • (Integer)


6803
6804
6805
6806
6807
6808
6809
6810
6811
6812
6813
6814
6815
6816
6817
6818
6819
6820
6821
6822
6823
6824
6825
6826
6827
6828
6829
6830
6831
6832
6833
6834
6835
6836
6837
6838
# File 'lib/aws-sdk-mediaconvert/types.rb', line 6803

class HlsGroupSettings < Struct.new(
  :ad_markers,
  :additional_manifests,
  :audio_only_header,
  :base_url,
  :caption_language_mappings,
  :caption_language_setting,
  :caption_segment_length_control,
  :client_cache,
  :codec_specification,
  :destination,
  :destination_settings,
  :directory_structure,
  :encryption,
  :image_based_trick_play,
  :image_based_trick_play_settings,
  :manifest_compression,
  :manifest_duration_format,
  :min_final_segment_length,
  :min_segment_length,
  :output_selection,
  :program_date_time,
  :program_date_time_period,
  :progressive_write_hls_manifest,
  :segment_control,
  :segment_length,
  :segment_length_control,
  :segments_per_subdirectory,
  :stream_inf_resolution,
  :target_duration_compatibility_mode,
  :timed_metadata_id_3_frame,
  :timed_metadata_id_3_period,
  :timestamp_delta_milliseconds)
  SENSITIVE = []
  include Aws::Structure
end

#stream_inf_resolutionString

Include or exclude RESOLUTION attribute for video in EXT-X-STREAM-INF tag of variant manifest.

Returns:

  • (String)


6803
6804
6805
6806
6807
6808
6809
6810
6811
6812
6813
6814
6815
6816
6817
6818
6819
6820
6821
6822
6823
6824
6825
6826
6827
6828
6829
6830
6831
6832
6833
6834
6835
6836
6837
6838
# File 'lib/aws-sdk-mediaconvert/types.rb', line 6803

class HlsGroupSettings < Struct.new(
  :ad_markers,
  :additional_manifests,
  :audio_only_header,
  :base_url,
  :caption_language_mappings,
  :caption_language_setting,
  :caption_segment_length_control,
  :client_cache,
  :codec_specification,
  :destination,
  :destination_settings,
  :directory_structure,
  :encryption,
  :image_based_trick_play,
  :image_based_trick_play_settings,
  :manifest_compression,
  :manifest_duration_format,
  :min_final_segment_length,
  :min_segment_length,
  :output_selection,
  :program_date_time,
  :program_date_time_period,
  :progressive_write_hls_manifest,
  :segment_control,
  :segment_length,
  :segment_length_control,
  :segments_per_subdirectory,
  :stream_inf_resolution,
  :target_duration_compatibility_mode,
  :timed_metadata_id_3_frame,
  :timed_metadata_id_3_period,
  :timestamp_delta_milliseconds)
  SENSITIVE = []
  include Aws::Structure
end

#target_duration_compatibility_modeString

When set to LEGACY, the segment target duration is always rounded up to the nearest integer value above its current value in seconds. When set to SPEC\\_COMPLIANT, the segment target duration is rounded up to the nearest integer value if fraction seconds are greater than or equal to 0.5 (>= 0.5) and rounded down if less than 0.5 (< 0.5). You may need to use LEGACY if your client needs to ensure that the target duration is always longer than the actual duration of the segment. Some older players may experience interrupted playback when the actual duration of a track in a segment is longer than the target duration.

Returns:

  • (String)


6803
6804
6805
6806
6807
6808
6809
6810
6811
6812
6813
6814
6815
6816
6817
6818
6819
6820
6821
6822
6823
6824
6825
6826
6827
6828
6829
6830
6831
6832
6833
6834
6835
6836
6837
6838
# File 'lib/aws-sdk-mediaconvert/types.rb', line 6803

class HlsGroupSettings < Struct.new(
  :ad_markers,
  :additional_manifests,
  :audio_only_header,
  :base_url,
  :caption_language_mappings,
  :caption_language_setting,
  :caption_segment_length_control,
  :client_cache,
  :codec_specification,
  :destination,
  :destination_settings,
  :directory_structure,
  :encryption,
  :image_based_trick_play,
  :image_based_trick_play_settings,
  :manifest_compression,
  :manifest_duration_format,
  :min_final_segment_length,
  :min_segment_length,
  :output_selection,
  :program_date_time,
  :program_date_time_period,
  :progressive_write_hls_manifest,
  :segment_control,
  :segment_length,
  :segment_length_control,
  :segments_per_subdirectory,
  :stream_inf_resolution,
  :target_duration_compatibility_mode,
  :timed_metadata_id_3_frame,
  :timed_metadata_id_3_period,
  :timestamp_delta_milliseconds)
  SENSITIVE = []
  include Aws::Structure
end

#timed_metadata_id_3_frameString

Specify the type of the ID3 frame (timedMetadataId3Frame) to use for ID3 timestamps (timedMetadataId3Period) in your output. To include ID3 timestamps: Specify PRIV (PRIV) or TDRL (TDRL) and set ID3 metadata (timedMetadata) to Passthrough (PASSTHROUGH). To exclude ID3 timestamps: Set ID3 timestamp frame type to None (NONE).

Returns:

  • (String)


6803
6804
6805
6806
6807
6808
6809
6810
6811
6812
6813
6814
6815
6816
6817
6818
6819
6820
6821
6822
6823
6824
6825
6826
6827
6828
6829
6830
6831
6832
6833
6834
6835
6836
6837
6838
# File 'lib/aws-sdk-mediaconvert/types.rb', line 6803

class HlsGroupSettings < Struct.new(
  :ad_markers,
  :additional_manifests,
  :audio_only_header,
  :base_url,
  :caption_language_mappings,
  :caption_language_setting,
  :caption_segment_length_control,
  :client_cache,
  :codec_specification,
  :destination,
  :destination_settings,
  :directory_structure,
  :encryption,
  :image_based_trick_play,
  :image_based_trick_play_settings,
  :manifest_compression,
  :manifest_duration_format,
  :min_final_segment_length,
  :min_segment_length,
  :output_selection,
  :program_date_time,
  :program_date_time_period,
  :progressive_write_hls_manifest,
  :segment_control,
  :segment_length,
  :segment_length_control,
  :segments_per_subdirectory,
  :stream_inf_resolution,
  :target_duration_compatibility_mode,
  :timed_metadata_id_3_frame,
  :timed_metadata_id_3_period,
  :timestamp_delta_milliseconds)
  SENSITIVE = []
  include Aws::Structure
end

#timed_metadata_id_3_periodInteger

Specify the interval in seconds to write ID3 timestamps in your output. The first timestamp starts at the output timecode and date, and increases incrementally with each ID3 timestamp. To use the default interval of 10 seconds: Leave blank. To include this metadata in your output: Set ID3 timestamp frame type (timedMetadataId3Frame) to PRIV (PRIV) or TDRL (TDRL), and set ID3 metadata (timedMetadata) to Passthrough (PASSTHROUGH).

Returns:

  • (Integer)


6803
6804
6805
6806
6807
6808
6809
6810
6811
6812
6813
6814
6815
6816
6817
6818
6819
6820
6821
6822
6823
6824
6825
6826
6827
6828
6829
6830
6831
6832
6833
6834
6835
6836
6837
6838
# File 'lib/aws-sdk-mediaconvert/types.rb', line 6803

class HlsGroupSettings < Struct.new(
  :ad_markers,
  :additional_manifests,
  :audio_only_header,
  :base_url,
  :caption_language_mappings,
  :caption_language_setting,
  :caption_segment_length_control,
  :client_cache,
  :codec_specification,
  :destination,
  :destination_settings,
  :directory_structure,
  :encryption,
  :image_based_trick_play,
  :image_based_trick_play_settings,
  :manifest_compression,
  :manifest_duration_format,
  :min_final_segment_length,
  :min_segment_length,
  :output_selection,
  :program_date_time,
  :program_date_time_period,
  :progressive_write_hls_manifest,
  :segment_control,
  :segment_length,
  :segment_length_control,
  :segments_per_subdirectory,
  :stream_inf_resolution,
  :target_duration_compatibility_mode,
  :timed_metadata_id_3_frame,
  :timed_metadata_id_3_period,
  :timestamp_delta_milliseconds)
  SENSITIVE = []
  include Aws::Structure
end

#timestamp_delta_millisecondsInteger

Provides an extra millisecond delta offset to fine tune the timestamps.

Returns:

  • (Integer)


6803
6804
6805
6806
6807
6808
6809
6810
6811
6812
6813
6814
6815
6816
6817
6818
6819
6820
6821
6822
6823
6824
6825
6826
6827
6828
6829
6830
6831
6832
6833
6834
6835
6836
6837
6838
# File 'lib/aws-sdk-mediaconvert/types.rb', line 6803

class HlsGroupSettings < Struct.new(
  :ad_markers,
  :additional_manifests,
  :audio_only_header,
  :base_url,
  :caption_language_mappings,
  :caption_language_setting,
  :caption_segment_length_control,
  :client_cache,
  :codec_specification,
  :destination,
  :destination_settings,
  :directory_structure,
  :encryption,
  :image_based_trick_play,
  :image_based_trick_play_settings,
  :manifest_compression,
  :manifest_duration_format,
  :min_final_segment_length,
  :min_segment_length,
  :output_selection,
  :program_date_time,
  :program_date_time_period,
  :progressive_write_hls_manifest,
  :segment_control,
  :segment_length,
  :segment_length_control,
  :segments_per_subdirectory,
  :stream_inf_resolution,
  :target_duration_compatibility_mode,
  :timed_metadata_id_3_frame,
  :timed_metadata_id_3_period,
  :timestamp_delta_milliseconds)
  SENSITIVE = []
  include Aws::Structure
end