Class: Aws::MediaConvert::Types::HlsImageBasedTrickPlaySettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::HlsImageBasedTrickPlaySettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
When making an API call, you may pass HlsImageBasedTrickPlaySettings data as a hash:
{
interval_cadence: "FOLLOW_IFRAME", # accepts FOLLOW_IFRAME, FOLLOW_CUSTOM
thumbnail_height: 1,
thumbnail_interval: 1.0,
thumbnail_width: 1,
tile_height: 1,
tile_width: 1,
}
Tile and thumbnail settings applicable when imageBasedTrickPlay is ADVANCED
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#interval_cadence ⇒ String
The cadence MediaConvert follows for generating thumbnails.
-
#thumbnail_height ⇒ Integer
Height of each thumbnail within each tile image, in pixels.
-
#thumbnail_interval ⇒ Float
Enter the interval, in seconds, that MediaConvert uses to generate thumbnails.
-
#thumbnail_width ⇒ Integer
Width of each thumbnail within each tile image, in pixels.
-
#tile_height ⇒ Integer
Number of thumbnails in each column of a tile image.
-
#tile_width ⇒ Integer
Number of thumbnails in each row of a tile image.
Instance Attribute Details
#interval_cadence ⇒ String
The cadence MediaConvert follows for generating thumbnails. If set to FOLLOW_IFRAME, MediaConvert generates thumbnails for each IDR frame in the output (matching the GOP cadence). If set to FOLLOW_CUSTOM, MediaConvert generates thumbnails according to the interval you specify in thumbnailInterval.
11370 11371 11372 11373 11374 11375 11376 11377 11378 11379 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 11370 class HlsImageBasedTrickPlaySettings < Struct.new( :interval_cadence, :thumbnail_height, :thumbnail_interval, :thumbnail_width, :tile_height, :tile_width) SENSITIVE = [] include Aws::Structure end |
#thumbnail_height ⇒ Integer
Height of each thumbnail within each tile image, in pixels. Leave blank to maintain aspect ratio with thumbnail width. If following the aspect ratio would lead to a total tile height greater than 4096, then the job will be rejected. Must be divisible by 2.
11370 11371 11372 11373 11374 11375 11376 11377 11378 11379 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 11370 class HlsImageBasedTrickPlaySettings < Struct.new( :interval_cadence, :thumbnail_height, :thumbnail_interval, :thumbnail_width, :tile_height, :tile_width) SENSITIVE = [] include Aws::Structure end |
#thumbnail_interval ⇒ Float
Enter the interval, in seconds, that MediaConvert uses to generate thumbnails. If the interval you enter doesn't align with the output frame rate, MediaConvert automatically rounds the interval to align with the output frame rate. For example, if the output frame rate is 29.97 frames per second and you enter 5, MediaConvert uses a 150 frame interval to generate thumbnails.
11370 11371 11372 11373 11374 11375 11376 11377 11378 11379 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 11370 class HlsImageBasedTrickPlaySettings < Struct.new( :interval_cadence, :thumbnail_height, :thumbnail_interval, :thumbnail_width, :tile_height, :tile_width) SENSITIVE = [] include Aws::Structure end |
#thumbnail_width ⇒ Integer
Width of each thumbnail within each tile image, in pixels. Default is 312. Must be divisible by 8.
11370 11371 11372 11373 11374 11375 11376 11377 11378 11379 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 11370 class HlsImageBasedTrickPlaySettings < Struct.new( :interval_cadence, :thumbnail_height, :thumbnail_interval, :thumbnail_width, :tile_height, :tile_width) SENSITIVE = [] include Aws::Structure end |
#tile_height ⇒ Integer
Number of thumbnails in each column of a tile image. Set a value between 2 and 2048. Must be divisible by 2.
11370 11371 11372 11373 11374 11375 11376 11377 11378 11379 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 11370 class HlsImageBasedTrickPlaySettings < Struct.new( :interval_cadence, :thumbnail_height, :thumbnail_interval, :thumbnail_width, :tile_height, :tile_width) SENSITIVE = [] include Aws::Structure end |
#tile_width ⇒ Integer
Number of thumbnails in each row of a tile image. Set a value between 1 and 512.
11370 11371 11372 11373 11374 11375 11376 11377 11378 11379 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 11370 class HlsImageBasedTrickPlaySettings < Struct.new( :interval_cadence, :thumbnail_height, :thumbnail_interval, :thumbnail_width, :tile_height, :tile_width) SENSITIVE = [] include Aws::Structure end |