Class: Aws::MediaConvert::Types::HopDestination
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::HopDestination
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
Optional. Configuration for a destination queue to which the job can hop once a customer-defined minimum wait time has passed.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#priority ⇒ Integer
Optional.
-
#queue ⇒ String
Optional unless the job is submitted on the default queue.
-
#wait_minutes ⇒ Integer
Required for setting up a job to use queue hopping.
Instance Attribute Details
#priority ⇒ Integer
Optional. When you set up a job to use queue hopping, you can specify a different relative priority for the job in the destination queue. If you don’t specify, the relative priority will remain the same as in the previous queue.
8459 8460 8461 8462 8463 8464 8465 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 8459 class HopDestination < Struct.new( :priority, :queue, :wait_minutes) SENSITIVE = [] include Aws::Structure end |
#queue ⇒ String
Optional unless the job is submitted on the default queue. When you set up a job to use queue hopping, you can specify a destination queue. This queue cannot be the original queue to which the job is submitted. If the original queue isn’t the default queue and you don’t specify the destination queue, the job will move to the default queue.
8459 8460 8461 8462 8463 8464 8465 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 8459 class HopDestination < Struct.new( :priority, :queue, :wait_minutes) SENSITIVE = [] include Aws::Structure end |
#wait_minutes ⇒ Integer
Required for setting up a job to use queue hopping. Minimum wait time in minutes until the job can hop to the destination queue. Valid range is 1 to 4320 minutes, inclusive.
8459 8460 8461 8462 8463 8464 8465 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 8459 class HopDestination < Struct.new( :priority, :queue, :wait_minutes) SENSITIVE = [] include Aws::Structure end |