Class: Aws::MediaConvert::Types::Id3Insertion
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::Id3Insertion
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
To insert ID3 tags in your output, specify two values. Use ID3 tag to specify the base 64 encoded string and use Timecode to specify the time when the tag should be inserted. To insert multiple ID3 tags in your output, create multiple instances of ID3 insertion.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#id_3 ⇒ String
Use ID3 tag to provide a fully formed ID3 tag in base64-encode format.
-
#timecode ⇒ String
Provide a Timecode in HH:MM:SS:FF or HH:MM:SS;FF format.
Instance Attribute Details
#id_3 ⇒ String
Use ID3 tag to provide a fully formed ID3 tag in base64-encode format.
6944 6945 6946 6947 6948 6949 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 6944 class Id3Insertion < Struct.new( :id_3, :timecode) SENSITIVE = [] include Aws::Structure end |
#timecode ⇒ String
Provide a Timecode in HH:MM:SS:FF or HH:MM:SS;FF format.
6944 6945 6946 6947 6948 6949 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 6944 class Id3Insertion < Struct.new( :id_3, :timecode) SENSITIVE = [] include Aws::Structure end |