Class: Aws::MediaConvert::Types::ImageInserter
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::ImageInserter
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
Note:
When making an API call, you may pass ImageInserter data as a hash:
{
insertable_images: [
{
duration: 1,
fade_in: 1,
fade_out: 1,
height: 1,
image_inserter_input: "__stringMin14PatternS3BmpBMPPngPNGTgaTGAHttpsBmpBMPPngPNGTgaTGA",
image_x: 1,
image_y: 1,
layer: 1,
opacity: 1,
start_time: "__stringPattern01D20305D205D",
width: 1,
},
],
}
Use the image inserter feature to include a graphic overlay on your video. Enable or disable this feature for each input or output individually. For more information, see docs.aws.amazon.com/mediaconvert/latest/ug/graphic-overlay.html. This setting is disabled by default.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#insertable_images ⇒ Array<Types::InsertableImage>
Specify the images that you want to overlay on your video.
Instance Attribute Details
#insertable_images ⇒ Array<Types::InsertableImage>
Specify the images that you want to overlay on your video. The images must be PNG or TGA files.
11625 11626 11627 11628 11629 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 11625 class ImageInserter < Struct.new( :insertable_images) SENSITIVE = [] include Aws::Structure end |