Class: Aws::MediaConvert::Types::ImscDestinationSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::ImscDestinationSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
Settings related to IMSC captions. IMSC is a sidecar format that holds captions in a file that is separate from the video container. Set up sidecar captions in the same output group, but different output from your video. For more information, see docs.aws.amazon.com/mediaconvert/latest/ug/ttml-and-webvtt-output-captions.html. When you work directly in your JSON job specification, include this object and any required children when you set destinationType to IMSC.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#accessibility ⇒ String
If the IMSC captions track is intended to provide accessibility for people who are deaf or hard of hearing: Set Accessibility subtitles to Enabled.
-
#style_passthrough ⇒ String
Keep this setting enabled to have MediaConvert use the font style and position information from the captions source in the output.
Instance Attribute Details
#accessibility ⇒ String
If the IMSC captions track is intended to provide accessibility for people who are deaf or hard of hearing: Set Accessibility subtitles to Enabled. When you do, MediaConvert adds accessibility attributes to your output HLS or DASH manifest. For HLS manifests, MediaConvert adds the following accessibility attributes under EXT-X-MEDIA for this track: CHARACTERISTICS=“public.accessibility.describes-spoken-dialog,public.accessibility.describes-music-and-sound” and AUTOSELECT=“YES”. For DASH manifests, MediaConvert adds the following in the adaptation set for this track: <Accessibility schemeIdUri=“urn:mpeg:dash:role:2011” value=“caption” />
. If the captions track is not intended to provide such accessibility: Keep the default value, Disabled. When you do, for DASH manifests, MediaConvert instead adds the following in the adaptation set for this track: <Role schemeIDUri=“urn:mpeg:dash:role:2011” value=“subtitle” />
.
7134 7135 7136 7137 7138 7139 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 7134 class ImscDestinationSettings < Struct.new( :accessibility, :style_passthrough) SENSITIVE = [] include Aws::Structure end |
#style_passthrough ⇒ String
Keep this setting enabled to have MediaConvert use the font style and position information from the captions source in the output. This option is available only when your input captions are IMSC, SMPTE-TT, or TTML. Disable this setting for simplified output captions.
7134 7135 7136 7137 7138 7139 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 7134 class ImscDestinationSettings < Struct.new( :accessibility, :style_passthrough) SENSITIVE = [] include Aws::Structure end |