Class: Aws::MediaConvert::Types::InputVideoGenerator
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::InputVideoGenerator
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
When you include Video generator, MediaConvert creates a video input with black frames. Use this setting if you do not have a video input or if you want to add black video frames before, or after, other inputs. You can specify Video generator, or you can specify an Input file, but you cannot specify both. For more information, see docs.aws.amazon.com/mediaconvert/latest/ug/video-generator.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#channels ⇒ Integer
Specify the number of audio channels to include in your video generator input.
-
#duration ⇒ Integer
Specify the duration, in milliseconds, for your video generator input.
-
#framerate_denominator ⇒ Integer
Specify the denominator of the fraction that represents the frame rate for your video generator input.
-
#framerate_numerator ⇒ Integer
Specify the numerator of the fraction that represents the frame rate for your video generator input.
-
#height ⇒ Integer
Specify the height, in pixels, for your video generator input.
-
#image_input ⇒ String
Specify the HTTP, HTTPS, or Amazon S3 location of the image that you want to overlay on the video.
-
#sample_rate ⇒ Integer
Specify the audio sample rate, in Hz, for the silent audio in your video generator input.
-
#width ⇒ Integer
Specify the width, in pixels, for your video generator input.
Instance Attribute Details
#channels ⇒ Integer
Specify the number of audio channels to include in your video generator input. MediaConvert creates these audio channels as silent audio within a single audio track. Enter an integer from 1 to 32.
8788 8789 8790 8791 8792 8793 8794 8795 8796 8797 8798 8799 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 8788 class InputVideoGenerator < Struct.new( :channels, :duration, :framerate_denominator, :framerate_numerator, :height, :image_input, :sample_rate, :width) SENSITIVE = [] include Aws::Structure end |
#duration ⇒ Integer
Specify the duration, in milliseconds, for your video generator input. Enter an integer from 1 to 86400000.
8788 8789 8790 8791 8792 8793 8794 8795 8796 8797 8798 8799 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 8788 class InputVideoGenerator < Struct.new( :channels, :duration, :framerate_denominator, :framerate_numerator, :height, :image_input, :sample_rate, :width) SENSITIVE = [] include Aws::Structure end |
#framerate_denominator ⇒ Integer
Specify the denominator of the fraction that represents the frame rate for your video generator input. When you do, you must also specify a value for Frame rate numerator. MediaConvert uses a default frame rate of 29.97 when you leave Frame rate numerator and Frame rate denominator blank.
8788 8789 8790 8791 8792 8793 8794 8795 8796 8797 8798 8799 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 8788 class InputVideoGenerator < Struct.new( :channels, :duration, :framerate_denominator, :framerate_numerator, :height, :image_input, :sample_rate, :width) SENSITIVE = [] include Aws::Structure end |
#framerate_numerator ⇒ Integer
Specify the numerator of the fraction that represents the frame rate for your video generator input. When you do, you must also specify a value for Frame rate denominator. MediaConvert uses a default frame rate of 29.97 when you leave Frame rate numerator and Frame rate denominator blank.
8788 8789 8790 8791 8792 8793 8794 8795 8796 8797 8798 8799 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 8788 class InputVideoGenerator < Struct.new( :channels, :duration, :framerate_denominator, :framerate_numerator, :height, :image_input, :sample_rate, :width) SENSITIVE = [] include Aws::Structure end |
#height ⇒ Integer
Specify the height, in pixels, for your video generator input. This is useful for positioning when you include one or more video overlays for this input. To use the default resolution 540x360: Leave both width and height blank. To specify a height: Enter an even integer from 32 to 8192. When you do, you must also specify a value for width.
8788 8789 8790 8791 8792 8793 8794 8795 8796 8797 8798 8799 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 8788 class InputVideoGenerator < Struct.new( :channels, :duration, :framerate_denominator, :framerate_numerator, :height, :image_input, :sample_rate, :width) SENSITIVE = [] include Aws::Structure end |
#image_input ⇒ String
Specify the HTTP, HTTPS, or Amazon S3 location of the image that you want to overlay on the video. Use a PNG or TGA file.
8788 8789 8790 8791 8792 8793 8794 8795 8796 8797 8798 8799 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 8788 class InputVideoGenerator < Struct.new( :channels, :duration, :framerate_denominator, :framerate_numerator, :height, :image_input, :sample_rate, :width) SENSITIVE = [] include Aws::Structure end |
#sample_rate ⇒ Integer
Specify the audio sample rate, in Hz, for the silent audio in your video generator input. Enter an integer from 32000 to 48000.
8788 8789 8790 8791 8792 8793 8794 8795 8796 8797 8798 8799 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 8788 class InputVideoGenerator < Struct.new( :channels, :duration, :framerate_denominator, :framerate_numerator, :height, :image_input, :sample_rate, :width) SENSITIVE = [] include Aws::Structure end |
#width ⇒ Integer
Specify the width, in pixels, for your video generator input. This is useful for positioning when you include one or more video overlays for this input. To use the default resolution 540x360: Leave both width and height blank. To specify a width: Enter an even integer from 32 to 8192. When you do, you must also specify a value for height.
8788 8789 8790 8791 8792 8793 8794 8795 8796 8797 8798 8799 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 8788 class InputVideoGenerator < Struct.new( :channels, :duration, :framerate_denominator, :framerate_numerator, :height, :image_input, :sample_rate, :width) SENSITIVE = [] include Aws::Structure end |