Class: Aws::MediaConvert::Types::InsertableImage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediaconvert/types.rb

Overview

Note:

When making an API call, you may pass InsertableImage data as a hash:

{
  duration: 1,
  fade_in: 1,
  fade_out: 1,
  height: 1,
  image_inserter_input: "__stringMin14PatternS3BmpBMPPngPNGTgaTGAHttpsBmpBMPPngPNGTgaTGA",
  image_x: 1,
  image_y: 1,
  layer: 1,
  opacity: 1,
  start_time: "__stringPattern01D20305D205D",
  width: 1,
}

These settings apply to a specific graphic overlay. You can include multiple overlays in your job.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#durationInteger

Specify the time, in milliseconds, for the image to remain on the output video. This duration includes fade-in time but not fade-out time.

Returns:

  • (Integer)


12701
12702
12703
12704
12705
12706
12707
12708
12709
12710
12711
12712
12713
12714
12715
# File 'lib/aws-sdk-mediaconvert/types.rb', line 12701

class InsertableImage < Struct.new(
  :duration,
  :fade_in,
  :fade_out,
  :height,
  :image_inserter_input,
  :image_x,
  :image_y,
  :layer,
  :opacity,
  :start_time,
  :width)
  SENSITIVE = []
  include Aws::Structure
end

#fade_inInteger

Specify the length of time, in milliseconds, between the Start time that you specify for the image insertion and the time that the image appears at full opacity. Full opacity is the level that you specify for the opacity setting. If you don't specify a value for Fade-in, the image will appear abruptly at the overlay start time.

Returns:

  • (Integer)


12701
12702
12703
12704
12705
12706
12707
12708
12709
12710
12711
12712
12713
12714
12715
# File 'lib/aws-sdk-mediaconvert/types.rb', line 12701

class InsertableImage < Struct.new(
  :duration,
  :fade_in,
  :fade_out,
  :height,
  :image_inserter_input,
  :image_x,
  :image_y,
  :layer,
  :opacity,
  :start_time,
  :width)
  SENSITIVE = []
  include Aws::Structure
end

#fade_outInteger

Specify the length of time, in milliseconds, between the end of the time that you have specified for the image overlay Duration and when the overlaid image has faded to total transparency. If you don't specify a value for Fade-out, the image will disappear abruptly at the end of the inserted image duration.

Returns:

  • (Integer)


12701
12702
12703
12704
12705
12706
12707
12708
12709
12710
12711
12712
12713
12714
12715
# File 'lib/aws-sdk-mediaconvert/types.rb', line 12701

class InsertableImage < Struct.new(
  :duration,
  :fade_in,
  :fade_out,
  :height,
  :image_inserter_input,
  :image_x,
  :image_y,
  :layer,
  :opacity,
  :start_time,
  :width)
  SENSITIVE = []
  include Aws::Structure
end

#heightInteger

Specify the height of the inserted image in pixels. If you specify a value that's larger than the video resolution height, the service will crop your overlaid image to fit. To use the native height of the image, keep this setting blank.

Returns:

  • (Integer)


12701
12702
12703
12704
12705
12706
12707
12708
12709
12710
12711
12712
12713
12714
12715
# File 'lib/aws-sdk-mediaconvert/types.rb', line 12701

class InsertableImage < Struct.new(
  :duration,
  :fade_in,
  :fade_out,
  :height,
  :image_inserter_input,
  :image_x,
  :image_y,
  :layer,
  :opacity,
  :start_time,
  :width)
  SENSITIVE = []
  include Aws::Structure
end

#image_inserter_inputString

Specify the HTTP, HTTPS, or Amazon S3 location of the image that you want to overlay on the video. Use a PNG or TGA file.

Returns:

  • (String)


12701
12702
12703
12704
12705
12706
12707
12708
12709
12710
12711
12712
12713
12714
12715
# File 'lib/aws-sdk-mediaconvert/types.rb', line 12701

class InsertableImage < Struct.new(
  :duration,
  :fade_in,
  :fade_out,
  :height,
  :image_inserter_input,
  :image_x,
  :image_y,
  :layer,
  :opacity,
  :start_time,
  :width)
  SENSITIVE = []
  include Aws::Structure
end

#image_xInteger

Specify the distance, in pixels, between the inserted image and the left edge of the video frame. Required for any image overlay that you specify.

Returns:

  • (Integer)


12701
12702
12703
12704
12705
12706
12707
12708
12709
12710
12711
12712
12713
12714
12715
# File 'lib/aws-sdk-mediaconvert/types.rb', line 12701

class InsertableImage < Struct.new(
  :duration,
  :fade_in,
  :fade_out,
  :height,
  :image_inserter_input,
  :image_x,
  :image_y,
  :layer,
  :opacity,
  :start_time,
  :width)
  SENSITIVE = []
  include Aws::Structure
end

#image_yInteger

Specify the distance, in pixels, between the overlaid image and the top edge of the video frame. Required for any image overlay that you specify.

Returns:

  • (Integer)


12701
12702
12703
12704
12705
12706
12707
12708
12709
12710
12711
12712
12713
12714
12715
# File 'lib/aws-sdk-mediaconvert/types.rb', line 12701

class InsertableImage < Struct.new(
  :duration,
  :fade_in,
  :fade_out,
  :height,
  :image_inserter_input,
  :image_x,
  :image_y,
  :layer,
  :opacity,
  :start_time,
  :width)
  SENSITIVE = []
  include Aws::Structure
end

#layerInteger

Specify how overlapping inserted images appear. Images with higher values for Layer appear on top of images with lower values for Layer.

Returns:

  • (Integer)


12701
12702
12703
12704
12705
12706
12707
12708
12709
12710
12711
12712
12713
12714
12715
# File 'lib/aws-sdk-mediaconvert/types.rb', line 12701

class InsertableImage < Struct.new(
  :duration,
  :fade_in,
  :fade_out,
  :height,
  :image_inserter_input,
  :image_x,
  :image_y,
  :layer,
  :opacity,
  :start_time,
  :width)
  SENSITIVE = []
  include Aws::Structure
end

#opacityInteger

Use Opacity (Opacity) to specify how much of the underlying video shows through the inserted image. 0 is transparent and 100 is fully opaque. Default is 50.

Returns:

  • (Integer)


12701
12702
12703
12704
12705
12706
12707
12708
12709
12710
12711
12712
12713
12714
12715
# File 'lib/aws-sdk-mediaconvert/types.rb', line 12701

class InsertableImage < Struct.new(
  :duration,
  :fade_in,
  :fade_out,
  :height,
  :image_inserter_input,
  :image_x,
  :image_y,
  :layer,
  :opacity,
  :start_time,
  :width)
  SENSITIVE = []
  include Aws::Structure
end

#start_timeString

Specify the timecode of the frame that you want the overlay to first appear on. This must be in timecode (HH:MM:SS:FF or HH:MM:SS;FF) format. Remember to take into account your timecode source settings.

Returns:

  • (String)


12701
12702
12703
12704
12705
12706
12707
12708
12709
12710
12711
12712
12713
12714
12715
# File 'lib/aws-sdk-mediaconvert/types.rb', line 12701

class InsertableImage < Struct.new(
  :duration,
  :fade_in,
  :fade_out,
  :height,
  :image_inserter_input,
  :image_x,
  :image_y,
  :layer,
  :opacity,
  :start_time,
  :width)
  SENSITIVE = []
  include Aws::Structure
end

#widthInteger

Specify the width of the inserted image in pixels. If you specify a value that's larger than the video resolution width, the service will crop your overlaid image to fit. To use the native width of the image, keep this setting blank.

Returns:

  • (Integer)


12701
12702
12703
12704
12705
12706
12707
12708
12709
12710
12711
12712
12713
12714
12715
# File 'lib/aws-sdk-mediaconvert/types.rb', line 12701

class InsertableImage < Struct.new(
  :duration,
  :fade_in,
  :fade_out,
  :height,
  :image_inserter_input,
  :image_x,
  :image_y,
  :layer,
  :opacity,
  :start_time,
  :width)
  SENSITIVE = []
  include Aws::Structure
end