Class: Aws::MediaConvert::Types::JobEngineVersion

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediaconvert/types.rb

Overview

Use Job engine versions to run jobs for your production workflow on one version, while you test and validate the latest version. Job engine versions are in a YYYY-MM-DD format.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#expiration_dateTime

The date that this Job engine version expires. Requests to create jobs with an expired version result in a regular job, as if no specific Job engine version was requested.

Returns:

  • (Time)


9742
9743
9744
9745
9746
9747
# File 'lib/aws-sdk-mediaconvert/types.rb', line 9742

class JobEngineVersion < Struct.new(
  :expiration_date,
  :version)
  SENSITIVE = []
  include Aws::Structure
end

#versionString

Use Job engine versions to run jobs for your production workflow on one version, while you test and validate the latest version. Job engine versions represent periodically grouped MediaConvert releases with new features, updates, improvements, and fixes. Job engine versions are in a YYYY-MM-DD format. Note that the Job engine version feature is not publicly available at this time. To request access, contact AWS support.

Returns:

  • (String)


9742
9743
9744
9745
9746
9747
# File 'lib/aws-sdk-mediaconvert/types.rb', line 9742

class JobEngineVersion < Struct.new(
  :expiration_date,
  :version)
  SENSITIVE = []
  include Aws::Structure
end