Class: Aws::MediaConvert::Types::JobMessages
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::JobMessages
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
Provides messages from the service about jobs that you have already successfully submitted.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#info ⇒ Array<String>
List of messages that are informational only and don't indicate a problem with your job.
-
#warning ⇒ Array<String>
List of messages that warn about conditions that might cause your job not to run or to fail.
Instance Attribute Details
#info ⇒ Array<String>
List of messages that are informational only and don't indicate a problem with your job.
9747 9748 9749 9750 9751 9752 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 9747 class JobMessages < Struct.new( :info, :warning) SENSITIVE = [] include Aws::Structure end |
#warning ⇒ Array<String>
List of messages that warn about conditions that might cause your job not to run or to fail.
9747 9748 9749 9750 9751 9752 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 9747 class JobMessages < Struct.new( :info, :warning) SENSITIVE = [] include Aws::Structure end |