Class: Aws::MediaConvert::Types::JobTemplate

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediaconvert/types.rb

Overview

A job template is a pre-made set of encoding instructions that you can use to quickly create a job.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#acceleration_settingsTypes::AccelerationSettings

Accelerated transcoding can significantly speed up jobs with long, visually complex content.



8916
8917
8918
8919
8920
8921
8922
8923
8924
8925
8926
8927
8928
8929
8930
8931
8932
# File 'lib/aws-sdk-mediaconvert/types.rb', line 8916

class JobTemplate < Struct.new(
  :acceleration_settings,
  :arn,
  :category,
  :created_at,
  :description,
  :hop_destinations,
  :last_updated,
  :name,
  :priority,
  :queue,
  :settings,
  :status_update_interval,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#arnString

An identifier for this resource that is unique within all of AWS.

Returns:

  • (String)


8916
8917
8918
8919
8920
8921
8922
8923
8924
8925
8926
8927
8928
8929
8930
8931
8932
# File 'lib/aws-sdk-mediaconvert/types.rb', line 8916

class JobTemplate < Struct.new(
  :acceleration_settings,
  :arn,
  :category,
  :created_at,
  :description,
  :hop_destinations,
  :last_updated,
  :name,
  :priority,
  :queue,
  :settings,
  :status_update_interval,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#categoryString

An optional category you create to organize your job templates.

Returns:

  • (String)


8916
8917
8918
8919
8920
8921
8922
8923
8924
8925
8926
8927
8928
8929
8930
8931
8932
# File 'lib/aws-sdk-mediaconvert/types.rb', line 8916

class JobTemplate < Struct.new(
  :acceleration_settings,
  :arn,
  :category,
  :created_at,
  :description,
  :hop_destinations,
  :last_updated,
  :name,
  :priority,
  :queue,
  :settings,
  :status_update_interval,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The timestamp in epoch seconds for Job template creation.

Returns:

  • (Time)


8916
8917
8918
8919
8920
8921
8922
8923
8924
8925
8926
8927
8928
8929
8930
8931
8932
# File 'lib/aws-sdk-mediaconvert/types.rb', line 8916

class JobTemplate < Struct.new(
  :acceleration_settings,
  :arn,
  :category,
  :created_at,
  :description,
  :hop_destinations,
  :last_updated,
  :name,
  :priority,
  :queue,
  :settings,
  :status_update_interval,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

An optional description you create for each job template.

Returns:

  • (String)


8916
8917
8918
8919
8920
8921
8922
8923
8924
8925
8926
8927
8928
8929
8930
8931
8932
# File 'lib/aws-sdk-mediaconvert/types.rb', line 8916

class JobTemplate < Struct.new(
  :acceleration_settings,
  :arn,
  :category,
  :created_at,
  :description,
  :hop_destinations,
  :last_updated,
  :name,
  :priority,
  :queue,
  :settings,
  :status_update_interval,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#hop_destinationsArray<Types::HopDestination>

Optional list of hop destinations.

Returns:



8916
8917
8918
8919
8920
8921
8922
8923
8924
8925
8926
8927
8928
8929
8930
8931
8932
# File 'lib/aws-sdk-mediaconvert/types.rb', line 8916

class JobTemplate < Struct.new(
  :acceleration_settings,
  :arn,
  :category,
  :created_at,
  :description,
  :hop_destinations,
  :last_updated,
  :name,
  :priority,
  :queue,
  :settings,
  :status_update_interval,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#last_updatedTime

The timestamp in epoch seconds when the Job template was last updated.

Returns:

  • (Time)


8916
8917
8918
8919
8920
8921
8922
8923
8924
8925
8926
8927
8928
8929
8930
8931
8932
# File 'lib/aws-sdk-mediaconvert/types.rb', line 8916

class JobTemplate < Struct.new(
  :acceleration_settings,
  :arn,
  :category,
  :created_at,
  :description,
  :hop_destinations,
  :last_updated,
  :name,
  :priority,
  :queue,
  :settings,
  :status_update_interval,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

A name you create for each job template. Each name must be unique within your account.

Returns:

  • (String)


8916
8917
8918
8919
8920
8921
8922
8923
8924
8925
8926
8927
8928
8929
8930
8931
8932
# File 'lib/aws-sdk-mediaconvert/types.rb', line 8916

class JobTemplate < Struct.new(
  :acceleration_settings,
  :arn,
  :category,
  :created_at,
  :description,
  :hop_destinations,
  :last_updated,
  :name,
  :priority,
  :queue,
  :settings,
  :status_update_interval,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#priorityInteger

Relative priority on the job.

Returns:

  • (Integer)


8916
8917
8918
8919
8920
8921
8922
8923
8924
8925
8926
8927
8928
8929
8930
8931
8932
# File 'lib/aws-sdk-mediaconvert/types.rb', line 8916

class JobTemplate < Struct.new(
  :acceleration_settings,
  :arn,
  :category,
  :created_at,
  :description,
  :hop_destinations,
  :last_updated,
  :name,
  :priority,
  :queue,
  :settings,
  :status_update_interval,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#queueString

Optional. The queue that jobs created from this template are assigned to. If you don’t specify this, jobs will go to the default queue.

Returns:

  • (String)


8916
8917
8918
8919
8920
8921
8922
8923
8924
8925
8926
8927
8928
8929
8930
8931
8932
# File 'lib/aws-sdk-mediaconvert/types.rb', line 8916

class JobTemplate < Struct.new(
  :acceleration_settings,
  :arn,
  :category,
  :created_at,
  :description,
  :hop_destinations,
  :last_updated,
  :name,
  :priority,
  :queue,
  :settings,
  :status_update_interval,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#settingsTypes::JobTemplateSettings

JobTemplateSettings contains all the transcode settings saved in the template that will be applied to jobs created from it.



8916
8917
8918
8919
8920
8921
8922
8923
8924
8925
8926
8927
8928
8929
8930
8931
8932
# File 'lib/aws-sdk-mediaconvert/types.rb', line 8916

class JobTemplate < Struct.new(
  :acceleration_settings,
  :arn,
  :category,
  :created_at,
  :description,
  :hop_destinations,
  :last_updated,
  :name,
  :priority,
  :queue,
  :settings,
  :status_update_interval,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#status_update_intervalString

Specify how often MediaConvert sends STATUS_UPDATE events to Amazon CloudWatch Events. Set the interval, in seconds, between status updates. MediaConvert sends an update at this interval from the time the service begins processing your job to the time it completes the transcode or encounters an error.

Returns:

  • (String)


8916
8917
8918
8919
8920
8921
8922
8923
8924
8925
8926
8927
8928
8929
8930
8931
8932
# File 'lib/aws-sdk-mediaconvert/types.rb', line 8916

class JobTemplate < Struct.new(
  :acceleration_settings,
  :arn,
  :category,
  :created_at,
  :description,
  :hop_destinations,
  :last_updated,
  :name,
  :priority,
  :queue,
  :settings,
  :status_update_interval,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

A job template can be of two types: system or custom. System or built-in job templates can’t be modified or deleted by the user.

Returns:

  • (String)


8916
8917
8918
8919
8920
8921
8922
8923
8924
8925
8926
8927
8928
8929
8930
8931
8932
# File 'lib/aws-sdk-mediaconvert/types.rb', line 8916

class JobTemplate < Struct.new(
  :acceleration_settings,
  :arn,
  :category,
  :created_at,
  :description,
  :hop_destinations,
  :last_updated,
  :name,
  :priority,
  :queue,
  :settings,
  :status_update_interval,
  :type)
  SENSITIVE = []
  include Aws::Structure
end