Class: Aws::MediaConvert::Types::JobTemplateSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::JobTemplateSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
JobTemplateSettings contains all the transcode settings saved in the template that will be applied to jobs created from it.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#ad_avail_offset ⇒ Integer
When specified, this offset (in milliseconds) is added to the input Ad Avail PTS time.
-
#avail_blanking ⇒ Types::AvailBlanking
Settings for ad avail blanking.
-
#esam ⇒ Types::EsamSettings
Settings for Event Signaling And Messaging (ESAM).
-
#extended_data_services ⇒ Types::ExtendedDataServices
If your source content has EIA-608 Line 21 Data Services, enable this feature to specify what MediaConvert does with the Extended Data Services (XDS) packets.
-
#inputs ⇒ Array<Types::InputTemplate>
Use Inputs (inputs) to define the source file used in the transcode job.
-
#kantar_watermark ⇒ Types::KantarWatermarkSettings
Use these settings only when you use Kantar watermarking.
-
#motion_image_inserter ⇒ Types::MotionImageInserter
Overlay motion graphics on top of your video.
-
#nielsen_configuration ⇒ Types::NielsenConfiguration
Settings for your Nielsen configuration.
-
#nielsen_non_linear_watermark ⇒ Types::NielsenNonLinearWatermarkSettings
Ignore these settings unless you are using Nielsen non-linear watermarking.
-
#output_groups ⇒ Array<Types::OutputGroup>
(OutputGroups) contains one group of settings for each set of outputs that share a common package type.
-
#timecode_config ⇒ Types::TimecodeConfig
These settings control how the service handles timecodes throughout the job.
-
#timed_metadata_insertion ⇒ Types::TimedMetadataInsertion
Insert user-defined custom ID3 metadata (id3) at timecodes (timecode) that you specify.
Instance Attribute Details
#ad_avail_offset ⇒ Integer
When specified, this offset (in milliseconds) is added to the input Ad Avail PTS time.
8173 8174 8175 8176 8177 8178 8179 8180 8181 8182 8183 8184 8185 8186 8187 8188 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 8173 class JobTemplateSettings < Struct.new( :ad_avail_offset, :avail_blanking, :esam, :extended_data_services, :inputs, :kantar_watermark, :motion_image_inserter, :nielsen_configuration, :nielsen_non_linear_watermark, :output_groups, :timecode_config, :timed_metadata_insertion) SENSITIVE = [] include Aws::Structure end |
#avail_blanking ⇒ Types::AvailBlanking
Settings for ad avail blanking. Video can be blanked or overlaid with an image, and audio muted during SCTE-35 triggered ad avails.
8173 8174 8175 8176 8177 8178 8179 8180 8181 8182 8183 8184 8185 8186 8187 8188 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 8173 class JobTemplateSettings < Struct.new( :ad_avail_offset, :avail_blanking, :esam, :extended_data_services, :inputs, :kantar_watermark, :motion_image_inserter, :nielsen_configuration, :nielsen_non_linear_watermark, :output_groups, :timecode_config, :timed_metadata_insertion) SENSITIVE = [] include Aws::Structure end |
#esam ⇒ Types::EsamSettings
Settings for Event Signaling And Messaging (ESAM). If you don’t do ad insertion, you can ignore these settings.
8173 8174 8175 8176 8177 8178 8179 8180 8181 8182 8183 8184 8185 8186 8187 8188 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 8173 class JobTemplateSettings < Struct.new( :ad_avail_offset, :avail_blanking, :esam, :extended_data_services, :inputs, :kantar_watermark, :motion_image_inserter, :nielsen_configuration, :nielsen_non_linear_watermark, :output_groups, :timecode_config, :timed_metadata_insertion) SENSITIVE = [] include Aws::Structure end |
#extended_data_services ⇒ Types::ExtendedDataServices
If your source content has EIA-608 Line 21 Data Services, enable this feature to specify what MediaConvert does with the Extended Data Services (XDS) packets. You can choose to pass through XDS packets, or remove them from the output. For more information about XDS, see EIA-608 Line Data Services, section 9.5.1.5 05h Content Advisory.
8173 8174 8175 8176 8177 8178 8179 8180 8181 8182 8183 8184 8185 8186 8187 8188 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 8173 class JobTemplateSettings < Struct.new( :ad_avail_offset, :avail_blanking, :esam, :extended_data_services, :inputs, :kantar_watermark, :motion_image_inserter, :nielsen_configuration, :nielsen_non_linear_watermark, :output_groups, :timecode_config, :timed_metadata_insertion) SENSITIVE = [] include Aws::Structure end |
#inputs ⇒ Array<Types::InputTemplate>
Use Inputs (inputs) to define the source file used in the transcode job. There can only be one input in a job template. Using the API, you can include multiple inputs when referencing a job template.
8173 8174 8175 8176 8177 8178 8179 8180 8181 8182 8183 8184 8185 8186 8187 8188 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 8173 class JobTemplateSettings < Struct.new( :ad_avail_offset, :avail_blanking, :esam, :extended_data_services, :inputs, :kantar_watermark, :motion_image_inserter, :nielsen_configuration, :nielsen_non_linear_watermark, :output_groups, :timecode_config, :timed_metadata_insertion) SENSITIVE = [] include Aws::Structure end |
#kantar_watermark ⇒ Types::KantarWatermarkSettings
Use these settings only when you use Kantar watermarking. Specify the values that MediaConvert uses to generate and place Kantar watermarks in your output audio. These settings apply to every output in your job. In addition to specifying these values, you also need to store your Kantar credentials in AWS Secrets Manager. For more information, see docs.aws.amazon.com/mediaconvert/latest/ug/kantar-watermarking.html.
8173 8174 8175 8176 8177 8178 8179 8180 8181 8182 8183 8184 8185 8186 8187 8188 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 8173 class JobTemplateSettings < Struct.new( :ad_avail_offset, :avail_blanking, :esam, :extended_data_services, :inputs, :kantar_watermark, :motion_image_inserter, :nielsen_configuration, :nielsen_non_linear_watermark, :output_groups, :timecode_config, :timed_metadata_insertion) SENSITIVE = [] include Aws::Structure end |
#motion_image_inserter ⇒ Types::MotionImageInserter
Overlay motion graphics on top of your video. The motion graphics that you specify here appear on all outputs in all output groups. For more information, see docs.aws.amazon.com/mediaconvert/latest/ug/motion-graphic-overlay.html.
8173 8174 8175 8176 8177 8178 8179 8180 8181 8182 8183 8184 8185 8186 8187 8188 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 8173 class JobTemplateSettings < Struct.new( :ad_avail_offset, :avail_blanking, :esam, :extended_data_services, :inputs, :kantar_watermark, :motion_image_inserter, :nielsen_configuration, :nielsen_non_linear_watermark, :output_groups, :timecode_config, :timed_metadata_insertion) SENSITIVE = [] include Aws::Structure end |
#nielsen_configuration ⇒ Types::NielsenConfiguration
Settings for your Nielsen configuration. If you don’t do Nielsen measurement and analytics, ignore these settings. When you enable Nielsen configuration (nielsenConfiguration), MediaConvert enables PCM to ID3 tagging for all outputs in the job. To enable Nielsen configuration programmatically, include an instance of nielsenConfiguration in your JSON job specification. Even if you don’t include any children of nielsenConfiguration, you still enable the setting.
8173 8174 8175 8176 8177 8178 8179 8180 8181 8182 8183 8184 8185 8186 8187 8188 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 8173 class JobTemplateSettings < Struct.new( :ad_avail_offset, :avail_blanking, :esam, :extended_data_services, :inputs, :kantar_watermark, :motion_image_inserter, :nielsen_configuration, :nielsen_non_linear_watermark, :output_groups, :timecode_config, :timed_metadata_insertion) SENSITIVE = [] include Aws::Structure end |
#nielsen_non_linear_watermark ⇒ Types::NielsenNonLinearWatermarkSettings
Ignore these settings unless you are using Nielsen non-linear watermarking. Specify the values that MediaConvert uses to generate and place Nielsen watermarks in your output audio. In addition to specifying these values, you also need to set up your cloud TIC server. These settings apply to every output in your job. The MediaConvert implementation is currently with the following Nielsen versions: Nielsen Watermark SDK Version 5.2.1 Nielsen NLM Watermark Engine Version 1.2.7 Nielsen Watermark Authenticator [SID_TIC] Version [5.0.0]
8173 8174 8175 8176 8177 8178 8179 8180 8181 8182 8183 8184 8185 8186 8187 8188 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 8173 class JobTemplateSettings < Struct.new( :ad_avail_offset, :avail_blanking, :esam, :extended_data_services, :inputs, :kantar_watermark, :motion_image_inserter, :nielsen_configuration, :nielsen_non_linear_watermark, :output_groups, :timecode_config, :timed_metadata_insertion) SENSITIVE = [] include Aws::Structure end |
#output_groups ⇒ Array<Types::OutputGroup>
(OutputGroups) contains one group of settings for each set of outputs that share a common package type. All unpackaged files (MPEG-4, MPEG-2 TS, Quicktime, MXF, and no container) are grouped in a single output group as well. Required in (OutputGroups) is a group of settings that apply to the whole group. This required object depends on the value you set for (Type) under (OutputGroups)>(OutputGroupSettings). Type, settings object pairs are as follows. * FILE_GROUP_SETTINGS, FileGroupSettings * HLS_GROUP_SETTINGS, HlsGroupSettings * DASH_ISO_GROUP_SETTINGS, DashIsoGroupSettings * MS_SMOOTH_GROUP_SETTINGS, MsSmoothGroupSettings * CMAF_GROUP_SETTINGS, CmafGroupSettings
8173 8174 8175 8176 8177 8178 8179 8180 8181 8182 8183 8184 8185 8186 8187 8188 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 8173 class JobTemplateSettings < Struct.new( :ad_avail_offset, :avail_blanking, :esam, :extended_data_services, :inputs, :kantar_watermark, :motion_image_inserter, :nielsen_configuration, :nielsen_non_linear_watermark, :output_groups, :timecode_config, :timed_metadata_insertion) SENSITIVE = [] include Aws::Structure end |
#timecode_config ⇒ Types::TimecodeConfig
These settings control how the service handles timecodes throughout the job. These settings don’t affect input clipping.
8173 8174 8175 8176 8177 8178 8179 8180 8181 8182 8183 8184 8185 8186 8187 8188 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 8173 class JobTemplateSettings < Struct.new( :ad_avail_offset, :avail_blanking, :esam, :extended_data_services, :inputs, :kantar_watermark, :motion_image_inserter, :nielsen_configuration, :nielsen_non_linear_watermark, :output_groups, :timecode_config, :timed_metadata_insertion) SENSITIVE = [] include Aws::Structure end |
#timed_metadata_insertion ⇒ Types::TimedMetadataInsertion
Insert user-defined custom ID3 metadata (id3) at timecodes (timecode) that you specify. In each output that you want to include this metadata, you must set ID3 metadata (timedMetadata) to Passthrough (PASSTHROUGH).
8173 8174 8175 8176 8177 8178 8179 8180 8181 8182 8183 8184 8185 8186 8187 8188 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 8173 class JobTemplateSettings < Struct.new( :ad_avail_offset, :avail_blanking, :esam, :extended_data_services, :inputs, :kantar_watermark, :motion_image_inserter, :nielsen_configuration, :nielsen_non_linear_watermark, :output_groups, :timecode_config, :timed_metadata_insertion) SENSITIVE = [] include Aws::Structure end |