Class: Aws::MediaConvert::Types::KantarWatermarkSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::KantarWatermarkSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
When making an API call, you may pass KantarWatermarkSettings data as a hash:
{
channel_name: "__stringMin1Max20",
content_reference: "__stringMin1Max50PatternAZAZ09",
credentials_secret_name: "__stringMin1Max512PatternAZAZ09",
file_offset: 1.0,
kantar_license_id: 1,
kantar_server_url: "__stringPatternHttpsKantarmediaCom",
log_destination: "__stringPatternS3",
metadata_3: "__stringMin1Max50",
metadata_4: "__stringMin1Max50",
metadata_5: "__stringMin1Max50",
metadata_6: "__stringMin1Max50",
metadata_7: "__stringMin1Max50",
metadata_8: "__stringMin1Max50",
}
Use these settings only when you use Kantar watermarking. Specify the values that MediaConvert uses to generate and place Kantar watermarks in your output audio. These settings apply to every output in your job. In addition to specifying these values, you also need to store your Kantar credentials in AWS Secrets Manager. For more information, see docs.aws.amazon.com/mediaconvert/latest/ug/kantar-watermarking.html.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#channel_name ⇒ String
Provide an audio channel name from your Kantar audio license.
-
#content_reference ⇒ String
Specify a unique identifier for Kantar to use for this piece of content.
-
#credentials_secret_name ⇒ String
Provide the name of the AWS Secrets Manager secret where your Kantar credentials are stored.
-
#file_offset ⇒ Float
Optional.
-
#kantar_license_id ⇒ Integer
Provide your Kantar license ID number.
-
#kantar_server_url ⇒ String
Provide the HTTPS endpoint to the Kantar server.
-
#log_destination ⇒ String
Optional.
-
#metadata_3 ⇒ String
You can optionally use this field to specify the first timestamp that Kantar embeds during watermarking.
-
#metadata_4 ⇒ String
Additional metadata that MediaConvert sends to Kantar.
-
#metadata_5 ⇒ String
Additional metadata that MediaConvert sends to Kantar.
-
#metadata_6 ⇒ String
Additional metadata that MediaConvert sends to Kantar.
-
#metadata_7 ⇒ String
Additional metadata that MediaConvert sends to Kantar.
-
#metadata_8 ⇒ String
Additional metadata that MediaConvert sends to Kantar.
Instance Attribute Details
#channel_name ⇒ String
Provide an audio channel name from your Kantar audio license.
15762 15763 15764 15765 15766 15767 15768 15769 15770 15771 15772 15773 15774 15775 15776 15777 15778 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 15762 class KantarWatermarkSettings < Struct.new( :channel_name, :content_reference, :credentials_secret_name, :file_offset, :kantar_license_id, :kantar_server_url, :log_destination, :metadata_3, :metadata_4, :metadata_5, :metadata_6, :metadata_7, :metadata_8) SENSITIVE = [] include Aws::Structure end |
#content_reference ⇒ String
Specify a unique identifier for Kantar to use for this piece of content.
15762 15763 15764 15765 15766 15767 15768 15769 15770 15771 15772 15773 15774 15775 15776 15777 15778 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 15762 class KantarWatermarkSettings < Struct.new( :channel_name, :content_reference, :credentials_secret_name, :file_offset, :kantar_license_id, :kantar_server_url, :log_destination, :metadata_3, :metadata_4, :metadata_5, :metadata_6, :metadata_7, :metadata_8) SENSITIVE = [] include Aws::Structure end |
#credentials_secret_name ⇒ String
Provide the name of the AWS Secrets Manager secret where your Kantar credentials are stored. Note that your MediaConvert service role must provide access to this secret. For more information, see docs.aws.amazon.com/mediaconvert/latest/ug/granting-permissions-for-mediaconvert-to-access-secrets-manager-secret.html. For instructions on creating a secret, see docs.aws.amazon.com/secretsmanager/latest/userguide/tutorials_basic.html, in the AWS Secrets Manager User Guide.
15762 15763 15764 15765 15766 15767 15768 15769 15770 15771 15772 15773 15774 15775 15776 15777 15778 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 15762 class KantarWatermarkSettings < Struct.new( :channel_name, :content_reference, :credentials_secret_name, :file_offset, :kantar_license_id, :kantar_server_url, :log_destination, :metadata_3, :metadata_4, :metadata_5, :metadata_6, :metadata_7, :metadata_8) SENSITIVE = [] include Aws::Structure end |
#file_offset ⇒ Float
Optional. Specify an offset, in whole seconds, from the start of your output and the beginning of the watermarking. When you don't specify an offset, Kantar defaults to zero.
15762 15763 15764 15765 15766 15767 15768 15769 15770 15771 15772 15773 15774 15775 15776 15777 15778 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 15762 class KantarWatermarkSettings < Struct.new( :channel_name, :content_reference, :credentials_secret_name, :file_offset, :kantar_license_id, :kantar_server_url, :log_destination, :metadata_3, :metadata_4, :metadata_5, :metadata_6, :metadata_7, :metadata_8) SENSITIVE = [] include Aws::Structure end |
#kantar_license_id ⇒ Integer
Provide your Kantar license ID number. You should get this number from Kantar.
15762 15763 15764 15765 15766 15767 15768 15769 15770 15771 15772 15773 15774 15775 15776 15777 15778 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 15762 class KantarWatermarkSettings < Struct.new( :channel_name, :content_reference, :credentials_secret_name, :file_offset, :kantar_license_id, :kantar_server_url, :log_destination, :metadata_3, :metadata_4, :metadata_5, :metadata_6, :metadata_7, :metadata_8) SENSITIVE = [] include Aws::Structure end |
#kantar_server_url ⇒ String
Provide the HTTPS endpoint to the Kantar server. You should get this endpoint from Kantar.
15762 15763 15764 15765 15766 15767 15768 15769 15770 15771 15772 15773 15774 15775 15776 15777 15778 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 15762 class KantarWatermarkSettings < Struct.new( :channel_name, :content_reference, :credentials_secret_name, :file_offset, :kantar_license_id, :kantar_server_url, :log_destination, :metadata_3, :metadata_4, :metadata_5, :metadata_6, :metadata_7, :metadata_8) SENSITIVE = [] include Aws::Structure end |
#log_destination ⇒ String
Optional. Specify the Amazon S3 bucket where you want MediaConvert to store your Kantar watermark XML logs. When you don't specify a bucket, MediaConvert doesn't save these logs. Note that your MediaConvert service role must provide access to this location. For more information, see docs.aws.amazon.com/mediaconvert/latest/ug/iam-role.html
15762 15763 15764 15765 15766 15767 15768 15769 15770 15771 15772 15773 15774 15775 15776 15777 15778 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 15762 class KantarWatermarkSettings < Struct.new( :channel_name, :content_reference, :credentials_secret_name, :file_offset, :kantar_license_id, :kantar_server_url, :log_destination, :metadata_3, :metadata_4, :metadata_5, :metadata_6, :metadata_7, :metadata_8) SENSITIVE = [] include Aws::Structure end |
#metadata_3 ⇒ String
You can optionally use this field to specify the first timestamp that Kantar embeds during watermarking. Kantar suggests that you be very cautious when using this Kantar feature, and that you use it only on channels that are managed specifically for use with this feature by your Audience Measurement Operator. For more information about this feature, contact Kantar technical support.
15762 15763 15764 15765 15766 15767 15768 15769 15770 15771 15772 15773 15774 15775 15776 15777 15778 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 15762 class KantarWatermarkSettings < Struct.new( :channel_name, :content_reference, :credentials_secret_name, :file_offset, :kantar_license_id, :kantar_server_url, :log_destination, :metadata_3, :metadata_4, :metadata_5, :metadata_6, :metadata_7, :metadata_8) SENSITIVE = [] include Aws::Structure end |
#metadata_4 ⇒ String
Additional metadata that MediaConvert sends to Kantar. Maximum length is 50 characters.
15762 15763 15764 15765 15766 15767 15768 15769 15770 15771 15772 15773 15774 15775 15776 15777 15778 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 15762 class KantarWatermarkSettings < Struct.new( :channel_name, :content_reference, :credentials_secret_name, :file_offset, :kantar_license_id, :kantar_server_url, :log_destination, :metadata_3, :metadata_4, :metadata_5, :metadata_6, :metadata_7, :metadata_8) SENSITIVE = [] include Aws::Structure end |
#metadata_5 ⇒ String
Additional metadata that MediaConvert sends to Kantar. Maximum length is 50 characters.
15762 15763 15764 15765 15766 15767 15768 15769 15770 15771 15772 15773 15774 15775 15776 15777 15778 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 15762 class KantarWatermarkSettings < Struct.new( :channel_name, :content_reference, :credentials_secret_name, :file_offset, :kantar_license_id, :kantar_server_url, :log_destination, :metadata_3, :metadata_4, :metadata_5, :metadata_6, :metadata_7, :metadata_8) SENSITIVE = [] include Aws::Structure end |
#metadata_6 ⇒ String
Additional metadata that MediaConvert sends to Kantar. Maximum length is 50 characters.
15762 15763 15764 15765 15766 15767 15768 15769 15770 15771 15772 15773 15774 15775 15776 15777 15778 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 15762 class KantarWatermarkSettings < Struct.new( :channel_name, :content_reference, :credentials_secret_name, :file_offset, :kantar_license_id, :kantar_server_url, :log_destination, :metadata_3, :metadata_4, :metadata_5, :metadata_6, :metadata_7, :metadata_8) SENSITIVE = [] include Aws::Structure end |
#metadata_7 ⇒ String
Additional metadata that MediaConvert sends to Kantar. Maximum length is 50 characters.
15762 15763 15764 15765 15766 15767 15768 15769 15770 15771 15772 15773 15774 15775 15776 15777 15778 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 15762 class KantarWatermarkSettings < Struct.new( :channel_name, :content_reference, :credentials_secret_name, :file_offset, :kantar_license_id, :kantar_server_url, :log_destination, :metadata_3, :metadata_4, :metadata_5, :metadata_6, :metadata_7, :metadata_8) SENSITIVE = [] include Aws::Structure end |
#metadata_8 ⇒ String
Additional metadata that MediaConvert sends to Kantar. Maximum length is 50 characters.
15762 15763 15764 15765 15766 15767 15768 15769 15770 15771 15772 15773 15774 15775 15776 15777 15778 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 15762 class KantarWatermarkSettings < Struct.new( :channel_name, :content_reference, :credentials_secret_name, :file_offset, :kantar_license_id, :kantar_server_url, :log_destination, :metadata_3, :metadata_4, :metadata_5, :metadata_6, :metadata_7, :metadata_8) SENSITIVE = [] include Aws::Structure end |