Class: Aws::MediaConvert::Types::ListJobTemplatesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediaconvert/types.rb

Overview

You can send list job templates requests with an empty body. Optionally, you can filter the response by category by specifying it in your request body. You can also optionally specify the maximum number, up to twenty, of job templates to be returned.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#categoryString

Optionally, specify a job template category to limit responses to only job templates from that category.

Returns:



9713
9714
9715
9716
9717
9718
9719
9720
9721
# File 'lib/aws-sdk-mediaconvert/types.rb', line 9713

class ListJobTemplatesRequest < Struct.new(
  :category,
  :list_by,
  :max_results,
  :next_token,
  :order)
  SENSITIVE = []
  include Aws::Structure
end

#list_byString

Optional. When you request a list of job templates, you can choose to list them alphabetically by NAME or chronologically by CREATION_DATE. If you don’t specify, the service will list them by name.

Returns:



9713
9714
9715
9716
9717
9718
9719
9720
9721
# File 'lib/aws-sdk-mediaconvert/types.rb', line 9713

class ListJobTemplatesRequest < Struct.new(
  :category,
  :list_by,
  :max_results,
  :next_token,
  :order)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

Optional. Number of job templates, up to twenty, that will be returned at one time.

Returns:



9713
9714
9715
9716
9717
9718
9719
9720
9721
# File 'lib/aws-sdk-mediaconvert/types.rb', line 9713

class ListJobTemplatesRequest < Struct.new(
  :category,
  :list_by,
  :max_results,
  :next_token,
  :order)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

Use this string, provided with the response to a previous request, to request the next batch of job templates.

Returns:



9713
9714
9715
9716
9717
9718
9719
9720
9721
# File 'lib/aws-sdk-mediaconvert/types.rb', line 9713

class ListJobTemplatesRequest < Struct.new(
  :category,
  :list_by,
  :max_results,
  :next_token,
  :order)
  SENSITIVE = []
  include Aws::Structure
end

#orderString

Optional. When you request lists of resources, you can specify whether they are sorted in ASCENDING or DESCENDING order. Default varies by resource.

Returns:



9713
9714
9715
9716
9717
9718
9719
9720
9721
# File 'lib/aws-sdk-mediaconvert/types.rb', line 9713

class ListJobTemplatesRequest < Struct.new(
  :category,
  :list_by,
  :max_results,
  :next_token,
  :order)
  SENSITIVE = []
  include Aws::Structure
end