Class: Aws::MediaConvert::Types::ListJobsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::ListJobsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
You can send list jobs requests with an empty body. Optionally, you can filter the response by queue and/or job status by specifying them in your request body. You can also optionally specify the maximum number, up to twenty, of jobs to be returned.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
Optional.
-
#next_token ⇒ String
Optional.
-
#order ⇒ String
Optional.
-
#queue ⇒ String
Optional.
-
#status ⇒ String
Optional.
Instance Attribute Details
#max_results ⇒ Integer
Optional. Number of jobs, up to twenty, that will be returned at one time.
10509 10510 10511 10512 10513 10514 10515 10516 10517 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 10509 class ListJobsRequest < Struct.new( :max_results, :next_token, :order, :queue, :status) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
Optional. Use this string, provided with the response to a previous request, to request the next batch of jobs.
10509 10510 10511 10512 10513 10514 10515 10516 10517 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 10509 class ListJobsRequest < Struct.new( :max_results, :next_token, :order, :queue, :status) SENSITIVE = [] include Aws::Structure end |
#order ⇒ String
Optional. When you request lists of resources, you can specify whether they are sorted in ASCENDING or DESCENDING order. Default varies by resource.
10509 10510 10511 10512 10513 10514 10515 10516 10517 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 10509 class ListJobsRequest < Struct.new( :max_results, :next_token, :order, :queue, :status) SENSITIVE = [] include Aws::Structure end |
#queue ⇒ String
Optional. Provide a queue name to get back only jobs from that queue.
10509 10510 10511 10512 10513 10514 10515 10516 10517 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 10509 class ListJobsRequest < Struct.new( :max_results, :next_token, :order, :queue, :status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
Optional. A job's status can be SUBMITTED, PROGRESSING, COMPLETE, CANCELED, or ERROR.
10509 10510 10511 10512 10513 10514 10515 10516 10517 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 10509 class ListJobsRequest < Struct.new( :max_results, :next_token, :order, :queue, :status) SENSITIVE = [] include Aws::Structure end |