Class: Aws::MediaConvert::Types::M2tsScte35Esam
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::M2tsScte35Esam
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
Settings for SCTE-35 signals from ESAM. Include this in your job settings to put SCTE-35 markers in your HLS and transport stream outputs at the insertion points that you specify in an ESAM XML document. Provide the document in the setting SCC XML.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#scte_35_esam_pid ⇒ Integer
Packet Identifier (PID) of the SCTE-35 stream in the transport stream generated by ESAM.
Instance Attribute Details
#scte_35_esam_pid ⇒ Integer
Packet Identifier (PID) of the SCTE-35 stream in the transport stream generated by ESAM.
8563 8564 8565 8566 8567 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 8563 class M2tsScte35Esam < Struct.new( :scte_35_esam_pid) SENSITIVE = [] include Aws::Structure end |