Class: Aws::MediaConvert::Types::MotionImageInsertionOffset
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::MotionImageInsertionOffset
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
Note:
When making an API call, you may pass MotionImageInsertionOffset data as a hash:
{
image_x: 1,
image_y: 1,
}
Specify the offset between the upper-left corner of the video frame and the top left corner of the overlay.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#image_x ⇒ Integer
Set the distance, in pixels, between the overlay and the left edge of the video frame.
-
#image_y ⇒ Integer
Set the distance, in pixels, between the overlay and the top edge of the video frame.
Instance Attribute Details
#image_x ⇒ Integer
Set the distance, in pixels, between the overlay and the left edge of the video frame.
16964 16965 16966 16967 16968 16969 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 16964 class MotionImageInsertionOffset < Struct.new( :image_x, :image_y) SENSITIVE = [] include Aws::Structure end |
#image_y ⇒ Integer
Set the distance, in pixels, between the overlay and the top edge of the video frame.
16964 16965 16966 16967 16968 16969 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 16964 class MotionImageInsertionOffset < Struct.new( :image_x, :image_y) SENSITIVE = [] include Aws::Structure end |