Class: Aws::MediaConvert::Types::Mp2Settings

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediaconvert/types.rb

Overview

Required when you set Codec to the value MP2.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#audio_description_mixString

Choose BROADCASTER_MIXED_AD when the input contains pre-mixed main audio + audio description (AD) as a stereo pair. The value for AudioType will be set to 3, which signals to downstream systems that this stream contains "broadcaster mixed AD". Note that the input received by the encoder must contain pre-mixed audio; the encoder does not perform the mixing. When you choose BROADCASTER_MIXED_AD, the encoder ignores any values you provide in AudioType and FollowInputAudioType. Choose NONE when the input does not contain pre-mixed audio + audio description (AD). In this case, the encoder will use any values you provide for AudioType and FollowInputAudioType.

Returns:

  • (String)


11503
11504
11505
11506
11507
11508
11509
11510
# File 'lib/aws-sdk-mediaconvert/types.rb', line 11503

class Mp2Settings < Struct.new(
  :audio_description_mix,
  :bitrate,
  :channels,
  :sample_rate)
  SENSITIVE = []
  include Aws::Structure
end

#bitrateInteger

Specify the average bitrate in bits per second.

Returns:

  • (Integer)


11503
11504
11505
11506
11507
11508
11509
11510
# File 'lib/aws-sdk-mediaconvert/types.rb', line 11503

class Mp2Settings < Struct.new(
  :audio_description_mix,
  :bitrate,
  :channels,
  :sample_rate)
  SENSITIVE = []
  include Aws::Structure
end

#channelsInteger

Set Channels to specify the number of channels in this output audio track. Choosing Follow input will use the number of channels found in the audio source; choosing Mono will give you 1 output channel; choosing Stereo will give you 2. In the API, valid values are 0, 1, and 2.

Returns:

  • (Integer)


11503
11504
11505
11506
11507
11508
11509
11510
# File 'lib/aws-sdk-mediaconvert/types.rb', line 11503

class Mp2Settings < Struct.new(
  :audio_description_mix,
  :bitrate,
  :channels,
  :sample_rate)
  SENSITIVE = []
  include Aws::Structure
end

#sample_rateInteger

Sample rate in Hz.

Returns:

  • (Integer)


11503
11504
11505
11506
11507
11508
11509
11510
# File 'lib/aws-sdk-mediaconvert/types.rb', line 11503

class Mp2Settings < Struct.new(
  :audio_description_mix,
  :bitrate,
  :channels,
  :sample_rate)
  SENSITIVE = []
  include Aws::Structure
end