Class: Aws::MediaConvert::Types::Mp4Settings

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediaconvert/types.rb

Overview

These settings relate to your MP4 output container. You can create audio only outputs with this container. For more information, see docs.aws.amazon.com/mediaconvert/latest/ug/supported-codecs-containers-audio-only.html#output-codecs-and-containers-supported-for-audio-only.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#audio_durationString

Specify this setting only when your output will be consumed by a downstream repackaging workflow that is sensitive to very small duration differences between video and audio. For this situation, choose Match video duration (MATCH_VIDEO_DURATION). In all other cases, keep the default value, Default codec duration (DEFAULT_CODEC_DURATION). When you choose Match video duration, MediaConvert pads the output audio streams with silence or trims them to ensure that the total duration of each audio stream is at least as long as the total duration of the video stream. After padding or trimming, the audio stream duration is no more than one frame longer than the video stream. MediaConvert applies audio padding or trimming only to the end of the last segment of the output. For unsegmented outputs, MediaConvert adds padding only to the end of the file. When you keep the default value, any minor discrepancies between audio and video duration will depend on your output audio codec.

Returns:

  • (String)


9601
9602
9603
9604
9605
9606
9607
9608
9609
9610
# File 'lib/aws-sdk-mediaconvert/types.rb', line 9601

class Mp4Settings < Struct.new(
  :audio_duration,
  :cslg_atom,
  :ctts_version,
  :free_space_box,
  :moov_placement,
  :mp_4_major_brand)
  SENSITIVE = []
  include Aws::Structure
end

#cslg_atomString

When enabled, file composition times will start at zero, composition times in the ‘ctts’ (composition time to sample) box for B-frames will be negative, and a ‘cslg’ (composition shift least greatest) box will be included per 14496-1 amendment 1. This improves compatibility with Apple players and tools.

Returns:

  • (String)


9601
9602
9603
9604
9605
9606
9607
9608
9609
9610
# File 'lib/aws-sdk-mediaconvert/types.rb', line 9601

class Mp4Settings < Struct.new(
  :audio_duration,
  :cslg_atom,
  :ctts_version,
  :free_space_box,
  :moov_placement,
  :mp_4_major_brand)
  SENSITIVE = []
  include Aws::Structure
end

#ctts_versionInteger

Ignore this setting unless compliance to the CTTS box version specification matters in your workflow. Specify a value of 1 to set your CTTS box version to 1 and make your output compliant with the specification. When you specify a value of 1, you must also set CSLG atom (cslgAtom) to the value INCLUDE. Keep the default value 0 to set your CTTS box version to 0. This can provide backward compatibility for some players and packagers.

Returns:

  • (Integer)


9601
9602
9603
9604
9605
9606
9607
9608
9609
9610
# File 'lib/aws-sdk-mediaconvert/types.rb', line 9601

class Mp4Settings < Struct.new(
  :audio_duration,
  :cslg_atom,
  :ctts_version,
  :free_space_box,
  :moov_placement,
  :mp_4_major_brand)
  SENSITIVE = []
  include Aws::Structure
end

#free_space_boxString

Inserts a free-space box immediately after the moov box.

Returns:

  • (String)


9601
9602
9603
9604
9605
9606
9607
9608
9609
9610
# File 'lib/aws-sdk-mediaconvert/types.rb', line 9601

class Mp4Settings < Struct.new(
  :audio_duration,
  :cslg_atom,
  :ctts_version,
  :free_space_box,
  :moov_placement,
  :mp_4_major_brand)
  SENSITIVE = []
  include Aws::Structure
end

#moov_placementString

If set to PROGRESSIVE_DOWNLOAD, the MOOV atom is relocated to the beginning of the archive as required for progressive downloading. Otherwise it is placed normally at the end.

Returns:

  • (String)


9601
9602
9603
9604
9605
9606
9607
9608
9609
9610
# File 'lib/aws-sdk-mediaconvert/types.rb', line 9601

class Mp4Settings < Struct.new(
  :audio_duration,
  :cslg_atom,
  :ctts_version,
  :free_space_box,
  :moov_placement,
  :mp_4_major_brand)
  SENSITIVE = []
  include Aws::Structure
end

#mp_4_major_brandString

Overrides the “Major Brand” field in the output file. Usually not necessary to specify.

Returns:

  • (String)


9601
9602
9603
9604
9605
9606
9607
9608
9609
9610
# File 'lib/aws-sdk-mediaconvert/types.rb', line 9601

class Mp4Settings < Struct.new(
  :audio_duration,
  :cslg_atom,
  :ctts_version,
  :free_space_box,
  :moov_placement,
  :mp_4_major_brand)
  SENSITIVE = []
  include Aws::Structure
end