Class: Aws::MediaConvert::Types::MpdSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::MpdSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
When making an API call, you may pass MpdSettings data as a hash:
{
accessibility_caption_hints: "INCLUDE", # accepts INCLUDE, EXCLUDE
audio_duration: "DEFAULT_CODEC_DURATION", # accepts DEFAULT_CODEC_DURATION, MATCH_VIDEO_DURATION
caption_container_type: "RAW", # accepts RAW, FRAGMENTED_MP4
klv_metadata: "NONE", # accepts NONE, PASSTHROUGH
scte_35_esam: "INSERT", # accepts INSERT, NONE
scte_35_source: "PASSTHROUGH", # accepts PASSTHROUGH, NONE
timed_metadata: "PASSTHROUGH", # accepts PASSTHROUGH, NONE
}
These settings relate to the fragmented MP4 container for the segments in your DASH outputs.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#accessibility_caption_hints ⇒ String
Optional.
-
#audio_duration ⇒ String
Specify this setting only when your output will be consumed by a downstream repackaging workflow that is sensitive to very small duration differences between video and audio.
-
#caption_container_type ⇒ String
Use this setting only in DASH output groups that include sidecar TTML or IMSC captions.
-
#klv_metadata ⇒ String
Applies to DASH ISO outputs.
-
#scte_35_esam ⇒ String
Use this setting only when you specify SCTE-35 markers from ESAM.
-
#scte_35_source ⇒ String
Ignore this setting unless you have SCTE-35 markers in your input video file.
-
#timed_metadata ⇒ String
To include ID3 metadata in this output: Set ID3 metadata (timedMetadata) to Passthrough (PASSTHROUGH).
Instance Attribute Details
#accessibility_caption_hints ⇒ String
Optional. Choose Include (INCLUDE) to have MediaConvert mark up your DASH manifest with <Accessibility> elements for embedded 608 captions. This markup isn't generally required, but some video players require it to discover and play embedded 608 captions. Keep the default value, Exclude (EXCLUDE), to leave these elements out. When you enable this setting, this is the markup that MediaConvert includes in your manifest: <Accessibility schemeIdUri=“urn:scte:dash:cc:cea-608:2015” value=“CC1=eng” /> </Accessibility>
17201 17202 17203 17204 17205 17206 17207 17208 17209 17210 17211 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 17201 class MpdSettings < Struct.new( :accessibility_caption_hints, :audio_duration, :caption_container_type, :klv_metadata, :scte_35_esam, :scte_35_source, :timed_metadata) SENSITIVE = [] include Aws::Structure end |
#audio_duration ⇒ String
Specify this setting only when your output will be consumed by a downstream repackaging workflow that is sensitive to very small duration differences between video and audio. For this situation, choose Match video duration (MATCH_VIDEO_DURATION). In all other cases, keep the default value, Default codec duration (DEFAULT_CODEC_DURATION). When you choose Match video duration, MediaConvert pads the output audio streams with silence or trims them to ensure that the total duration of each audio stream is at least as long as the total duration of the video stream. After padding or trimming, the audio stream duration is no more than one frame longer than the video stream. MediaConvert applies audio padding or trimming only to the end of the last segment of the output. For unsegmented outputs, MediaConvert adds padding only to the end of the file. When you keep the default value, any minor discrepancies between audio and video duration will depend on your output audio codec.
17201 17202 17203 17204 17205 17206 17207 17208 17209 17210 17211 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 17201 class MpdSettings < Struct.new( :accessibility_caption_hints, :audio_duration, :caption_container_type, :klv_metadata, :scte_35_esam, :scte_35_source, :timed_metadata) SENSITIVE = [] include Aws::Structure end |
#caption_container_type ⇒ String
Use this setting only in DASH output groups that include sidecar TTML or IMSC captions. You specify sidecar captions in a separate output from your audio and video. Choose Raw (RAW) for captions in a single XML file in a raw container. Choose Fragmented MPEG-4 (FRAGMENTED_MP4) for captions in XML format contained within fragmented MP4 files. This set of fragmented MP4 files is separate from your video and audio fragmented MP4 files.
17201 17202 17203 17204 17205 17206 17207 17208 17209 17210 17211 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 17201 class MpdSettings < Struct.new( :accessibility_caption_hints, :audio_duration, :caption_container_type, :klv_metadata, :scte_35_esam, :scte_35_source, :timed_metadata) SENSITIVE = [] include Aws::Structure end |
#klv_metadata ⇒ String
Applies to DASH ISO outputs. Use this setting to specify whether the service inserts the KLV metadata from the input in this output.
17201 17202 17203 17204 17205 17206 17207 17208 17209 17210 17211 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 17201 class MpdSettings < Struct.new( :accessibility_caption_hints, :audio_duration, :caption_container_type, :klv_metadata, :scte_35_esam, :scte_35_source, :timed_metadata) SENSITIVE = [] include Aws::Structure end |
#scte_35_esam ⇒ String
Use this setting only when you specify SCTE-35 markers from ESAM. Choose INSERT to put SCTE-35 markers in this output at the insertion points that you specify in an ESAM XML document. Provide the document in the setting SCC XML (sccXml).
17201 17202 17203 17204 17205 17206 17207 17208 17209 17210 17211 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 17201 class MpdSettings < Struct.new( :accessibility_caption_hints, :audio_duration, :caption_container_type, :klv_metadata, :scte_35_esam, :scte_35_source, :timed_metadata) SENSITIVE = [] include Aws::Structure end |
#scte_35_source ⇒ String
Ignore this setting unless you have SCTE-35 markers in your input video file. Choose Passthrough (PASSTHROUGH) if you want SCTE-35 markers that appear in your input to also appear in this output. Choose None (NONE) if you don't want those SCTE-35 markers in this output.
17201 17202 17203 17204 17205 17206 17207 17208 17209 17210 17211 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 17201 class MpdSettings < Struct.new( :accessibility_caption_hints, :audio_duration, :caption_container_type, :klv_metadata, :scte_35_esam, :scte_35_source, :timed_metadata) SENSITIVE = [] include Aws::Structure end |
#timed_metadata ⇒ String
To include ID3 metadata in this output: Set ID3 metadata (timedMetadata) to Passthrough (PASSTHROUGH). Specify this ID3 metadata in Custom ID3 metadata inserter (timedMetadataInsertion). MediaConvert writes each instance of ID3 metadata in a separate Event Message (eMSG) box. To exclude this ID3 metadata: Set ID3 metadata to None (NONE) or leave blank.
17201 17202 17203 17204 17205 17206 17207 17208 17209 17210 17211 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 17201 class MpdSettings < Struct.new( :accessibility_caption_hints, :audio_duration, :caption_container_type, :klv_metadata, :scte_35_esam, :scte_35_source, :timed_metadata) SENSITIVE = [] include Aws::Structure end |