Class: Aws::MediaConvert::Types::MsSmoothEncryptionSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::MsSmoothEncryptionSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
Note:
When making an API call, you may pass MsSmoothEncryptionSettings data as a hash:
{
speke_key_provider: {
certificate_arn: "__stringPatternArnAwsUsGovAcm",
resource_id: "__string",
system_ids: ["__stringPattern09aFAF809aFAF409aFAF409aFAF409aFAF12"],
url: "__stringPatternHttps",
},
}
If you are using DRM, set DRM System (MsSmoothEncryptionSettings) to specify the value SpekeKeyProvider.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#speke_key_provider ⇒ Types::SpekeKeyProvider
If your output group type is HLS, DASH, or Microsoft Smooth, use these settings when doing DRM encryption with a SPEKE-compliant key provider.
Instance Attribute Details
#speke_key_provider ⇒ Types::SpekeKeyProvider
If your output group type is HLS, DASH, or Microsoft Smooth, use these settings when doing DRM encryption with a SPEKE-compliant key provider. If your output group type is CMAF, use the SpekeKeyProviderCmaf settings instead.
17589 17590 17591 17592 17593 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 17589 class MsSmoothEncryptionSettings < Struct.new( :speke_key_provider) SENSITIVE = [] include Aws::Structure end |