Class: Aws::MediaConvert::Types::MsSmoothGroupSettings

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediaconvert/types.rb

Overview

Settings related to your Microsoft Smooth Streaming output package. For more information, see docs.aws.amazon.com/mediaconvert/latest/ug/outputs-file-ABR.html.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#additional_manifestsArray<Types::MsSmoothAdditionalManifest>

By default, the service creates one .ism Microsoft Smooth Streaming manifest for each Microsoft Smooth Streaming output group in your job. This default manifest references every output in the output group. To create additional manifests that reference a subset of the outputs in the output group, specify a list of them here.



11817
11818
11819
11820
11821
11822
11823
11824
11825
11826
11827
11828
# File 'lib/aws-sdk-mediaconvert/types.rb', line 11817

class MsSmoothGroupSettings < Struct.new(
  :additional_manifests,
  :audio_deduplication,
  :destination,
  :destination_settings,
  :encryption,
  :fragment_length,
  :fragment_length_control,
  :manifest_encoding)
  SENSITIVE = []
  include Aws::Structure
end

#audio_deduplicationString

COMBINE_DUPLICATE_STREAMS combines identical audio encoding settings across a Microsoft Smooth output group into a single audio stream.

Returns:

  • (String)


11817
11818
11819
11820
11821
11822
11823
11824
11825
11826
11827
11828
# File 'lib/aws-sdk-mediaconvert/types.rb', line 11817

class MsSmoothGroupSettings < Struct.new(
  :additional_manifests,
  :audio_deduplication,
  :destination,
  :destination_settings,
  :encryption,
  :fragment_length,
  :fragment_length_control,
  :manifest_encoding)
  SENSITIVE = []
  include Aws::Structure
end

#destinationString

Use Destination to specify the S3 output location and the output filename base. Destination accepts format identifiers. If you do not specify the base filename in the URI, the service will use the filename of the input file. If your job has multiple inputs, the service uses the filename of the first input file.

Returns:

  • (String)


11817
11818
11819
11820
11821
11822
11823
11824
11825
11826
11827
11828
# File 'lib/aws-sdk-mediaconvert/types.rb', line 11817

class MsSmoothGroupSettings < Struct.new(
  :additional_manifests,
  :audio_deduplication,
  :destination,
  :destination_settings,
  :encryption,
  :fragment_length,
  :fragment_length_control,
  :manifest_encoding)
  SENSITIVE = []
  include Aws::Structure
end

#destination_settingsTypes::DestinationSettings

Settings associated with the destination. Will vary based on the type of destination



11817
11818
11819
11820
11821
11822
11823
11824
11825
11826
11827
11828
# File 'lib/aws-sdk-mediaconvert/types.rb', line 11817

class MsSmoothGroupSettings < Struct.new(
  :additional_manifests,
  :audio_deduplication,
  :destination,
  :destination_settings,
  :encryption,
  :fragment_length,
  :fragment_length_control,
  :manifest_encoding)
  SENSITIVE = []
  include Aws::Structure
end

#encryptionTypes::MsSmoothEncryptionSettings

If you are using DRM, set DRM System to specify the value SpekeKeyProvider.



11817
11818
11819
11820
11821
11822
11823
11824
11825
11826
11827
11828
# File 'lib/aws-sdk-mediaconvert/types.rb', line 11817

class MsSmoothGroupSettings < Struct.new(
  :additional_manifests,
  :audio_deduplication,
  :destination,
  :destination_settings,
  :encryption,
  :fragment_length,
  :fragment_length_control,
  :manifest_encoding)
  SENSITIVE = []
  include Aws::Structure
end

#fragment_lengthInteger

Specify how you want MediaConvert to determine the fragment length. Choose Exact to have the encoder use the exact length that you specify with the setting Fragment length. This might result in extra I-frames. Choose Multiple of GOP to have the encoder round up the segment lengths to match the next GOP boundary.

Returns:

  • (Integer)


11817
11818
11819
11820
11821
11822
11823
11824
11825
11826
11827
11828
# File 'lib/aws-sdk-mediaconvert/types.rb', line 11817

class MsSmoothGroupSettings < Struct.new(
  :additional_manifests,
  :audio_deduplication,
  :destination,
  :destination_settings,
  :encryption,
  :fragment_length,
  :fragment_length_control,
  :manifest_encoding)
  SENSITIVE = []
  include Aws::Structure
end

#fragment_length_controlString

Specify how you want MediaConvert to determine the fragment length. Choose Exact to have the encoder use the exact length that you specify with the setting Fragment length. This might result in extra I-frames. Choose Multiple of GOP to have the encoder round up the segment lengths to match the next GOP boundary.

Returns:

  • (String)


11817
11818
11819
11820
11821
11822
11823
11824
11825
11826
11827
11828
# File 'lib/aws-sdk-mediaconvert/types.rb', line 11817

class MsSmoothGroupSettings < Struct.new(
  :additional_manifests,
  :audio_deduplication,
  :destination,
  :destination_settings,
  :encryption,
  :fragment_length,
  :fragment_length_control,
  :manifest_encoding)
  SENSITIVE = []
  include Aws::Structure
end

#manifest_encodingString

Use Manifest encoding to specify the encoding format for the server and client manifest. Valid options are utf8 and utf16.

Returns:

  • (String)


11817
11818
11819
11820
11821
11822
11823
11824
11825
11826
11827
11828
# File 'lib/aws-sdk-mediaconvert/types.rb', line 11817

class MsSmoothGroupSettings < Struct.new(
  :additional_manifests,
  :audio_deduplication,
  :destination,
  :destination_settings,
  :encryption,
  :fragment_length,
  :fragment_length_control,
  :manifest_encoding)
  SENSITIVE = []
  include Aws::Structure
end