Class: Aws::MediaConvert::Types::MultiViewSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::MultiViewSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
Specify the enhancement layer input video file path for Multi View outputs. The base layer input is treated as the left eye and this Multi View input is treated as the right eye. Only one Multi View input is currently supported. MediaConvert encodes both views into a single MV-HEVC output codec. When you add MultiViewSettings to your job, you can only produce Multi View outputs. Adding any other codec output to the same job is not supported.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#input ⇒ Types::MultiViewInput
Input settings for MultiView Settings.
Instance Attribute Details
#input ⇒ Types::MultiViewInput
Input settings for MultiView Settings. You can include exactly one input as enhancement layer.
12362 12363 12364 12365 12366 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 12362 class MultiViewSettings < Struct.new( :input) SENSITIVE = [] include Aws::Structure end |