Class: Aws::MediaConvert::Types::MxfXavcProfileSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::MxfXavcProfileSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
When making an API call, you may pass MxfXavcProfileSettings data as a hash:
{
duration_mode: "ALLOW_ANY_DURATION", # accepts ALLOW_ANY_DURATION, DROP_FRAMES_FOR_COMPLIANCE
max_anc_data_size: 1,
}
Specify the XAVC profile settings for MXF outputs when you set your MXF profile to XAVC.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#duration_mode ⇒ String
To create an output that complies with the XAVC file format guidelines for interoperability, keep the default value, Drop frames for compliance (DROP_FRAMES_FOR_COMPLIANCE).
-
#max_anc_data_size ⇒ Integer
Specify a value for this setting only for outputs that you set up with one of these two XAVC profiles: XAVC HD Intra CBG (XAVC_HD_INTRA_CBG) or XAVC 4K Intra CBG (XAVC_4K_INTRA_CBG).
Instance Attribute Details
#duration_mode ⇒ String
To create an output that complies with the XAVC file format guidelines for interoperability, keep the default value, Drop frames for compliance (DROP_FRAMES_FOR_COMPLIANCE). To include all frames from your input in this output, keep the default setting, Allow any duration (ALLOW_ANY_DURATION). The number of frames that MediaConvert excludes when you set this to Drop frames for compliance depends on the output frame rate and duration.
18400 18401 18402 18403 18404 18405 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 18400 class MxfXavcProfileSettings < Struct.new( :duration_mode, :max_anc_data_size) SENSITIVE = [] include Aws::Structure end |
#max_anc_data_size ⇒ Integer
Specify a value for this setting only for outputs that you set up with one of these two XAVC profiles: XAVC HD Intra CBG (XAVC_HD_INTRA_CBG) or XAVC 4K Intra CBG (XAVC_4K_INTRA_CBG). Specify the amount of space in each frame that the service reserves for ancillary data, such as teletext captions. The default value for this setting is 1492 bytes per frame. This should be sufficient to prevent overflow unless you have multiple pages of teletext captions data. If you have a large amount of teletext data, specify a larger number.
18400 18401 18402 18403 18404 18405 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 18400 class MxfXavcProfileSettings < Struct.new( :duration_mode, :max_anc_data_size) SENSITIVE = [] include Aws::Structure end |