Class: Aws::MediaConvert::Types::NoiseReducer
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::NoiseReducer
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
Enable the Noise reducer feature to remove noise from your video output if necessary. Enable or disable this feature for each output individually. This setting is disabled by default. When you enable Noise reducer, you must also select a value for Noise reducer filter. For AVC outputs, when you include Noise reducer, you cannot include the Bandwidth reduction filter.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#filter ⇒ String
Use Noise reducer filter to select one of the following spatial image filtering functions.
-
#filter_settings ⇒ Types::NoiseReducerFilterSettings
Settings for a noise reducer filter.
-
#spatial_filter_settings ⇒ Types::NoiseReducerSpatialFilterSettings
Noise reducer filter settings for spatial filter.
-
#temporal_filter_settings ⇒ Types::NoiseReducerTemporalFilterSettings
Noise reducer filter settings for temporal filter.
Instance Attribute Details
#filter ⇒ String
Use Noise reducer filter to select one of the following spatial image filtering functions. To use this setting, you must also enable Noise reducer. * Bilateral preserves edges while reducing noise. * Mean (softest), Gaussian, Lanczos, and Sharpen (sharpest) do convolution filtering. * Conserve does min/max noise reduction. * Spatial does frequency-domain filtering based on JND principles. * Temporal optimizes video quality for complex motion.
12663 12664 12665 12666 12667 12668 12669 12670 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 12663 class NoiseReducer < Struct.new( :filter, :filter_settings, :spatial_filter_settings, :temporal_filter_settings) SENSITIVE = [] include Aws::Structure end |
#filter_settings ⇒ Types::NoiseReducerFilterSettings
Settings for a noise reducer filter
12663 12664 12665 12666 12667 12668 12669 12670 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 12663 class NoiseReducer < Struct.new( :filter, :filter_settings, :spatial_filter_settings, :temporal_filter_settings) SENSITIVE = [] include Aws::Structure end |
#spatial_filter_settings ⇒ Types::NoiseReducerSpatialFilterSettings
Noise reducer filter settings for spatial filter.
12663 12664 12665 12666 12667 12668 12669 12670 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 12663 class NoiseReducer < Struct.new( :filter, :filter_settings, :spatial_filter_settings, :temporal_filter_settings) SENSITIVE = [] include Aws::Structure end |
#temporal_filter_settings ⇒ Types::NoiseReducerTemporalFilterSettings
Noise reducer filter settings for temporal filter.
12663 12664 12665 12666 12667 12668 12669 12670 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 12663 class NoiseReducer < Struct.new( :filter, :filter_settings, :spatial_filter_settings, :temporal_filter_settings) SENSITIVE = [] include Aws::Structure end |