Class: Aws::MediaConvert::Types::Output
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::Output
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
Each output in your job is a collection of settings that describes how you want MediaConvert to encode a single output file or stream. For more information, see docs.aws.amazon.com/mediaconvert/latest/ug/create-outputs.html.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#audio_descriptions ⇒ Array<Types::AudioDescription>
Contains groups of audio encoding settings organized by audio codec.
-
#caption_descriptions ⇒ Array<Types::CaptionDescription>
Contains groups of captions settings.
-
#container_settings ⇒ Types::ContainerSettings
Container specific settings.
-
#extension ⇒ String
Use Extension to specify the file extension for outputs in File output groups.
-
#name_modifier ⇒ String
Use Name modifier to have the service add a string to the end of each output filename.
-
#output_settings ⇒ Types::OutputSettings
Specific settings for this type of output.
-
#preset ⇒ String
Use Preset to specify a preset for your transcoding settings.
-
#video_description ⇒ Types::VideoDescription
VideoDescription contains a group of video encoding settings.
Instance Attribute Details
#audio_descriptions ⇒ Array<Types::AudioDescription>
Contains groups of audio encoding settings organized by audio codec. Include one instance of per output. Can contain multiple groups of encoding settings.
10631 10632 10633 10634 10635 10636 10637 10638 10639 10640 10641 10642 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 10631 class Output < Struct.new( :audio_descriptions, :caption_descriptions, :container_settings, :extension, :name_modifier, :output_settings, :preset, :video_description) SENSITIVE = [] include Aws::Structure end |
#caption_descriptions ⇒ Array<Types::CaptionDescription>
Contains groups of captions settings. For each output that has captions, include one instance of CaptionDescriptions. Can contain multiple groups of captions settings.
10631 10632 10633 10634 10635 10636 10637 10638 10639 10640 10641 10642 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 10631 class Output < Struct.new( :audio_descriptions, :caption_descriptions, :container_settings, :extension, :name_modifier, :output_settings, :preset, :video_description) SENSITIVE = [] include Aws::Structure end |
#container_settings ⇒ Types::ContainerSettings
Container specific settings.
10631 10632 10633 10634 10635 10636 10637 10638 10639 10640 10641 10642 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 10631 class Output < Struct.new( :audio_descriptions, :caption_descriptions, :container_settings, :extension, :name_modifier, :output_settings, :preset, :video_description) SENSITIVE = [] include Aws::Structure end |
#extension ⇒ String
Use Extension to specify the file extension for outputs in File output groups. If you do not specify a value, the service will use default extensions by container type as follows * MPEG-2 transport stream, m2ts * Quicktime, mov * MXF container, mxf * MPEG-4 container, mp4 * WebM container, webm * No Container, the service will use codec extensions (e.g. AAC, H265, H265, AC3)
10631 10632 10633 10634 10635 10636 10637 10638 10639 10640 10641 10642 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 10631 class Output < Struct.new( :audio_descriptions, :caption_descriptions, :container_settings, :extension, :name_modifier, :output_settings, :preset, :video_description) SENSITIVE = [] include Aws::Structure end |
#name_modifier ⇒ String
Use Name modifier to have the service add a string to the end of each output filename. You specify the base filename as part of your destination URI. When you create multiple outputs in the same output group, Name modifier is required. Name modifier also accepts format identifiers. For DASH ISO outputs, if you use the format identifiers $Number$ or $Time$ in one output, you must use them in the same way in all outputs of the output group.
10631 10632 10633 10634 10635 10636 10637 10638 10639 10640 10641 10642 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 10631 class Output < Struct.new( :audio_descriptions, :caption_descriptions, :container_settings, :extension, :name_modifier, :output_settings, :preset, :video_description) SENSITIVE = [] include Aws::Structure end |
#output_settings ⇒ Types::OutputSettings
Specific settings for this type of output.
10631 10632 10633 10634 10635 10636 10637 10638 10639 10640 10641 10642 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 10631 class Output < Struct.new( :audio_descriptions, :caption_descriptions, :container_settings, :extension, :name_modifier, :output_settings, :preset, :video_description) SENSITIVE = [] include Aws::Structure end |
#preset ⇒ String
Use Preset to specify a preset for your transcoding settings. Provide the system or custom preset name. You can specify either Preset or Container settings, but not both.
10631 10632 10633 10634 10635 10636 10637 10638 10639 10640 10641 10642 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 10631 class Output < Struct.new( :audio_descriptions, :caption_descriptions, :container_settings, :extension, :name_modifier, :output_settings, :preset, :video_description) SENSITIVE = [] include Aws::Structure end |
#video_description ⇒ Types::VideoDescription
VideoDescription contains a group of video encoding settings. The specific video settings depend on the video codec that you choose for the property codec. Include one instance of VideoDescription per output.
10631 10632 10633 10634 10635 10636 10637 10638 10639 10640 10641 10642 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 10631 class Output < Struct.new( :audio_descriptions, :caption_descriptions, :container_settings, :extension, :name_modifier, :output_settings, :preset, :video_description) SENSITIVE = [] include Aws::Structure end |