Class: Aws::MediaConvert::Types::Policy
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::Policy
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
Note:
When making an API call, you may pass Policy data as a hash:
{
http_inputs: "ALLOWED", # accepts ALLOWED, DISALLOWED
https_inputs: "ALLOWED", # accepts ALLOWED, DISALLOWED
s3_inputs: "ALLOWED", # accepts ALLOWED, DISALLOWED
}
A policy configures behavior that you allow or disallow for your account. For information about MediaConvert policies, see the user guide at docs.aws.amazon.com/mediaconvert/latest/ug/what-is.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#http_inputs ⇒ String
Allow or disallow jobs that specify HTTP inputs.
-
#https_inputs ⇒ String
Allow or disallow jobs that specify HTTPS inputs.
-
#s3_inputs ⇒ String
Allow or disallow jobs that specify Amazon S3 inputs.
Instance Attribute Details
#http_inputs ⇒ String
Allow or disallow jobs that specify HTTP inputs.
20653 20654 20655 20656 20657 20658 20659 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 20653 class Policy < Struct.new( :http_inputs, :https_inputs, :s3_inputs) SENSITIVE = [] include Aws::Structure end |