Class: Aws::MediaConvert::Types::Queue
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::Queue
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
You can use queues to manage the resources that are available to your AWS account for running multiple transcoding jobs at the same time. If you don’t specify a queue, the service sends all jobs through the default queue. For more information, see docs.aws.amazon.com/mediaconvert/latest/ug/working-with-queues.html.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
An identifier for this resource that is unique within all of AWS.
-
#concurrent_jobs ⇒ Integer
The maximum number of jobs your queue can process concurrently.
-
#created_at ⇒ Time
The timestamp in epoch seconds for when you created the queue.
-
#description ⇒ String
An optional description that you create for each queue.
-
#last_updated ⇒ Time
The timestamp in epoch seconds for when you most recently updated the queue.
-
#maximum_concurrent_feeds ⇒ Integer
Specify the maximum number of Elemental Inference feeds MediaConvert can process concurrently.
-
#name ⇒ String
A name that you create for each queue.
-
#pricing_plan ⇒ String
Specifies whether the pricing plan for the queue is on-demand or reserved.
-
#progressing_jobs_count ⇒ Integer
The estimated number of jobs with a PROGRESSING status.
-
#reservation_plan ⇒ Types::ReservationPlan
Details about the pricing plan for your reserved queue.
-
#service_overrides ⇒ Array<Types::ServiceOverride>
A list of any service overrides applied by MediaConvert to the settings that you have configured.
-
#status ⇒ String
Queues can be ACTIVE or PAUSED.
-
#submitted_jobs_count ⇒ Integer
The estimated number of jobs with a SUBMITTED status.
-
#type ⇒ String
Specifies whether this on-demand queue is system or custom.
Instance Attribute Details
#arn ⇒ String
An identifier for this resource that is unique within all of AWS.
13196 13197 13198 13199 13200 13201 13202 13203 13204 13205 13206 13207 13208 13209 13210 13211 13212 13213 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 13196 class Queue < Struct.new( :arn, :concurrent_jobs, :created_at, :description, :last_updated, :maximum_concurrent_feeds, :name, :pricing_plan, :progressing_jobs_count, :reservation_plan, :service_overrides, :status, :submitted_jobs_count, :type) SENSITIVE = [] include Aws::Structure end |
#concurrent_jobs ⇒ Integer
The maximum number of jobs your queue can process concurrently.
13196 13197 13198 13199 13200 13201 13202 13203 13204 13205 13206 13207 13208 13209 13210 13211 13212 13213 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 13196 class Queue < Struct.new( :arn, :concurrent_jobs, :created_at, :description, :last_updated, :maximum_concurrent_feeds, :name, :pricing_plan, :progressing_jobs_count, :reservation_plan, :service_overrides, :status, :submitted_jobs_count, :type) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The timestamp in epoch seconds for when you created the queue.
13196 13197 13198 13199 13200 13201 13202 13203 13204 13205 13206 13207 13208 13209 13210 13211 13212 13213 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 13196 class Queue < Struct.new( :arn, :concurrent_jobs, :created_at, :description, :last_updated, :maximum_concurrent_feeds, :name, :pricing_plan, :progressing_jobs_count, :reservation_plan, :service_overrides, :status, :submitted_jobs_count, :type) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
An optional description that you create for each queue.
13196 13197 13198 13199 13200 13201 13202 13203 13204 13205 13206 13207 13208 13209 13210 13211 13212 13213 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 13196 class Queue < Struct.new( :arn, :concurrent_jobs, :created_at, :description, :last_updated, :maximum_concurrent_feeds, :name, :pricing_plan, :progressing_jobs_count, :reservation_plan, :service_overrides, :status, :submitted_jobs_count, :type) SENSITIVE = [] include Aws::Structure end |
#last_updated ⇒ Time
The timestamp in epoch seconds for when you most recently updated the queue.
13196 13197 13198 13199 13200 13201 13202 13203 13204 13205 13206 13207 13208 13209 13210 13211 13212 13213 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 13196 class Queue < Struct.new( :arn, :concurrent_jobs, :created_at, :description, :last_updated, :maximum_concurrent_feeds, :name, :pricing_plan, :progressing_jobs_count, :reservation_plan, :service_overrides, :status, :submitted_jobs_count, :type) SENSITIVE = [] include Aws::Structure end |
#maximum_concurrent_feeds ⇒ Integer
Specify the maximum number of Elemental Inference feeds MediaConvert can process concurrently.
13196 13197 13198 13199 13200 13201 13202 13203 13204 13205 13206 13207 13208 13209 13210 13211 13212 13213 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 13196 class Queue < Struct.new( :arn, :concurrent_jobs, :created_at, :description, :last_updated, :maximum_concurrent_feeds, :name, :pricing_plan, :progressing_jobs_count, :reservation_plan, :service_overrides, :status, :submitted_jobs_count, :type) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
A name that you create for each queue. Each name must be unique within your account.
13196 13197 13198 13199 13200 13201 13202 13203 13204 13205 13206 13207 13208 13209 13210 13211 13212 13213 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 13196 class Queue < Struct.new( :arn, :concurrent_jobs, :created_at, :description, :last_updated, :maximum_concurrent_feeds, :name, :pricing_plan, :progressing_jobs_count, :reservation_plan, :service_overrides, :status, :submitted_jobs_count, :type) SENSITIVE = [] include Aws::Structure end |
#pricing_plan ⇒ String
Specifies whether the pricing plan for the queue is on-demand or reserved. For on-demand, you pay per minute, billed in increments of .01 minute. For reserved, you pay for the transcoding capacity of the entire queue, regardless of how much or how little you use it. Reserved pricing requires a 12-month commitment.
13196 13197 13198 13199 13200 13201 13202 13203 13204 13205 13206 13207 13208 13209 13210 13211 13212 13213 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 13196 class Queue < Struct.new( :arn, :concurrent_jobs, :created_at, :description, :last_updated, :maximum_concurrent_feeds, :name, :pricing_plan, :progressing_jobs_count, :reservation_plan, :service_overrides, :status, :submitted_jobs_count, :type) SENSITIVE = [] include Aws::Structure end |
#progressing_jobs_count ⇒ Integer
The estimated number of jobs with a PROGRESSING status.
13196 13197 13198 13199 13200 13201 13202 13203 13204 13205 13206 13207 13208 13209 13210 13211 13212 13213 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 13196 class Queue < Struct.new( :arn, :concurrent_jobs, :created_at, :description, :last_updated, :maximum_concurrent_feeds, :name, :pricing_plan, :progressing_jobs_count, :reservation_plan, :service_overrides, :status, :submitted_jobs_count, :type) SENSITIVE = [] include Aws::Structure end |
#reservation_plan ⇒ Types::ReservationPlan
Details about the pricing plan for your reserved queue. Required for reserved queues and not applicable to on-demand queues.
13196 13197 13198 13199 13200 13201 13202 13203 13204 13205 13206 13207 13208 13209 13210 13211 13212 13213 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 13196 class Queue < Struct.new( :arn, :concurrent_jobs, :created_at, :description, :last_updated, :maximum_concurrent_feeds, :name, :pricing_plan, :progressing_jobs_count, :reservation_plan, :service_overrides, :status, :submitted_jobs_count, :type) SENSITIVE = [] include Aws::Structure end |
#service_overrides ⇒ Array<Types::ServiceOverride>
A list of any service overrides applied by MediaConvert to the settings that you have configured. If you see any overrides, we recommend that you contact AWS Support.
13196 13197 13198 13199 13200 13201 13202 13203 13204 13205 13206 13207 13208 13209 13210 13211 13212 13213 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 13196 class Queue < Struct.new( :arn, :concurrent_jobs, :created_at, :description, :last_updated, :maximum_concurrent_feeds, :name, :pricing_plan, :progressing_jobs_count, :reservation_plan, :service_overrides, :status, :submitted_jobs_count, :type) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
Queues can be ACTIVE or PAUSED. If you pause a queue, the service won’t begin processing jobs in that queue. Jobs that are running when you pause the queue continue to run until they finish or result in an error.
13196 13197 13198 13199 13200 13201 13202 13203 13204 13205 13206 13207 13208 13209 13210 13211 13212 13213 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 13196 class Queue < Struct.new( :arn, :concurrent_jobs, :created_at, :description, :last_updated, :maximum_concurrent_feeds, :name, :pricing_plan, :progressing_jobs_count, :reservation_plan, :service_overrides, :status, :submitted_jobs_count, :type) SENSITIVE = [] include Aws::Structure end |
#submitted_jobs_count ⇒ Integer
The estimated number of jobs with a SUBMITTED status.
13196 13197 13198 13199 13200 13201 13202 13203 13204 13205 13206 13207 13208 13209 13210 13211 13212 13213 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 13196 class Queue < Struct.new( :arn, :concurrent_jobs, :created_at, :description, :last_updated, :maximum_concurrent_feeds, :name, :pricing_plan, :progressing_jobs_count, :reservation_plan, :service_overrides, :status, :submitted_jobs_count, :type) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
Specifies whether this on-demand queue is system or custom. System queues are built in. You can’t modify or delete system queues. You can create and modify custom queues.
13196 13197 13198 13199 13200 13201 13202 13203 13204 13205 13206 13207 13208 13209 13210 13211 13212 13213 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 13196 class Queue < Struct.new( :arn, :concurrent_jobs, :created_at, :description, :last_updated, :maximum_concurrent_feeds, :name, :pricing_plan, :progressing_jobs_count, :reservation_plan, :service_overrides, :status, :submitted_jobs_count, :type) SENSITIVE = [] include Aws::Structure end |