Class: Aws::MediaConvert::Types::Rectangle

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediaconvert/types.rb

Overview

Use Rectangle to identify a specific area of the video frame.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#heightInteger

Height of rectangle in pixels. Specify only even numbers.

Returns:

  • (Integer)


13839
13840
13841
13842
13843
13844
13845
13846
# File 'lib/aws-sdk-mediaconvert/types.rb', line 13839

class Rectangle < Struct.new(
  :height,
  :width,
  :x,
  :y)
  SENSITIVE = []
  include Aws::Structure
end

#widthInteger

Width of rectangle in pixels. Specify only even numbers.

Returns:

  • (Integer)


13839
13840
13841
13842
13843
13844
13845
13846
# File 'lib/aws-sdk-mediaconvert/types.rb', line 13839

class Rectangle < Struct.new(
  :height,
  :width,
  :x,
  :y)
  SENSITIVE = []
  include Aws::Structure
end

#xInteger

The distance, in pixels, between the rectangle and the left edge of the video frame. Specify only even numbers.

Returns:

  • (Integer)


13839
13840
13841
13842
13843
13844
13845
13846
# File 'lib/aws-sdk-mediaconvert/types.rb', line 13839

class Rectangle < Struct.new(
  :height,
  :width,
  :x,
  :y)
  SENSITIVE = []
  include Aws::Structure
end

#yInteger

The distance, in pixels, between the rectangle and the top edge of the video frame. Specify only even numbers.

Returns:

  • (Integer)


13839
13840
13841
13842
13843
13844
13845
13846
# File 'lib/aws-sdk-mediaconvert/types.rb', line 13839

class Rectangle < Struct.new(
  :height,
  :width,
  :x,
  :y)
  SENSITIVE = []
  include Aws::Structure
end