Class: Aws::MediaConvert::Types::S3DestinationSettings

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediaconvert/types.rb

Overview

Settings associated with S3 destination

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#access_controlTypes::S3DestinationAccessControl

Optional. Have MediaConvert automatically apply Amazon S3 access control for the outputs in this output group. When you don’t use this setting, S3 automatically applies the default access control list PRIVATE.



13494
13495
13496
13497
13498
13499
13500
# File 'lib/aws-sdk-mediaconvert/types.rb', line 13494

class S3DestinationSettings < Struct.new(
  :access_control,
  :encryption,
  :storage_class)
  SENSITIVE = []
  include Aws::Structure
end

#encryptionTypes::S3EncryptionSettings

Settings for how your job outputs are encrypted as they are uploaded to Amazon S3.



13494
13495
13496
13497
13498
13499
13500
# File 'lib/aws-sdk-mediaconvert/types.rb', line 13494

class S3DestinationSettings < Struct.new(
  :access_control,
  :encryption,
  :storage_class)
  SENSITIVE = []
  include Aws::Structure
end

#storage_classString

Specify the S3 storage class to use for this output. To use your destination’s default storage class: Keep the default value, Not set. For more information about S3 storage classes, see docs.aws.amazon.com/AmazonS3/latest/userguide/storage-class-intro.html

Returns:

  • (String)


13494
13495
13496
13497
13498
13499
13500
# File 'lib/aws-sdk-mediaconvert/types.rb', line 13494

class S3DestinationSettings < Struct.new(
  :access_control,
  :encryption,
  :storage_class)
  SENSITIVE = []
  include Aws::Structure
end