Class: Aws::MediaConvert::Types::SpekeKeyProviderCmaf
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::SpekeKeyProviderCmaf
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
When making an API call, you may pass SpekeKeyProviderCmaf data as a hash:
{
certificate_arn: "__stringPatternArnAwsUsGovAcm",
dash_signaled_system_ids: ["__stringMin36Max36Pattern09aFAF809aFAF409aFAF409aFAF409aFAF12"],
hls_signaled_system_ids: ["__stringMin36Max36Pattern09aFAF809aFAF409aFAF409aFAF409aFAF12"],
resource_id: "__stringPatternW",
url: "__stringPatternHttps",
}
If your output group type is CMAF, use these settings when doing DRM encryption with a SPEKE-compliant key provider. If your output group type is HLS, DASH, or Microsoft Smooth, use the SpekeKeyProvider settings instead.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#certificate_arn ⇒ String
If you want your key provider to encrypt the content keys that it provides to MediaConvert, set up a certificate with a master key using AWS Certificate Manager.
-
#dash_signaled_system_ids ⇒ Array<String>
Specify the DRM system IDs that you want signaled in the DASH manifest that MediaConvert creates as part of this CMAF package.
-
#hls_signaled_system_ids ⇒ Array<String>
Specify the DRM system ID that you want signaled in the HLS manifest that MediaConvert creates as part of this CMAF package.
-
#resource_id ⇒ String
Specify the resource ID that your SPEKE-compliant key provider uses to identify this content.
-
#url ⇒ String
Specify the URL to the key server that your SPEKE-compliant DRM key provider uses to provide keys for encrypting your content.
Instance Attribute Details
#certificate_arn ⇒ String
If you want your key provider to encrypt the content keys that it provides to MediaConvert, set up a certificate with a master key using AWS Certificate Manager. Specify the certificate's Amazon Resource Name (ARN) here.
22997 22998 22999 23000 23001 23002 23003 23004 23005 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 22997 class SpekeKeyProviderCmaf < Struct.new( :certificate_arn, :dash_signaled_system_ids, :hls_signaled_system_ids, :resource_id, :url) SENSITIVE = [] include Aws::Structure end |
#dash_signaled_system_ids ⇒ Array<String>
Specify the DRM system IDs that you want signaled in the DASH manifest that MediaConvert creates as part of this CMAF package. The DASH manifest can currently signal up to three system IDs. For more information, see dashif.org/identifiers/content_protection/.
22997 22998 22999 23000 23001 23002 23003 23004 23005 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 22997 class SpekeKeyProviderCmaf < Struct.new( :certificate_arn, :dash_signaled_system_ids, :hls_signaled_system_ids, :resource_id, :url) SENSITIVE = [] include Aws::Structure end |
#hls_signaled_system_ids ⇒ Array<String>
Specify the DRM system ID that you want signaled in the HLS manifest that MediaConvert creates as part of this CMAF package. The HLS manifest can currently signal only one system ID. For more information, see dashif.org/identifiers/content_protection/.
22997 22998 22999 23000 23001 23002 23003 23004 23005 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 22997 class SpekeKeyProviderCmaf < Struct.new( :certificate_arn, :dash_signaled_system_ids, :hls_signaled_system_ids, :resource_id, :url) SENSITIVE = [] include Aws::Structure end |
#resource_id ⇒ String
Specify the resource ID that your SPEKE-compliant key provider uses to identify this content.
22997 22998 22999 23000 23001 23002 23003 23004 23005 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 22997 class SpekeKeyProviderCmaf < Struct.new( :certificate_arn, :dash_signaled_system_ids, :hls_signaled_system_ids, :resource_id, :url) SENSITIVE = [] include Aws::Structure end |
#url ⇒ String
Specify the URL to the key server that your SPEKE-compliant DRM key provider uses to provide keys for encrypting your content.
22997 22998 22999 23000 23001 23002 23003 23004 23005 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 22997 class SpekeKeyProviderCmaf < Struct.new( :certificate_arn, :dash_signaled_system_ids, :hls_signaled_system_ids, :resource_id, :url) SENSITIVE = [] include Aws::Structure end |