Class: Aws::MediaConvert::Types::StartJobsQueryRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::StartJobsQueryRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
Start an asynchronous jobs query using the provided filters. To receive the list of jobs that match your query, call the GetJobsQueryResults API using the query ID returned by this API.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#filter_list ⇒ Array<Types::JobsQueryFilter>
Optional.
-
#max_results ⇒ Integer
Optional.
-
#next_token ⇒ String
Use this string to request the next batch of jobs matched by a jobs query.
-
#order ⇒ String
Optional.
Instance Attribute Details
#filter_list ⇒ Array<Types::JobsQueryFilter>
Optional. Provide an array of JobsQueryFilters for your StartJobsQuery request.
13845 13846 13847 13848 13849 13850 13851 13852 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 13845 class StartJobsQueryRequest < Struct.new( :filter_list, :max_results, :next_token, :order) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
Optional. Number of jobs, up to twenty, that will be included in the jobs query.
13845 13846 13847 13848 13849 13850 13851 13852 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 13845 class StartJobsQueryRequest < Struct.new( :filter_list, :max_results, :next_token, :order) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
Use this string to request the next batch of jobs matched by a jobs query.
13845 13846 13847 13848 13849 13850 13851 13852 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 13845 class StartJobsQueryRequest < Struct.new( :filter_list, :max_results, :next_token, :order) SENSITIVE = [] include Aws::Structure end |
#order ⇒ String
Optional. When you request lists of resources, you can specify whether they are sorted in ASCENDING or DESCENDING order. Default varies by resource.
13845 13846 13847 13848 13849 13850 13851 13852 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 13845 class StartJobsQueryRequest < Struct.new( :filter_list, :max_results, :next_token, :order) SENSITIVE = [] include Aws::Structure end |