Class: Aws::MediaConvert::Types::TeletextDestinationSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::TeletextDestinationSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
Settings related to teletext captions. Set up teletext captions in the same output as your video. For more information, see docs.aws.amazon.com/mediaconvert/latest/ug/teletext-output-captions.html. When you work directly in your JSON job specification, include this object and any required children when you set destinationType to TELETEXT.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#page_number ⇒ String
Set pageNumber to the Teletext page number for the destination captions for this output.
-
#page_types ⇒ Array<String>
Specify the page types for this Teletext page.
Instance Attribute Details
#page_number ⇒ String
Set pageNumber to the Teletext page number for the destination captions for this output. This value must be a three-digit hexadecimal string; strings ending in -FF are invalid. If you are passing through the entire set of Teletext data, do not use this field.
11737 11738 11739 11740 11741 11742 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 11737 class TeletextDestinationSettings < Struct.new( :page_number, :page_types) SENSITIVE = [] include Aws::Structure end |
#page_types ⇒ Array<String>
Specify the page types for this Teletext page. If you don’t specify a value here, the service sets the page type to the default value Subtitle (PAGE_TYPE_SUBTITLE). If you pass through the entire set of Teletext data, don’t use this field. When you pass through a set of Teletext pages, your output has the same page types as your input.
11737 11738 11739 11740 11741 11742 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 11737 class TeletextDestinationSettings < Struct.new( :page_number, :page_types) SENSITIVE = [] include Aws::Structure end |