Class: Aws::MediaConvert::Types::TeletextSourceSettings

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediaconvert/types.rb

Overview

Settings specific to Teletext caption sources, including Page number.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#page_numberString

Use Page Number to specify the three-digit hexadecimal page number that will be used for Teletext captions. Do not use this setting if you are passing through teletext from the input source to output.



13850
13851
13852
13853
13854
# File 'lib/aws-sdk-mediaconvert/types.rb', line 13850

class TeletextSourceSettings < Struct.new(
  :page_number)
  SENSITIVE = []
  include Aws::Structure
end