Class: Aws::MediaConvert::Types::TimecodeBurnin
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::TimecodeBurnin
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
When making an API call, you may pass TimecodeBurnin data as a hash:
{
font_size: 1,
position: "TOP_CENTER", # accepts TOP_CENTER, TOP_LEFT, TOP_RIGHT, MIDDLE_LEFT, MIDDLE_CENTER, MIDDLE_RIGHT, BOTTOM_LEFT, BOTTOM_CENTER, BOTTOM_RIGHT
prefix: "__stringPattern",
}
Settings for burning the output timecode and specified prefix into the output.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#font_size ⇒ Integer
Use Font Size (FontSize) to set the font size of any burned-in timecode.
-
#position ⇒ String
Use Position (Position) under under Timecode burn-in (TimecodeBurnIn) to specify the location the burned-in timecode on output video.
-
#prefix ⇒ String
Use Prefix (Prefix) to place ASCII characters before any burned-in timecode.
Instance Attribute Details
#font_size ⇒ Integer
Use Font Size (FontSize) to set the font size of any burned-in timecode. Valid values are 10, 16, 32, 48.
23221 23222 23223 23224 23225 23226 23227 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 23221 class TimecodeBurnin < Struct.new( :font_size, :position, :prefix) SENSITIVE = [] include Aws::Structure end |
#position ⇒ String
Use Position (Position) under under Timecode burn-in (TimecodeBurnIn) to specify the location the burned-in timecode on output video.
23221 23222 23223 23224 23225 23226 23227 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 23221 class TimecodeBurnin < Struct.new( :font_size, :position, :prefix) SENSITIVE = [] include Aws::Structure end |
#prefix ⇒ String
Use Prefix (Prefix) to place ASCII characters before any burned-in timecode. For example, a prefix of “EZ-” will result in the timecode “EZ-00:00:00:00”. Provide either the characters themselves or the ASCII code equivalents. The supported range of characters is 0x20 through 0x7e. This includes letters, numbers, and all special characters represented on a standard English keyboard.
23221 23222 23223 23224 23225 23226 23227 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 23221 class TimecodeBurnin < Struct.new( :font_size, :position, :prefix) SENSITIVE = [] include Aws::Structure end |