Class: Aws::MediaConvert::Types::TtmlDestinationSettings

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediaconvert/types.rb

Overview

Settings related to TTML captions. TTML is a sidecar format that holds captions in a file that is separate from the video container. Set up sidecar captions in the same output group, but different output from your video. For more information, see https://docs.aws.amazon.com/mediaconvert/latest/ug/ttml-and-webvtt-output-captions.html.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#background_colorString

Specify the color of the rectangle behind the captions. If Style passthrough is set to enabled, leave blank or set to Auto to pass through the background color from your input captions. If Style passthrough is set to disabled, leave blank or set to Auto to use the default black.

Returns:

  • (String)


14878
14879
14880
14881
14882
14883
14884
14885
14886
14887
14888
14889
14890
# File 'lib/aws-sdk-mediaconvert/types.rb', line 14878

class TtmlDestinationSettings < Struct.new(
  :background_color,
  :background_opacity,
  :font_color,
  :font_opacity,
  :font_size,
  :font_style,
  :font_weight,
  :style_passthrough,
  :text_decoration)
  SENSITIVE = []
  include Aws::Structure
end

#background_opacityInteger

Specify the opacity of the background rectangle. Enter a value from 0 to 255, where 0 is transparent and 255 is opaque. If Style passthrough is set to enabled, leave blank to pass through the background style information in your input captions to your output captions. If Style passthrough is set to disabled and backgroundColor is set, leave blank to use a value of 255 (opaque).

Returns:

  • (Integer)


14878
14879
14880
14881
14882
14883
14884
14885
14886
14887
14888
14889
14890
# File 'lib/aws-sdk-mediaconvert/types.rb', line 14878

class TtmlDestinationSettings < Struct.new(
  :background_color,
  :background_opacity,
  :font_color,
  :font_opacity,
  :font_size,
  :font_style,
  :font_weight,
  :style_passthrough,
  :text_decoration)
  SENSITIVE = []
  include Aws::Structure
end

#font_colorString

Specify the color of the captions text. If Style passthrough is set to enabled, leave blank or set to Auto to pass through the font color from your input captions. If Style passthrough is set to disabled, leave blank or set to Auto to use the default white.

Returns:

  • (String)


14878
14879
14880
14881
14882
14883
14884
14885
14886
14887
14888
14889
14890
# File 'lib/aws-sdk-mediaconvert/types.rb', line 14878

class TtmlDestinationSettings < Struct.new(
  :background_color,
  :background_opacity,
  :font_color,
  :font_opacity,
  :font_size,
  :font_style,
  :font_weight,
  :style_passthrough,
  :text_decoration)
  SENSITIVE = []
  include Aws::Structure
end

#font_opacityInteger

Specify the opacity of the captions. Enter a value from 0 to 255, where 0 is transparent and 255 is opaque. If Style passthrough is set to enabled, leave blank to pass through the font opacity information in your input captions to your output captions. If Style passthrough is set to disabled and fontColor is set, leave blank to use a value of 255 (opaque).

Returns:

  • (Integer)


14878
14879
14880
14881
14882
14883
14884
14885
14886
14887
14888
14889
14890
# File 'lib/aws-sdk-mediaconvert/types.rb', line 14878

class TtmlDestinationSettings < Struct.new(
  :background_color,
  :background_opacity,
  :font_color,
  :font_opacity,
  :font_size,
  :font_style,
  :font_weight,
  :style_passthrough,
  :text_decoration)
  SENSITIVE = []
  include Aws::Structure
end

#font_sizeInteger

Specify the Font size in pixels. Must be a positive integer. Set to 0, or leave blank, for automatic font size.

Returns:

  • (Integer)


14878
14879
14880
14881
14882
14883
14884
14885
14886
14887
14888
14889
14890
# File 'lib/aws-sdk-mediaconvert/types.rb', line 14878

class TtmlDestinationSettings < Struct.new(
  :background_color,
  :background_opacity,
  :font_color,
  :font_opacity,
  :font_size,
  :font_style,
  :font_weight,
  :style_passthrough,
  :text_decoration)
  SENSITIVE = []
  include Aws::Structure
end

#font_styleString

Specify the font style of the caption text. If Style passthrough is set to enabled, leave blank to pass through the font style from your input captions. If Style passthrough is set to disabled, leave blank to use the default normal style.

Returns:

  • (String)


14878
14879
14880
14881
14882
14883
14884
14885
14886
14887
14888
14889
14890
# File 'lib/aws-sdk-mediaconvert/types.rb', line 14878

class TtmlDestinationSettings < Struct.new(
  :background_color,
  :background_opacity,
  :font_color,
  :font_opacity,
  :font_size,
  :font_style,
  :font_weight,
  :style_passthrough,
  :text_decoration)
  SENSITIVE = []
  include Aws::Structure
end

#font_weightString

Specify the font weight of the caption text. If Style passthrough is set to enabled, leave blank to pass through the font weight from your input captions. If Style passthrough is set to disabled, leave blank to use the default normal weight.

Returns:

  • (String)


14878
14879
14880
14881
14882
14883
14884
14885
14886
14887
14888
14889
14890
# File 'lib/aws-sdk-mediaconvert/types.rb', line 14878

class TtmlDestinationSettings < Struct.new(
  :background_color,
  :background_opacity,
  :font_color,
  :font_opacity,
  :font_size,
  :font_style,
  :font_weight,
  :style_passthrough,
  :text_decoration)
  SENSITIVE = []
  include Aws::Structure
end

#style_passthroughString

Pass through style and position information from a TTML-like input source (TTML, IMSC, SMPTE-TT) to the TTML output.

Returns:

  • (String)


14878
14879
14880
14881
14882
14883
14884
14885
14886
14887
14888
14889
14890
# File 'lib/aws-sdk-mediaconvert/types.rb', line 14878

class TtmlDestinationSettings < Struct.new(
  :background_color,
  :background_opacity,
  :font_color,
  :font_opacity,
  :font_size,
  :font_style,
  :font_weight,
  :style_passthrough,
  :text_decoration)
  SENSITIVE = []
  include Aws::Structure
end

#text_decorationString

Specify the text decoration of the caption text. If Style passthrough is set to enabled, leave blank to pass through the text decoration from your input captions. If Style passthrough is set to disabled, leave blank to use the default of none.

Returns:

  • (String)


14878
14879
14880
14881
14882
14883
14884
14885
14886
14887
14888
14889
14890
# File 'lib/aws-sdk-mediaconvert/types.rb', line 14878

class TtmlDestinationSettings < Struct.new(
  :background_color,
  :background_opacity,
  :font_color,
  :font_opacity,
  :font_size,
  :font_style,
  :font_weight,
  :style_passthrough,
  :text_decoration)
  SENSITIVE = []
  include Aws::Structure
end