Class: Aws::MediaConvert::Types::UpdateJobTemplateRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediaconvert/types.rb

Overview

Modify a job template by sending a request with the job template name and any of the following that you wish to change: description, category, and queue.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#acceleration_settingsTypes::AccelerationSettings

Accelerated transcoding can significantly speed up jobs with long, visually complex content. Outputs that use this feature incur pro-tier pricing. For information about feature limitations, see the AWS Elemental MediaConvert User Guide.



15099
15100
15101
15102
15103
15104
15105
15106
15107
15108
15109
15110
15111
# File 'lib/aws-sdk-mediaconvert/types.rb', line 15099

class UpdateJobTemplateRequest < Struct.new(
  :acceleration_settings,
  :category,
  :description,
  :hop_destinations,
  :name,
  :priority,
  :queue,
  :settings,
  :status_update_interval)
  SENSITIVE = []
  include Aws::Structure
end

#categoryString

The new category for the job template, if you are changing it.

Returns:

  • (String)


15099
15100
15101
15102
15103
15104
15105
15106
15107
15108
15109
15110
15111
# File 'lib/aws-sdk-mediaconvert/types.rb', line 15099

class UpdateJobTemplateRequest < Struct.new(
  :acceleration_settings,
  :category,
  :description,
  :hop_destinations,
  :name,
  :priority,
  :queue,
  :settings,
  :status_update_interval)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The new description for the job template, if you are changing it.

Returns:

  • (String)


15099
15100
15101
15102
15103
15104
15105
15106
15107
15108
15109
15110
15111
# File 'lib/aws-sdk-mediaconvert/types.rb', line 15099

class UpdateJobTemplateRequest < Struct.new(
  :acceleration_settings,
  :category,
  :description,
  :hop_destinations,
  :name,
  :priority,
  :queue,
  :settings,
  :status_update_interval)
  SENSITIVE = []
  include Aws::Structure
end

#hop_destinationsArray<Types::HopDestination>

Optional list of hop destinations.

Returns:



15099
15100
15101
15102
15103
15104
15105
15106
15107
15108
15109
15110
15111
# File 'lib/aws-sdk-mediaconvert/types.rb', line 15099

class UpdateJobTemplateRequest < Struct.new(
  :acceleration_settings,
  :category,
  :description,
  :hop_destinations,
  :name,
  :priority,
  :queue,
  :settings,
  :status_update_interval)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the job template you are modifying

Returns:

  • (String)


15099
15100
15101
15102
15103
15104
15105
15106
15107
15108
15109
15110
15111
# File 'lib/aws-sdk-mediaconvert/types.rb', line 15099

class UpdateJobTemplateRequest < Struct.new(
  :acceleration_settings,
  :category,
  :description,
  :hop_destinations,
  :name,
  :priority,
  :queue,
  :settings,
  :status_update_interval)
  SENSITIVE = []
  include Aws::Structure
end

#priorityInteger

Specify the relative priority for this job. In any given queue, the service begins processing the job with the highest value first. When more than one job has the same priority, the service begins processing the job that you submitted first. If you don't specify a priority, the service uses the default value 0.

Returns:

  • (Integer)


15099
15100
15101
15102
15103
15104
15105
15106
15107
15108
15109
15110
15111
# File 'lib/aws-sdk-mediaconvert/types.rb', line 15099

class UpdateJobTemplateRequest < Struct.new(
  :acceleration_settings,
  :category,
  :description,
  :hop_destinations,
  :name,
  :priority,
  :queue,
  :settings,
  :status_update_interval)
  SENSITIVE = []
  include Aws::Structure
end

#queueString

The new queue for the job template, if you are changing it.

Returns:

  • (String)


15099
15100
15101
15102
15103
15104
15105
15106
15107
15108
15109
15110
15111
# File 'lib/aws-sdk-mediaconvert/types.rb', line 15099

class UpdateJobTemplateRequest < Struct.new(
  :acceleration_settings,
  :category,
  :description,
  :hop_destinations,
  :name,
  :priority,
  :queue,
  :settings,
  :status_update_interval)
  SENSITIVE = []
  include Aws::Structure
end

#settingsTypes::JobTemplateSettings

JobTemplateSettings contains all the transcode settings saved in the template that will be applied to jobs created from it.



15099
15100
15101
15102
15103
15104
15105
15106
15107
15108
15109
15110
15111
# File 'lib/aws-sdk-mediaconvert/types.rb', line 15099

class UpdateJobTemplateRequest < Struct.new(
  :acceleration_settings,
  :category,
  :description,
  :hop_destinations,
  :name,
  :priority,
  :queue,
  :settings,
  :status_update_interval)
  SENSITIVE = []
  include Aws::Structure
end

#status_update_intervalString

Specify how often MediaConvert sends STATUS_UPDATE events to Amazon CloudWatch Events. Set the interval, in seconds, between status updates. MediaConvert sends an update at this interval from the time the service begins processing your job to the time it completes the transcode or encounters an error.

Returns:

  • (String)


15099
15100
15101
15102
15103
15104
15105
15106
15107
15108
15109
15110
15111
# File 'lib/aws-sdk-mediaconvert/types.rb', line 15099

class UpdateJobTemplateRequest < Struct.new(
  :acceleration_settings,
  :category,
  :description,
  :hop_destinations,
  :name,
  :priority,
  :queue,
  :settings,
  :status_update_interval)
  SENSITIVE = []
  include Aws::Structure
end