Class: Aws::MediaConvert::Types::UpdateQueueRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediaconvert/types.rb

Overview

Modify a queue by sending a request with the queue name and any changes to the queue.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#concurrent_jobsInteger

Specify the maximum number of jobs your queue can process concurrently. For on-demand queues, the value you enter is constrained by your service quotas for Maximum concurrent jobs, per on-demand queue and Maximum concurrent jobs, per account. For reserved queues, update your reservation plan instead in order to increase your yearly commitment.

Returns:

  • (Integer)


14907
14908
14909
14910
14911
14912
14913
14914
14915
14916
# File 'lib/aws-sdk-mediaconvert/types.rb', line 14907

class UpdateQueueRequest < Struct.new(
  :concurrent_jobs,
  :description,
  :maximum_concurrent_feeds,
  :name,
  :reservation_plan_settings,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The new description for the queue, if you are changing it.

Returns:

  • (String)


14907
14908
14909
14910
14911
14912
14913
14914
14915
14916
# File 'lib/aws-sdk-mediaconvert/types.rb', line 14907

class UpdateQueueRequest < Struct.new(
  :concurrent_jobs,
  :description,
  :maximum_concurrent_feeds,
  :name,
  :reservation_plan_settings,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#maximum_concurrent_feedsInteger

Specify the maximum number of Elemental Inference feeds MediaConvert can process concurrently.

Returns:

  • (Integer)


14907
14908
14909
14910
14911
14912
14913
14914
14915
14916
# File 'lib/aws-sdk-mediaconvert/types.rb', line 14907

class UpdateQueueRequest < Struct.new(
  :concurrent_jobs,
  :description,
  :maximum_concurrent_feeds,
  :name,
  :reservation_plan_settings,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the queue that you are modifying.

Returns:

  • (String)


14907
14908
14909
14910
14911
14912
14913
14914
14915
14916
# File 'lib/aws-sdk-mediaconvert/types.rb', line 14907

class UpdateQueueRequest < Struct.new(
  :concurrent_jobs,
  :description,
  :maximum_concurrent_feeds,
  :name,
  :reservation_plan_settings,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#reservation_plan_settingsTypes::ReservationPlanSettings

The new details of your pricing plan for your reserved queue. When you set up a new pricing plan to replace an expired one, you enter into another 12-month commitment. When you add capacity to your queue by increasing the number of RTS, you extend the term of your commitment to 12 months from when you add capacity. After you make these commitments, you can’t cancel them.



14907
14908
14909
14910
14911
14912
14913
14914
14915
14916
# File 'lib/aws-sdk-mediaconvert/types.rb', line 14907

class UpdateQueueRequest < Struct.new(
  :concurrent_jobs,
  :description,
  :maximum_concurrent_feeds,
  :name,
  :reservation_plan_settings,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

Pause or activate a queue by changing its status between ACTIVE and PAUSED. If you pause a queue, jobs in that queue won’t begin. Jobs that are running when you pause the queue continue to run until they finish or result in an error.

Returns:

  • (String)


14907
14908
14909
14910
14911
14912
14913
14914
14915
14916
# File 'lib/aws-sdk-mediaconvert/types.rb', line 14907

class UpdateQueueRequest < Struct.new(
  :concurrent_jobs,
  :description,
  :maximum_concurrent_feeds,
  :name,
  :reservation_plan_settings,
  :status)
  SENSITIVE = []
  include Aws::Structure
end