Class: Aws::MediaConvert::Types::VideoOverlayInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::VideoOverlayInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
Input settings for Video overlay. You can include one or more video overlays in sequence at different times that you specify.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#file_input ⇒ String
Specify the input file S3, HTTP, or HTTPS URI for your video overlay.
-
#input_clippings ⇒ Array<Types::VideoOverlayInputClipping>
Specify one or more clips to use from your video overlay.
-
#timecode_source ⇒ String
Specify the timecode source for your video overlay input clips.
-
#timecode_start ⇒ String
Specify the starting timecode for this video overlay.
Instance Attribute Details
#file_input ⇒ String
Specify the input file S3, HTTP, or HTTPS URI for your video overlay. For consistency in color and formatting in your output video image, we recommend that you specify a video with similar characteristics as the underlying input video.
12552 12553 12554 12555 12556 12557 12558 12559 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 12552 class VideoOverlayInput < Struct.new( :file_input, :input_clippings, :timecode_source, :timecode_start) SENSITIVE = [] include Aws::Structure end |
#input_clippings ⇒ Array<Types::VideoOverlayInputClipping>
Specify one or more clips to use from your video overlay. When you include an input clip, you must also specify its start timecode, end timecode, or both start and end timecode.
12552 12553 12554 12555 12556 12557 12558 12559 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 12552 class VideoOverlayInput < Struct.new( :file_input, :input_clippings, :timecode_source, :timecode_start) SENSITIVE = [] include Aws::Structure end |
#timecode_source ⇒ String
Specify the timecode source for your video overlay input clips. To use the timecode present in your video overlay: Choose Embedded. To use a zerobased timecode: Choose Start at 0. To choose a timecode: Choose Specified start. When you do, enter the starting timecode in Start timecode. If you don’t specify a value for Timecode source, MediaConvert uses Embedded by default.
12552 12553 12554 12555 12556 12557 12558 12559 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 12552 class VideoOverlayInput < Struct.new( :file_input, :input_clippings, :timecode_source, :timecode_start) SENSITIVE = [] include Aws::Structure end |
#timecode_start ⇒ String
Specify the starting timecode for this video overlay. To use this setting, you must set Timecode source to Specified start.
12552 12553 12554 12555 12556 12557 12558 12559 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 12552 class VideoOverlayInput < Struct.new( :file_input, :input_clippings, :timecode_source, :timecode_start) SENSITIVE = [] include Aws::Structure end |