Class: Aws::MediaConvert::Types::VideoOverlayInputClipping

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediaconvert/types.rb

Overview

To transcode only portions of your video overlay, include one input clip for each part of your video overlay that you want in your output.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#end_timecodeString

Specify the timecode of the last frame to include in your video overlay’s clip. Use the format HH:MM:SS:FF or HH:MM:SS;FF, where HH is the hour, MM is the minute, SS is the second, and FF is the frame number. When entering this value, take into account your choice for Timecode source.

Returns:

  • (String)


12786
12787
12788
12789
12790
12791
# File 'lib/aws-sdk-mediaconvert/types.rb', line 12786

class VideoOverlayInputClipping < Struct.new(
  :end_timecode,
  :start_timecode)
  SENSITIVE = []
  include Aws::Structure
end

#start_timecodeString

Specify the timecode of the first frame to include in your video overlay’s clip. Use the format HH:MM:SS:FF or HH:MM:SS;FF, where HH is the hour, MM is the minute, SS is the second, and FF is the frame number. When entering this value, take into account your choice for Timecode source.

Returns:

  • (String)


12786
12787
12788
12789
12790
12791
# File 'lib/aws-sdk-mediaconvert/types.rb', line 12786

class VideoOverlayInputClipping < Struct.new(
  :end_timecode,
  :start_timecode)
  SENSITIVE = []
  include Aws::Structure
end