Class: Aws::MediaConvert::Types::VideoPreprocessor
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::VideoPreprocessor
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
Find additional transcoding features under Preprocessors. Enable the features at each output individually. These features are disabled by default.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#color_corrector ⇒ Types::ColorCorrector
Use these settings to convert the color space or to modify properties such as hue and contrast for this output.
-
#deinterlacer ⇒ Types::Deinterlacer
Use the deinterlacer to produce smoother motion and a clearer picture.
-
#dolby_vision ⇒ Types::DolbyVision
Enable Dolby Vision feature to produce Dolby Vision compatible video output.
-
#duration_control ⇒ Types::DurationControl
Enable integer-second duration normalization.
-
#hdr_10_plus ⇒ Types::Hdr10Plus
Enable HDR10+ analysis and metadata injection.
-
#image_inserter ⇒ Types::ImageInserter
Enable the Image inserter feature to include a graphic overlay on your video.
-
#noise_reducer ⇒ Types::NoiseReducer
Enable the Noise reducer feature to remove noise from your video output if necessary.
-
#partner_watermarking ⇒ Types::PartnerWatermarking
If you work with a third party video watermarking partner, use the group of settings that correspond with your watermarking partner to include watermarks in your output.
-
#timecode_burnin ⇒ Types::TimecodeBurnin
Settings for burning the output timecode and specified prefix into the output.
Instance Attribute Details
#color_corrector ⇒ Types::ColorCorrector
Use these settings to convert the color space or to modify properties such as hue and contrast for this output. For more information, see https://docs.aws.amazon.com/mediaconvert/latest/ug/converting-the-color-space.html.
15814 15815 15816 15817 15818 15819 15820 15821 15822 15823 15824 15825 15826 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 15814 class VideoPreprocessor < Struct.new( :color_corrector, :deinterlacer, :dolby_vision, :duration_control, :hdr_10_plus, :image_inserter, :noise_reducer, :partner_watermarking, :timecode_burnin) SENSITIVE = [] include Aws::Structure end |
#deinterlacer ⇒ Types::Deinterlacer
Use the deinterlacer to produce smoother motion and a clearer picture. For more information, see https://docs.aws.amazon.com/mediaconvert/latest/ug/working-with-scan-type.html.
15814 15815 15816 15817 15818 15819 15820 15821 15822 15823 15824 15825 15826 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 15814 class VideoPreprocessor < Struct.new( :color_corrector, :deinterlacer, :dolby_vision, :duration_control, :hdr_10_plus, :image_inserter, :noise_reducer, :partner_watermarking, :timecode_burnin) SENSITIVE = [] include Aws::Structure end |
#dolby_vision ⇒ Types::DolbyVision
Enable Dolby Vision feature to produce Dolby Vision compatible video output.
15814 15815 15816 15817 15818 15819 15820 15821 15822 15823 15824 15825 15826 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 15814 class VideoPreprocessor < Struct.new( :color_corrector, :deinterlacer, :dolby_vision, :duration_control, :hdr_10_plus, :image_inserter, :noise_reducer, :partner_watermarking, :timecode_burnin) SENSITIVE = [] include Aws::Structure end |
#duration_control ⇒ Types::DurationControl
Enable integer-second duration normalization. When enabled, the output duration is adjusted to land on an exact integer-second boundary. The adjustment method (trim, compress, or pad) is chosen automatically based on how far the input duration is from the nearest integer second.
15814 15815 15816 15817 15818 15819 15820 15821 15822 15823 15824 15825 15826 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 15814 class VideoPreprocessor < Struct.new( :color_corrector, :deinterlacer, :dolby_vision, :duration_control, :hdr_10_plus, :image_inserter, :noise_reducer, :partner_watermarking, :timecode_burnin) SENSITIVE = [] include Aws::Structure end |
#hdr_10_plus ⇒ Types::Hdr10Plus
Enable HDR10+ analysis and metadata injection. Compatible with HEVC only.
15814 15815 15816 15817 15818 15819 15820 15821 15822 15823 15824 15825 15826 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 15814 class VideoPreprocessor < Struct.new( :color_corrector, :deinterlacer, :dolby_vision, :duration_control, :hdr_10_plus, :image_inserter, :noise_reducer, :partner_watermarking, :timecode_burnin) SENSITIVE = [] include Aws::Structure end |
#image_inserter ⇒ Types::ImageInserter
Enable the Image inserter feature to include a graphic overlay on your video. Enable or disable this feature for each output individually. This setting is disabled by default.
15814 15815 15816 15817 15818 15819 15820 15821 15822 15823 15824 15825 15826 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 15814 class VideoPreprocessor < Struct.new( :color_corrector, :deinterlacer, :dolby_vision, :duration_control, :hdr_10_plus, :image_inserter, :noise_reducer, :partner_watermarking, :timecode_burnin) SENSITIVE = [] include Aws::Structure end |
#noise_reducer ⇒ Types::NoiseReducer
Enable the Noise reducer feature to remove noise from your video output if necessary. Enable or disable this feature for each output individually. This setting is disabled by default. When you enable Noise reducer, you must also select a value for Noise reducer filter. For AVC outputs, when you include Noise reducer, you cannot include the Bandwidth reduction filter.
15814 15815 15816 15817 15818 15819 15820 15821 15822 15823 15824 15825 15826 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 15814 class VideoPreprocessor < Struct.new( :color_corrector, :deinterlacer, :dolby_vision, :duration_control, :hdr_10_plus, :image_inserter, :noise_reducer, :partner_watermarking, :timecode_burnin) SENSITIVE = [] include Aws::Structure end |
#partner_watermarking ⇒ Types::PartnerWatermarking
If you work with a third party video watermarking partner, use the group of settings that correspond with your watermarking partner to include watermarks in your output.
15814 15815 15816 15817 15818 15819 15820 15821 15822 15823 15824 15825 15826 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 15814 class VideoPreprocessor < Struct.new( :color_corrector, :deinterlacer, :dolby_vision, :duration_control, :hdr_10_plus, :image_inserter, :noise_reducer, :partner_watermarking, :timecode_burnin) SENSITIVE = [] include Aws::Structure end |
#timecode_burnin ⇒ Types::TimecodeBurnin
Settings for burning the output timecode and specified prefix into the output.
15814 15815 15816 15817 15818 15819 15820 15821 15822 15823 15824 15825 15826 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 15814 class VideoPreprocessor < Struct.new( :color_corrector, :deinterlacer, :dolby_vision, :duration_control, :hdr_10_plus, :image_inserter, :noise_reducer, :partner_watermarking, :timecode_burnin) SENSITIVE = [] include Aws::Structure end |