Class: Aws::MediaConvert::Types::WarningGroup

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediaconvert/types.rb

Overview

Contains any warning codes and their count for the job.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#codeInteger

Warning code that identifies a specific warning in the job. For more information, see docs.aws.amazon.com/mediaconvert/latest/ug/warning_codes.html



15849
15850
15851
15852
15853
15854
# File 'lib/aws-sdk-mediaconvert/types.rb', line 15849

class WarningGroup < Struct.new(
  :code,
  :count)
  SENSITIVE = []
  include Aws::Structure
end

#countInteger

The number of times this warning occurred in the job.



15849
15850
15851
15852
15853
15854
# File 'lib/aws-sdk-mediaconvert/types.rb', line 15849

class WarningGroup < Struct.new(
  :code,
  :count)
  SENSITIVE = []
  include Aws::Structure
end