Class: Aws::MediaConvert::Types::WavSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::WavSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
Required when you set Codec to the value WAV.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bit_depth ⇒ Integer
Specify Bit depth, in bits per sample, to choose the encoding quality for this audio track.
-
#channels ⇒ Integer
Specify the number of channels in this output audio track.
-
#format ⇒ String
Specify the file format for your wave audio output.
-
#sample_rate ⇒ Integer
Sample rate in Hz.
Instance Attribute Details
#bit_depth ⇒ Integer
Specify Bit depth, in bits per sample, to choose the encoding quality for this audio track.
15882 15883 15884 15885 15886 15887 15888 15889 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 15882 class WavSettings < Struct.new( :bit_depth, :channels, :format, :sample_rate) SENSITIVE = [] include Aws::Structure end |
#channels ⇒ Integer
Specify the number of channels in this output audio track. Valid values are 0, 1, and even numbers up to 64. Choose 0 to follow the number of channels from your input audio. Otherwise, manually choose from 1, 2, 4, 6, and so on, up to 64.
15882 15883 15884 15885 15886 15887 15888 15889 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 15882 class WavSettings < Struct.new( :bit_depth, :channels, :format, :sample_rate) SENSITIVE = [] include Aws::Structure end |
#format ⇒ String
Specify the file format for your wave audio output. To use a RIFF wave format: Keep the default value, RIFF. If your output audio is likely to exceed 4GB in file size, or if you otherwise need the extended support of the RF64 format: Choose RF64. If your player only supports the extensible wave format: Choose Extensible.
15882 15883 15884 15885 15886 15887 15888 15889 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 15882 class WavSettings < Struct.new( :bit_depth, :channels, :format, :sample_rate) SENSITIVE = [] include Aws::Structure end |
#sample_rate ⇒ Integer
Sample rate in Hz.
15882 15883 15884 15885 15886 15887 15888 15889 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 15882 class WavSettings < Struct.new( :bit_depth, :channels, :format, :sample_rate) SENSITIVE = [] include Aws::Structure end |