Class: Aws::MediaConvert::Types::WebvttHlsSourceSettings

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediaconvert/types.rb

Overview

Settings specific to WebVTT sources in HLS alternative rendition group. Specify the properties (renditionGroupId, renditionName or renditionLanguageCode) to identify the unique subtitle track among the alternative rendition groups present in the HLS manifest. If no unique track is found, or multiple tracks match the specified properties, the job fails. If there is only one subtitle track in the rendition group, the settings can be left empty and the default subtitle track will be chosen. If your caption source is a sidecar file, use FileSourceSettings instead of WebvttHlsSourceSettings.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#rendition_group_idString

Optional. Specify alternative group ID



15973
15974
15975
15976
15977
15978
15979
# File 'lib/aws-sdk-mediaconvert/types.rb', line 15973

class WebvttHlsSourceSettings < Struct.new(
  :rendition_group_id,
  :rendition_language_code,
  :rendition_name)
  SENSITIVE = []
  include Aws::Structure
end

#rendition_language_codeString

Optionally specify the language, using an ISO 639-2 or ISO 639-3 three-letter code in all capital letters. You can find a list of codes at: www.loc.gov/standards/iso639-2/php/code_list.php



15973
15974
15975
15976
15977
15978
15979
# File 'lib/aws-sdk-mediaconvert/types.rb', line 15973

class WebvttHlsSourceSettings < Struct.new(
  :rendition_group_id,
  :rendition_language_code,
  :rendition_name)
  SENSITIVE = []
  include Aws::Structure
end

#rendition_nameString

Optional. Specify media name



15973
15974
15975
15976
15977
15978
15979
# File 'lib/aws-sdk-mediaconvert/types.rb', line 15973

class WebvttHlsSourceSettings < Struct.new(
  :rendition_group_id,
  :rendition_language_code,
  :rendition_name)
  SENSITIVE = []
  include Aws::Structure
end