Class: Aws::MediaConvert::Types::Xavc4kProfileSettings

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediaconvert/types.rb

Overview

Note:

When making an API call, you may pass Xavc4kProfileSettings data as a hash:

{
  bitrate_class: "BITRATE_CLASS_100", # accepts BITRATE_CLASS_100, BITRATE_CLASS_140, BITRATE_CLASS_200
  codec_profile: "HIGH", # accepts HIGH, HIGH_422
  flicker_adaptive_quantization: "DISABLED", # accepts DISABLED, ENABLED
  gop_b_reference: "DISABLED", # accepts DISABLED, ENABLED
  gop_closed_cadence: 1,
  hrd_buffer_size: 1,
  quality_tuning_level: "SINGLE_PASS", # accepts SINGLE_PASS, SINGLE_PASS_HQ, MULTI_PASS_HQ
  slices: 1,
}

Required when you set (Profile) under (VideoDescription)>(CodecSettings)>(XavcSettings) to the value XAVC_4K.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bitrate_classString

Specify the XAVC 4k (Long GOP) Bitrate Class to set the bitrate of your output. Outputs of the same class have similar image quality over the operating points that are valid for that class.

Returns:

  • (String)


27646
27647
27648
27649
27650
27651
27652
27653
27654
27655
27656
27657
# File 'lib/aws-sdk-mediaconvert/types.rb', line 27646

class Xavc4kProfileSettings < Struct.new(
  :bitrate_class,
  :codec_profile,
  :flicker_adaptive_quantization,
  :gop_b_reference,
  :gop_closed_cadence,
  :hrd_buffer_size,
  :quality_tuning_level,
  :slices)
  SENSITIVE = []
  include Aws::Structure
end

#codec_profileString

Specify the codec profile for this output. Choose High, 8-bit, 4:2:0 (HIGH) or High, 10-bit, 4:2:2 (HIGH_422). These profiles are specified in ITU-T H.264.

Returns:

  • (String)


27646
27647
27648
27649
27650
27651
27652
27653
27654
27655
27656
27657
# File 'lib/aws-sdk-mediaconvert/types.rb', line 27646

class Xavc4kProfileSettings < Struct.new(
  :bitrate_class,
  :codec_profile,
  :flicker_adaptive_quantization,
  :gop_b_reference,
  :gop_closed_cadence,
  :hrd_buffer_size,
  :quality_tuning_level,
  :slices)
  SENSITIVE = []
  include Aws::Structure
end

#flicker_adaptive_quantizationString

The best way to set up adaptive quantization is to keep the default value, Auto (AUTO), for the setting Adaptive quantization (XavcAdaptiveQuantization). When you do so, MediaConvert automatically applies the best types of quantization for your video content. Include this setting in your JSON job specification only when you choose to change the default value for Adaptive quantization. Enable this setting to have the encoder reduce I-frame pop. I-frame pop appears as a visual flicker that can arise when the encoder saves bits by copying some macroblocks many times from frame to frame, and then refreshes them at the I-frame. When you enable this setting, the encoder updates these macroblocks slightly more often to smooth out the flicker. This setting is disabled by default. Related setting: In addition to enabling this setting, you must also set Adaptive quantization (adaptiveQuantization) to a value other than Off (OFF) or Auto (AUTO). Use Adaptive quantization to adjust the degree of smoothing that Flicker adaptive quantization provides.

Returns:

  • (String)


27646
27647
27648
27649
27650
27651
27652
27653
27654
27655
27656
27657
# File 'lib/aws-sdk-mediaconvert/types.rb', line 27646

class Xavc4kProfileSettings < Struct.new(
  :bitrate_class,
  :codec_profile,
  :flicker_adaptive_quantization,
  :gop_b_reference,
  :gop_closed_cadence,
  :hrd_buffer_size,
  :quality_tuning_level,
  :slices)
  SENSITIVE = []
  include Aws::Structure
end

#gop_b_referenceString

Specify whether the encoder uses B-frames as reference frames for other pictures in the same GOP. Choose Allow (ENABLED) to allow the encoder to use B-frames as reference frames. Choose Don't allow (DISABLED) to prevent the encoder from using B-frames as reference frames.

Returns:

  • (String)


27646
27647
27648
27649
27650
27651
27652
27653
27654
27655
27656
27657
# File 'lib/aws-sdk-mediaconvert/types.rb', line 27646

class Xavc4kProfileSettings < Struct.new(
  :bitrate_class,
  :codec_profile,
  :flicker_adaptive_quantization,
  :gop_b_reference,
  :gop_closed_cadence,
  :hrd_buffer_size,
  :quality_tuning_level,
  :slices)
  SENSITIVE = []
  include Aws::Structure
end

#gop_closed_cadenceInteger

Frequency of closed GOPs. In streaming applications, it is recommended that this be set to 1 so a decoder joining mid-stream will receive an IDR frame as quickly as possible. Setting this value to 0 will break output segmenting.

Returns:

  • (Integer)


27646
27647
27648
27649
27650
27651
27652
27653
27654
27655
27656
27657
# File 'lib/aws-sdk-mediaconvert/types.rb', line 27646

class Xavc4kProfileSettings < Struct.new(
  :bitrate_class,
  :codec_profile,
  :flicker_adaptive_quantization,
  :gop_b_reference,
  :gop_closed_cadence,
  :hrd_buffer_size,
  :quality_tuning_level,
  :slices)
  SENSITIVE = []
  include Aws::Structure
end

#hrd_buffer_sizeInteger

Specify the size of the buffer that MediaConvert uses in the HRD buffer model for this output. Specify this value in bits; for example, enter five megabits as 5000000. When you don't set this value, or you set it to zero, MediaConvert calculates the default by doubling the bitrate of this output point.

Returns:

  • (Integer)


27646
27647
27648
27649
27650
27651
27652
27653
27654
27655
27656
27657
# File 'lib/aws-sdk-mediaconvert/types.rb', line 27646

class Xavc4kProfileSettings < Struct.new(
  :bitrate_class,
  :codec_profile,
  :flicker_adaptive_quantization,
  :gop_b_reference,
  :gop_closed_cadence,
  :hrd_buffer_size,
  :quality_tuning_level,
  :slices)
  SENSITIVE = []
  include Aws::Structure
end

#quality_tuning_levelString

Optional. Use Quality tuning level (qualityTuningLevel) to choose how you want to trade off encoding speed for output video quality. The default behavior is faster, lower quality, single-pass encoding.

Returns:

  • (String)


27646
27647
27648
27649
27650
27651
27652
27653
27654
27655
27656
27657
# File 'lib/aws-sdk-mediaconvert/types.rb', line 27646

class Xavc4kProfileSettings < Struct.new(
  :bitrate_class,
  :codec_profile,
  :flicker_adaptive_quantization,
  :gop_b_reference,
  :gop_closed_cadence,
  :hrd_buffer_size,
  :quality_tuning_level,
  :slices)
  SENSITIVE = []
  include Aws::Structure
end

#slicesInteger

Number of slices per picture. Must be less than or equal to the number of macroblock rows for progressive pictures, and less than or equal to half the number of macroblock rows for interlaced pictures.

Returns:

  • (Integer)


27646
27647
27648
27649
27650
27651
27652
27653
27654
27655
27656
27657
# File 'lib/aws-sdk-mediaconvert/types.rb', line 27646

class Xavc4kProfileSettings < Struct.new(
  :bitrate_class,
  :codec_profile,
  :flicker_adaptive_quantization,
  :gop_b_reference,
  :gop_closed_cadence,
  :hrd_buffer_size,
  :quality_tuning_level,
  :slices)
  SENSITIVE = []
  include Aws::Structure
end