Class: Aws::MediaConvert::Types::AudioCodecSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::AudioCodecSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
Settings related to audio encoding. The settings in this group vary depending on the value that you choose for your audio codec.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aac_settings ⇒ Types::AacSettings
Required when you set (Codec) under (AudioDescriptions)>(CodecSettings) to the value AAC.
-
#ac_3_settings ⇒ Types::Ac3Settings
Required when you set (Codec) under (AudioDescriptions)>(CodecSettings) to the value AC3.
-
#aiff_settings ⇒ Types::AiffSettings
Required when you set (Codec) under (AudioDescriptions)>(CodecSettings) to the value AIFF.
-
#codec ⇒ String
Choose the audio codec for this output.
-
#eac_3_atmos_settings ⇒ Types::Eac3AtmosSettings
Required when you set (Codec) under (AudioDescriptions)>(CodecSettings) to the value EAC3_ATMOS.
-
#eac_3_settings ⇒ Types::Eac3Settings
Required when you set (Codec) under (AudioDescriptions)>(CodecSettings) to the value EAC3.
-
#mp_2_settings ⇒ Types::Mp2Settings
Required when you set (Codec) under (AudioDescriptions)>(CodecSettings) to the value MP2.
-
#mp_3_settings ⇒ Types::Mp3Settings
Required when you set Codec, under AudioDescriptions>CodecSettings, to the value MP3.
-
#opus_settings ⇒ Types::OpusSettings
Required when you set Codec, under AudioDescriptions>CodecSettings, to the value OPUS.
-
#vorbis_settings ⇒ Types::VorbisSettings
Required when you set Codec, under AudioDescriptions>CodecSettings, to the value Vorbis.
-
#wav_settings ⇒ Types::WavSettings
Required when you set (Codec) under (AudioDescriptions)>(CodecSettings) to the value WAV.
Instance Attribute Details
#aac_settings ⇒ Types::AacSettings
Required when you set (Codec) under (AudioDescriptions)>(CodecSettings) to the value AAC. The service accepts one of two mutually exclusive groups of AAC settings–VBR and CBR. To select one of these modes, set the value of Bitrate control mode (rateControlMode) to “VBR” or “CBR”. In VBR mode, you control the audio quality with the setting VBR quality (vbrQuality). In CBR mode, you use the setting Bitrate (bitrate). Defaults and valid values depend on the rate control mode.
445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 445 class AudioCodecSettings < Struct.new( :aac_settings, :ac_3_settings, :aiff_settings, :codec, :eac_3_atmos_settings, :eac_3_settings, :mp_2_settings, :mp_3_settings, :opus_settings, :vorbis_settings, :wav_settings) SENSITIVE = [] include Aws::Structure end |
#ac_3_settings ⇒ Types::Ac3Settings
Required when you set (Codec) under (AudioDescriptions)>(CodecSettings) to the value AC3.
445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 445 class AudioCodecSettings < Struct.new( :aac_settings, :ac_3_settings, :aiff_settings, :codec, :eac_3_atmos_settings, :eac_3_settings, :mp_2_settings, :mp_3_settings, :opus_settings, :vorbis_settings, :wav_settings) SENSITIVE = [] include Aws::Structure end |
#aiff_settings ⇒ Types::AiffSettings
Required when you set (Codec) under (AudioDescriptions)>(CodecSettings) to the value AIFF.
445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 445 class AudioCodecSettings < Struct.new( :aac_settings, :ac_3_settings, :aiff_settings, :codec, :eac_3_atmos_settings, :eac_3_settings, :mp_2_settings, :mp_3_settings, :opus_settings, :vorbis_settings, :wav_settings) SENSITIVE = [] include Aws::Structure end |
#codec ⇒ String
Choose the audio codec for this output. Note that the option Dolby Digital passthrough (PASSTHROUGH) applies only to Dolby Digital and Dolby Digital Plus audio inputs. Make sure that you choose a codec that's supported with your output container: docs.aws.amazon.com/mediaconvert/latest/ug/reference-codecs-containers.html#reference-codecs-containers-output-audio For audio-only outputs, make sure that both your input audio codec and your output audio codec are supported for audio-only workflows. For more information, see: docs.aws.amazon.com/mediaconvert/latest/ug/reference-codecs-containers-input.html#reference-codecs-containers-input-audio-only and docs.aws.amazon.com/mediaconvert/latest/ug/reference-codecs-containers.html#audio-only-output
445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 445 class AudioCodecSettings < Struct.new( :aac_settings, :ac_3_settings, :aiff_settings, :codec, :eac_3_atmos_settings, :eac_3_settings, :mp_2_settings, :mp_3_settings, :opus_settings, :vorbis_settings, :wav_settings) SENSITIVE = [] include Aws::Structure end |
#eac_3_atmos_settings ⇒ Types::Eac3AtmosSettings
Required when you set (Codec) under (AudioDescriptions)>(CodecSettings) to the value EAC3_ATMOS.
445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 445 class AudioCodecSettings < Struct.new( :aac_settings, :ac_3_settings, :aiff_settings, :codec, :eac_3_atmos_settings, :eac_3_settings, :mp_2_settings, :mp_3_settings, :opus_settings, :vorbis_settings, :wav_settings) SENSITIVE = [] include Aws::Structure end |
#eac_3_settings ⇒ Types::Eac3Settings
Required when you set (Codec) under (AudioDescriptions)>(CodecSettings) to the value EAC3.
445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 445 class AudioCodecSettings < Struct.new( :aac_settings, :ac_3_settings, :aiff_settings, :codec, :eac_3_atmos_settings, :eac_3_settings, :mp_2_settings, :mp_3_settings, :opus_settings, :vorbis_settings, :wav_settings) SENSITIVE = [] include Aws::Structure end |
#mp_2_settings ⇒ Types::Mp2Settings
Required when you set (Codec) under (AudioDescriptions)>(CodecSettings) to the value MP2.
445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 445 class AudioCodecSettings < Struct.new( :aac_settings, :ac_3_settings, :aiff_settings, :codec, :eac_3_atmos_settings, :eac_3_settings, :mp_2_settings, :mp_3_settings, :opus_settings, :vorbis_settings, :wav_settings) SENSITIVE = [] include Aws::Structure end |
#mp_3_settings ⇒ Types::Mp3Settings
Required when you set Codec, under AudioDescriptions>CodecSettings, to the value MP3.
445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 445 class AudioCodecSettings < Struct.new( :aac_settings, :ac_3_settings, :aiff_settings, :codec, :eac_3_atmos_settings, :eac_3_settings, :mp_2_settings, :mp_3_settings, :opus_settings, :vorbis_settings, :wav_settings) SENSITIVE = [] include Aws::Structure end |
#opus_settings ⇒ Types::OpusSettings
Required when you set Codec, under AudioDescriptions>CodecSettings, to the value OPUS.
445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 445 class AudioCodecSettings < Struct.new( :aac_settings, :ac_3_settings, :aiff_settings, :codec, :eac_3_atmos_settings, :eac_3_settings, :mp_2_settings, :mp_3_settings, :opus_settings, :vorbis_settings, :wav_settings) SENSITIVE = [] include Aws::Structure end |
#vorbis_settings ⇒ Types::VorbisSettings
Required when you set Codec, under AudioDescriptions>CodecSettings, to the value Vorbis.
445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 445 class AudioCodecSettings < Struct.new( :aac_settings, :ac_3_settings, :aiff_settings, :codec, :eac_3_atmos_settings, :eac_3_settings, :mp_2_settings, :mp_3_settings, :opus_settings, :vorbis_settings, :wav_settings) SENSITIVE = [] include Aws::Structure end |
#wav_settings ⇒ Types::WavSettings
Required when you set (Codec) under (AudioDescriptions)>(CodecSettings) to the value WAV.
445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 445 class AudioCodecSettings < Struct.new( :aac_settings, :ac_3_settings, :aiff_settings, :codec, :eac_3_atmos_settings, :eac_3_settings, :mp_2_settings, :mp_3_settings, :opus_settings, :vorbis_settings, :wav_settings) SENSITIVE = [] include Aws::Structure end |