Class: Aws::MediaConvert::Types::AudioProperties

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediaconvert/types.rb

Overview

Details about the media file’s audio track.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bit_depthInteger

The bit depth of the audio track.

Returns:

  • (Integer)


927
928
929
930
931
932
933
934
935
936
937
# File 'lib/aws-sdk-mediaconvert/types.rb', line 927

class AudioProperties < Struct.new(
  :bit_depth,
  :bit_rate,
  :channels,
  :frame_rate,
  :language_code,
  :object_count,
  :sample_rate)
  SENSITIVE = []
  include Aws::Structure
end

#bit_rateInteger

The bit rate of the audio track, in bits per second.

Returns:

  • (Integer)


927
928
929
930
931
932
933
934
935
936
937
# File 'lib/aws-sdk-mediaconvert/types.rb', line 927

class AudioProperties < Struct.new(
  :bit_depth,
  :bit_rate,
  :channels,
  :frame_rate,
  :language_code,
  :object_count,
  :sample_rate)
  SENSITIVE = []
  include Aws::Structure
end

#channelsInteger

The number of audio channels in the audio track.

Returns:

  • (Integer)


927
928
929
930
931
932
933
934
935
936
937
# File 'lib/aws-sdk-mediaconvert/types.rb', line 927

class AudioProperties < Struct.new(
  :bit_depth,
  :bit_rate,
  :channels,
  :frame_rate,
  :language_code,
  :object_count,
  :sample_rate)
  SENSITIVE = []
  include Aws::Structure
end

#frame_rateTypes::FrameRate

The frame rate of the video or audio track, expressed as a fraction with numerator and denominator values.

Returns:



927
928
929
930
931
932
933
934
935
936
937
# File 'lib/aws-sdk-mediaconvert/types.rb', line 927

class AudioProperties < Struct.new(
  :bit_depth,
  :bit_rate,
  :channels,
  :frame_rate,
  :language_code,
  :object_count,
  :sample_rate)
  SENSITIVE = []
  include Aws::Structure
end

#language_codeString

The language code of the audio track, in three character ISO 639-3 format.

Returns:

  • (String)


927
928
929
930
931
932
933
934
935
936
937
# File 'lib/aws-sdk-mediaconvert/types.rb', line 927

class AudioProperties < Struct.new(
  :bit_depth,
  :bit_rate,
  :channels,
  :frame_rate,
  :language_code,
  :object_count,
  :sample_rate)
  SENSITIVE = []
  include Aws::Structure
end

#object_countInteger

The number of audio objects in an object-based or immersive audio track. This field is present for codecs that support object-based audio, such as E-AC-3 with Joint Object Coding (JOC) or IAMF. This field is null when the audio track does not contain object-based audio metadata.

Returns:

  • (Integer)


927
928
929
930
931
932
933
934
935
936
937
# File 'lib/aws-sdk-mediaconvert/types.rb', line 927

class AudioProperties < Struct.new(
  :bit_depth,
  :bit_rate,
  :channels,
  :frame_rate,
  :language_code,
  :object_count,
  :sample_rate)
  SENSITIVE = []
  include Aws::Structure
end

#sample_rateInteger

The sample rate of the audio track.

Returns:

  • (Integer)


927
928
929
930
931
932
933
934
935
936
937
# File 'lib/aws-sdk-mediaconvert/types.rb', line 927

class AudioProperties < Struct.new(
  :bit_depth,
  :bit_rate,
  :channels,
  :frame_rate,
  :language_code,
  :object_count,
  :sample_rate)
  SENSITIVE = []
  include Aws::Structure
end