Class: Aws::MediaConvert::Types::AudioProperties
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::AudioProperties
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
Details about the media file's audio track.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bit_depth ⇒ Integer
The bit depth of the audio track.
-
#bit_rate ⇒ Integer
The bit rate of the audio track, in bits per second.
-
#channel_layout ⇒ String
The audio channel layout of the track, such as "mono", "stereo", "5.1", or "7.1".
-
#channels ⇒ Integer
The number of audio channels in the audio track.
-
#frame_rate ⇒ Types::FrameRate
The frame rate of the video or audio track, expressed as a fraction with numerator and denominator values.
-
#language_code ⇒ String
The language code of the audio track, in three character ISO 639-3 format.
-
#object_count ⇒ Integer
The number of audio objects in an object-based or immersive audio track.
-
#sample_rate ⇒ Integer
The sample rate of the audio track.
Instance Attribute Details
#bit_depth ⇒ Integer
The bit depth of the audio track.
976 977 978 979 980 981 982 983 984 985 986 987 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 976 class AudioProperties < Struct.new( :bit_depth, :bit_rate, :channel_layout, :channels, :frame_rate, :language_code, :object_count, :sample_rate) SENSITIVE = [] include Aws::Structure end |
#bit_rate ⇒ Integer
The bit rate of the audio track, in bits per second.
976 977 978 979 980 981 982 983 984 985 986 987 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 976 class AudioProperties < Struct.new( :bit_depth, :bit_rate, :channel_layout, :channels, :frame_rate, :language_code, :object_count, :sample_rate) SENSITIVE = [] include Aws::Structure end |
#channel_layout ⇒ String
The audio channel layout of the track, such as "mono", "stereo", "5.1", or "7.1". Object-based or immersive audio is reported as "5.1.4" or "7.1.4".
976 977 978 979 980 981 982 983 984 985 986 987 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 976 class AudioProperties < Struct.new( :bit_depth, :bit_rate, :channel_layout, :channels, :frame_rate, :language_code, :object_count, :sample_rate) SENSITIVE = [] include Aws::Structure end |
#channels ⇒ Integer
The number of audio channels in the audio track.
976 977 978 979 980 981 982 983 984 985 986 987 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 976 class AudioProperties < Struct.new( :bit_depth, :bit_rate, :channel_layout, :channels, :frame_rate, :language_code, :object_count, :sample_rate) SENSITIVE = [] include Aws::Structure end |
#frame_rate ⇒ Types::FrameRate
The frame rate of the video or audio track, expressed as a fraction with numerator and denominator values.
976 977 978 979 980 981 982 983 984 985 986 987 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 976 class AudioProperties < Struct.new( :bit_depth, :bit_rate, :channel_layout, :channels, :frame_rate, :language_code, :object_count, :sample_rate) SENSITIVE = [] include Aws::Structure end |
#language_code ⇒ String
The language code of the audio track, in three character ISO 639-3 format.
976 977 978 979 980 981 982 983 984 985 986 987 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 976 class AudioProperties < Struct.new( :bit_depth, :bit_rate, :channel_layout, :channels, :frame_rate, :language_code, :object_count, :sample_rate) SENSITIVE = [] include Aws::Structure end |
#object_count ⇒ Integer
The number of audio objects in an object-based or immersive audio track. This field is present for codecs that support object-based audio, such as E-AC-3 with Joint Object Coding (JOC) or IAMF. This field is null when the audio track does not contain object-based audio metadata.
976 977 978 979 980 981 982 983 984 985 986 987 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 976 class AudioProperties < Struct.new( :bit_depth, :bit_rate, :channel_layout, :channels, :frame_rate, :language_code, :object_count, :sample_rate) SENSITIVE = [] include Aws::Structure end |
#sample_rate ⇒ Integer
The sample rate of the audio track.
976 977 978 979 980 981 982 983 984 985 986 987 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 976 class AudioProperties < Struct.new( :bit_depth, :bit_rate, :channel_layout, :channels, :frame_rate, :language_code, :object_count, :sample_rate) SENSITIVE = [] include Aws::Structure end |