Class: Aws::MediaConvert::Types::AutomatedEncodingSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::AutomatedEncodingSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
Note:
When making an API call, you may pass AutomatedEncodingSettings data as a hash:
{
abr_settings: {
max_abr_bitrate: 1,
max_renditions: 1,
min_abr_bitrate: 1,
},
}
Use automated encoding to have MediaConvert choose your encoding settings for you, based on characteristics of your input video.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#abr_settings ⇒ Types::AutomatedAbrSettings
Use automated ABR to have MediaConvert set up the renditions in your ABR package for you automatically, based on characteristics of your input video.
Instance Attribute Details
#abr_settings ⇒ Types::AutomatedAbrSettings
Use automated ABR to have MediaConvert set up the renditions in your ABR package for you automatically, based on characteristics of your input video. This feature optimizes video quality while minimizing the overall size of your ABR package.
1147 1148 1149 1150 1151 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 1147 class AutomatedEncodingSettings < Struct.new( :abr_settings) SENSITIVE = [] include Aws::Structure end |