Class: Aws::MediaConvert::Types::AvailBlanking
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::AvailBlanking
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
Note:
When making an API call, you may pass AvailBlanking data as a hash:
{
avail_blanking_image: "__stringMin14PatternS3BmpBMPPngPNGHttpsBmpBMPPngPNG",
}
Use ad avail blanking settings to specify your output content during SCTE-35 triggered ad avails. You can blank your video or overlay it with an image. MediaConvert also removes any audio and embedded captions during the ad avail. For more information, see docs.aws.amazon.com/mediaconvert/latest/ug/ad-avail-blanking.html.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#avail_blanking_image ⇒ String
Blanking image to be used.
Instance Attribute Details
#avail_blanking_image ⇒ String
Blanking image to be used. Leave empty for solid black. Only bmp and png images are supported.
1639 1640 1641 1642 1643 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 1639 class AvailBlanking < Struct.new( :avail_blanking_image) SENSITIVE = [] include Aws::Structure end |