Class: Aws::MediaConvert::Types::AvcIntraUhdSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::AvcIntraUhdSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
Note:
When making an API call, you may pass AvcIntraUhdSettings data as a hash:
{
quality_tuning_level: "SINGLE_PASS", # accepts SINGLE_PASS, MULTI_PASS
}
Optional when you set AVC-Intra class (avcIntraClass) to Class 4K/2K (CLASS_4K_2K). When you set AVC-Intra class to a different value, this object isn't allowed.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#quality_tuning_level ⇒ String
Optional.
Instance Attribute Details
#quality_tuning_level ⇒ String
Optional. Use Quality tuning level (qualityTuningLevel) to choose how many transcoding passes MediaConvert does with your video. When you choose Multi-pass (MULTI_PASS), your video quality is better and your output bitrate is more accurate. That is, the actual bitrate of your output is closer to the target bitrate defined in the specification. When you choose Single-pass (SINGLE_PASS), your encoding time is faster. The default behavior is Single-pass (SINGLE_PASS).
1832 1833 1834 1835 1836 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 1832 class AvcIntraUhdSettings < Struct.new( :quality_tuning_level) SENSITIVE = [] include Aws::Structure end |