Class: Aws::MediaConvert::Types::CaptionSourceFramerate

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediaconvert/types.rb

Overview

Ignore this setting unless your input captions format is SCC. To have the service compensate for differing frame rates between your input captions and input video, specify the frame rate of the captions file. Specify this value as a fraction. When you work directly in your JSON job specification, use the settings framerateNumerator and framerateDenominator. For example, you might specify 24 / 1 for 24 fps, 25 / 1 for 25 fps, 24000 / 1001 for 23.976 fps, or 30000 / 1001 for 29.97 fps.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#framerate_denominatorInteger

Specify the denominator of the fraction that represents the frame rate for the setting Caption source frame rate (CaptionSourceFramerate). Use this setting along with the setting Framerate numerator (framerateNumerator).

Returns:

  • (Integer)


1937
1938
1939
1940
1941
1942
# File 'lib/aws-sdk-mediaconvert/types.rb', line 1937

class CaptionSourceFramerate < Struct.new(
  :framerate_denominator,
  :framerate_numerator)
  SENSITIVE = []
  include Aws::Structure
end

#framerate_numeratorInteger

Specify the numerator of the fraction that represents the frame rate for the setting Caption source frame rate (CaptionSourceFramerate). Use this setting along with the setting Framerate denominator (framerateDenominator).

Returns:

  • (Integer)


1937
1938
1939
1940
1941
1942
# File 'lib/aws-sdk-mediaconvert/types.rb', line 1937

class CaptionSourceFramerate < Struct.new(
  :framerate_denominator,
  :framerate_numerator)
  SENSITIVE = []
  include Aws::Structure
end