Class: Aws::MediaConvert::Types::CmafEncryptionSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::CmafEncryptionSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
Settings for CMAF encryption
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#clear_lead_segments ⇒ Integer
Reduce video startup latency by leaving initial segments unencrypted while DRM license retrieval occurs in parallel.
-
#constant_initialization_vector ⇒ String
This is a 128-bit, 16-byte hex value represented by a 32-character text string.
-
#encryption_method ⇒ String
Specify the encryption scheme that you want the service to use when encrypting your CMAF segments.
-
#initialization_vector_in_manifest ⇒ String
When you use DRM with CMAF outputs, choose whether the service writes the 128-bit encryption initialization vector in the HLS and DASH manifests.
-
#speke_key_provider ⇒ Types::SpekeKeyProviderCmaf
If your output group type is CMAF, use these settings when doing DRM encryption with a SPEKE-compliant key provider.
-
#static_key_provider ⇒ Types::StaticKeyProvider
Use these settings to set up encryption with a static key provider.
-
#type ⇒ String
Specify whether your DRM encryption key is static or from a key provider that follows the SPEKE standard.
Instance Attribute Details
#clear_lead_segments ⇒ Integer
Reduce video startup latency by leaving initial segments unencrypted while DRM license retrieval occurs in parallel. This optimization allows immediate playback startup while maintaining content protection for the remainder of the stream. Specify the number of initial segments to leave unencrypted. Omit this field to disable Clear Lead. The HLS manifest will omit #EXT-X-KEY tags during clear segments and insert the first #EXT-X-KEY immediately before the first encrypted segment. Because encryption is applied at the fragment level, the actual duration of unencrypted content may be slightly longer than expected if the segment length is not evenly divisible by the fragment length. In such cases, encryption begins at the next fragment boundary after the specified clear lead segments, rather than at the exact segment boundary. This feature is supported exclusively for CMAF HLS (fMP4) outputs and is compatible with all existing key provider integrations (SPEKE v1, SPEKE v2, and Static Key encryption). Supported codecs: H.264, H.265, and AV1 video codecs, and AAC audio codec.
2551 2552 2553 2554 2555 2556 2557 2558 2559 2560 2561 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 2551 class CmafEncryptionSettings < Struct.new( :clear_lead_segments, :constant_initialization_vector, :encryption_method, :initialization_vector_in_manifest, :speke_key_provider, :static_key_provider, :type) SENSITIVE = [] include Aws::Structure end |
#constant_initialization_vector ⇒ String
This is a 128-bit, 16-byte hex value represented by a 32-character text string. If this parameter is not set then the Initialization Vector will follow the segment number by default.
2551 2552 2553 2554 2555 2556 2557 2558 2559 2560 2561 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 2551 class CmafEncryptionSettings < Struct.new( :clear_lead_segments, :constant_initialization_vector, :encryption_method, :initialization_vector_in_manifest, :speke_key_provider, :static_key_provider, :type) SENSITIVE = [] include Aws::Structure end |
#encryption_method ⇒ String
Specify the encryption scheme that you want the service to use when encrypting your CMAF segments. Choose AES-CBC subsample or AES_CTR.
2551 2552 2553 2554 2555 2556 2557 2558 2559 2560 2561 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 2551 class CmafEncryptionSettings < Struct.new( :clear_lead_segments, :constant_initialization_vector, :encryption_method, :initialization_vector_in_manifest, :speke_key_provider, :static_key_provider, :type) SENSITIVE = [] include Aws::Structure end |
#initialization_vector_in_manifest ⇒ String
When you use DRM with CMAF outputs, choose whether the service writes the 128-bit encryption initialization vector in the HLS and DASH manifests.
2551 2552 2553 2554 2555 2556 2557 2558 2559 2560 2561 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 2551 class CmafEncryptionSettings < Struct.new( :clear_lead_segments, :constant_initialization_vector, :encryption_method, :initialization_vector_in_manifest, :speke_key_provider, :static_key_provider, :type) SENSITIVE = [] include Aws::Structure end |
#speke_key_provider ⇒ Types::SpekeKeyProviderCmaf
If your output group type is CMAF, use these settings when doing DRM encryption with a SPEKE-compliant key provider. If your output group type is HLS, DASH, or Microsoft Smooth, use the SpekeKeyProvider settings instead.
2551 2552 2553 2554 2555 2556 2557 2558 2559 2560 2561 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 2551 class CmafEncryptionSettings < Struct.new( :clear_lead_segments, :constant_initialization_vector, :encryption_method, :initialization_vector_in_manifest, :speke_key_provider, :static_key_provider, :type) SENSITIVE = [] include Aws::Structure end |
#static_key_provider ⇒ Types::StaticKeyProvider
Use these settings to set up encryption with a static key provider.
2551 2552 2553 2554 2555 2556 2557 2558 2559 2560 2561 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 2551 class CmafEncryptionSettings < Struct.new( :clear_lead_segments, :constant_initialization_vector, :encryption_method, :initialization_vector_in_manifest, :speke_key_provider, :static_key_provider, :type) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
Specify whether your DRM encryption key is static or from a key provider that follows the SPEKE standard. For more information about SPEKE, see docs.aws.amazon.com/speke/latest/documentation/what-is-speke.html.
2551 2552 2553 2554 2555 2556 2557 2558 2559 2560 2561 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 2551 class CmafEncryptionSettings < Struct.new( :clear_lead_segments, :constant_initialization_vector, :encryption_method, :initialization_vector_in_manifest, :speke_key_provider, :static_key_provider, :type) SENSITIVE = [] include Aws::Structure end |