Class: Aws::MediaConvert::Types::CmafEncryptionSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::CmafEncryptionSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
When making an API call, you may pass CmafEncryptionSettings data as a hash:
{
constant_initialization_vector: "__stringMin32Max32Pattern09aFAF32",
encryption_method: "SAMPLE_AES", # accepts SAMPLE_AES, AES_CTR
initialization_vector_in_manifest: "INCLUDE", # accepts INCLUDE, EXCLUDE
speke_key_provider: {
certificate_arn: "__stringPatternArnAwsUsGovAcm",
dash_signaled_system_ids: ["__stringMin36Max36Pattern09aFAF809aFAF409aFAF409aFAF409aFAF12"],
hls_signaled_system_ids: ["__stringMin36Max36Pattern09aFAF809aFAF409aFAF409aFAF409aFAF12"],
resource_id: "__stringPatternW",
url: "__stringPatternHttps",
},
static_key_provider: {
key_format: "__stringPatternIdentityAZaZ26AZaZ09163",
key_format_versions: "__stringPatternDD",
static_key_value: "__stringPatternAZaZ0932",
url: "__string",
},
type: "SPEKE", # accepts SPEKE, STATIC_KEY
}
Settings for CMAF encryption
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#constant_initialization_vector ⇒ String
This is a 128-bit, 16-byte hex value represented by a 32-character text string.
-
#encryption_method ⇒ String
Specify the encryption scheme that you want the service to use when encrypting your CMAF segments.
-
#initialization_vector_in_manifest ⇒ String
When you use DRM with CMAF outputs, choose whether the service writes the 128-bit encryption initialization vector in the HLS and DASH manifests.
-
#speke_key_provider ⇒ Types::SpekeKeyProviderCmaf
If your output group type is CMAF, use these settings when doing DRM encryption with a SPEKE-compliant key provider.
-
#static_key_provider ⇒ Types::StaticKeyProvider
Use these settings to set up encryption with a static key provider.
-
#type ⇒ String
Specify whether your DRM encryption key is static or from a key provider that follows the SPEKE standard.
Instance Attribute Details
#constant_initialization_vector ⇒ String
This is a 128-bit, 16-byte hex value represented by a 32-character text string. If this parameter is not set then the Initialization Vector will follow the segment number by default.
2989 2990 2991 2992 2993 2994 2995 2996 2997 2998 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 2989 class CmafEncryptionSettings < Struct.new( :constant_initialization_vector, :encryption_method, :initialization_vector_in_manifest, :speke_key_provider, :static_key_provider, :type) SENSITIVE = [] include Aws::Structure end |
#encryption_method ⇒ String
Specify the encryption scheme that you want the service to use when encrypting your CMAF segments. Choose AES-CBC subsample (SAMPLE-AES) or AES_CTR (AES-CTR).
2989 2990 2991 2992 2993 2994 2995 2996 2997 2998 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 2989 class CmafEncryptionSettings < Struct.new( :constant_initialization_vector, :encryption_method, :initialization_vector_in_manifest, :speke_key_provider, :static_key_provider, :type) SENSITIVE = [] include Aws::Structure end |
#initialization_vector_in_manifest ⇒ String
When you use DRM with CMAF outputs, choose whether the service writes the 128-bit encryption initialization vector in the HLS and DASH manifests.
2989 2990 2991 2992 2993 2994 2995 2996 2997 2998 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 2989 class CmafEncryptionSettings < Struct.new( :constant_initialization_vector, :encryption_method, :initialization_vector_in_manifest, :speke_key_provider, :static_key_provider, :type) SENSITIVE = [] include Aws::Structure end |
#speke_key_provider ⇒ Types::SpekeKeyProviderCmaf
If your output group type is CMAF, use these settings when doing DRM encryption with a SPEKE-compliant key provider. If your output group type is HLS, DASH, or Microsoft Smooth, use the SpekeKeyProvider settings instead.
2989 2990 2991 2992 2993 2994 2995 2996 2997 2998 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 2989 class CmafEncryptionSettings < Struct.new( :constant_initialization_vector, :encryption_method, :initialization_vector_in_manifest, :speke_key_provider, :static_key_provider, :type) SENSITIVE = [] include Aws::Structure end |
#static_key_provider ⇒ Types::StaticKeyProvider
Use these settings to set up encryption with a static key provider.
2989 2990 2991 2992 2993 2994 2995 2996 2997 2998 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 2989 class CmafEncryptionSettings < Struct.new( :constant_initialization_vector, :encryption_method, :initialization_vector_in_manifest, :speke_key_provider, :static_key_provider, :type) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
Specify whether your DRM encryption key is static or from a key provider that follows the SPEKE standard. For more information about SPEKE, see docs.aws.amazon.com/speke/latest/documentation/what-is-speke.html.
2989 2990 2991 2992 2993 2994 2995 2996 2997 2998 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 2989 class CmafEncryptionSettings < Struct.new( :constant_initialization_vector, :encryption_method, :initialization_vector_in_manifest, :speke_key_provider, :static_key_provider, :type) SENSITIVE = [] include Aws::Structure end |