Class: Aws::MediaConvert::Types::CmafEncryptionSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::CmafEncryptionSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
Settings for CMAF encryption
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#clear_lead ⇒ String
Enable Clear Lead DRM to reduce video startup latency by leaving the first segment unencrypted while DRM license retrieval occurs in parallel.
-
#constant_initialization_vector ⇒ String
This is a 128-bit, 16-byte hex value represented by a 32-character text string.
-
#encryption_method ⇒ String
Specify the encryption scheme that you want the service to use when encrypting your CMAF segments.
-
#initialization_vector_in_manifest ⇒ String
When you use DRM with CMAF outputs, choose whether the service writes the 128-bit encryption initialization vector in the HLS and DASH manifests.
-
#speke_key_provider ⇒ Types::SpekeKeyProviderCmaf
If your output group type is CMAF, use these settings when doing DRM encryption with a SPEKE-compliant key provider.
-
#static_key_provider ⇒ Types::StaticKeyProvider
Use these settings to set up encryption with a static key provider.
-
#type ⇒ String
Specify whether your DRM encryption key is static or from a key provider that follows the SPEKE standard.
Instance Attribute Details
#clear_lead ⇒ String
Enable Clear Lead DRM to reduce video startup latency by leaving the first segment unencrypted while DRM license retrieval occurs in parallel. This optimization allows immediate playback startup while maintaining content protection for the remainder of the stream. When enabled, the first output segment remains fully unencrypted, and encryption begins at the start of the second segment. The HLS manifest will omit #EXT-X-KEY tags during the clear segment and insert the first #EXT-X-KEY immediately before the first encrypted fragment. This feature is supported exclusively for CMAF HLS (fMP4) outputs and is compatible with all existing key provider integrations (SPEKE v1, SPEKE v2, and Static Key encryption). Supported codecs: H.264 and H.265 video codecs, and AAC audio codec. Choose Enabled to activate Clear Lead DRM optimization. Choose Disabled to use standard encryption where all segments are encrypted from the beginning.
2540 2541 2542 2543 2544 2545 2546 2547 2548 2549 2550 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 2540 class CmafEncryptionSettings < Struct.new( :clear_lead, :constant_initialization_vector, :encryption_method, :initialization_vector_in_manifest, :speke_key_provider, :static_key_provider, :type) SENSITIVE = [] include Aws::Structure end |
#constant_initialization_vector ⇒ String
This is a 128-bit, 16-byte hex value represented by a 32-character text string. If this parameter is not set then the Initialization Vector will follow the segment number by default.
2540 2541 2542 2543 2544 2545 2546 2547 2548 2549 2550 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 2540 class CmafEncryptionSettings < Struct.new( :clear_lead, :constant_initialization_vector, :encryption_method, :initialization_vector_in_manifest, :speke_key_provider, :static_key_provider, :type) SENSITIVE = [] include Aws::Structure end |
#encryption_method ⇒ String
Specify the encryption scheme that you want the service to use when encrypting your CMAF segments. Choose AES-CBC subsample or AES_CTR.
2540 2541 2542 2543 2544 2545 2546 2547 2548 2549 2550 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 2540 class CmafEncryptionSettings < Struct.new( :clear_lead, :constant_initialization_vector, :encryption_method, :initialization_vector_in_manifest, :speke_key_provider, :static_key_provider, :type) SENSITIVE = [] include Aws::Structure end |
#initialization_vector_in_manifest ⇒ String
When you use DRM with CMAF outputs, choose whether the service writes the 128-bit encryption initialization vector in the HLS and DASH manifests.
2540 2541 2542 2543 2544 2545 2546 2547 2548 2549 2550 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 2540 class CmafEncryptionSettings < Struct.new( :clear_lead, :constant_initialization_vector, :encryption_method, :initialization_vector_in_manifest, :speke_key_provider, :static_key_provider, :type) SENSITIVE = [] include Aws::Structure end |
#speke_key_provider ⇒ Types::SpekeKeyProviderCmaf
If your output group type is CMAF, use these settings when doing DRM encryption with a SPEKE-compliant key provider. If your output group type is HLS, DASH, or Microsoft Smooth, use the SpekeKeyProvider settings instead.
2540 2541 2542 2543 2544 2545 2546 2547 2548 2549 2550 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 2540 class CmafEncryptionSettings < Struct.new( :clear_lead, :constant_initialization_vector, :encryption_method, :initialization_vector_in_manifest, :speke_key_provider, :static_key_provider, :type) SENSITIVE = [] include Aws::Structure end |
#static_key_provider ⇒ Types::StaticKeyProvider
Use these settings to set up encryption with a static key provider.
2540 2541 2542 2543 2544 2545 2546 2547 2548 2549 2550 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 2540 class CmafEncryptionSettings < Struct.new( :clear_lead, :constant_initialization_vector, :encryption_method, :initialization_vector_in_manifest, :speke_key_provider, :static_key_provider, :type) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
Specify whether your DRM encryption key is static or from a key provider that follows the SPEKE standard. For more information about SPEKE, see docs.aws.amazon.com/speke/latest/documentation/what-is-speke.html.
2540 2541 2542 2543 2544 2545 2546 2547 2548 2549 2550 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 2540 class CmafEncryptionSettings < Struct.new( :clear_lead, :constant_initialization_vector, :encryption_method, :initialization_vector_in_manifest, :speke_key_provider, :static_key_provider, :type) SENSITIVE = [] include Aws::Structure end |