Class: Aws::MediaConvert::Types::CreateQueueRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::CreateQueueRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
When making an API call, you may pass CreateQueueRequest data as a hash:
{
description: "__string",
name: "__string", # required
pricing_plan: "ON_DEMAND", # accepts ON_DEMAND, RESERVED
reservation_plan_settings: {
commitment: "ONE_YEAR", # required, accepts ONE_YEAR
renewal_type: "AUTO_RENEW", # required, accepts AUTO_RENEW, EXPIRE
reserved_slots: 1, # required
},
status: "ACTIVE", # accepts ACTIVE, PAUSED
tags: {
"__string" => "__string",
},
}
Create an on-demand queue by sending a CreateQueue request with the name of the queue. Create a reserved queue by sending a CreateQueue request with the pricing plan set to RESERVED and with values specified for the settings under reservationPlanSettings. When you create a reserved queue, you enter into a 12-month commitment to purchase the RTS that you specify. You can't cancel this commitment.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
Optional.
-
#name ⇒ String
The name of the queue that you are creating.
-
#pricing_plan ⇒ String
Specifies whether the pricing plan for the queue is on-demand or reserved.
-
#reservation_plan_settings ⇒ Types::ReservationPlanSettings
Details about the pricing plan for your reserved queue.
-
#status ⇒ String
Initial state of the queue.
-
#tags ⇒ Hash<String,String>
The tags that you want to add to the resource.
Instance Attribute Details
#description ⇒ String
Optional. A description of the queue that you are creating.
7528 7529 7530 7531 7532 7533 7534 7535 7536 7537 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 7528 class CreateQueueRequest < Struct.new( :description, :name, :pricing_plan, :reservation_plan_settings, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the queue that you are creating.
7528 7529 7530 7531 7532 7533 7534 7535 7536 7537 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 7528 class CreateQueueRequest < Struct.new( :description, :name, :pricing_plan, :reservation_plan_settings, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#pricing_plan ⇒ String
Specifies whether the pricing plan for the queue is on-demand or reserved. For on-demand, you pay per minute, billed in increments of .01 minute. For reserved, you pay for the transcoding capacity of the entire queue, regardless of how much or how little you use it. Reserved pricing requires a 12-month commitment. When you use the API to create a queue, the default is on-demand.
7528 7529 7530 7531 7532 7533 7534 7535 7536 7537 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 7528 class CreateQueueRequest < Struct.new( :description, :name, :pricing_plan, :reservation_plan_settings, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#reservation_plan_settings ⇒ Types::ReservationPlanSettings
Details about the pricing plan for your reserved queue. Required for reserved queues and not applicable to on-demand queues.
7528 7529 7530 7531 7532 7533 7534 7535 7536 7537 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 7528 class CreateQueueRequest < Struct.new( :description, :name, :pricing_plan, :reservation_plan_settings, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
Initial state of the queue. If you create a paused queue, then jobs in that queue won't begin.
7528 7529 7530 7531 7532 7533 7534 7535 7536 7537 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 7528 class CreateQueueRequest < Struct.new( :description, :name, :pricing_plan, :reservation_plan_settings, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags that you want to add to the resource. You can tag resources with a key-value pair or with only a key.
7528 7529 7530 7531 7532 7533 7534 7535 7536 7537 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 7528 class CreateQueueRequest < Struct.new( :description, :name, :pricing_plan, :reservation_plan_settings, :status, :tags) SENSITIVE = [] include Aws::Structure end |