Class: Aws::MediaConvert::Types::DashIsoEncryptionSettings

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediaconvert/types.rb

Overview

Specifies DRM settings for DASH outputs.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#playback_device_compatibilityString

This setting can improve the compatibility of your output with video players on obsolete devices. It applies only to DASH H.264 outputs with DRM encryption. Choose Unencrypted SEI (UNENCRYPTED_SEI) only to correct problems with playback on older devices. Otherwise, keep the default setting CENC v1 (CENC_V1). If you choose Unencrypted SEI, for that output, the service will exclude the access unit delimiter and will leave the SEI NAL units unencrypted.

Returns:

  • (String)


3291
3292
3293
3294
3295
3296
# File 'lib/aws-sdk-mediaconvert/types.rb', line 3291

class DashIsoEncryptionSettings < Struct.new(
  :playback_device_compatibility,
  :speke_key_provider)
  SENSITIVE = []
  include Aws::Structure
end

#speke_key_providerTypes::SpekeKeyProvider

If your output group type is HLS, DASH, or Microsoft Smooth, use these settings when doing DRM encryption with a SPEKE-compliant key provider. If your output group type is CMAF, use the SpekeKeyProviderCmaf settings instead.



3291
3292
3293
3294
3295
3296
# File 'lib/aws-sdk-mediaconvert/types.rb', line 3291

class DashIsoEncryptionSettings < Struct.new(
  :playback_device_compatibility,
  :speke_key_provider)
  SENSITIVE = []
  include Aws::Structure
end