Class: Aws::MediaConvert::Types::DashIsoEncryptionSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::DashIsoEncryptionSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
Specifies DRM settings for DASH outputs.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#playback_device_compatibility ⇒ String
This setting can improve the compatibility of your output with video players on obsolete devices.
-
#speke_key_provider ⇒ Types::SpekeKeyProvider
If your output group type is HLS, DASH, or Microsoft Smooth, use these settings when doing DRM encryption with a SPEKE-compliant key provider.
Instance Attribute Details
#playback_device_compatibility ⇒ String
This setting can improve the compatibility of your output with video players on obsolete devices. It applies only to DASH outputs with DRM encryption. Choose Unencrypted SEI only to correct problems with playback on older H.264 devices. Choose CENC v1 unencrypted headers to leave NAL unit headers and slice headers unencrypted for H.265 outputs, improving compatibility with strict HEVC decoders. Otherwise, keep the default setting CENC v1.
4179 4180 4181 4182 4183 4184 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 4179 class DashIsoEncryptionSettings < Struct.new( :playback_device_compatibility, :speke_key_provider) SENSITIVE = [] include Aws::Structure end |
#speke_key_provider ⇒ Types::SpekeKeyProvider
If your output group type is HLS, DASH, or Microsoft Smooth, use these settings when doing DRM encryption with a SPEKE-compliant key provider. If your output group type is CMAF, use the SpekeKeyProviderCmaf settings instead.
4179 4180 4181 4182 4183 4184 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 4179 class DashIsoEncryptionSettings < Struct.new( :playback_device_compatibility, :speke_key_provider) SENSITIVE = [] include Aws::Structure end |