Class: Aws::MediaConvert::Types::Deinterlacer
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::Deinterlacer
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
When making an API call, you may pass Deinterlacer data as a hash:
{
algorithm: "INTERPOLATE", # accepts INTERPOLATE, INTERPOLATE_TICKER, BLEND, BLEND_TICKER
control: "FORCE_ALL_FRAMES", # accepts FORCE_ALL_FRAMES, NORMAL
mode: "DEINTERLACE", # accepts DEINTERLACE, INVERSE_TELECINE, ADAPTIVE
}
Settings for deinterlacer
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#algorithm ⇒ String
Only applies when you set Deinterlacer (DeinterlaceMode) to Deinterlace (DEINTERLACE) or Adaptive (ADAPTIVE).
-
#control ⇒ String
- When set to NORMAL (default), the deinterlacer does not convert frames that are tagged in metadata as progressive.
-
#mode ⇒ String
Use Deinterlacer (DeinterlaceMode) to choose how the service will do deinterlacing.
Instance Attribute Details
#algorithm ⇒ String
Only applies when you set Deinterlacer (DeinterlaceMode) to Deinterlace (DEINTERLACE) or Adaptive (ADAPTIVE). Motion adaptive interpolate (INTERPOLATE) produces sharper pictures, while blend (BLEND) produces smoother motion. Use (INTERPOLATE_TICKER) OR (BLEND_TICKER) if your source file includes a ticker, such as a scrolling headline at the bottom of the frame.
7655 7656 7657 7658 7659 7660 7661 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 7655 class Deinterlacer < Struct.new( :algorithm, :control, :mode) SENSITIVE = [] include Aws::Structure end |
#control ⇒ String
- When set to NORMAL (default), the deinterlacer does not convert frames that are tagged in metadata as progressive. It will only convert those that are tagged as some other type. - When set to FORCE_ALL_FRAMES, the deinterlacer converts every frame to progressive - even those that are already tagged as progressive. Turn Force mode on only if there is a good chance that the metadata has tagged frames as progressive when they are not progressive. Do not turn on otherwise; processing frames that are already progressive into progressive will probably result in lower quality video.
7655 7656 7657 7658 7659 7660 7661 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 7655 class Deinterlacer < Struct.new( :algorithm, :control, :mode) SENSITIVE = [] include Aws::Structure end |
#mode ⇒ String
Use Deinterlacer (DeinterlaceMode) to choose how the service will do deinterlacing. Default is Deinterlace. - Deinterlace converts interlaced to progressive. - Inverse telecine converts Hard Telecine 29.97i to progressive 23.976p. - Adaptive auto-detects and converts to progressive.
7655 7656 7657 7658 7659 7660 7661 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 7655 class Deinterlacer < Struct.new( :algorithm, :control, :mode) SENSITIVE = [] include Aws::Structure end |