Class: Aws::MediaConvert::Types::DescribeEndpointsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediaconvert/types.rb

Overview

Send an request with an empty body to the regional API endpoint to get your account API endpoint.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_resultsInteger

Optional. Max number of endpoints, up to twenty, that will be returned at one time.

Returns:

  • (Integer)


3535
3536
3537
3538
3539
3540
3541
# File 'lib/aws-sdk-mediaconvert/types.rb', line 3535

class DescribeEndpointsRequest < Struct.new(
  :max_results,
  :mode,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#modeString

Optional field, defaults to DEFAULT. Specify DEFAULT for this operation to return your endpoints if any exist, or to create an endpoint for you and return it if one doesn't already exist. Specify GET_ONLY to return your endpoints if any exist, or an empty list if none exist.

Returns:

  • (String)


3535
3536
3537
3538
3539
3540
3541
# File 'lib/aws-sdk-mediaconvert/types.rb', line 3535

class DescribeEndpointsRequest < Struct.new(
  :max_results,
  :mode,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

Use this string, provided with the response to a previous request, to request the next batch of endpoints.

Returns:

  • (String)


3535
3536
3537
3538
3539
3540
3541
# File 'lib/aws-sdk-mediaconvert/types.rb', line 3535

class DescribeEndpointsRequest < Struct.new(
  :max_results,
  :mode,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end