Class: Aws::MediaConvert::Types::DescribeEndpointsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::DescribeEndpointsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
When making an API call, you may pass DescribeEndpointsRequest data as a hash:
{
max_results: 1,
mode: "DEFAULT", # accepts DEFAULT, GET_ONLY
next_token: "__string",
}
Send an request with an empty body to the regional API endpoint to get your account API endpoint.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
Optional.
-
#mode ⇒ String
Optional field, defaults to DEFAULT.
-
#next_token ⇒ String
Use this string, provided with the response to a previous request, to request the next batch of endpoints.
Instance Attribute Details
#max_results ⇒ Integer
Optional. Max number of endpoints, up to twenty, that will be returned at one time.
8173 8174 8175 8176 8177 8178 8179 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 8173 class DescribeEndpointsRequest < Struct.new( :max_results, :mode, :next_token) SENSITIVE = [] include Aws::Structure end |
#mode ⇒ String
Optional field, defaults to DEFAULT. Specify DEFAULT for this operation to return your endpoints if any exist, or to create an endpoint for you and return it if one doesn't already exist. Specify GET_ONLY to return your endpoints if any exist, or an empty list if none exist.
8173 8174 8175 8176 8177 8178 8179 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 8173 class DescribeEndpointsRequest < Struct.new( :max_results, :mode, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
Use this string, provided with the response to a previous request, to request the next batch of endpoints.
8173 8174 8175 8176 8177 8178 8179 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 8173 class DescribeEndpointsRequest < Struct.new( :max_results, :mode, :next_token) SENSITIVE = [] include Aws::Structure end |