Class: Aws::MediaConvert::Types::DolbyVisionMetadata
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::DolbyVisionMetadata
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
Dolby Vision characteristics of the video track: the profile and level, and whether the RPU (dynamic metadata), base layer, and enhancement layer are present. Use this to distinguish Dolby Vision content from standard HEVC and to choose your encoding or passthrough settings. Omitted when the content is not Dolby Vision.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#base_layer ⇒ String
Whether a Dolby Vision component is present in the track.
-
#enhancement_layer ⇒ String
Whether a Dolby Vision component is present in the track.
-
#level ⇒ Integer
The Dolby Vision level, which indicates the maximum resolution and frame rate.
-
#profile ⇒ Integer
The Dolby Vision profile, for example 5, 7, or 8.
-
#rpu ⇒ String
Whether a Dolby Vision component is present in the track.
Instance Attribute Details
#base_layer ⇒ String
Whether a Dolby Vision component is present in the track.
4904 4905 4906 4907 4908 4909 4910 4911 4912 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 4904 class DolbyVisionMetadata < Struct.new( :base_layer, :enhancement_layer, :level, :profile, :rpu) SENSITIVE = [] include Aws::Structure end |
#enhancement_layer ⇒ String
Whether a Dolby Vision component is present in the track.
4904 4905 4906 4907 4908 4909 4910 4911 4912 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 4904 class DolbyVisionMetadata < Struct.new( :base_layer, :enhancement_layer, :level, :profile, :rpu) SENSITIVE = [] include Aws::Structure end |
#level ⇒ Integer
The Dolby Vision level, which indicates the maximum resolution and frame rate.
4904 4905 4906 4907 4908 4909 4910 4911 4912 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 4904 class DolbyVisionMetadata < Struct.new( :base_layer, :enhancement_layer, :level, :profile, :rpu) SENSITIVE = [] include Aws::Structure end |
#profile ⇒ Integer
The Dolby Vision profile, for example 5, 7, or 8. The profile determines the layer structure and playback compatibility of the content.
4904 4905 4906 4907 4908 4909 4910 4911 4912 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 4904 class DolbyVisionMetadata < Struct.new( :base_layer, :enhancement_layer, :level, :profile, :rpu) SENSITIVE = [] include Aws::Structure end |
#rpu ⇒ String
Whether a Dolby Vision component is present in the track.
4904 4905 4906 4907 4908 4909 4910 4911 4912 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 4904 class DolbyVisionMetadata < Struct.new( :base_layer, :enhancement_layer, :level, :profile, :rpu) SENSITIVE = [] include Aws::Structure end |