Class: Aws::MediaConvert::Types::DurationControl
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::DurationControl
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
Settings for integer-second duration normalization. When this preprocessor is present, the output duration will be adjusted to an exact integer-second boundary. If the input is within the trim threshold of an integer second, trailing frames are dropped. If within the compression threshold and less than 500ms over the previous integer second, the output is sped up slightly. Otherwise, black frames are padded to the next integer second.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#integer_duration_maximum_compression_denominator ⇒ Integer
Required.
-
#integer_duration_maximum_compression_numerator ⇒ Integer
Required.
-
#integer_duration_trim_threshold_milliseconds ⇒ Integer
Maximum number of fractional milliseconds past an integer second that qualify for the trim path (frame dropping).
Instance Attribute Details
#integer_duration_maximum_compression_denominator ⇒ Integer
Required. Denominator of the maximum allowed compression ratio.
4941 4942 4943 4944 4945 4946 4947 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 4941 class DurationControl < Struct.new( :integer_duration_maximum_compression_denominator, :integer_duration_maximum_compression_numerator, :integer_duration_trim_threshold_milliseconds) SENSITIVE = [] include Aws::Structure end |
#integer_duration_maximum_compression_numerator ⇒ Integer
Required. Numerator of the maximum allowed compression ratio, defined as overrun divided by target duration. For example, numerator 5 with denominator 100 means max 5% compression. Set to 0 to disable compression entirely (only trim or pad will be used).
4941 4942 4943 4944 4945 4946 4947 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 4941 class DurationControl < Struct.new( :integer_duration_maximum_compression_denominator, :integer_duration_maximum_compression_numerator, :integer_duration_trim_threshold_milliseconds) SENSITIVE = [] include Aws::Structure end |
#integer_duration_trim_threshold_milliseconds ⇒ Integer
Maximum number of fractional milliseconds past an integer second that qualify for the trim path (frame dropping). Default is 0 (trimming disabled).
4941 4942 4943 4944 4945 4946 4947 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 4941 class DurationControl < Struct.new( :integer_duration_maximum_compression_denominator, :integer_duration_maximum_compression_numerator, :integer_duration_trim_threshold_milliseconds) SENSITIVE = [] include Aws::Structure end |