Class: Aws::MediaConvert::Types::DvbSdtSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::DvbSdtSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
When making an API call, you may pass DvbSdtSettings data as a hash:
{
output_sdt: "SDT_FOLLOW", # accepts SDT_FOLLOW, SDT_FOLLOW_IF_PRESENT, SDT_MANUAL, SDT_NONE
sdt_interval: 1,
service_name: "__stringMin1Max256",
service_provider_name: "__stringMin1Max256",
}
Use these settings to insert a DVB Service Description Table (SDT) in the transport stream of this output. When you work directly in your JSON job specification, include this object only when your job has a transport stream output and the container settings contain the object M2tsSettings.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#output_sdt ⇒ String
Selects method of inserting SDT information into output stream.
-
#sdt_interval ⇒ Integer
The number of milliseconds between instances of this table in the output transport stream.
-
#service_name ⇒ String
The service name placed in the service_descriptor in the Service Description Table.
-
#service_provider_name ⇒ String
The service provider name placed in the service_descriptor in the Service Description Table.
Instance Attribute Details
#output_sdt ⇒ String
Selects method of inserting SDT information into output stream. “Follow input SDT” copies SDT information from input stream to output stream. “Follow input SDT if present” copies SDT information from input stream to output stream if SDT information is present in the input, otherwise it will fall back on the user-defined values. Enter “SDT Manually” means user will enter the SDT information. “No SDT” means output stream will not contain SDT information.
8393 8394 8395 8396 8397 8398 8399 8400 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 8393 class DvbSdtSettings < Struct.new( :output_sdt, :sdt_interval, :service_name, :service_provider_name) SENSITIVE = [] include Aws::Structure end |
#sdt_interval ⇒ Integer
The number of milliseconds between instances of this table in the output transport stream.
8393 8394 8395 8396 8397 8398 8399 8400 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 8393 class DvbSdtSettings < Struct.new( :output_sdt, :sdt_interval, :service_name, :service_provider_name) SENSITIVE = [] include Aws::Structure end |
#service_name ⇒ String
The service name placed in the service_descriptor in the Service Description Table. Maximum length is 256 characters.
8393 8394 8395 8396 8397 8398 8399 8400 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 8393 class DvbSdtSettings < Struct.new( :output_sdt, :sdt_interval, :service_name, :service_provider_name) SENSITIVE = [] include Aws::Structure end |
#service_provider_name ⇒ String
The service provider name placed in the service_descriptor in the Service Description Table. Maximum length is 256 characters.
8393 8394 8395 8396 8397 8398 8399 8400 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 8393 class DvbSdtSettings < Struct.new( :output_sdt, :sdt_interval, :service_name, :service_provider_name) SENSITIVE = [] include Aws::Structure end |