Class: Aws::MediaConvert::Types::FileGroupSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::FileGroupSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
Settings related to your File output group. MediaConvert uses this group of settings to generate a single standalone file, rather than a streaming package.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#destination ⇒ String
Use Destination to specify the S3 output location and the output filename base.
-
#destination_settings ⇒ Types::DestinationSettings
Settings associated with the destination.
Instance Attribute Details
#destination ⇒ String
Use Destination to specify the S3 output location and the output filename base. Destination accepts format identifiers. If you do not specify the base filename in the URI, the service will use the filename of the input file. If your job has multiple inputs, the service uses the filename of the first input file.
4798 4799 4800 4801 4802 4803 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 4798 class FileGroupSettings < Struct.new( :destination, :destination_settings) SENSITIVE = [] include Aws::Structure end |
#destination_settings ⇒ Types::DestinationSettings
Settings associated with the destination. Will vary based on the type of destination
4798 4799 4800 4801 4802 4803 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 4798 class FileGroupSettings < Struct.new( :destination, :destination_settings) SENSITIVE = [] include Aws::Structure end |