Class: Aws::MediaConvert::Types::FileGroupSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::FileGroupSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
Settings related to your File output group. MediaConvert uses this group of settings to generate a single standalone file, rather than a streaming package. When you work directly in your JSON job specification, include this object and any required children when you set Type, under OutputGroupSettings, to FILE_GROUP_SETTINGS.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#destination ⇒ String
Use Destination (Destination) to specify the S3 output location and the output filename base.
-
#destination_settings ⇒ Types::DestinationSettings
Settings associated with the destination.
Instance Attribute Details
#destination ⇒ String
Use Destination (Destination) to specify the S3 output location and the output filename base. Destination accepts format identifiers. If you do not specify the base filename in the URI, the service will use the filename of the input file. If your job has multiple inputs, the service uses the filename of the first input file.
4706 4707 4708 4709 4710 4711 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 4706 class FileGroupSettings < Struct.new( :destination, :destination_settings) SENSITIVE = [] include Aws::Structure end |
#destination_settings ⇒ Types::DestinationSettings
Settings associated with the destination. Will vary based on the type of destination
4706 4707 4708 4709 4710 4711 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 4706 class FileGroupSettings < Struct.new( :destination, :destination_settings) SENSITIVE = [] include Aws::Structure end |