Class: Aws::MediaConvert::Types::FileGroupSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::FileGroupSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
When making an API call, you may pass FileGroupSettings data as a hash:
{
destination: "__stringPatternS3",
destination_settings: {
s3_settings: {
access_control: {
canned_acl: "PUBLIC_READ", # accepts PUBLIC_READ, AUTHENTICATED_READ, BUCKET_OWNER_READ, BUCKET_OWNER_FULL_CONTROL
},
encryption: {
encryption_type: "SERVER_SIDE_ENCRYPTION_S3", # accepts SERVER_SIDE_ENCRYPTION_S3, SERVER_SIDE_ENCRYPTION_KMS
kms_encryption_context: "__stringPatternAZaZ0902",
kms_key_arn: "__stringPatternArnAwsUsGovCnKmsAZ26EastWestCentralNorthSouthEastWest1912D12KeyAFAF098AFAF094AFAF094AFAF094AFAF0912MrkAFAF0932",
},
},
},
}
Settings related to your File output group. MediaConvert uses this group of settings to generate a single standalone file, rather than a streaming package. When you work directly in your JSON job specification, include this object and any required children when you set Type, under OutputGroupSettings, to FILE_GROUP_SETTINGS.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#destination ⇒ String
Use Destination (Destination) to specify the S3 output location and the output filename base.
-
#destination_settings ⇒ Types::DestinationSettings
Settings associated with the destination.
Instance Attribute Details
#destination ⇒ String
Use Destination (Destination) to specify the S3 output location and the output filename base. Destination accepts format identifiers. If you do not specify the base filename in the URI, the service will use the filename of the input file. If your job has multiple inputs, the service uses the filename of the first input file.
9583 9584 9585 9586 9587 9588 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 9583 class FileGroupSettings < Struct.new( :destination, :destination_settings) SENSITIVE = [] include Aws::Structure end |
#destination_settings ⇒ Types::DestinationSettings
Settings associated with the destination. Will vary based on the type of destination
9583 9584 9585 9586 9587 9588 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 9583 class FileGroupSettings < Struct.new( :destination, :destination_settings) SENSITIVE = [] include Aws::Structure end |