Class: Aws::MediaConvert::Types::GetJobsQueryResultsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::GetJobsQueryResultsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
If the jobs query completed successfully, then a JSON array of jobs will be included in this response. To retrieve the twenty next most recent jobs matched by your jobs query, call the StartJobsQuery using the nextToken string returned in this response.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#jobs ⇒ Array<Types::Job>
List of jobs.
-
#next_token ⇒ String
Use this string to request the next batch of jobs via the StartJobsQuery API.
-
#status ⇒ String
The status of the jobs query.
Instance Attribute Details
#jobs ⇒ Array<Types::Job>
List of jobs.
6304 6305 6306 6307 6308 6309 6310 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 6304 class GetJobsQueryResultsResponse < Struct.new( :jobs, :next_token, :status) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
Use this string to request the next batch of jobs via the StartJobsQuery API.
6304 6305 6306 6307 6308 6309 6310 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 6304 class GetJobsQueryResultsResponse < Struct.new( :jobs, :next_token, :status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the jobs query.
6304 6305 6306 6307 6308 6309 6310 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 6304 class GetJobsQueryResultsResponse < Struct.new( :jobs, :next_token, :status) SENSITIVE = [] include Aws::Structure end |