Class: Aws::MediaConvert::Types::Hdr10Metadata
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::Hdr10Metadata
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
Use these settings to specify static color calibration metadata, as defined by SMPTE ST 2086. These values don't affect the pixel values that are encoded in the video stream. They are intended to help the downstream video player display content in a way that reflects the intentions of the the content creator.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#blue_primary_x ⇒ Integer
HDR Master Display Information must be provided by a color grader, using color grading tools.
-
#blue_primary_y ⇒ Integer
HDR Master Display Information must be provided by a color grader, using color grading tools.
-
#green_primary_x ⇒ Integer
HDR Master Display Information must be provided by a color grader, using color grading tools.
-
#green_primary_y ⇒ Integer
HDR Master Display Information must be provided by a color grader, using color grading tools.
-
#max_content_light_level ⇒ Integer
Maximum light level among all samples in the coded video sequence, in units of candelas per square meter.
-
#max_frame_average_light_level ⇒ Integer
Maximum average light level of any frame in the coded video sequence, in units of candelas per square meter.
-
#max_luminance ⇒ Integer
Nominal maximum mastering display luminance in units of of 0.0001 candelas per square meter.
-
#min_luminance ⇒ Integer
Nominal minimum mastering display luminance in units of of 0.0001 candelas per square meter.
-
#red_primary_x ⇒ Integer
HDR Master Display Information must be provided by a color grader, using color grading tools.
-
#red_primary_y ⇒ Integer
HDR Master Display Information must be provided by a color grader, using color grading tools.
-
#white_point_x ⇒ Integer
HDR Master Display Information must be provided by a color grader, using color grading tools.
-
#white_point_y ⇒ Integer
HDR Master Display Information must be provided by a color grader, using color grading tools.
Instance Attribute Details
#blue_primary_x ⇒ Integer
HDR Master Display Information must be provided by a color grader, using color grading tools. Range is 0 to 50,000, each increment represents 0.00002 in CIE1931 color coordinate. Note that this setting is not for color correction.
7750 7751 7752 7753 7754 7755 7756 7757 7758 7759 7760 7761 7762 7763 7764 7765 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 7750 class Hdr10Metadata < Struct.new( :blue_primary_x, :blue_primary_y, :green_primary_x, :green_primary_y, :max_content_light_level, :max_frame_average_light_level, :max_luminance, :min_luminance, :red_primary_x, :red_primary_y, :white_point_x, :white_point_y) SENSITIVE = [] include Aws::Structure end |
#blue_primary_y ⇒ Integer
HDR Master Display Information must be provided by a color grader, using color grading tools. Range is 0 to 50,000, each increment represents 0.00002 in CIE1931 color coordinate. Note that this setting is not for color correction.
7750 7751 7752 7753 7754 7755 7756 7757 7758 7759 7760 7761 7762 7763 7764 7765 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 7750 class Hdr10Metadata < Struct.new( :blue_primary_x, :blue_primary_y, :green_primary_x, :green_primary_y, :max_content_light_level, :max_frame_average_light_level, :max_luminance, :min_luminance, :red_primary_x, :red_primary_y, :white_point_x, :white_point_y) SENSITIVE = [] include Aws::Structure end |
#green_primary_x ⇒ Integer
HDR Master Display Information must be provided by a color grader, using color grading tools. Range is 0 to 50,000, each increment represents 0.00002 in CIE1931 color coordinate. Note that this setting is not for color correction.
7750 7751 7752 7753 7754 7755 7756 7757 7758 7759 7760 7761 7762 7763 7764 7765 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 7750 class Hdr10Metadata < Struct.new( :blue_primary_x, :blue_primary_y, :green_primary_x, :green_primary_y, :max_content_light_level, :max_frame_average_light_level, :max_luminance, :min_luminance, :red_primary_x, :red_primary_y, :white_point_x, :white_point_y) SENSITIVE = [] include Aws::Structure end |
#green_primary_y ⇒ Integer
HDR Master Display Information must be provided by a color grader, using color grading tools. Range is 0 to 50,000, each increment represents 0.00002 in CIE1931 color coordinate. Note that this setting is not for color correction.
7750 7751 7752 7753 7754 7755 7756 7757 7758 7759 7760 7761 7762 7763 7764 7765 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 7750 class Hdr10Metadata < Struct.new( :blue_primary_x, :blue_primary_y, :green_primary_x, :green_primary_y, :max_content_light_level, :max_frame_average_light_level, :max_luminance, :min_luminance, :red_primary_x, :red_primary_y, :white_point_x, :white_point_y) SENSITIVE = [] include Aws::Structure end |
#max_content_light_level ⇒ Integer
Maximum light level among all samples in the coded video sequence, in units of candelas per square meter. This setting doesn't have a default value; you must specify a value that is suitable for the content.
7750 7751 7752 7753 7754 7755 7756 7757 7758 7759 7760 7761 7762 7763 7764 7765 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 7750 class Hdr10Metadata < Struct.new( :blue_primary_x, :blue_primary_y, :green_primary_x, :green_primary_y, :max_content_light_level, :max_frame_average_light_level, :max_luminance, :min_luminance, :red_primary_x, :red_primary_y, :white_point_x, :white_point_y) SENSITIVE = [] include Aws::Structure end |
#max_frame_average_light_level ⇒ Integer
Maximum average light level of any frame in the coded video sequence, in units of candelas per square meter. This setting doesn't have a default value; you must specify a value that is suitable for the content.
7750 7751 7752 7753 7754 7755 7756 7757 7758 7759 7760 7761 7762 7763 7764 7765 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 7750 class Hdr10Metadata < Struct.new( :blue_primary_x, :blue_primary_y, :green_primary_x, :green_primary_y, :max_content_light_level, :max_frame_average_light_level, :max_luminance, :min_luminance, :red_primary_x, :red_primary_y, :white_point_x, :white_point_y) SENSITIVE = [] include Aws::Structure end |
#max_luminance ⇒ Integer
Nominal maximum mastering display luminance in units of of 0.0001 candelas per square meter.
7750 7751 7752 7753 7754 7755 7756 7757 7758 7759 7760 7761 7762 7763 7764 7765 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 7750 class Hdr10Metadata < Struct.new( :blue_primary_x, :blue_primary_y, :green_primary_x, :green_primary_y, :max_content_light_level, :max_frame_average_light_level, :max_luminance, :min_luminance, :red_primary_x, :red_primary_y, :white_point_x, :white_point_y) SENSITIVE = [] include Aws::Structure end |
#min_luminance ⇒ Integer
Nominal minimum mastering display luminance in units of of 0.0001 candelas per square meter
7750 7751 7752 7753 7754 7755 7756 7757 7758 7759 7760 7761 7762 7763 7764 7765 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 7750 class Hdr10Metadata < Struct.new( :blue_primary_x, :blue_primary_y, :green_primary_x, :green_primary_y, :max_content_light_level, :max_frame_average_light_level, :max_luminance, :min_luminance, :red_primary_x, :red_primary_y, :white_point_x, :white_point_y) SENSITIVE = [] include Aws::Structure end |
#red_primary_x ⇒ Integer
HDR Master Display Information must be provided by a color grader, using color grading tools. Range is 0 to 50,000, each increment represents 0.00002 in CIE1931 color coordinate. Note that this setting is not for color correction.
7750 7751 7752 7753 7754 7755 7756 7757 7758 7759 7760 7761 7762 7763 7764 7765 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 7750 class Hdr10Metadata < Struct.new( :blue_primary_x, :blue_primary_y, :green_primary_x, :green_primary_y, :max_content_light_level, :max_frame_average_light_level, :max_luminance, :min_luminance, :red_primary_x, :red_primary_y, :white_point_x, :white_point_y) SENSITIVE = [] include Aws::Structure end |
#red_primary_y ⇒ Integer
HDR Master Display Information must be provided by a color grader, using color grading tools. Range is 0 to 50,000, each increment represents 0.00002 in CIE1931 color coordinate. Note that this setting is not for color correction.
7750 7751 7752 7753 7754 7755 7756 7757 7758 7759 7760 7761 7762 7763 7764 7765 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 7750 class Hdr10Metadata < Struct.new( :blue_primary_x, :blue_primary_y, :green_primary_x, :green_primary_y, :max_content_light_level, :max_frame_average_light_level, :max_luminance, :min_luminance, :red_primary_x, :red_primary_y, :white_point_x, :white_point_y) SENSITIVE = [] include Aws::Structure end |
#white_point_x ⇒ Integer
HDR Master Display Information must be provided by a color grader, using color grading tools. Range is 0 to 50,000, each increment represents 0.00002 in CIE1931 color coordinate. Note that this setting is not for color correction.
7750 7751 7752 7753 7754 7755 7756 7757 7758 7759 7760 7761 7762 7763 7764 7765 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 7750 class Hdr10Metadata < Struct.new( :blue_primary_x, :blue_primary_y, :green_primary_x, :green_primary_y, :max_content_light_level, :max_frame_average_light_level, :max_luminance, :min_luminance, :red_primary_x, :red_primary_y, :white_point_x, :white_point_y) SENSITIVE = [] include Aws::Structure end |
#white_point_y ⇒ Integer
HDR Master Display Information must be provided by a color grader, using color grading tools. Range is 0 to 50,000, each increment represents 0.00002 in CIE1931 color coordinate. Note that this setting is not for color correction.
7750 7751 7752 7753 7754 7755 7756 7757 7758 7759 7760 7761 7762 7763 7764 7765 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 7750 class Hdr10Metadata < Struct.new( :blue_primary_x, :blue_primary_y, :green_primary_x, :green_primary_y, :max_content_light_level, :max_frame_average_light_level, :max_luminance, :min_luminance, :red_primary_x, :red_primary_y, :white_point_x, :white_point_y) SENSITIVE = [] include Aws::Structure end |