Class: Aws::MediaConvert::Types::Hdr10Metadata
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::Hdr10Metadata
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
When making an API call, you may pass Hdr10Metadata data as a hash:
{
blue_primary_x: 1,
blue_primary_y: 1,
green_primary_x: 1,
green_primary_y: 1,
max_content_light_level: 1,
max_frame_average_light_level: 1,
max_luminance: 1,
min_luminance: 1,
red_primary_x: 1,
red_primary_y: 1,
white_point_x: 1,
white_point_y: 1,
}
Use these settings to specify static color calibration metadata, as defined by SMPTE ST 2086. These values don't affect the pixel values that are encoded in the video stream. They are intended to help the downstream video player display content in a way that reflects the intentions of the the content creator.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#blue_primary_x ⇒ Integer
HDR Master Display Information must be provided by a color grader, using color grading tools.
-
#blue_primary_y ⇒ Integer
HDR Master Display Information must be provided by a color grader, using color grading tools.
-
#green_primary_x ⇒ Integer
HDR Master Display Information must be provided by a color grader, using color grading tools.
-
#green_primary_y ⇒ Integer
HDR Master Display Information must be provided by a color grader, using color grading tools.
-
#max_content_light_level ⇒ Integer
Maximum light level among all samples in the coded video sequence, in units of candelas per square meter.
-
#max_frame_average_light_level ⇒ Integer
Maximum average light level of any frame in the coded video sequence, in units of candelas per square meter.
-
#max_luminance ⇒ Integer
Nominal maximum mastering display luminance in units of of 0.0001 candelas per square meter.
-
#min_luminance ⇒ Integer
Nominal minimum mastering display luminance in units of of 0.0001 candelas per square meter.
-
#red_primary_x ⇒ Integer
HDR Master Display Information must be provided by a color grader, using color grading tools.
-
#red_primary_y ⇒ Integer
HDR Master Display Information must be provided by a color grader, using color grading tools.
-
#white_point_x ⇒ Integer
HDR Master Display Information must be provided by a color grader, using color grading tools.
-
#white_point_y ⇒ Integer
HDR Master Display Information must be provided by a color grader, using color grading tools.
Instance Attribute Details
#blue_primary_x ⇒ Integer
HDR Master Display Information must be provided by a color grader, using color grading tools. Range is 0 to 50,000, each increment represents 0.00002 in CIE1931 color coordinate. Note that this setting is not for color correction.
10823 10824 10825 10826 10827 10828 10829 10830 10831 10832 10833 10834 10835 10836 10837 10838 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 10823 class Hdr10Metadata < Struct.new( :blue_primary_x, :blue_primary_y, :green_primary_x, :green_primary_y, :max_content_light_level, :max_frame_average_light_level, :max_luminance, :min_luminance, :red_primary_x, :red_primary_y, :white_point_x, :white_point_y) SENSITIVE = [] include Aws::Structure end |
#blue_primary_y ⇒ Integer
HDR Master Display Information must be provided by a color grader, using color grading tools. Range is 0 to 50,000, each increment represents 0.00002 in CIE1931 color coordinate. Note that this setting is not for color correction.
10823 10824 10825 10826 10827 10828 10829 10830 10831 10832 10833 10834 10835 10836 10837 10838 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 10823 class Hdr10Metadata < Struct.new( :blue_primary_x, :blue_primary_y, :green_primary_x, :green_primary_y, :max_content_light_level, :max_frame_average_light_level, :max_luminance, :min_luminance, :red_primary_x, :red_primary_y, :white_point_x, :white_point_y) SENSITIVE = [] include Aws::Structure end |
#green_primary_x ⇒ Integer
HDR Master Display Information must be provided by a color grader, using color grading tools. Range is 0 to 50,000, each increment represents 0.00002 in CIE1931 color coordinate. Note that this setting is not for color correction.
10823 10824 10825 10826 10827 10828 10829 10830 10831 10832 10833 10834 10835 10836 10837 10838 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 10823 class Hdr10Metadata < Struct.new( :blue_primary_x, :blue_primary_y, :green_primary_x, :green_primary_y, :max_content_light_level, :max_frame_average_light_level, :max_luminance, :min_luminance, :red_primary_x, :red_primary_y, :white_point_x, :white_point_y) SENSITIVE = [] include Aws::Structure end |
#green_primary_y ⇒ Integer
HDR Master Display Information must be provided by a color grader, using color grading tools. Range is 0 to 50,000, each increment represents 0.00002 in CIE1931 color coordinate. Note that this setting is not for color correction.
10823 10824 10825 10826 10827 10828 10829 10830 10831 10832 10833 10834 10835 10836 10837 10838 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 10823 class Hdr10Metadata < Struct.new( :blue_primary_x, :blue_primary_y, :green_primary_x, :green_primary_y, :max_content_light_level, :max_frame_average_light_level, :max_luminance, :min_luminance, :red_primary_x, :red_primary_y, :white_point_x, :white_point_y) SENSITIVE = [] include Aws::Structure end |
#max_content_light_level ⇒ Integer
Maximum light level among all samples in the coded video sequence, in units of candelas per square meter. This setting doesn't have a default value; you must specify a value that is suitable for the content.
10823 10824 10825 10826 10827 10828 10829 10830 10831 10832 10833 10834 10835 10836 10837 10838 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 10823 class Hdr10Metadata < Struct.new( :blue_primary_x, :blue_primary_y, :green_primary_x, :green_primary_y, :max_content_light_level, :max_frame_average_light_level, :max_luminance, :min_luminance, :red_primary_x, :red_primary_y, :white_point_x, :white_point_y) SENSITIVE = [] include Aws::Structure end |
#max_frame_average_light_level ⇒ Integer
Maximum average light level of any frame in the coded video sequence, in units of candelas per square meter. This setting doesn't have a default value; you must specify a value that is suitable for the content.
10823 10824 10825 10826 10827 10828 10829 10830 10831 10832 10833 10834 10835 10836 10837 10838 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 10823 class Hdr10Metadata < Struct.new( :blue_primary_x, :blue_primary_y, :green_primary_x, :green_primary_y, :max_content_light_level, :max_frame_average_light_level, :max_luminance, :min_luminance, :red_primary_x, :red_primary_y, :white_point_x, :white_point_y) SENSITIVE = [] include Aws::Structure end |
#max_luminance ⇒ Integer
Nominal maximum mastering display luminance in units of of 0.0001 candelas per square meter.
10823 10824 10825 10826 10827 10828 10829 10830 10831 10832 10833 10834 10835 10836 10837 10838 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 10823 class Hdr10Metadata < Struct.new( :blue_primary_x, :blue_primary_y, :green_primary_x, :green_primary_y, :max_content_light_level, :max_frame_average_light_level, :max_luminance, :min_luminance, :red_primary_x, :red_primary_y, :white_point_x, :white_point_y) SENSITIVE = [] include Aws::Structure end |
#min_luminance ⇒ Integer
Nominal minimum mastering display luminance in units of of 0.0001 candelas per square meter
10823 10824 10825 10826 10827 10828 10829 10830 10831 10832 10833 10834 10835 10836 10837 10838 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 10823 class Hdr10Metadata < Struct.new( :blue_primary_x, :blue_primary_y, :green_primary_x, :green_primary_y, :max_content_light_level, :max_frame_average_light_level, :max_luminance, :min_luminance, :red_primary_x, :red_primary_y, :white_point_x, :white_point_y) SENSITIVE = [] include Aws::Structure end |
#red_primary_x ⇒ Integer
HDR Master Display Information must be provided by a color grader, using color grading tools. Range is 0 to 50,000, each increment represents 0.00002 in CIE1931 color coordinate. Note that this setting is not for color correction.
10823 10824 10825 10826 10827 10828 10829 10830 10831 10832 10833 10834 10835 10836 10837 10838 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 10823 class Hdr10Metadata < Struct.new( :blue_primary_x, :blue_primary_y, :green_primary_x, :green_primary_y, :max_content_light_level, :max_frame_average_light_level, :max_luminance, :min_luminance, :red_primary_x, :red_primary_y, :white_point_x, :white_point_y) SENSITIVE = [] include Aws::Structure end |
#red_primary_y ⇒ Integer
HDR Master Display Information must be provided by a color grader, using color grading tools. Range is 0 to 50,000, each increment represents 0.00002 in CIE1931 color coordinate. Note that this setting is not for color correction.
10823 10824 10825 10826 10827 10828 10829 10830 10831 10832 10833 10834 10835 10836 10837 10838 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 10823 class Hdr10Metadata < Struct.new( :blue_primary_x, :blue_primary_y, :green_primary_x, :green_primary_y, :max_content_light_level, :max_frame_average_light_level, :max_luminance, :min_luminance, :red_primary_x, :red_primary_y, :white_point_x, :white_point_y) SENSITIVE = [] include Aws::Structure end |
#white_point_x ⇒ Integer
HDR Master Display Information must be provided by a color grader, using color grading tools. Range is 0 to 50,000, each increment represents 0.00002 in CIE1931 color coordinate. Note that this setting is not for color correction.
10823 10824 10825 10826 10827 10828 10829 10830 10831 10832 10833 10834 10835 10836 10837 10838 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 10823 class Hdr10Metadata < Struct.new( :blue_primary_x, :blue_primary_y, :green_primary_x, :green_primary_y, :max_content_light_level, :max_frame_average_light_level, :max_luminance, :min_luminance, :red_primary_x, :red_primary_y, :white_point_x, :white_point_y) SENSITIVE = [] include Aws::Structure end |
#white_point_y ⇒ Integer
HDR Master Display Information must be provided by a color grader, using color grading tools. Range is 0 to 50,000, each increment represents 0.00002 in CIE1931 color coordinate. Note that this setting is not for color correction.
10823 10824 10825 10826 10827 10828 10829 10830 10831 10832 10833 10834 10835 10836 10837 10838 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 10823 class Hdr10Metadata < Struct.new( :blue_primary_x, :blue_primary_y, :green_primary_x, :green_primary_y, :max_content_light_level, :max_frame_average_light_level, :max_luminance, :min_luminance, :red_primary_x, :red_primary_y, :white_point_x, :white_point_y) SENSITIVE = [] include Aws::Structure end |