Class: Aws::MediaConvert::Types::HdrMetadata

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediaconvert/types.rb

Overview

HDR (High Dynamic Range) metadata extracted from the container, including mastering display color volume and content light level information. This metadata is present in HDR10 and similar HDR content.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#content_light_levelTypes::ContentLightLevel

Content light level information (CTA-861.3). Describes the light level characteristics of the content.



7826
7827
7828
7829
7830
7831
# File 'lib/aws-sdk-mediaconvert/types.rb', line 7826

class HdrMetadata < Struct.new(
  :content_light_level,
  :mastering_display_color_volume)
  SENSITIVE = []
  include Aws::Structure
end

#mastering_display_color_volumeTypes::MasteringDisplayColorVolume

Mastering display color volume metadata (SMPTE ST 2086). Describes the color volume of the display used to master the content. Chromaticity coordinates are in units of 0.00002. Luminance values are in units of 0.0001 cd/m².



7826
7827
7828
7829
7830
7831
# File 'lib/aws-sdk-mediaconvert/types.rb', line 7826

class HdrMetadata < Struct.new(
  :content_light_level,
  :mastering_display_color_volume)
  SENSITIVE = []
  include Aws::Structure
end