Class: Aws::MediaConvert::Types::HlsCaptionLanguageMapping
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::HlsCaptionLanguageMapping
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
Note:
When making an API call, you may pass HlsCaptionLanguageMapping data as a hash:
{
caption_channel: 1,
custom_language_code: "__stringMin3Max3PatternAZaZ3",
language_code: "ENG", # accepts ENG, SPA, FRA, DEU, GER, ZHO, ARA, HIN, JPN, RUS, POR, ITA, URD, VIE, KOR, PAN, ABK, AAR, AFR, AKA, SQI, AMH, ARG, HYE, ASM, AVA, AVE, AYM, AZE, BAM, BAK, EUS, BEL, BEN, BIH, BIS, BOS, BRE, BUL, MYA, CAT, KHM, CHA, CHE, NYA, CHU, CHV, COR, COS, CRE, HRV, CES, DAN, DIV, NLD, DZO, ENM, EPO, EST, EWE, FAO, FIJ, FIN, FRM, FUL, GLA, GLG, LUG, KAT, ELL, GRN, GUJ, HAT, HAU, HEB, HER, HMO, HUN, ISL, IDO, IBO, IND, INA, ILE, IKU, IPK, GLE, JAV, KAL, KAN, KAU, KAS, KAZ, KIK, KIN, KIR, KOM, KON, KUA, KUR, LAO, LAT, LAV, LIM, LIN, LIT, LUB, LTZ, MKD, MLG, MSA, MAL, MLT, GLV, MRI, MAR, MAH, MON, NAU, NAV, NDE, NBL, NDO, NEP, SME, NOR, NOB, NNO, OCI, OJI, ORI, ORM, OSS, PLI, FAS, POL, PUS, QUE, QAA, RON, ROH, RUN, SMO, SAG, SAN, SRD, SRB, SNA, III, SND, SIN, SLK, SLV, SOM, SOT, SUN, SWA, SSW, SWE, TGL, TAH, TGK, TAM, TAT, TEL, THA, BOD, TIR, TON, TSO, TSN, TUR, TUK, TWI, UIG, UKR, UZB, VEN, VOL, WLN, CYM, FRY, WOL, XHO, YID, YOR, ZHA, ZUL, ORJ, QPC, TNG, SRP
language_description: "__string",
}
Caption Language Mapping
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#caption_channel ⇒ Integer
Caption channel.
-
#custom_language_code ⇒ String
Specify the language for this captions channel, using the ISO 639-2 or ISO 639-3 three-letter language code.
-
#language_code ⇒ String
Specify the language, using the ISO 639-2 three-letter code listed at www.loc.gov/standards/iso639-2/php/code_list.php.
-
#language_description ⇒ String
Caption language description.
Instance Attribute Details
#caption_channel ⇒ Integer
Caption channel.
10889 10890 10891 10892 10893 10894 10895 10896 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 10889 class HlsCaptionLanguageMapping < Struct.new( :caption_channel, :custom_language_code, :language_code, :language_description) SENSITIVE = [] include Aws::Structure end |
#custom_language_code ⇒ String
Specify the language for this captions channel, using the ISO 639-2 or ISO 639-3 three-letter language code
10889 10890 10891 10892 10893 10894 10895 10896 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 10889 class HlsCaptionLanguageMapping < Struct.new( :caption_channel, :custom_language_code, :language_code, :language_description) SENSITIVE = [] include Aws::Structure end |
#language_code ⇒ String
Specify the language, using the ISO 639-2 three-letter code listed at www.loc.gov/standards/iso639-2/php/code_list.php.
10889 10890 10891 10892 10893 10894 10895 10896 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 10889 class HlsCaptionLanguageMapping < Struct.new( :caption_channel, :custom_language_code, :language_code, :language_description) SENSITIVE = [] include Aws::Structure end |
#language_description ⇒ String
Caption language description.
10889 10890 10891 10892 10893 10894 10895 10896 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 10889 class HlsCaptionLanguageMapping < Struct.new( :caption_channel, :custom_language_code, :language_code, :language_description) SENSITIVE = [] include Aws::Structure end |