Class: Aws::MediaConvert::Types::Id3Insertion
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::Id3Insertion
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
Note:
When making an API call, you may pass Id3Insertion data as a hash:
{
id_3: "__stringPatternAZaZ0902",
timecode: "__stringPattern010920405090509092",
}
To insert ID3 tags in your output, specify two values. Use ID3 tag (Id3) to specify the base 64 encoded string and use Timecode (TimeCode) to specify the time when the tag should be inserted. To insert multiple ID3 tags in your output, create multiple instances of ID3 insertion (Id3Insertion).
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#id_3 ⇒ String
Use ID3 tag (Id3) to provide a fully formed ID3 tag in base64-encode format.
-
#timecode ⇒ String
Provide a Timecode (TimeCode) in HH:MM:SS:FF or HH:MM:SS;FF format.
Instance Attribute Details
#id_3 ⇒ String
Use ID3 tag (Id3) to provide a fully formed ID3 tag in base64-encode format.
11660 11661 11662 11663 11664 11665 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 11660 class Id3Insertion < Struct.new( :id_3, :timecode) SENSITIVE = [] include Aws::Structure end |
#timecode ⇒ String
Provide a Timecode (TimeCode) in HH:MM:SS:FF or HH:MM:SS;FF format.
11660 11661 11662 11663 11664 11665 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 11660 class Id3Insertion < Struct.new( :id_3, :timecode) SENSITIVE = [] include Aws::Structure end |