Class: Aws::MediaConvert::Types::Id3Insertion

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediaconvert/types.rb

Overview

Note:

When making an API call, you may pass Id3Insertion data as a hash:

{
  id_3: "__stringPatternAZaZ0902",
  timecode: "__stringPattern010920405090509092",
}

To insert ID3 tags in your output, specify two values. Use ID3 tag (Id3) to specify the base 64 encoded string and use Timecode (TimeCode) to specify the time when the tag should be inserted. To insert multiple ID3 tags in your output, create multiple instances of ID3 insertion (Id3Insertion).

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#id_3String

Use ID3 tag (Id3) to provide a fully formed ID3 tag in base64-encode format.

Returns:

  • (String)


11633
11634
11635
11636
11637
11638
# File 'lib/aws-sdk-mediaconvert/types.rb', line 11633

class Id3Insertion < Struct.new(
  :id_3,
  :timecode)
  SENSITIVE = []
  include Aws::Structure
end

#timecodeString

Provide a Timecode (TimeCode) in HH:MM:SS:FF or HH:MM:SS;FF format.

Returns:

  • (String)


11633
11634
11635
11636
11637
11638
# File 'lib/aws-sdk-mediaconvert/types.rb', line 11633

class Id3Insertion < Struct.new(
  :id_3,
  :timecode)
  SENSITIVE = []
  include Aws::Structure
end