Class: Aws::MediaConvert::Types::ImscDestinationSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::ImscDestinationSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
Settings related to IMSC captions. IMSC is a sidecar format that holds captions in a file that is separate from the video container. Set up sidecar captions in the same output group, but different output from your video. For more information, see docs.aws.amazon.com/mediaconvert/latest/ug/ttml-and-webvtt-output-captions.html. When you work directly in your JSON job specification, include this object and any required children when you set destinationType to IMSC.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#accessibility ⇒ String
Set Accessibility subtitles to Enabled if the ISMC or WebVTT captions track is intended to provide accessibility for people who are deaf or hard of hearing.
-
#style_passthrough ⇒ String
Keep this setting enabled to have MediaConvert use the font style and position information from the captions source in the output.
Instance Attribute Details
#accessibility ⇒ String
Set Accessibility subtitles to Enabled if the ISMC or WebVTT captions track is intended to provide accessibility for people who are deaf or hard of hearing. When you enable this feature, MediaConvert adds the following attributes under EXT-X-MEDIA in the HLS or CMAF manifest for this track: CHARACTERISTICS=“public.accessibility.describes-spoken-dialog,public.accessibility.describes-music-and-sound” and AUTOSELECT=“YES”. Keep the default value, Disabled, if the captions track is not intended to provide such accessibility. MediaConvert will not add the above attributes.
6973 6974 6975 6976 6977 6978 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 6973 class ImscDestinationSettings < Struct.new( :accessibility, :style_passthrough) SENSITIVE = [] include Aws::Structure end |
#style_passthrough ⇒ String
Keep this setting enabled to have MediaConvert use the font style and position information from the captions source in the output. This option is available only when your input captions are IMSC, SMPTE-TT, or TTML. Disable this setting for simplified output captions.
6973 6974 6975 6976 6977 6978 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 6973 class ImscDestinationSettings < Struct.new( :accessibility, :style_passthrough) SENSITIVE = [] include Aws::Structure end |