Class: Aws::MediaConvert::Types::ImscDestinationSettings

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediaconvert/types.rb

Overview

Note:

When making an API call, you may pass ImscDestinationSettings data as a hash:

{
  accessibility: "DISABLED", # accepts DISABLED, ENABLED
  style_passthrough: "ENABLED", # accepts ENABLED, DISABLED
}

Settings related to IMSC captions. IMSC is a sidecar format that holds captions in a file that is separate from the video container. Set up sidecar captions in the same output group, but different output from your video. For more information, see docs.aws.amazon.com/mediaconvert/latest/ug/ttml-and-webvtt-output-captions.html. When you work directly in your JSON job specification, include this object and any required children when you set destinationType to IMSC.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#accessibilityString

Set Accessibility subtitles to Enabled if the ISMC or WebVTT captions track is intended to provide accessibility for people who are deaf or hard of hearing. When you enable this feature, MediaConvert adds the following attributes under EXT-X-MEDIA in the HLS or CMAF manifest for this track: CHARACTERISTICS=“public.accessibility.describes-spoken-dialog,public.accessibility.describes-music-and-sound” and AUTOSELECT=“YES”. Keep the default value, Disabled, if the captions track is not intended to provide such accessibility. MediaConvert will not add the above attributes.

Returns:

  • (String)


12163
12164
12165
12166
12167
12168
# File 'lib/aws-sdk-mediaconvert/types.rb', line 12163

class ImscDestinationSettings < Struct.new(
  :accessibility,
  :style_passthrough)
  SENSITIVE = []
  include Aws::Structure
end

#style_passthroughString

Keep this setting enabled to have MediaConvert use the font style and position information from the captions source in the output. This option is available only when your input captions are IMSC, SMPTE-TT, or TTML. Disable this setting for simplified output captions.

Returns:

  • (String)


12163
12164
12165
12166
12167
12168
# File 'lib/aws-sdk-mediaconvert/types.rb', line 12163

class ImscDestinationSettings < Struct.new(
  :accessibility,
  :style_passthrough)
  SENSITIVE = []
  include Aws::Structure
end