Class: Aws::MediaConvert::Types::ImscDestinationSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::ImscDestinationSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
When making an API call, you may pass ImscDestinationSettings data as a hash:
{
accessibility: "DISABLED", # accepts DISABLED, ENABLED
style_passthrough: "ENABLED", # accepts ENABLED, DISABLED
}
Settings related to IMSC captions. IMSC is a sidecar format that holds captions in a file that is separate from the video container. Set up sidecar captions in the same output group, but different output from your video. For more information, see docs.aws.amazon.com/mediaconvert/latest/ug/ttml-and-webvtt-output-captions.html. When you work directly in your JSON job specification, include this object and any required children when you set destinationType to IMSC.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#accessibility ⇒ String
Specify whether to flag this caption track as accessibility in your HLS/CMAF parent manifest.
-
#style_passthrough ⇒ String
Keep this setting enabled to have MediaConvert use the font style and position information from the captions source in the output.
Instance Attribute Details
#accessibility ⇒ String
Specify whether to flag this caption track as accessibility in your HLS/CMAF parent manifest. When you choose ENABLED, MediaConvert includes the parameters CHARACTERISTICS=“public.accessibility.describes-spoken-dialog,public.accessibility.describes-music-and-sound” and AUTOSELECT=“YES” in the EXT-X-MEDIA entry for this track. When you keep the default choice, DISABLED, MediaConvert leaves this parameter out.
11667 11668 11669 11670 11671 11672 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 11667 class ImscDestinationSettings < Struct.new( :accessibility, :style_passthrough) SENSITIVE = [] include Aws::Structure end |
#style_passthrough ⇒ String
Keep this setting enabled to have MediaConvert use the font style and position information from the captions source in the output. This option is available only when your input captions are IMSC, SMPTE-TT, or TTML. Disable this setting for simplified output captions.
11667 11668 11669 11670 11671 11672 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 11667 class ImscDestinationSettings < Struct.new( :accessibility, :style_passthrough) SENSITIVE = [] include Aws::Structure end |