Class: Aws::MediaConvert::Types::InputVideoGenerator

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediaconvert/types.rb

Overview

When you include Video generator, MediaConvert creates a video input with black frames. Use this setting if you do not have a video input or if you want to add black video frames before, or after, other inputs. You can specify Video generator, or you can specify an Input file, but you cannot specify both. For more information, see docs.aws.amazon.com/mediaconvert/latest/ug/video-generator.html

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#channelsInteger

Specify the number of audio channels to include in your video generator input. MediaConvert creates these audio channels as silent audio within a single audio track. Enter an integer from 1 to 32.

Returns:

  • (Integer)


9031
9032
9033
9034
9035
9036
9037
9038
9039
9040
9041
9042
# File 'lib/aws-sdk-mediaconvert/types.rb', line 9031

class InputVideoGenerator < Struct.new(
  :channels,
  :duration,
  :framerate_denominator,
  :framerate_numerator,
  :height,
  :image_input,
  :sample_rate,
  :width)
  SENSITIVE = []
  include Aws::Structure
end

#durationInteger

Specify the duration, in milliseconds, for your video generator input. Enter an integer from 1 to 86400000.

Returns:

  • (Integer)


9031
9032
9033
9034
9035
9036
9037
9038
9039
9040
9041
9042
# File 'lib/aws-sdk-mediaconvert/types.rb', line 9031

class InputVideoGenerator < Struct.new(
  :channels,
  :duration,
  :framerate_denominator,
  :framerate_numerator,
  :height,
  :image_input,
  :sample_rate,
  :width)
  SENSITIVE = []
  include Aws::Structure
end

#framerate_denominatorInteger

Specify the denominator of the fraction that represents the frame rate for your video generator input. When you do, you must also specify a value for Frame rate numerator. MediaConvert uses a default frame rate of 29.97 when you leave Frame rate numerator and Frame rate denominator blank.

Returns:

  • (Integer)


9031
9032
9033
9034
9035
9036
9037
9038
9039
9040
9041
9042
# File 'lib/aws-sdk-mediaconvert/types.rb', line 9031

class InputVideoGenerator < Struct.new(
  :channels,
  :duration,
  :framerate_denominator,
  :framerate_numerator,
  :height,
  :image_input,
  :sample_rate,
  :width)
  SENSITIVE = []
  include Aws::Structure
end

#framerate_numeratorInteger

Specify the numerator of the fraction that represents the frame rate for your video generator input. When you do, you must also specify a value for Frame rate denominator. MediaConvert uses a default frame rate of 29.97 when you leave Frame rate numerator and Frame rate denominator blank.

Returns:

  • (Integer)


9031
9032
9033
9034
9035
9036
9037
9038
9039
9040
9041
9042
# File 'lib/aws-sdk-mediaconvert/types.rb', line 9031

class InputVideoGenerator < Struct.new(
  :channels,
  :duration,
  :framerate_denominator,
  :framerate_numerator,
  :height,
  :image_input,
  :sample_rate,
  :width)
  SENSITIVE = []
  include Aws::Structure
end

#heightInteger

Specify the height, in pixels, for your video generator input. This is useful for positioning when you include one or more video overlays for this input. To use the default resolution 540x360: Leave both width and height blank. To specify a height: Enter an even integer from 32 to 8192. When you do, you must also specify a value for width.

Returns:

  • (Integer)


9031
9032
9033
9034
9035
9036
9037
9038
9039
9040
9041
9042
# File 'lib/aws-sdk-mediaconvert/types.rb', line 9031

class InputVideoGenerator < Struct.new(
  :channels,
  :duration,
  :framerate_denominator,
  :framerate_numerator,
  :height,
  :image_input,
  :sample_rate,
  :width)
  SENSITIVE = []
  include Aws::Structure
end

#image_inputString

Specify the HTTP, HTTPS, or Amazon S3 location of the image that you want to overlay on the video. Use a PNG or TGA file.

Returns:

  • (String)


9031
9032
9033
9034
9035
9036
9037
9038
9039
9040
9041
9042
# File 'lib/aws-sdk-mediaconvert/types.rb', line 9031

class InputVideoGenerator < Struct.new(
  :channels,
  :duration,
  :framerate_denominator,
  :framerate_numerator,
  :height,
  :image_input,
  :sample_rate,
  :width)
  SENSITIVE = []
  include Aws::Structure
end

#sample_rateInteger

Specify the audio sample rate, in Hz, for the silent audio in your video generator input. Enter an integer from 32000 to 48000.

Returns:

  • (Integer)


9031
9032
9033
9034
9035
9036
9037
9038
9039
9040
9041
9042
# File 'lib/aws-sdk-mediaconvert/types.rb', line 9031

class InputVideoGenerator < Struct.new(
  :channels,
  :duration,
  :framerate_denominator,
  :framerate_numerator,
  :height,
  :image_input,
  :sample_rate,
  :width)
  SENSITIVE = []
  include Aws::Structure
end

#widthInteger

Specify the width, in pixels, for your video generator input. This is useful for positioning when you include one or more video overlays for this input. To use the default resolution 540x360: Leave both width and height blank. To specify a width: Enter an even integer from 32 to 8192. When you do, you must also specify a value for height.

Returns:

  • (Integer)


9031
9032
9033
9034
9035
9036
9037
9038
9039
9040
9041
9042
# File 'lib/aws-sdk-mediaconvert/types.rb', line 9031

class InputVideoGenerator < Struct.new(
  :channels,
  :duration,
  :framerate_denominator,
  :framerate_numerator,
  :height,
  :image_input,
  :sample_rate,
  :width)
  SENSITIVE = []
  include Aws::Structure
end