Class: Aws::MediaConvert::Types::InputVideoGenerator

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediaconvert/types.rb

Overview

Note:

When making an API call, you may pass InputVideoGenerator data as a hash:

{
  duration: 1,
}

Use this setting if you do not have a video input or if you want to add black video frames before, or after, other inputs. When you include Video generator, MediaConvert creates a video input with black frames and without an audio track. You can specify a value for Video generator, or you can specify an Input file, but you cannot specify both.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#durationInteger

Specify an integer value for Black video duration from 50 to 86400000 to generate a black video input for that many milliseconds. Required when you include Video generator.

Returns:

  • (Integer)


12916
12917
12918
12919
12920
# File 'lib/aws-sdk-mediaconvert/types.rb', line 12916

class InputVideoGenerator < Struct.new(
  :duration)
  SENSITIVE = []
  include Aws::Structure
end