Class: Aws::MediaConvert::Types::InputVideoGenerator
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::InputVideoGenerator
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
Note:
When making an API call, you may pass InputVideoGenerator data as a hash:
{
duration: 1,
}
Use this setting if you do not have a video input or if you want to add black video frames before, or after, other inputs. When you include Video generator, MediaConvert creates a video input with black frames and without an audio track. You can specify a value for Video generator, or you can specify an Input file, but you cannot specify both.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#duration ⇒ Integer
Specify an integer value for Black video duration from 50 to 86400000 to generate a black video input for that many milliseconds.
Instance Attribute Details
#duration ⇒ Integer
Specify an integer value for Black video duration from 50 to 86400000 to generate a black video input for that many milliseconds. Required when you include Video generator.
12602 12603 12604 12605 12606 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 12602 class InputVideoGenerator < Struct.new( :duration) SENSITIVE = [] include Aws::Structure end |