Class: Aws::MediaConvert::Types::JobTemplate
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::JobTemplate
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
A job template is a pre-made set of encoding instructions that you can use to quickly create a job.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#acceleration_settings ⇒ Types::AccelerationSettings
Accelerated transcoding can significantly speed up jobs with long, visually complex content.
-
#arn ⇒ String
An identifier for this resource that is unique within all of AWS.
-
#category ⇒ String
An optional category you create to organize your job templates.
-
#created_at ⇒ Time
The timestamp in epoch seconds for Job template creation.
-
#description ⇒ String
An optional description you create for each job template.
-
#hop_destinations ⇒ Array<Types::HopDestination>
Optional list of hop destinations.
-
#last_updated ⇒ Time
The timestamp in epoch seconds when the Job template was last updated.
-
#name ⇒ String
A name you create for each job template.
-
#priority ⇒ Integer
Relative priority on the job.
-
#queue ⇒ String
Optional.
-
#settings ⇒ Types::JobTemplateSettings
JobTemplateSettings contains all the transcode settings saved in the template that will be applied to jobs created from it.
-
#status_update_interval ⇒ String
Specify how often MediaConvert sends STATUS_UPDATE events to Amazon CloudWatch Events.
-
#type ⇒ String
A job template can be of two types: system or custom.
Instance Attribute Details
#acceleration_settings ⇒ Types::AccelerationSettings
Accelerated transcoding can significantly speed up jobs with long, visually complex content.
7982 7983 7984 7985 7986 7987 7988 7989 7990 7991 7992 7993 7994 7995 7996 7997 7998 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 7982 class JobTemplate < Struct.new( :acceleration_settings, :arn, :category, :created_at, :description, :hop_destinations, :last_updated, :name, :priority, :queue, :settings, :status_update_interval, :type) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
An identifier for this resource that is unique within all of AWS.
7982 7983 7984 7985 7986 7987 7988 7989 7990 7991 7992 7993 7994 7995 7996 7997 7998 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 7982 class JobTemplate < Struct.new( :acceleration_settings, :arn, :category, :created_at, :description, :hop_destinations, :last_updated, :name, :priority, :queue, :settings, :status_update_interval, :type) SENSITIVE = [] include Aws::Structure end |
#category ⇒ String
An optional category you create to organize your job templates.
7982 7983 7984 7985 7986 7987 7988 7989 7990 7991 7992 7993 7994 7995 7996 7997 7998 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 7982 class JobTemplate < Struct.new( :acceleration_settings, :arn, :category, :created_at, :description, :hop_destinations, :last_updated, :name, :priority, :queue, :settings, :status_update_interval, :type) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The timestamp in epoch seconds for Job template creation.
7982 7983 7984 7985 7986 7987 7988 7989 7990 7991 7992 7993 7994 7995 7996 7997 7998 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 7982 class JobTemplate < Struct.new( :acceleration_settings, :arn, :category, :created_at, :description, :hop_destinations, :last_updated, :name, :priority, :queue, :settings, :status_update_interval, :type) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
An optional description you create for each job template.
7982 7983 7984 7985 7986 7987 7988 7989 7990 7991 7992 7993 7994 7995 7996 7997 7998 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 7982 class JobTemplate < Struct.new( :acceleration_settings, :arn, :category, :created_at, :description, :hop_destinations, :last_updated, :name, :priority, :queue, :settings, :status_update_interval, :type) SENSITIVE = [] include Aws::Structure end |
#hop_destinations ⇒ Array<Types::HopDestination>
Optional list of hop destinations.
7982 7983 7984 7985 7986 7987 7988 7989 7990 7991 7992 7993 7994 7995 7996 7997 7998 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 7982 class JobTemplate < Struct.new( :acceleration_settings, :arn, :category, :created_at, :description, :hop_destinations, :last_updated, :name, :priority, :queue, :settings, :status_update_interval, :type) SENSITIVE = [] include Aws::Structure end |
#last_updated ⇒ Time
The timestamp in epoch seconds when the Job template was last updated.
7982 7983 7984 7985 7986 7987 7988 7989 7990 7991 7992 7993 7994 7995 7996 7997 7998 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 7982 class JobTemplate < Struct.new( :acceleration_settings, :arn, :category, :created_at, :description, :hop_destinations, :last_updated, :name, :priority, :queue, :settings, :status_update_interval, :type) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
A name you create for each job template. Each name must be unique within your account.
7982 7983 7984 7985 7986 7987 7988 7989 7990 7991 7992 7993 7994 7995 7996 7997 7998 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 7982 class JobTemplate < Struct.new( :acceleration_settings, :arn, :category, :created_at, :description, :hop_destinations, :last_updated, :name, :priority, :queue, :settings, :status_update_interval, :type) SENSITIVE = [] include Aws::Structure end |
#priority ⇒ Integer
Relative priority on the job.
7982 7983 7984 7985 7986 7987 7988 7989 7990 7991 7992 7993 7994 7995 7996 7997 7998 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 7982 class JobTemplate < Struct.new( :acceleration_settings, :arn, :category, :created_at, :description, :hop_destinations, :last_updated, :name, :priority, :queue, :settings, :status_update_interval, :type) SENSITIVE = [] include Aws::Structure end |
#queue ⇒ String
Optional. The queue that jobs created from this template are assigned to. If you don't specify this, jobs will go to the default queue.
7982 7983 7984 7985 7986 7987 7988 7989 7990 7991 7992 7993 7994 7995 7996 7997 7998 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 7982 class JobTemplate < Struct.new( :acceleration_settings, :arn, :category, :created_at, :description, :hop_destinations, :last_updated, :name, :priority, :queue, :settings, :status_update_interval, :type) SENSITIVE = [] include Aws::Structure end |
#settings ⇒ Types::JobTemplateSettings
JobTemplateSettings contains all the transcode settings saved in the template that will be applied to jobs created from it.
7982 7983 7984 7985 7986 7987 7988 7989 7990 7991 7992 7993 7994 7995 7996 7997 7998 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 7982 class JobTemplate < Struct.new( :acceleration_settings, :arn, :category, :created_at, :description, :hop_destinations, :last_updated, :name, :priority, :queue, :settings, :status_update_interval, :type) SENSITIVE = [] include Aws::Structure end |
#status_update_interval ⇒ String
Specify how often MediaConvert sends STATUS_UPDATE events to Amazon CloudWatch Events. Set the interval, in seconds, between status updates. MediaConvert sends an update at this interval from the time the service begins processing your job to the time it completes the transcode or encounters an error.
7982 7983 7984 7985 7986 7987 7988 7989 7990 7991 7992 7993 7994 7995 7996 7997 7998 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 7982 class JobTemplate < Struct.new( :acceleration_settings, :arn, :category, :created_at, :description, :hop_destinations, :last_updated, :name, :priority, :queue, :settings, :status_update_interval, :type) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
A job template can be of two types: system or custom. System or built-in job templates can't be modified or deleted by the user.
7982 7983 7984 7985 7986 7987 7988 7989 7990 7991 7992 7993 7994 7995 7996 7997 7998 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 7982 class JobTemplate < Struct.new( :acceleration_settings, :arn, :category, :created_at, :description, :hop_destinations, :last_updated, :name, :priority, :queue, :settings, :status_update_interval, :type) SENSITIVE = [] include Aws::Structure end |