Class: Aws::MediaConvert::Types::ListJobsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediaconvert/types.rb

Overview

You can send list jobs requests with an empty body. Optionally, you can filter the response by queue and/or job status by specifying them in your request body. You can also optionally specify the maximum number, up to twenty, of jobs to be returned.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_resultsInteger

Optional. Number of jobs, up to twenty, that will be returned at one time.



9947
9948
9949
9950
9951
9952
9953
9954
9955
# File 'lib/aws-sdk-mediaconvert/types.rb', line 9947

class ListJobsRequest < Struct.new(
  :max_results,
  :next_token,
  :order,
  :queue,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

Optional. Use this string, provided with the response to a previous request, to request the next batch of jobs.



9947
9948
9949
9950
9951
9952
9953
9954
9955
# File 'lib/aws-sdk-mediaconvert/types.rb', line 9947

class ListJobsRequest < Struct.new(
  :max_results,
  :next_token,
  :order,
  :queue,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#orderString

Optional. When you request lists of resources, you can specify whether they are sorted in ASCENDING or DESCENDING order. Default varies by resource.



9947
9948
9949
9950
9951
9952
9953
9954
9955
# File 'lib/aws-sdk-mediaconvert/types.rb', line 9947

class ListJobsRequest < Struct.new(
  :max_results,
  :next_token,
  :order,
  :queue,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#queueString

Optional. Provide a queue name to get back only jobs from that queue.



9947
9948
9949
9950
9951
9952
9953
9954
9955
# File 'lib/aws-sdk-mediaconvert/types.rb', line 9947

class ListJobsRequest < Struct.new(
  :max_results,
  :next_token,
  :order,
  :queue,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

Optional. A job’s status can be SUBMITTED, PROGRESSING, COMPLETE, CANCELED, or ERROR.



9947
9948
9949
9950
9951
9952
9953
9954
9955
# File 'lib/aws-sdk-mediaconvert/types.rb', line 9947

class ListJobsRequest < Struct.new(
  :max_results,
  :next_token,
  :order,
  :queue,
  :status)
  SENSITIVE = []
  include Aws::Structure
end