Class: Aws::MediaConvert::Types::ListQueuesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::ListQueuesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
You can send list queues requests with an empty body. You can optionally specify the maximum number, up to twenty, of queues to be returned.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#list_by ⇒ String
Optional.
-
#max_results ⇒ Integer
Optional.
-
#next_token ⇒ String
Use this string, provided with the response to a previous request, to request the next batch of queues.
-
#order ⇒ String
Optional.
Instance Attribute Details
#list_by ⇒ String
Optional. When you request a list of queues, you can choose to list them alphabetically by NAME or chronologically by CREATION_DATE. If you don’t specify, the service will list them by creation date.
10071 10072 10073 10074 10075 10076 10077 10078 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 10071 class ListQueuesRequest < Struct.new( :list_by, :max_results, :next_token, :order) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
Optional. Number of queues, up to twenty, that will be returned at one time.
10071 10072 10073 10074 10075 10076 10077 10078 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 10071 class ListQueuesRequest < Struct.new( :list_by, :max_results, :next_token, :order) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
Use this string, provided with the response to a previous request, to request the next batch of queues.
10071 10072 10073 10074 10075 10076 10077 10078 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 10071 class ListQueuesRequest < Struct.new( :list_by, :max_results, :next_token, :order) SENSITIVE = [] include Aws::Structure end |
#order ⇒ String
Optional. When you request lists of resources, you can specify whether they are sorted in ASCENDING or DESCENDING order. Default varies by resource.
10071 10072 10073 10074 10075 10076 10077 10078 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 10071 class ListQueuesRequest < Struct.new( :list_by, :max_results, :next_token, :order) SENSITIVE = [] include Aws::Structure end |