Class: Aws::MediaConvert::Types::M2tsScte35Esam
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::M2tsScte35Esam
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
Note:
When making an API call, you may pass M2tsScte35Esam data as a hash:
{
scte_35_esam_pid: 1,
}
Settings for SCTE-35 signals from ESAM. Include this in your job settings to put SCTE-35 markers in your HLS and transport stream outputs at the insertion points that you specify in an ESAM XML document. Provide the document in the setting SCC XML (sccXml).
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#scte_35_esam_pid ⇒ Integer
Packet Identifier (PID) of the SCTE-35 stream in the transport stream generated by ESAM.
Instance Attribute Details
#scte_35_esam_pid ⇒ Integer
Packet Identifier (PID) of the SCTE-35 stream in the transport stream generated by ESAM.
16725 16726 16727 16728 16729 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 16725 class M2tsScte35Esam < Struct.new( :scte_35_esam_pid) SENSITIVE = [] include Aws::Structure end |