Class: Aws::MediaConvert::Types::MotionImageInsertionFramerate
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::MotionImageInsertionFramerate
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
For motion overlays that don’t have a built-in frame rate, specify the frame rate of the overlay in frames per second, as a fraction. For example, specify 24 fps as 24/1. The overlay frame rate doesn’t need to match the frame rate of the underlying video.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#framerate_denominator ⇒ Integer
The bottom of the fraction that expresses your overlay frame rate.
-
#framerate_numerator ⇒ Integer
The top of the fraction that expresses your overlay frame rate.
Instance Attribute Details
#framerate_denominator ⇒ Integer
The bottom of the fraction that expresses your overlay frame rate. For example, if your frame rate is 24 fps, set this value to 1.
9253 9254 9255 9256 9257 9258 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 9253 class MotionImageInsertionFramerate < Struct.new( :framerate_denominator, :framerate_numerator) SENSITIVE = [] include Aws::Structure end |
#framerate_numerator ⇒ Integer
The top of the fraction that expresses your overlay frame rate. For example, if your frame rate is 24 fps, set this value to 24.
9253 9254 9255 9256 9257 9258 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 9253 class MotionImageInsertionFramerate < Struct.new( :framerate_denominator, :framerate_numerator) SENSITIVE = [] include Aws::Structure end |