Class: Aws::MediaConvert::Types::MotionImageInsertionFramerate
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::MotionImageInsertionFramerate
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
Note:
When making an API call, you may pass MotionImageInsertionFramerate data as a hash:
{
framerate_denominator: 1,
framerate_numerator: 1,
}
For motion overlays that don't have a built-in frame rate, specify the frame rate of the overlay in frames per second, as a fraction. For example, specify 24 fps as 24/1. The overlay frame rate doesn't need to match the frame rate of the underlying video.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#framerate_denominator ⇒ Integer
The bottom of the fraction that expresses your overlay frame rate.
-
#framerate_numerator ⇒ Integer
The top of the fraction that expresses your overlay frame rate.
Instance Attribute Details
#framerate_denominator ⇒ Integer
The bottom of the fraction that expresses your overlay frame rate. For example, if your frame rate is 24 fps, set this value to 1.
17373 17374 17375 17376 17377 17378 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 17373 class MotionImageInsertionFramerate < Struct.new( :framerate_denominator, :framerate_numerator) SENSITIVE = [] include Aws::Structure end |
#framerate_numerator ⇒ Integer
The top of the fraction that expresses your overlay frame rate. For example, if your frame rate is 24 fps, set this value to 24.
17373 17374 17375 17376 17377 17378 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 17373 class MotionImageInsertionFramerate < Struct.new( :framerate_denominator, :framerate_numerator) SENSITIVE = [] include Aws::Structure end |