Class: Aws::MediaConvert::Types::MovSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::MovSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
These settings relate to your QuickTime MOV output container.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#audio_duration ⇒ String
Specify this setting only when your output will be consumed by a downstream repackaging workflow that is sensitive to very small duration differences between video and audio.
-
#clap_atom ⇒ String
When enabled, include 'clap' atom if appropriate for the video output settings.
-
#cslg_atom ⇒ String
When enabled, file composition times will start at zero, composition times in the 'ctts' (composition time to sample) box for B-frames will be negative, and a 'cslg' (composition shift least greatest) box will be included per 14496-1 amendment 1.
-
#mpeg_2_four_cc_control ⇒ String
When set to XDCAM, writes MPEG2 video streams into the QuickTime file using XDCAM fourcc codes.
-
#padding_control ⇒ String
Unless you need Omneon compatibility: Keep the default value, None.
-
#reference ⇒ String
Always keep the default value (SELF_CONTAINED) for this setting.
Instance Attribute Details
#audio_duration ⇒ String
Specify this setting only when your output will be consumed by a downstream repackaging workflow that is sensitive to very small duration differences between video and audio. For this situation, choose Match video duration. In all other cases, keep the default value, Default codec duration. When you choose Match video duration, MediaConvert pads the output audio streams with silence or trims them to ensure that the total duration of each audio stream is at least as long as the total duration of the video stream. After padding or trimming, the audio stream duration is no more than one frame longer than the video stream. MediaConvert applies audio padding or trimming only to the end of the last segment of the output. For unsegmented outputs, MediaConvert adds padding only to the end of the file. When you keep the default value, any minor discrepancies between audio and video duration will depend on your output audio codec.
11494 11495 11496 11497 11498 11499 11500 11501 11502 11503 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 11494 class MovSettings < Struct.new( :audio_duration, :clap_atom, :cslg_atom, :mpeg_2_four_cc_control, :padding_control, :reference) SENSITIVE = [] include Aws::Structure end |
#clap_atom ⇒ String
When enabled, include 'clap' atom if appropriate for the video output settings.
11494 11495 11496 11497 11498 11499 11500 11501 11502 11503 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 11494 class MovSettings < Struct.new( :audio_duration, :clap_atom, :cslg_atom, :mpeg_2_four_cc_control, :padding_control, :reference) SENSITIVE = [] include Aws::Structure end |
#cslg_atom ⇒ String
When enabled, file composition times will start at zero, composition times in the 'ctts' (composition time to sample) box for B-frames will be negative, and a 'cslg' (composition shift least greatest) box will be included per 14496-1 amendment 1. This improves compatibility with Apple players and tools.
11494 11495 11496 11497 11498 11499 11500 11501 11502 11503 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 11494 class MovSettings < Struct.new( :audio_duration, :clap_atom, :cslg_atom, :mpeg_2_four_cc_control, :padding_control, :reference) SENSITIVE = [] include Aws::Structure end |
#mpeg_2_four_cc_control ⇒ String
When set to XDCAM, writes MPEG2 video streams into the QuickTime file using XDCAM fourcc codes. This increases compatibility with Apple editors and players, but may decrease compatibility with other players. Only applicable when the video codec is MPEG2.
11494 11495 11496 11497 11498 11499 11500 11501 11502 11503 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 11494 class MovSettings < Struct.new( :audio_duration, :clap_atom, :cslg_atom, :mpeg_2_four_cc_control, :padding_control, :reference) SENSITIVE = [] include Aws::Structure end |
#padding_control ⇒ String
Unless you need Omneon compatibility: Keep the default value, None. To make this output compatible with Omneon: Choose Omneon. When you do, MediaConvert increases the length of the 'elst' edit list atom. Note that this might cause file rejections when a recipient of the output file doesn't expect this extra padding.
11494 11495 11496 11497 11498 11499 11500 11501 11502 11503 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 11494 class MovSettings < Struct.new( :audio_duration, :clap_atom, :cslg_atom, :mpeg_2_four_cc_control, :padding_control, :reference) SENSITIVE = [] include Aws::Structure end |
#reference ⇒ String
Always keep the default value (SELF_CONTAINED) for this setting.
11494 11495 11496 11497 11498 11499 11500 11501 11502 11503 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 11494 class MovSettings < Struct.new( :audio_duration, :clap_atom, :cslg_atom, :mpeg_2_four_cc_control, :padding_control, :reference) SENSITIVE = [] include Aws::Structure end |