Class: Aws::MediaConvert::Types::MovSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::MovSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
These settings relate to your QuickTime MOV output container.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#clap_atom ⇒ String
When enabled, include ‘clap’ atom if appropriate for the video output settings.
-
#cslg_atom ⇒ String
When enabled, file composition times will start at zero, composition times in the ‘ctts’ (composition time to sample) box for B-frames will be negative, and a ‘cslg’ (composition shift least greatest) box will be included per 14496-1 amendment 1.
-
#mpeg_2_four_cc_control ⇒ String
When set to XDCAM, writes MPEG2 video streams into the QuickTime file using XDCAM fourcc codes.
-
#padding_control ⇒ String
Unless you need Omneon compatibility: Keep the default value, None.
-
#reference ⇒ String
Always keep the default value (SELF_CONTAINED) for this setting.
Instance Attribute Details
#clap_atom ⇒ String
When enabled, include ‘clap’ atom if appropriate for the video output settings.
9299 9300 9301 9302 9303 9304 9305 9306 9307 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 9299 class MovSettings < Struct.new( :clap_atom, :cslg_atom, :mpeg_2_four_cc_control, :padding_control, :reference) SENSITIVE = [] include Aws::Structure end |
#cslg_atom ⇒ String
When enabled, file composition times will start at zero, composition times in the ‘ctts’ (composition time to sample) box for B-frames will be negative, and a ‘cslg’ (composition shift least greatest) box will be included per 14496-1 amendment 1. This improves compatibility with Apple players and tools.
9299 9300 9301 9302 9303 9304 9305 9306 9307 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 9299 class MovSettings < Struct.new( :clap_atom, :cslg_atom, :mpeg_2_four_cc_control, :padding_control, :reference) SENSITIVE = [] include Aws::Structure end |
#mpeg_2_four_cc_control ⇒ String
When set to XDCAM, writes MPEG2 video streams into the QuickTime file using XDCAM fourcc codes. This increases compatibility with Apple editors and players, but may decrease compatibility with other players. Only applicable when the video codec is MPEG2.
9299 9300 9301 9302 9303 9304 9305 9306 9307 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 9299 class MovSettings < Struct.new( :clap_atom, :cslg_atom, :mpeg_2_four_cc_control, :padding_control, :reference) SENSITIVE = [] include Aws::Structure end |
#padding_control ⇒ String
Unless you need Omneon compatibility: Keep the default value, None. To make this output compatible with Omneon: Choose Omneon. When you do, MediaConvert increases the length of the ‘elst’ edit list atom. Note that this might cause file rejections when a recipient of the output file doesn’t expect this extra padding.
9299 9300 9301 9302 9303 9304 9305 9306 9307 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 9299 class MovSettings < Struct.new( :clap_atom, :cslg_atom, :mpeg_2_four_cc_control, :padding_control, :reference) SENSITIVE = [] include Aws::Structure end |
#reference ⇒ String
Always keep the default value (SELF_CONTAINED) for this setting.
9299 9300 9301 9302 9303 9304 9305 9306 9307 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 9299 class MovSettings < Struct.new( :clap_atom, :cslg_atom, :mpeg_2_four_cc_control, :padding_control, :reference) SENSITIVE = [] include Aws::Structure end |