Class: Aws::MediaConvert::Types::MovSettings

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediaconvert/types.rb

Overview

These settings relate to your QuickTime MOV output container.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#clap_atomString

When enabled, include ‘clap’ atom if appropriate for the video output settings.

Returns:

  • (String)


9234
9235
9236
9237
9238
9239
9240
9241
9242
# File 'lib/aws-sdk-mediaconvert/types.rb', line 9234

class MovSettings < Struct.new(
  :clap_atom,
  :cslg_atom,
  :mpeg_2_four_cc_control,
  :padding_control,
  :reference)
  SENSITIVE = []
  include Aws::Structure
end

#cslg_atomString

When enabled, file composition times will start at zero, composition times in the ‘ctts’ (composition time to sample) box for B-frames will be negative, and a ‘cslg’ (composition shift least greatest) box will be included per 14496-1 amendment 1. This improves compatibility with Apple players and tools.

Returns:

  • (String)


9234
9235
9236
9237
9238
9239
9240
9241
9242
# File 'lib/aws-sdk-mediaconvert/types.rb', line 9234

class MovSettings < Struct.new(
  :clap_atom,
  :cslg_atom,
  :mpeg_2_four_cc_control,
  :padding_control,
  :reference)
  SENSITIVE = []
  include Aws::Structure
end

#mpeg_2_four_cc_controlString

When set to XDCAM, writes MPEG2 video streams into the QuickTime file using XDCAM fourcc codes. This increases compatibility with Apple editors and players, but may decrease compatibility with other players. Only applicable when the video codec is MPEG2.

Returns:

  • (String)


9234
9235
9236
9237
9238
9239
9240
9241
9242
# File 'lib/aws-sdk-mediaconvert/types.rb', line 9234

class MovSettings < Struct.new(
  :clap_atom,
  :cslg_atom,
  :mpeg_2_four_cc_control,
  :padding_control,
  :reference)
  SENSITIVE = []
  include Aws::Structure
end

#padding_controlString

To make this output compatible with Omenon, keep the default value, OMNEON. Unless you need Omneon compatibility, set this value to NONE. When you keep the default value, OMNEON, MediaConvert increases the length of the edit list atom. This might cause file rejections when a recipient of the output file doesn’t expct this extra padding.

Returns:

  • (String)


9234
9235
9236
9237
9238
9239
9240
9241
9242
# File 'lib/aws-sdk-mediaconvert/types.rb', line 9234

class MovSettings < Struct.new(
  :clap_atom,
  :cslg_atom,
  :mpeg_2_four_cc_control,
  :padding_control,
  :reference)
  SENSITIVE = []
  include Aws::Structure
end

#referenceString

Always keep the default value (SELF_CONTAINED) for this setting.

Returns:

  • (String)


9234
9235
9236
9237
9238
9239
9240
9241
9242
# File 'lib/aws-sdk-mediaconvert/types.rb', line 9234

class MovSettings < Struct.new(
  :clap_atom,
  :cslg_atom,
  :mpeg_2_four_cc_control,
  :padding_control,
  :reference)
  SENSITIVE = []
  include Aws::Structure
end