Class: Aws::MediaConvert::Types::MovSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::MovSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
When making an API call, you may pass MovSettings data as a hash:
{
clap_atom: "INCLUDE", # accepts INCLUDE, EXCLUDE
cslg_atom: "INCLUDE", # accepts INCLUDE, EXCLUDE
mpeg_2_four_cc_control: "XDCAM", # accepts XDCAM, MPEG
padding_control: "OMNEON", # accepts OMNEON, NONE
reference: "SELF_CONTAINED", # accepts SELF_CONTAINED, EXTERNAL
}
These settings relate to your QuickTime MOV output container.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#clap_atom ⇒ String
When enabled, include 'clap' atom if appropriate for the video output settings.
-
#cslg_atom ⇒ String
When enabled, file composition times will start at zero, composition times in the 'ctts' (composition time to sample) box for B-frames will be negative, and a 'cslg' (composition shift least greatest) box will be included per 14496-1 amendment 1.
-
#mpeg_2_four_cc_control ⇒ String
When set to XDCAM, writes MPEG2 video streams into the QuickTime file using XDCAM fourcc codes.
-
#padding_control ⇒ String
To make this output compatible with Omenon, keep the default value, OMNEON.
-
#reference ⇒ String
Always keep the default value (SELF_CONTAINED) for this setting.
Instance Attribute Details
#clap_atom ⇒ String
When enabled, include 'clap' atom if appropriate for the video output settings.
17019 17020 17021 17022 17023 17024 17025 17026 17027 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 17019 class MovSettings < Struct.new( :clap_atom, :cslg_atom, :mpeg_2_four_cc_control, :padding_control, :reference) SENSITIVE = [] include Aws::Structure end |
#cslg_atom ⇒ String
When enabled, file composition times will start at zero, composition times in the 'ctts' (composition time to sample) box for B-frames will be negative, and a 'cslg' (composition shift least greatest) box will be included per 14496-1 amendment 1. This improves compatibility with Apple players and tools.
17019 17020 17021 17022 17023 17024 17025 17026 17027 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 17019 class MovSettings < Struct.new( :clap_atom, :cslg_atom, :mpeg_2_four_cc_control, :padding_control, :reference) SENSITIVE = [] include Aws::Structure end |
#mpeg_2_four_cc_control ⇒ String
When set to XDCAM, writes MPEG2 video streams into the QuickTime file using XDCAM fourcc codes. This increases compatibility with Apple editors and players, but may decrease compatibility with other players. Only applicable when the video codec is MPEG2.
17019 17020 17021 17022 17023 17024 17025 17026 17027 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 17019 class MovSettings < Struct.new( :clap_atom, :cslg_atom, :mpeg_2_four_cc_control, :padding_control, :reference) SENSITIVE = [] include Aws::Structure end |
#padding_control ⇒ String
To make this output compatible with Omenon, keep the default value, OMNEON. Unless you need Omneon compatibility, set this value to NONE. When you keep the default value, OMNEON, MediaConvert increases the length of the edit list atom. This might cause file rejections when a recipient of the output file doesn't expct this extra padding.
17019 17020 17021 17022 17023 17024 17025 17026 17027 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 17019 class MovSettings < Struct.new( :clap_atom, :cslg_atom, :mpeg_2_four_cc_control, :padding_control, :reference) SENSITIVE = [] include Aws::Structure end |
#reference ⇒ String
Always keep the default value (SELF_CONTAINED) for this setting.
17019 17020 17021 17022 17023 17024 17025 17026 17027 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 17019 class MovSettings < Struct.new( :clap_atom, :cslg_atom, :mpeg_2_four_cc_control, :padding_control, :reference) SENSITIVE = [] include Aws::Structure end |