Class: Aws::MediaConvert::Types::Mp2Settings
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::Mp2Settings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
Note:
When making an API call, you may pass Mp2Settings data as a hash:
{
bitrate: 1,
channels: 1,
sample_rate: 1,
}
Required when you set (Codec) under (AudioDescriptions)>(CodecSettings) to the value MP2.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bitrate ⇒ Integer
Specify the average bitrate in bits per second.
-
#channels ⇒ Integer
Set Channels to specify the number of channels in this output audio track.
-
#sample_rate ⇒ Integer
Sample rate in hz.
Instance Attribute Details
#bitrate ⇒ Integer
Specify the average bitrate in bits per second.
17560 17561 17562 17563 17564 17565 17566 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 17560 class Mp2Settings < Struct.new( :bitrate, :channels, :sample_rate) SENSITIVE = [] include Aws::Structure end |
#channels ⇒ Integer
Set Channels to specify the number of channels in this output audio track. Choosing Mono in the console will give you 1 output channel; choosing Stereo will give you 2. In the API, valid values are 1 and 2.
17560 17561 17562 17563 17564 17565 17566 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 17560 class Mp2Settings < Struct.new( :bitrate, :channels, :sample_rate) SENSITIVE = [] include Aws::Structure end |
#sample_rate ⇒ Integer
Sample rate in hz.
17560 17561 17562 17563 17564 17565 17566 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 17560 class Mp2Settings < Struct.new( :bitrate, :channels, :sample_rate) SENSITIVE = [] include Aws::Structure end |