Class: Aws::MediaConvert::Types::MsSmoothAdditionalManifest
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::MsSmoothAdditionalManifest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
When making an API call, you may pass MsSmoothAdditionalManifest data as a hash:
{
manifest_name_modifier: "__stringMin1",
selected_outputs: ["__stringMin1"],
}
Specify the details for each additional Microsoft Smooth Streaming manifest that you want the service to generate for this output group. Each manifest can reference a different subset of outputs in the group.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#manifest_name_modifier ⇒ String
Specify a name modifier that the service adds to the name of this manifest to make it different from the file names of the other main manifests in the output group.
-
#selected_outputs ⇒ Array<String>
Specify the outputs that you want this additional top-level manifest to reference.
Instance Attribute Details
#manifest_name_modifier ⇒ String
Specify a name modifier that the service adds to the name of this manifest to make it different from the file names of the other main manifests in the output group. For example, say that the default main manifest for your Microsoft Smooth group is film-name.ismv. If you enter “-no-premium” for this setting, then the file name the service generates for this top-level manifest is film-name-no-premium.ismv.
17641 17642 17643 17644 17645 17646 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 17641 class MsSmoothAdditionalManifest < Struct.new( :manifest_name_modifier, :selected_outputs) SENSITIVE = [] include Aws::Structure end |
#selected_outputs ⇒ Array<String>
Specify the outputs that you want this additional top-level manifest to reference.
17641 17642 17643 17644 17645 17646 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 17641 class MsSmoothAdditionalManifest < Struct.new( :manifest_name_modifier, :selected_outputs) SENSITIVE = [] include Aws::Structure end |