Class: Aws::MediaConvert::Types::MsSmoothGroupSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::MsSmoothGroupSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
Settings related to your Microsoft Smooth Streaming output package. For more information, see docs.aws.amazon.com/mediaconvert/latest/ug/outputs-file-ABR.html.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#additional_manifests ⇒ Array<Types::MsSmoothAdditionalManifest>
By default, the service creates one .ism Microsoft Smooth Streaming manifest for each Microsoft Smooth Streaming output group in your job.
-
#audio_deduplication ⇒ String
COMBINE_DUPLICATE_STREAMS combines identical audio encoding settings across a Microsoft Smooth output group into a single audio stream.
-
#destination ⇒ String
Use Destination to specify the S3 output location and the output filename base.
-
#destination_settings ⇒ Types::DestinationSettings
Settings associated with the destination.
-
#encryption ⇒ Types::MsSmoothEncryptionSettings
If you are using DRM, set DRM System to specify the value SpekeKeyProvider.
-
#fragment_length ⇒ Integer
Specify how you want MediaConvert to determine the fragment length.
-
#fragment_length_control ⇒ String
Specify how you want MediaConvert to determine the fragment length.
-
#manifest_encoding ⇒ String
Use Manifest encoding to specify the encoding format for the server and client manifest.
Instance Attribute Details
#additional_manifests ⇒ Array<Types::MsSmoothAdditionalManifest>
By default, the service creates one .ism Microsoft Smooth Streaming manifest for each Microsoft Smooth Streaming output group in your job. This default manifest references every output in the output group. To create additional manifests that reference a subset of the outputs in the output group, specify a list of them here.
12240 12241 12242 12243 12244 12245 12246 12247 12248 12249 12250 12251 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 12240 class MsSmoothGroupSettings < Struct.new( :additional_manifests, :audio_deduplication, :destination, :destination_settings, :encryption, :fragment_length, :fragment_length_control, :manifest_encoding) SENSITIVE = [] include Aws::Structure end |
#audio_deduplication ⇒ String
COMBINE_DUPLICATE_STREAMS combines identical audio encoding settings across a Microsoft Smooth output group into a single audio stream.
12240 12241 12242 12243 12244 12245 12246 12247 12248 12249 12250 12251 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 12240 class MsSmoothGroupSettings < Struct.new( :additional_manifests, :audio_deduplication, :destination, :destination_settings, :encryption, :fragment_length, :fragment_length_control, :manifest_encoding) SENSITIVE = [] include Aws::Structure end |
#destination ⇒ String
Use Destination to specify the S3 output location and the output filename base. Destination accepts format identifiers. If you do not specify the base filename in the URI, the service will use the filename of the input file. If your job has multiple inputs, the service uses the filename of the first input file.
12240 12241 12242 12243 12244 12245 12246 12247 12248 12249 12250 12251 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 12240 class MsSmoothGroupSettings < Struct.new( :additional_manifests, :audio_deduplication, :destination, :destination_settings, :encryption, :fragment_length, :fragment_length_control, :manifest_encoding) SENSITIVE = [] include Aws::Structure end |
#destination_settings ⇒ Types::DestinationSettings
Settings associated with the destination. Will vary based on the type of destination
12240 12241 12242 12243 12244 12245 12246 12247 12248 12249 12250 12251 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 12240 class MsSmoothGroupSettings < Struct.new( :additional_manifests, :audio_deduplication, :destination, :destination_settings, :encryption, :fragment_length, :fragment_length_control, :manifest_encoding) SENSITIVE = [] include Aws::Structure end |
#encryption ⇒ Types::MsSmoothEncryptionSettings
If you are using DRM, set DRM System to specify the value SpekeKeyProvider.
12240 12241 12242 12243 12244 12245 12246 12247 12248 12249 12250 12251 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 12240 class MsSmoothGroupSettings < Struct.new( :additional_manifests, :audio_deduplication, :destination, :destination_settings, :encryption, :fragment_length, :fragment_length_control, :manifest_encoding) SENSITIVE = [] include Aws::Structure end |
#fragment_length ⇒ Integer
Specify how you want MediaConvert to determine the fragment length. Choose Exact to have the encoder use the exact length that you specify with the setting Fragment length. This might result in extra I-frames. Choose Multiple of GOP to have the encoder round up the segment lengths to match the next GOP boundary.
12240 12241 12242 12243 12244 12245 12246 12247 12248 12249 12250 12251 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 12240 class MsSmoothGroupSettings < Struct.new( :additional_manifests, :audio_deduplication, :destination, :destination_settings, :encryption, :fragment_length, :fragment_length_control, :manifest_encoding) SENSITIVE = [] include Aws::Structure end |
#fragment_length_control ⇒ String
Specify how you want MediaConvert to determine the fragment length. Choose Exact to have the encoder use the exact length that you specify with the setting Fragment length. This might result in extra I-frames. Choose Multiple of GOP to have the encoder round up the segment lengths to match the next GOP boundary.
12240 12241 12242 12243 12244 12245 12246 12247 12248 12249 12250 12251 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 12240 class MsSmoothGroupSettings < Struct.new( :additional_manifests, :audio_deduplication, :destination, :destination_settings, :encryption, :fragment_length, :fragment_length_control, :manifest_encoding) SENSITIVE = [] include Aws::Structure end |
#manifest_encoding ⇒ String
Use Manifest encoding to specify the encoding format for the server and client manifest. Valid options are utf8 and utf16.
12240 12241 12242 12243 12244 12245 12246 12247 12248 12249 12250 12251 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 12240 class MsSmoothGroupSettings < Struct.new( :additional_manifests, :audio_deduplication, :destination, :destination_settings, :encryption, :fragment_length, :fragment_length_control, :manifest_encoding) SENSITIVE = [] include Aws::Structure end |