Class: Aws::MediaConvert::Types::MultiViewSettings

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediaconvert/types.rb

Overview

Specify the enhancement layer input video file path for Multi View outputs. The base layer input is treated as the left eye and this Multi View input is treated as the right eye. Only one Multi View input is currently supported. MediaConvert encodes both views into a single MV-HEVC output codec. When you add MultiViewSettings to your job, you can only produce Multi View outputs. Adding any other codec output to the same job is not supported.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#inputTypes::MultiViewInput

Input settings for MultiView Settings. You can include exactly one input as enhancement layer.



11942
11943
11944
11945
11946
# File 'lib/aws-sdk-mediaconvert/types.rb', line 11942

class MultiViewSettings < Struct.new(
  :input)
  SENSITIVE = []
  include Aws::Structure
end