Class: Aws::MediaConvert::Types::MxfSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::MxfSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
These settings relate to your MXF output container.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#afd_signaling ⇒ String
Optional.
-
#profile ⇒ String
Specify the MXF profile, also called shim, for this output.
-
#uncompressed_audio_wrapping ⇒ String
Choose the audio frame wrapping mode for PCM tracks in MXF outputs.
-
#xavc_profile_settings ⇒ Types::MxfXavcProfileSettings
Specify the XAVC profile settings for MXF outputs when you set your MXF profile to XAVC.
Instance Attribute Details
#afd_signaling ⇒ String
Optional. When you have AFD signaling set up in your output video stream, use this setting to choose whether to also include it in the MXF wrapper. Choose Don’t copy to exclude AFD signaling from the MXF wrapper. Choose Copy from video stream to copy the AFD values from the video stream for this output to the MXF wrapper. Regardless of which option you choose, the AFD values remain in the video stream. Related settings: To set up your output to include or exclude AFD values, see AfdSignaling, under VideoDescription. On the console, find AFD signaling under the output’s video encoding settings.
11988 11989 11990 11991 11992 11993 11994 11995 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 11988 class MxfSettings < Struct.new( :afd_signaling, :profile, :uncompressed_audio_wrapping, :xavc_profile_settings) SENSITIVE = [] include Aws::Structure end |
#profile ⇒ String
Specify the MXF profile, also called shim, for this output. To automatically select a profile according to your output video codec and resolution, leave blank. For a list of codecs supported with each MXF profile, see docs.aws.amazon.com/mediaconvert/latest/ug/codecs-supported-with-each-mxf-profile.html. For more information about the automatic selection behavior, see docs.aws.amazon.com/mediaconvert/latest/ug/default-automatic-selection-of-mxf-profiles.html.
11988 11989 11990 11991 11992 11993 11994 11995 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 11988 class MxfSettings < Struct.new( :afd_signaling, :profile, :uncompressed_audio_wrapping, :xavc_profile_settings) SENSITIVE = [] include Aws::Structure end |
#uncompressed_audio_wrapping ⇒ String
Choose the audio frame wrapping mode for PCM tracks in MXF outputs. AUTO (default): Uses codec-appropriate defaults - BWF for H.264/AVC, AES3 for MPEG2/XDCAM. AES3: Use AES3 frame wrapping with SMPTE-compliant descriptors. This setting only takes effect when the MXF profile is OP1a.
11988 11989 11990 11991 11992 11993 11994 11995 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 11988 class MxfSettings < Struct.new( :afd_signaling, :profile, :uncompressed_audio_wrapping, :xavc_profile_settings) SENSITIVE = [] include Aws::Structure end |
#xavc_profile_settings ⇒ Types::MxfXavcProfileSettings
Specify the XAVC profile settings for MXF outputs when you set your MXF profile to XAVC.
11988 11989 11990 11991 11992 11993 11994 11995 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 11988 class MxfSettings < Struct.new( :afd_signaling, :profile, :uncompressed_audio_wrapping, :xavc_profile_settings) SENSITIVE = [] include Aws::Structure end |