Class: Aws::MediaConvert::Types::NielsenConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::NielsenConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
Settings for your Nielsen configuration. If you don’t do Nielsen measurement and analytics, ignore these settings. When you enable Nielsen configuration, MediaConvert enables PCM to ID3 tagging for all outputs in the job.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#breakout_code ⇒ Integer
Nielsen has discontinued the use of breakout code functionality.
-
#distributor_id ⇒ String
Use Distributor ID to specify the distributor ID that is assigned to your organization by Nielsen.
Instance Attribute Details
#breakout_code ⇒ Integer
Nielsen has discontinued the use of breakout code functionality. If you must include this property, set the value to zero.
10414 10415 10416 10417 10418 10419 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 10414 class NielsenConfiguration < Struct.new( :breakout_code, :distributor_id) SENSITIVE = [] include Aws::Structure end |
#distributor_id ⇒ String
Use Distributor ID to specify the distributor ID that is assigned to your organization by Nielsen.
10414 10415 10416 10417 10418 10419 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 10414 class NielsenConfiguration < Struct.new( :breakout_code, :distributor_id) SENSITIVE = [] include Aws::Structure end |