Class: Aws::MediaConvert::Types::NoiseReducer

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediaconvert/types.rb

Overview

Note:

When making an API call, you may pass NoiseReducer data as a hash:

{
  filter: "BILATERAL", # accepts BILATERAL, MEAN, GAUSSIAN, LANCZOS, SHARPEN, CONSERVE, SPATIAL, TEMPORAL
  filter_settings: {
    strength: 1,
  },
  spatial_filter_settings: {
    post_filter_sharpen_strength: 1,
    speed: 1,
    strength: 1,
  },
  temporal_filter_settings: {
    aggressive_mode: 1,
    post_temporal_sharpening: "DISABLED", # accepts DISABLED, ENABLED, AUTO
    post_temporal_sharpening_strength: "LOW", # accepts LOW, MEDIUM, HIGH
    speed: 1,
    strength: 1,
  },
}

Enable the Noise reducer (NoiseReducer) feature to remove noise from your video output if necessary. Enable or disable this feature for each output individually. This setting is disabled by default. When you enable Noise reducer (NoiseReducer), you must also select a value for Noise reducer filter (NoiseReducerFilter).

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#filterString

Use Noise reducer filter (NoiseReducerFilter) to select one of the following spatial image filtering functions. To use this setting, you must also enable Noise reducer (NoiseReducer). * Bilateral preserves edges while reducing noise. * Mean (softest), Gaussian, Lanczos, and Sharpen (sharpest) do convolution filtering. * Conserve does min/max noise reduction. * Spatial does frequency-domain filtering based on JND principles. * Temporal optimizes video quality for complex motion.

Returns:

  • (String)


18760
18761
18762
18763
18764
18765
18766
18767
# File 'lib/aws-sdk-mediaconvert/types.rb', line 18760

class NoiseReducer < Struct.new(
  :filter,
  :filter_settings,
  :spatial_filter_settings,
  :temporal_filter_settings)
  SENSITIVE = []
  include Aws::Structure
end

#filter_settingsTypes::NoiseReducerFilterSettings

Settings for a noise reducer filter



18760
18761
18762
18763
18764
18765
18766
18767
# File 'lib/aws-sdk-mediaconvert/types.rb', line 18760

class NoiseReducer < Struct.new(
  :filter,
  :filter_settings,
  :spatial_filter_settings,
  :temporal_filter_settings)
  SENSITIVE = []
  include Aws::Structure
end

#spatial_filter_settingsTypes::NoiseReducerSpatialFilterSettings

Noise reducer filter settings for spatial filter.



18760
18761
18762
18763
18764
18765
18766
18767
# File 'lib/aws-sdk-mediaconvert/types.rb', line 18760

class NoiseReducer < Struct.new(
  :filter,
  :filter_settings,
  :spatial_filter_settings,
  :temporal_filter_settings)
  SENSITIVE = []
  include Aws::Structure
end

#temporal_filter_settingsTypes::NoiseReducerTemporalFilterSettings

Noise reducer filter settings for temporal filter.



18760
18761
18762
18763
18764
18765
18766
18767
# File 'lib/aws-sdk-mediaconvert/types.rb', line 18760

class NoiseReducer < Struct.new(
  :filter,
  :filter_settings,
  :spatial_filter_settings,
  :temporal_filter_settings)
  SENSITIVE = []
  include Aws::Structure
end