Class: Aws::MediaConvert::Types::OpusSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::OpusSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
Required when you set Codec, under AudioDescriptions>CodecSettings, to the value OPUS.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bitrate ⇒ Integer
Optional.
-
#channels ⇒ Integer
Specify the number of channels in this output audio track.
-
#sample_rate ⇒ Integer
Optional.
Instance Attribute Details
#bitrate ⇒ Integer
Optional. Specify the average bitrate in bits per second. Valid values are multiples of 8000, from 32000 through 192000. The default value is 96000, which we recommend for quality and bandwidth.
12768 12769 12770 12771 12772 12773 12774 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 12768 class OpusSettings < Struct.new( :bitrate, :channels, :sample_rate) SENSITIVE = [] include Aws::Structure end |
#channels ⇒ Integer
Specify the number of channels in this output audio track. Choosing Follow input will use the number of channels found in the audio source; choosing Mono gives you 1 output channel; choosing Stereo gives you 2. In the API, valid values are 0, 1, and 2.
12768 12769 12770 12771 12772 12773 12774 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 12768 class OpusSettings < Struct.new( :bitrate, :channels, :sample_rate) SENSITIVE = [] include Aws::Structure end |
#sample_rate ⇒ Integer
Optional. Sample rate in Hz. Valid values are 16000, 24000, and 48000. The default value is 48000.
12768 12769 12770 12771 12772 12773 12774 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 12768 class OpusSettings < Struct.new( :bitrate, :channels, :sample_rate) SENSITIVE = [] include Aws::Structure end |