Class: Aws::MediaConvert::Types::OpusSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::OpusSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
Note:
When making an API call, you may pass OpusSettings data as a hash:
{
bitrate: 1,
channels: 1,
sample_rate: 1,
}
Required when you set Codec, under AudioDescriptions>CodecSettings, to the value OPUS.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bitrate ⇒ Integer
Optional.
-
#channels ⇒ Integer
Specify the number of channels in this output audio track.
-
#sample_rate ⇒ Integer
Optional.
Instance Attribute Details
#bitrate ⇒ Integer
Optional. Specify the average bitrate in bits per second. Valid values are multiples of 8000, from 32000 through 192000. The default value is 96000, which we recommend for quality and bandwidth.
18307 18308 18309 18310 18311 18312 18313 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 18307 class OpusSettings < Struct.new( :bitrate, :channels, :sample_rate) SENSITIVE = [] include Aws::Structure end |
#channels ⇒ Integer
Specify the number of channels in this output audio track. Choosing Mono on the console gives you 1 output channel; choosing Stereo gives you 2. In the API, valid values are 1 and 2.
18307 18308 18309 18310 18311 18312 18313 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 18307 class OpusSettings < Struct.new( :bitrate, :channels, :sample_rate) SENSITIVE = [] include Aws::Structure end |
#sample_rate ⇒ Integer
Optional. Sample rate in hz. Valid values are 16000, 24000, and
-
The default value is 48000.
18307 18308 18309 18310 18311 18312 18313 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 18307 class OpusSettings < Struct.new( :bitrate, :channels, :sample_rate) SENSITIVE = [] include Aws::Structure end |