Class: Aws::MediaConvert::Types::PresetSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::PresetSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
Settings for preset
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#audio_descriptions ⇒ Array<Types::AudioDescription>
Contains groups of audio encoding settings organized by audio codec.
-
#caption_descriptions ⇒ Array<Types::CaptionDescriptionPreset>
This object holds groups of settings related to captions for one output.
-
#container_settings ⇒ Types::ContainerSettings
Container specific settings.
-
#video_description ⇒ Types::VideoDescription
VideoDescription contains a group of video encoding settings.
Instance Attribute Details
#audio_descriptions ⇒ Array<Types::AudioDescription>
Contains groups of audio encoding settings organized by audio codec. Include one instance of per output. Can contain multiple groups of encoding settings.
12810 12811 12812 12813 12814 12815 12816 12817 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 12810 class PresetSettings < Struct.new( :audio_descriptions, :caption_descriptions, :container_settings, :video_description) SENSITIVE = [] include Aws::Structure end |
#caption_descriptions ⇒ Array<Types::CaptionDescriptionPreset>
This object holds groups of settings related to captions for one output. For each output that has captions, include one instance of CaptionDescriptions.
12810 12811 12812 12813 12814 12815 12816 12817 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 12810 class PresetSettings < Struct.new( :audio_descriptions, :caption_descriptions, :container_settings, :video_description) SENSITIVE = [] include Aws::Structure end |
#container_settings ⇒ Types::ContainerSettings
Container specific settings.
12810 12811 12812 12813 12814 12815 12816 12817 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 12810 class PresetSettings < Struct.new( :audio_descriptions, :caption_descriptions, :container_settings, :video_description) SENSITIVE = [] include Aws::Structure end |
#video_description ⇒ Types::VideoDescription
VideoDescription contains a group of video encoding settings. The specific video settings depend on the video codec that you choose for the property codec. Include one instance of VideoDescription per output.
12810 12811 12812 12813 12814 12815 12816 12817 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 12810 class PresetSettings < Struct.new( :audio_descriptions, :caption_descriptions, :container_settings, :video_description) SENSITIVE = [] include Aws::Structure end |