Class: Aws::MediaConvert::Types::ProbeResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::ProbeResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
Probe results for your media file.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#container ⇒ Types::Container
The container of your media file.
-
#metadata ⇒ Types::Metadata
Metadata and other file information.
-
#track_mappings ⇒ Array<Types::TrackMapping>
An array containing track mapping information.
Instance Attribute Details
#container ⇒ Types::Container
The container of your media file. This information helps you understand the overall structure and details of your media, including format, duration, and track layout.
11998 11999 12000 12001 12002 12003 12004 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 11998 class ProbeResult < Struct.new( :container, :metadata, :track_mappings) SENSITIVE = [] include Aws::Structure end |
#metadata ⇒ Types::Metadata
Metadata and other file information.
11998 11999 12000 12001 12002 12003 12004 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 11998 class ProbeResult < Struct.new( :container, :metadata, :track_mappings) SENSITIVE = [] include Aws::Structure end |
#track_mappings ⇒ Array<Types::TrackMapping>
An array containing track mapping information.
11998 11999 12000 12001 12002 12003 12004 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 11998 class ProbeResult < Struct.new( :container, :metadata, :track_mappings) SENSITIVE = [] include Aws::Structure end |