Class: Aws::MediaConvert::Types::Queue
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::Queue
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
You can use queues to manage the resources that are available to your AWS account for running multiple transcoding jobs at the same time. If you don't specify a queue, the service sends all jobs through the default queue. For more information, see docs.aws.amazon.com/mediaconvert/latest/ug/working-with-queues.html.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
An identifier for this resource that is unique within all of AWS.
-
#created_at ⇒ Time
The timestamp in epoch seconds for when you created the queue.
-
#description ⇒ String
An optional description that you create for each queue.
-
#last_updated ⇒ Time
The timestamp in epoch seconds for when you most recently updated the queue.
-
#name ⇒ String
A name that you create for each queue.
-
#pricing_plan ⇒ String
Specifies whether the pricing plan for the queue is on-demand or reserved.
-
#progressing_jobs_count ⇒ Integer
The estimated number of jobs with a PROGRESSING status.
-
#reservation_plan ⇒ Types::ReservationPlan
Details about the pricing plan for your reserved queue.
-
#status ⇒ String
Queues can be ACTIVE or PAUSED.
-
#submitted_jobs_count ⇒ Integer
The estimated number of jobs with a SUBMITTED status.
-
#type ⇒ String
Specifies whether this on-demand queue is system or custom.
Instance Attribute Details
#arn ⇒ String
An identifier for this resource that is unique within all of AWS.
11013 11014 11015 11016 11017 11018 11019 11020 11021 11022 11023 11024 11025 11026 11027 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 11013 class Queue < Struct.new( :arn, :created_at, :description, :last_updated, :name, :pricing_plan, :progressing_jobs_count, :reservation_plan, :status, :submitted_jobs_count, :type) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The timestamp in epoch seconds for when you created the queue.
11013 11014 11015 11016 11017 11018 11019 11020 11021 11022 11023 11024 11025 11026 11027 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 11013 class Queue < Struct.new( :arn, :created_at, :description, :last_updated, :name, :pricing_plan, :progressing_jobs_count, :reservation_plan, :status, :submitted_jobs_count, :type) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
An optional description that you create for each queue.
11013 11014 11015 11016 11017 11018 11019 11020 11021 11022 11023 11024 11025 11026 11027 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 11013 class Queue < Struct.new( :arn, :created_at, :description, :last_updated, :name, :pricing_plan, :progressing_jobs_count, :reservation_plan, :status, :submitted_jobs_count, :type) SENSITIVE = [] include Aws::Structure end |
#last_updated ⇒ Time
The timestamp in epoch seconds for when you most recently updated the queue.
11013 11014 11015 11016 11017 11018 11019 11020 11021 11022 11023 11024 11025 11026 11027 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 11013 class Queue < Struct.new( :arn, :created_at, :description, :last_updated, :name, :pricing_plan, :progressing_jobs_count, :reservation_plan, :status, :submitted_jobs_count, :type) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
A name that you create for each queue. Each name must be unique within your account.
11013 11014 11015 11016 11017 11018 11019 11020 11021 11022 11023 11024 11025 11026 11027 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 11013 class Queue < Struct.new( :arn, :created_at, :description, :last_updated, :name, :pricing_plan, :progressing_jobs_count, :reservation_plan, :status, :submitted_jobs_count, :type) SENSITIVE = [] include Aws::Structure end |
#pricing_plan ⇒ String
Specifies whether the pricing plan for the queue is on-demand or reserved. For on-demand, you pay per minute, billed in increments of .01 minute. For reserved, you pay for the transcoding capacity of the entire queue, regardless of how much or how little you use it. Reserved pricing requires a 12-month commitment.
11013 11014 11015 11016 11017 11018 11019 11020 11021 11022 11023 11024 11025 11026 11027 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 11013 class Queue < Struct.new( :arn, :created_at, :description, :last_updated, :name, :pricing_plan, :progressing_jobs_count, :reservation_plan, :status, :submitted_jobs_count, :type) SENSITIVE = [] include Aws::Structure end |
#progressing_jobs_count ⇒ Integer
The estimated number of jobs with a PROGRESSING status.
11013 11014 11015 11016 11017 11018 11019 11020 11021 11022 11023 11024 11025 11026 11027 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 11013 class Queue < Struct.new( :arn, :created_at, :description, :last_updated, :name, :pricing_plan, :progressing_jobs_count, :reservation_plan, :status, :submitted_jobs_count, :type) SENSITIVE = [] include Aws::Structure end |
#reservation_plan ⇒ Types::ReservationPlan
Details about the pricing plan for your reserved queue. Required for reserved queues and not applicable to on-demand queues.
11013 11014 11015 11016 11017 11018 11019 11020 11021 11022 11023 11024 11025 11026 11027 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 11013 class Queue < Struct.new( :arn, :created_at, :description, :last_updated, :name, :pricing_plan, :progressing_jobs_count, :reservation_plan, :status, :submitted_jobs_count, :type) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
Queues can be ACTIVE or PAUSED. If you pause a queue, the service won't begin processing jobs in that queue. Jobs that are running when you pause the queue continue to run until they finish or result in an error.
11013 11014 11015 11016 11017 11018 11019 11020 11021 11022 11023 11024 11025 11026 11027 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 11013 class Queue < Struct.new( :arn, :created_at, :description, :last_updated, :name, :pricing_plan, :progressing_jobs_count, :reservation_plan, :status, :submitted_jobs_count, :type) SENSITIVE = [] include Aws::Structure end |
#submitted_jobs_count ⇒ Integer
The estimated number of jobs with a SUBMITTED status.
11013 11014 11015 11016 11017 11018 11019 11020 11021 11022 11023 11024 11025 11026 11027 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 11013 class Queue < Struct.new( :arn, :created_at, :description, :last_updated, :name, :pricing_plan, :progressing_jobs_count, :reservation_plan, :status, :submitted_jobs_count, :type) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
Specifies whether this on-demand queue is system or custom. System queues are built in. You can't modify or delete system queues. You can create and modify custom queues.
11013 11014 11015 11016 11017 11018 11019 11020 11021 11022 11023 11024 11025 11026 11027 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 11013 class Queue < Struct.new( :arn, :created_at, :description, :last_updated, :name, :pricing_plan, :progressing_jobs_count, :reservation_plan, :status, :submitted_jobs_count, :type) SENSITIVE = [] include Aws::Structure end |