Class: Aws::MediaConvert::Types::Rectangle

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediaconvert/types.rb

Overview

Note:

When making an API call, you may pass Rectangle data as a hash:

{
  height: 1,
  width: 1,
  x: 1,
  y: 1,
}

Use Rectangle to identify a specific area of the video frame.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#heightInteger

Height of rectangle in pixels. Specify only even numbers.

Returns:

  • (Integer)


22464
22465
22466
22467
22468
22469
22470
22471
# File 'lib/aws-sdk-mediaconvert/types.rb', line 22464

class Rectangle < Struct.new(
  :height,
  :width,
  :x,
  :y)
  SENSITIVE = []
  include Aws::Structure
end

#widthInteger

Width of rectangle in pixels. Specify only even numbers.

Returns:

  • (Integer)


22464
22465
22466
22467
22468
22469
22470
22471
# File 'lib/aws-sdk-mediaconvert/types.rb', line 22464

class Rectangle < Struct.new(
  :height,
  :width,
  :x,
  :y)
  SENSITIVE = []
  include Aws::Structure
end

#xInteger

The distance, in pixels, between the rectangle and the left edge of the video frame. Specify only even numbers.

Returns:

  • (Integer)


22464
22465
22466
22467
22468
22469
22470
22471
# File 'lib/aws-sdk-mediaconvert/types.rb', line 22464

class Rectangle < Struct.new(
  :height,
  :width,
  :x,
  :y)
  SENSITIVE = []
  include Aws::Structure
end

#yInteger

The distance, in pixels, between the rectangle and the top edge of the video frame. Specify only even numbers.

Returns:

  • (Integer)


22464
22465
22466
22467
22468
22469
22470
22471
# File 'lib/aws-sdk-mediaconvert/types.rb', line 22464

class Rectangle < Struct.new(
  :height,
  :width,
  :x,
  :y)
  SENSITIVE = []
  include Aws::Structure
end