Class: Aws::MediaConvert::Types::S3DestinationSettings

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediaconvert/types.rb

Overview

Settings associated with S3 destination

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#access_controlTypes::S3DestinationAccessControl

Optional. Have MediaConvert automatically apply Amazon S3 access control for the outputs in this output group. When you don’t use this setting, S3 automatically applies the default access control list PRIVATE.



11453
11454
11455
11456
11457
11458
# File 'lib/aws-sdk-mediaconvert/types.rb', line 11453

class S3DestinationSettings < Struct.new(
  :access_control,
  :encryption)
  SENSITIVE = []
  include Aws::Structure
end

#encryptionTypes::S3EncryptionSettings

Settings for how your job outputs are encrypted as they are uploaded to Amazon S3.



11453
11454
11455
11456
11457
11458
# File 'lib/aws-sdk-mediaconvert/types.rb', line 11453

class S3DestinationSettings < Struct.new(
  :access_control,
  :encryption)
  SENSITIVE = []
  include Aws::Structure
end