Class: Aws::MediaConvert::Types::S3DestinationSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::S3DestinationSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
Note:
When making an API call, you may pass S3DestinationSettings data as a hash:
{
access_control: {
canned_acl: "PUBLIC_READ", # accepts PUBLIC_READ, AUTHENTICATED_READ, BUCKET_OWNER_READ, BUCKET_OWNER_FULL_CONTROL
},
encryption: {
encryption_type: "SERVER_SIDE_ENCRYPTION_S3", # accepts SERVER_SIDE_ENCRYPTION_S3, SERVER_SIDE_ENCRYPTION_KMS
kms_encryption_context: "__stringPatternAZaZ0902",
kms_key_arn: "__stringPatternArnAwsUsGovCnKmsAZ26EastWestCentralNorthSouthEastWest1912D12KeyAFAF098AFAF094AFAF094AFAF094AFAF0912MrkAFAF0932",
},
}
Settings associated with S3 destination
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#access_control ⇒ Types::S3DestinationAccessControl
Optional.
-
#encryption ⇒ Types::S3EncryptionSettings
Settings for how your job outputs are encrypted as they are uploaded to Amazon S3.
Instance Attribute Details
#access_control ⇒ Types::S3DestinationAccessControl
Optional. Have MediaConvert automatically apply Amazon S3 access control for the outputs in this output group. When you don't use this setting, S3 automatically applies the default access control list PRIVATE.
22794 22795 22796 22797 22798 22799 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 22794 class S3DestinationSettings < Struct.new( :access_control, :encryption) SENSITIVE = [] include Aws::Structure end |
#encryption ⇒ Types::S3EncryptionSettings
Settings for how your job outputs are encrypted as they are uploaded to Amazon S3.
22794 22795 22796 22797 22798 22799 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 22794 class S3DestinationSettings < Struct.new( :access_control, :encryption) SENSITIVE = [] include Aws::Structure end |