Class: Aws::MediaConvert::Types::SearchJobsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::SearchJobsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
Retrieve a JSON array that includes job details for up to twenty of your most recent jobs. Optionally filter results further according to input file, queue, or status. To retrieve the twenty next most recent jobs, use the nextToken string returned with the array.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#input_file ⇒ String
Optional.
-
#max_results ⇒ Integer
Optional.
-
#next_token ⇒ String
Optional.
-
#order ⇒ String
Optional.
-
#queue ⇒ String
Optional.
-
#status ⇒ String
Optional.
Instance Attribute Details
#input_file ⇒ String
Optional. Provide your input file URL or your partial input file name. The maximum length for an input file is 300 characters.
11982 11983 11984 11985 11986 11987 11988 11989 11990 11991 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 11982 class SearchJobsRequest < Struct.new( :input_file, :max_results, :next_token, :order, :queue, :status) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
Optional. Number of jobs, up to twenty, that will be returned at one time.
11982 11983 11984 11985 11986 11987 11988 11989 11990 11991 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 11982 class SearchJobsRequest < Struct.new( :input_file, :max_results, :next_token, :order, :queue, :status) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
Optional. Use this string, provided with the response to a previous request, to request the next batch of jobs.
11982 11983 11984 11985 11986 11987 11988 11989 11990 11991 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 11982 class SearchJobsRequest < Struct.new( :input_file, :max_results, :next_token, :order, :queue, :status) SENSITIVE = [] include Aws::Structure end |
#order ⇒ String
Optional. When you request lists of resources, you can specify whether they are sorted in ASCENDING or DESCENDING order. Default varies by resource.
11982 11983 11984 11985 11986 11987 11988 11989 11990 11991 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 11982 class SearchJobsRequest < Struct.new( :input_file, :max_results, :next_token, :order, :queue, :status) SENSITIVE = [] include Aws::Structure end |
#queue ⇒ String
Optional. Provide a queue name, or a queue ARN, to return only jobs from that queue.
11982 11983 11984 11985 11986 11987 11988 11989 11990 11991 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 11982 class SearchJobsRequest < Struct.new( :input_file, :max_results, :next_token, :order, :queue, :status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
Optional. A job’s status can be SUBMITTED, PROGRESSING, COMPLETE, CANCELED, or ERROR.
11982 11983 11984 11985 11986 11987 11988 11989 11990 11991 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 11982 class SearchJobsRequest < Struct.new( :input_file, :max_results, :next_token, :order, :queue, :status) SENSITIVE = [] include Aws::Structure end |