Class: Aws::MediaConvert::Types::TeletextDestinationSettings

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediaconvert/types.rb

Overview

Settings related to teletext captions. Set up teletext captions in the same output as your video. For more information, see docs.aws.amazon.com/mediaconvert/latest/ug/teletext-output-captions.html. When you work directly in your JSON job specification, include this object and any required children when you set destinationType to TELETEXT.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#page_numberString

Set pageNumber to the Teletext page number for the destination captions for this output. This value must be a three-digit hexadecimal string; strings ending in -FF are invalid. If you are passing through the entire set of Teletext data, do not use this field.

Returns:

  • (String)


11569
11570
11571
11572
11573
11574
# File 'lib/aws-sdk-mediaconvert/types.rb', line 11569

class TeletextDestinationSettings < Struct.new(
  :page_number,
  :page_types)
  SENSITIVE = []
  include Aws::Structure
end

#page_typesArray<String>

Specify the page types for this Teletext page. If you don't specify a value here, the service sets the page type to the default value Subtitle (PAGE_TYPE_SUBTITLE). If you pass through the entire set of Teletext data, don't use this field. When you pass through a set of Teletext pages, your output has the same page types as your input.

Returns:

  • (Array<String>)


11569
11570
11571
11572
11573
11574
# File 'lib/aws-sdk-mediaconvert/types.rb', line 11569

class TeletextDestinationSettings < Struct.new(
  :page_number,
  :page_types)
  SENSITIVE = []
  include Aws::Structure
end