Class: Aws::MediaConvert::Types::TeletextSourceSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::TeletextSourceSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
Settings specific to Teletext caption sources, including Page number.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#page_number ⇒ String
Use Page Number to specify the three-digit hexadecimal page number that will be used for Teletext captions.
Instance Attribute Details
#page_number ⇒ String
Use Page Number to specify the three-digit hexadecimal page number that will be used for Teletext captions. Do not use this setting if you are passing through teletext from the input source to output.
14313 14314 14315 14316 14317 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 14313 class TeletextSourceSettings < Struct.new( :page_number) SENSITIVE = [] include Aws::Structure end |