Class: Aws::MediaConvert::Types::TeletextSourceSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::TeletextSourceSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
Settings specific to Teletext caption sources, including Page number.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#page_number ⇒ String
Use Page Number to specify the three-digit hexadecimal page number that will be used for Teletext captions.
Instance Attribute Details
#page_number ⇒ String
Use Page Number to specify the three-digit hexadecimal page number that will be used for Teletext captions. Do not use this setting if you are passing through teletext from the input source to output.
12138 12139 12140 12141 12142 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 12138 class TeletextSourceSettings < Struct.new( :page_number) SENSITIVE = [] include Aws::Structure end |