Class: Aws::MediaConvert::Types::TeletextSourceSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::TeletextSourceSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
Settings specific to Teletext caption sources, including Page number.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#page_number ⇒ String
Use Page Number (PageNumber) to specify the three-digit hexadecimal page number that will be used for Teletext captions.
Instance Attribute Details
#page_number ⇒ String
Use Page Number (PageNumber) to specify the three-digit hexadecimal page number that will be used for Teletext captions. Do not use this setting if you are passing through teletext from the input source to output.
11924 11925 11926 11927 11928 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 11924 class TeletextSourceSettings < Struct.new( :page_number) SENSITIVE = [] include Aws::Structure end |