Class: Aws::MediaConvert::Types::TeletextSourceSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::TeletextSourceSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
Note:
When making an API call, you may pass TeletextSourceSettings data as a hash:
{
page_number: "__stringMin3Max3Pattern1809aFAF09aEAE",
}
Settings specific to Teletext caption sources, including Page number.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#page_number ⇒ String
Use Page Number (PageNumber) to specify the three-digit hexadecimal page number that will be used for Teletext captions.
Instance Attribute Details
#page_number ⇒ String
Use Page Number (PageNumber) to specify the three-digit hexadecimal page number that will be used for Teletext captions. Do not use this setting if you are passing through teletext from the input source to output.
23181 23182 23183 23184 23185 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 23181 class TeletextSourceSettings < Struct.new( :page_number) SENSITIVE = [] include Aws::Structure end |