Class: Aws::MediaConvert::Types::TeletextSourceSettings

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediaconvert/types.rb

Overview

Note:

When making an API call, you may pass TeletextSourceSettings data as a hash:

{
  page_number: "__stringMin3Max3Pattern1809aFAF09aEAE",
}

Settings specific to Teletext caption sources, including Page number.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#page_numberString

Use Page Number (PageNumber) to specify the three-digit hexadecimal page number that will be used for Teletext captions. Do not use this setting if you are passing through teletext from the input source to output.

Returns:

  • (String)


22456
22457
22458
22459
22460
# File 'lib/aws-sdk-mediaconvert/types.rb', line 22456

class TeletextSourceSettings < Struct.new(
  :page_number)
  SENSITIVE = []
  include Aws::Structure
end