Class: Aws::MediaConvert::Types::UpdateJobTemplateRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::UpdateJobTemplateRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
Modify a job template by sending a request with the job template name and any of the following that you wish to change: description, category, and queue.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#acceleration_settings ⇒ Types::AccelerationSettings
Accelerated transcoding can significantly speed up jobs with long, visually complex content.
-
#category ⇒ String
The new category for the job template, if you are changing it.
-
#description ⇒ String
The new description for the job template, if you are changing it.
-
#hop_destinations ⇒ Array<Types::HopDestination>
Optional list of hop destinations.
-
#name ⇒ String
The name of the job template you are modifying.
-
#priority ⇒ Integer
Specify the relative priority for this job.
-
#queue ⇒ String
The new queue for the job template, if you are changing it.
-
#settings ⇒ Types::JobTemplateSettings
JobTemplateSettings contains all the transcode settings saved in the template that will be applied to jobs created from it.
-
#status_update_interval ⇒ String
Specify how often MediaConvert sends STATUS_UPDATE events to Amazon CloudWatch Events.
Instance Attribute Details
#acceleration_settings ⇒ Types::AccelerationSettings
Accelerated transcoding can significantly speed up jobs with long, visually complex content. Outputs that use this feature incur pro-tier pricing. For information about feature limitations, see the AWS Elemental MediaConvert User Guide.
14787 14788 14789 14790 14791 14792 14793 14794 14795 14796 14797 14798 14799 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 14787 class UpdateJobTemplateRequest < Struct.new( :acceleration_settings, :category, :description, :hop_destinations, :name, :priority, :queue, :settings, :status_update_interval) SENSITIVE = [] include Aws::Structure end |
#category ⇒ String
The new category for the job template, if you are changing it.
14787 14788 14789 14790 14791 14792 14793 14794 14795 14796 14797 14798 14799 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 14787 class UpdateJobTemplateRequest < Struct.new( :acceleration_settings, :category, :description, :hop_destinations, :name, :priority, :queue, :settings, :status_update_interval) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The new description for the job template, if you are changing it.
14787 14788 14789 14790 14791 14792 14793 14794 14795 14796 14797 14798 14799 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 14787 class UpdateJobTemplateRequest < Struct.new( :acceleration_settings, :category, :description, :hop_destinations, :name, :priority, :queue, :settings, :status_update_interval) SENSITIVE = [] include Aws::Structure end |
#hop_destinations ⇒ Array<Types::HopDestination>
Optional list of hop destinations.
14787 14788 14789 14790 14791 14792 14793 14794 14795 14796 14797 14798 14799 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 14787 class UpdateJobTemplateRequest < Struct.new( :acceleration_settings, :category, :description, :hop_destinations, :name, :priority, :queue, :settings, :status_update_interval) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the job template you are modifying
14787 14788 14789 14790 14791 14792 14793 14794 14795 14796 14797 14798 14799 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 14787 class UpdateJobTemplateRequest < Struct.new( :acceleration_settings, :category, :description, :hop_destinations, :name, :priority, :queue, :settings, :status_update_interval) SENSITIVE = [] include Aws::Structure end |
#priority ⇒ Integer
Specify the relative priority for this job. In any given queue, the service begins processing the job with the highest value first. When more than one job has the same priority, the service begins processing the job that you submitted first. If you don’t specify a priority, the service uses the default value 0.
14787 14788 14789 14790 14791 14792 14793 14794 14795 14796 14797 14798 14799 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 14787 class UpdateJobTemplateRequest < Struct.new( :acceleration_settings, :category, :description, :hop_destinations, :name, :priority, :queue, :settings, :status_update_interval) SENSITIVE = [] include Aws::Structure end |
#queue ⇒ String
The new queue for the job template, if you are changing it.
14787 14788 14789 14790 14791 14792 14793 14794 14795 14796 14797 14798 14799 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 14787 class UpdateJobTemplateRequest < Struct.new( :acceleration_settings, :category, :description, :hop_destinations, :name, :priority, :queue, :settings, :status_update_interval) SENSITIVE = [] include Aws::Structure end |
#settings ⇒ Types::JobTemplateSettings
JobTemplateSettings contains all the transcode settings saved in the template that will be applied to jobs created from it.
14787 14788 14789 14790 14791 14792 14793 14794 14795 14796 14797 14798 14799 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 14787 class UpdateJobTemplateRequest < Struct.new( :acceleration_settings, :category, :description, :hop_destinations, :name, :priority, :queue, :settings, :status_update_interval) SENSITIVE = [] include Aws::Structure end |
#status_update_interval ⇒ String
Specify how often MediaConvert sends STATUS_UPDATE events to Amazon CloudWatch Events. Set the interval, in seconds, between status updates. MediaConvert sends an update at this interval from the time the service begins processing your job to the time it completes the transcode or encounters an error.
14787 14788 14789 14790 14791 14792 14793 14794 14795 14796 14797 14798 14799 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 14787 class UpdateJobTemplateRequest < Struct.new( :acceleration_settings, :category, :description, :hop_destinations, :name, :priority, :queue, :settings, :status_update_interval) SENSITIVE = [] include Aws::Structure end |