Class: Aws::MediaConvert::Types::VideoCodecSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::VideoCodecSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
Video codec settings contains the group of settings related to video encoding. The settings in this group vary depending on the value that you choose for Video codec. For each codec enum that you choose, define the corresponding settings object. The following lists the codec enum, settings object pairs. * AV1, Av1Settings * AVC_INTRA, AvcIntraSettings * FRAME_CAPTURE, FrameCaptureSettings * GIF, GifSettings * H_264, H264Settings * H_265, H265Settings * MPEG2, Mpeg2Settings * PRORES, ProresSettings * UNCOMPRESSED, UncompressedSettings * VC3, Vc3Settings * VP8, Vp8Settings * VP9, Vp9Settings * XAVC, XavcSettings
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#av_1_settings ⇒ Types::Av1Settings
Required when you set Codec, under VideoDescription>CodecSettings to the value AV1.
-
#avc_intra_settings ⇒ Types::AvcIntraSettings
Required when you choose AVC-Intra for your output video codec.
-
#codec ⇒ String
Specifies the video codec.
-
#frame_capture_settings ⇒ Types::FrameCaptureSettings
Required when you set Codec to the value FRAME_CAPTURE.
-
#gif_settings ⇒ Types::GifSettings
Required when you set (Codec) under (VideoDescription)>(CodecSettings) to the value GIF.
-
#h264_settings ⇒ Types::H264Settings
Required when you set Codec to the value H_264.
-
#h265_settings ⇒ Types::H265Settings
Settings for H265 codec.
-
#mpeg_2_settings ⇒ Types::Mpeg2Settings
Required when you set Codec to the value MPEG2.
-
#passthrough_settings ⇒ Types::PassthroughSettings
Optional settings when you set Codec to the value Passthrough.
-
#prores_settings ⇒ Types::ProresSettings
Required when you set Codec to the value PRORES.
-
#uncompressed_settings ⇒ Types::UncompressedSettings
Required when you set Codec, under VideoDescription>CodecSettings to the value UNCOMPRESSED.
-
#vc_3_settings ⇒ Types::Vc3Settings
Required when you set Codec to the value VC3.
-
#vp_8_settings ⇒ Types::Vp8Settings
Required when you set Codec to the value VP8.
-
#vp_9_settings ⇒ Types::Vp9Settings
Required when you set Codec to the value VP9.
-
#xavc_settings ⇒ Types::XavcSettings
Required when you set Codec to the value XAVC.
Instance Attribute Details
#av_1_settings ⇒ Types::Av1Settings
Required when you set Codec, under VideoDescription>CodecSettings to the value AV1.
15221 15222 15223 15224 15225 15226 15227 15228 15229 15230 15231 15232 15233 15234 15235 15236 15237 15238 15239 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 15221 class VideoCodecSettings < Struct.new( :av_1_settings, :avc_intra_settings, :codec, :frame_capture_settings, :gif_settings, :h264_settings, :h265_settings, :mpeg_2_settings, :passthrough_settings, :prores_settings, :uncompressed_settings, :vc_3_settings, :vp_8_settings, :vp_9_settings, :xavc_settings) SENSITIVE = [] include Aws::Structure end |
#avc_intra_settings ⇒ Types::AvcIntraSettings
Required when you choose AVC-Intra for your output video codec. For more information about the AVC-Intra settings, see the relevant specification. For detailed information about SD and HD in AVC-Intra, see https://ieeexplore.ieee.org/document/7290936. For information about 4K/2K in AVC-Intra, see https://pro-av.panasonic.net/en/avc-ultra/AVC-ULTRAoverview.pdf.
15221 15222 15223 15224 15225 15226 15227 15228 15229 15230 15231 15232 15233 15234 15235 15236 15237 15238 15239 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 15221 class VideoCodecSettings < Struct.new( :av_1_settings, :avc_intra_settings, :codec, :frame_capture_settings, :gif_settings, :h264_settings, :h265_settings, :mpeg_2_settings, :passthrough_settings, :prores_settings, :uncompressed_settings, :vc_3_settings, :vp_8_settings, :vp_9_settings, :xavc_settings) SENSITIVE = [] include Aws::Structure end |
#codec ⇒ String
Specifies the video codec. This must be equal to one of the enum values defined by the object VideoCodec. To passthrough the video stream of your input without any video encoding: Choose Passthrough. More information about passthrough codec support and job settings requirements, see: https://docs.aws.amazon.com/mediaconvert/latest/ug/video-passthrough-feature-restrictions.html
15221 15222 15223 15224 15225 15226 15227 15228 15229 15230 15231 15232 15233 15234 15235 15236 15237 15238 15239 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 15221 class VideoCodecSettings < Struct.new( :av_1_settings, :avc_intra_settings, :codec, :frame_capture_settings, :gif_settings, :h264_settings, :h265_settings, :mpeg_2_settings, :passthrough_settings, :prores_settings, :uncompressed_settings, :vc_3_settings, :vp_8_settings, :vp_9_settings, :xavc_settings) SENSITIVE = [] include Aws::Structure end |
#frame_capture_settings ⇒ Types::FrameCaptureSettings
Required when you set Codec to the value FRAME_CAPTURE.
15221 15222 15223 15224 15225 15226 15227 15228 15229 15230 15231 15232 15233 15234 15235 15236 15237 15238 15239 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 15221 class VideoCodecSettings < Struct.new( :av_1_settings, :avc_intra_settings, :codec, :frame_capture_settings, :gif_settings, :h264_settings, :h265_settings, :mpeg_2_settings, :passthrough_settings, :prores_settings, :uncompressed_settings, :vc_3_settings, :vp_8_settings, :vp_9_settings, :xavc_settings) SENSITIVE = [] include Aws::Structure end |
#gif_settings ⇒ Types::GifSettings
Required when you set (Codec) under (VideoDescription)>(CodecSettings) to the value GIF
15221 15222 15223 15224 15225 15226 15227 15228 15229 15230 15231 15232 15233 15234 15235 15236 15237 15238 15239 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 15221 class VideoCodecSettings < Struct.new( :av_1_settings, :avc_intra_settings, :codec, :frame_capture_settings, :gif_settings, :h264_settings, :h265_settings, :mpeg_2_settings, :passthrough_settings, :prores_settings, :uncompressed_settings, :vc_3_settings, :vp_8_settings, :vp_9_settings, :xavc_settings) SENSITIVE = [] include Aws::Structure end |
#h264_settings ⇒ Types::H264Settings
Required when you set Codec to the value H_264.
15221 15222 15223 15224 15225 15226 15227 15228 15229 15230 15231 15232 15233 15234 15235 15236 15237 15238 15239 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 15221 class VideoCodecSettings < Struct.new( :av_1_settings, :avc_intra_settings, :codec, :frame_capture_settings, :gif_settings, :h264_settings, :h265_settings, :mpeg_2_settings, :passthrough_settings, :prores_settings, :uncompressed_settings, :vc_3_settings, :vp_8_settings, :vp_9_settings, :xavc_settings) SENSITIVE = [] include Aws::Structure end |
#h265_settings ⇒ Types::H265Settings
Settings for H265 codec
15221 15222 15223 15224 15225 15226 15227 15228 15229 15230 15231 15232 15233 15234 15235 15236 15237 15238 15239 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 15221 class VideoCodecSettings < Struct.new( :av_1_settings, :avc_intra_settings, :codec, :frame_capture_settings, :gif_settings, :h264_settings, :h265_settings, :mpeg_2_settings, :passthrough_settings, :prores_settings, :uncompressed_settings, :vc_3_settings, :vp_8_settings, :vp_9_settings, :xavc_settings) SENSITIVE = [] include Aws::Structure end |
#mpeg_2_settings ⇒ Types::Mpeg2Settings
Required when you set Codec to the value MPEG2.
15221 15222 15223 15224 15225 15226 15227 15228 15229 15230 15231 15232 15233 15234 15235 15236 15237 15238 15239 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 15221 class VideoCodecSettings < Struct.new( :av_1_settings, :avc_intra_settings, :codec, :frame_capture_settings, :gif_settings, :h264_settings, :h265_settings, :mpeg_2_settings, :passthrough_settings, :prores_settings, :uncompressed_settings, :vc_3_settings, :vp_8_settings, :vp_9_settings, :xavc_settings) SENSITIVE = [] include Aws::Structure end |
#passthrough_settings ⇒ Types::PassthroughSettings
Optional settings when you set Codec to the value Passthrough.
15221 15222 15223 15224 15225 15226 15227 15228 15229 15230 15231 15232 15233 15234 15235 15236 15237 15238 15239 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 15221 class VideoCodecSettings < Struct.new( :av_1_settings, :avc_intra_settings, :codec, :frame_capture_settings, :gif_settings, :h264_settings, :h265_settings, :mpeg_2_settings, :passthrough_settings, :prores_settings, :uncompressed_settings, :vc_3_settings, :vp_8_settings, :vp_9_settings, :xavc_settings) SENSITIVE = [] include Aws::Structure end |
#prores_settings ⇒ Types::ProresSettings
Required when you set Codec to the value PRORES.
15221 15222 15223 15224 15225 15226 15227 15228 15229 15230 15231 15232 15233 15234 15235 15236 15237 15238 15239 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 15221 class VideoCodecSettings < Struct.new( :av_1_settings, :avc_intra_settings, :codec, :frame_capture_settings, :gif_settings, :h264_settings, :h265_settings, :mpeg_2_settings, :passthrough_settings, :prores_settings, :uncompressed_settings, :vc_3_settings, :vp_8_settings, :vp_9_settings, :xavc_settings) SENSITIVE = [] include Aws::Structure end |
#uncompressed_settings ⇒ Types::UncompressedSettings
Required when you set Codec, under VideoDescription>CodecSettings to the value UNCOMPRESSED.
15221 15222 15223 15224 15225 15226 15227 15228 15229 15230 15231 15232 15233 15234 15235 15236 15237 15238 15239 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 15221 class VideoCodecSettings < Struct.new( :av_1_settings, :avc_intra_settings, :codec, :frame_capture_settings, :gif_settings, :h264_settings, :h265_settings, :mpeg_2_settings, :passthrough_settings, :prores_settings, :uncompressed_settings, :vc_3_settings, :vp_8_settings, :vp_9_settings, :xavc_settings) SENSITIVE = [] include Aws::Structure end |
#vc_3_settings ⇒ Types::Vc3Settings
Required when you set Codec to the value VC3
15221 15222 15223 15224 15225 15226 15227 15228 15229 15230 15231 15232 15233 15234 15235 15236 15237 15238 15239 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 15221 class VideoCodecSettings < Struct.new( :av_1_settings, :avc_intra_settings, :codec, :frame_capture_settings, :gif_settings, :h264_settings, :h265_settings, :mpeg_2_settings, :passthrough_settings, :prores_settings, :uncompressed_settings, :vc_3_settings, :vp_8_settings, :vp_9_settings, :xavc_settings) SENSITIVE = [] include Aws::Structure end |
#vp_8_settings ⇒ Types::Vp8Settings
Required when you set Codec to the value VP8.
15221 15222 15223 15224 15225 15226 15227 15228 15229 15230 15231 15232 15233 15234 15235 15236 15237 15238 15239 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 15221 class VideoCodecSettings < Struct.new( :av_1_settings, :avc_intra_settings, :codec, :frame_capture_settings, :gif_settings, :h264_settings, :h265_settings, :mpeg_2_settings, :passthrough_settings, :prores_settings, :uncompressed_settings, :vc_3_settings, :vp_8_settings, :vp_9_settings, :xavc_settings) SENSITIVE = [] include Aws::Structure end |
#vp_9_settings ⇒ Types::Vp9Settings
Required when you set Codec to the value VP9.
15221 15222 15223 15224 15225 15226 15227 15228 15229 15230 15231 15232 15233 15234 15235 15236 15237 15238 15239 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 15221 class VideoCodecSettings < Struct.new( :av_1_settings, :avc_intra_settings, :codec, :frame_capture_settings, :gif_settings, :h264_settings, :h265_settings, :mpeg_2_settings, :passthrough_settings, :prores_settings, :uncompressed_settings, :vc_3_settings, :vp_8_settings, :vp_9_settings, :xavc_settings) SENSITIVE = [] include Aws::Structure end |
#xavc_settings ⇒ Types::XavcSettings
Required when you set Codec to the value XAVC.
15221 15222 15223 15224 15225 15226 15227 15228 15229 15230 15231 15232 15233 15234 15235 15236 15237 15238 15239 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 15221 class VideoCodecSettings < Struct.new( :av_1_settings, :avc_intra_settings, :codec, :frame_capture_settings, :gif_settings, :h264_settings, :h265_settings, :mpeg_2_settings, :passthrough_settings, :prores_settings, :uncompressed_settings, :vc_3_settings, :vp_8_settings, :vp_9_settings, :xavc_settings) SENSITIVE = [] include Aws::Structure end |