Class: Aws::MediaConvert::Types::VideoCodecSettings

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediaconvert/types.rb

Overview

Video codec settings contains the group of settings related to video encoding. The settings in this group vary depending on the value that you choose for Video codec. For each codec enum that you choose, define the corresponding settings object. The following lists the codec enum, settings object pairs. * AV1, Av1Settings * AVC_INTRA, AvcIntraSettings * FRAME_CAPTURE, FrameCaptureSettings * GIF, GifSettings * H_264, H264Settings * H_265, H265Settings * MPEG2, Mpeg2Settings * PRORES, ProresSettings * UNCOMPRESSED, UncompressedSettings * VC3, Vc3Settings * VP8, Vp8Settings * VP9, Vp9Settings * XAVC, XavcSettings

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#av_1_settingsTypes::Av1Settings

Required when you set Codec, under VideoDescription>CodecSettings to the value AV1.

Returns:



14801
14802
14803
14804
14805
14806
14807
14808
14809
14810
14811
14812
14813
14814
14815
14816
14817
14818
14819
# File 'lib/aws-sdk-mediaconvert/types.rb', line 14801

class VideoCodecSettings < Struct.new(
  :av_1_settings,
  :avc_intra_settings,
  :codec,
  :frame_capture_settings,
  :gif_settings,
  :h264_settings,
  :h265_settings,
  :mpeg_2_settings,
  :passthrough_settings,
  :prores_settings,
  :uncompressed_settings,
  :vc_3_settings,
  :vp_8_settings,
  :vp_9_settings,
  :xavc_settings)
  SENSITIVE = []
  include Aws::Structure
end

#avc_intra_settingsTypes::AvcIntraSettings

Required when you choose AVC-Intra for your output video codec. For more information about the AVC-Intra settings, see the relevant specification. For detailed information about SD and HD in AVC-Intra, see ieeexplore.ieee.org/document/7290936. For information about 4K/2K in AVC-Intra, see pro-av.panasonic.net/en/avc-ultra/AVC-ULTRAoverview.pdf.



14801
14802
14803
14804
14805
14806
14807
14808
14809
14810
14811
14812
14813
14814
14815
14816
14817
14818
14819
# File 'lib/aws-sdk-mediaconvert/types.rb', line 14801

class VideoCodecSettings < Struct.new(
  :av_1_settings,
  :avc_intra_settings,
  :codec,
  :frame_capture_settings,
  :gif_settings,
  :h264_settings,
  :h265_settings,
  :mpeg_2_settings,
  :passthrough_settings,
  :prores_settings,
  :uncompressed_settings,
  :vc_3_settings,
  :vp_8_settings,
  :vp_9_settings,
  :xavc_settings)
  SENSITIVE = []
  include Aws::Structure
end

#codecString

Specifies the video codec. This must be equal to one of the enum values defined by the object VideoCodec. To passthrough the video stream of your input without any video encoding: Choose Passthrough. More information about passthrough codec support and job settings requirements, see: docs.aws.amazon.com/mediaconvert/latest/ug/video-passthrough-feature-restrictions.html

Returns:

  • (String)


14801
14802
14803
14804
14805
14806
14807
14808
14809
14810
14811
14812
14813
14814
14815
14816
14817
14818
14819
# File 'lib/aws-sdk-mediaconvert/types.rb', line 14801

class VideoCodecSettings < Struct.new(
  :av_1_settings,
  :avc_intra_settings,
  :codec,
  :frame_capture_settings,
  :gif_settings,
  :h264_settings,
  :h265_settings,
  :mpeg_2_settings,
  :passthrough_settings,
  :prores_settings,
  :uncompressed_settings,
  :vc_3_settings,
  :vp_8_settings,
  :vp_9_settings,
  :xavc_settings)
  SENSITIVE = []
  include Aws::Structure
end

#frame_capture_settingsTypes::FrameCaptureSettings

Required when you set Codec to the value FRAME_CAPTURE.



14801
14802
14803
14804
14805
14806
14807
14808
14809
14810
14811
14812
14813
14814
14815
14816
14817
14818
14819
# File 'lib/aws-sdk-mediaconvert/types.rb', line 14801

class VideoCodecSettings < Struct.new(
  :av_1_settings,
  :avc_intra_settings,
  :codec,
  :frame_capture_settings,
  :gif_settings,
  :h264_settings,
  :h265_settings,
  :mpeg_2_settings,
  :passthrough_settings,
  :prores_settings,
  :uncompressed_settings,
  :vc_3_settings,
  :vp_8_settings,
  :vp_9_settings,
  :xavc_settings)
  SENSITIVE = []
  include Aws::Structure
end

#gif_settingsTypes::GifSettings

Required when you set (Codec) under (VideoDescription)>(CodecSettings) to the value GIF

Returns:



14801
14802
14803
14804
14805
14806
14807
14808
14809
14810
14811
14812
14813
14814
14815
14816
14817
14818
14819
# File 'lib/aws-sdk-mediaconvert/types.rb', line 14801

class VideoCodecSettings < Struct.new(
  :av_1_settings,
  :avc_intra_settings,
  :codec,
  :frame_capture_settings,
  :gif_settings,
  :h264_settings,
  :h265_settings,
  :mpeg_2_settings,
  :passthrough_settings,
  :prores_settings,
  :uncompressed_settings,
  :vc_3_settings,
  :vp_8_settings,
  :vp_9_settings,
  :xavc_settings)
  SENSITIVE = []
  include Aws::Structure
end

#h264_settingsTypes::H264Settings

Required when you set Codec to the value H_264.

Returns:



14801
14802
14803
14804
14805
14806
14807
14808
14809
14810
14811
14812
14813
14814
14815
14816
14817
14818
14819
# File 'lib/aws-sdk-mediaconvert/types.rb', line 14801

class VideoCodecSettings < Struct.new(
  :av_1_settings,
  :avc_intra_settings,
  :codec,
  :frame_capture_settings,
  :gif_settings,
  :h264_settings,
  :h265_settings,
  :mpeg_2_settings,
  :passthrough_settings,
  :prores_settings,
  :uncompressed_settings,
  :vc_3_settings,
  :vp_8_settings,
  :vp_9_settings,
  :xavc_settings)
  SENSITIVE = []
  include Aws::Structure
end

#h265_settingsTypes::H265Settings

Settings for H265 codec

Returns:



14801
14802
14803
14804
14805
14806
14807
14808
14809
14810
14811
14812
14813
14814
14815
14816
14817
14818
14819
# File 'lib/aws-sdk-mediaconvert/types.rb', line 14801

class VideoCodecSettings < Struct.new(
  :av_1_settings,
  :avc_intra_settings,
  :codec,
  :frame_capture_settings,
  :gif_settings,
  :h264_settings,
  :h265_settings,
  :mpeg_2_settings,
  :passthrough_settings,
  :prores_settings,
  :uncompressed_settings,
  :vc_3_settings,
  :vp_8_settings,
  :vp_9_settings,
  :xavc_settings)
  SENSITIVE = []
  include Aws::Structure
end

#mpeg_2_settingsTypes::Mpeg2Settings

Required when you set Codec to the value MPEG2.



14801
14802
14803
14804
14805
14806
14807
14808
14809
14810
14811
14812
14813
14814
14815
14816
14817
14818
14819
# File 'lib/aws-sdk-mediaconvert/types.rb', line 14801

class VideoCodecSettings < Struct.new(
  :av_1_settings,
  :avc_intra_settings,
  :codec,
  :frame_capture_settings,
  :gif_settings,
  :h264_settings,
  :h265_settings,
  :mpeg_2_settings,
  :passthrough_settings,
  :prores_settings,
  :uncompressed_settings,
  :vc_3_settings,
  :vp_8_settings,
  :vp_9_settings,
  :xavc_settings)
  SENSITIVE = []
  include Aws::Structure
end

#passthrough_settingsTypes::PassthroughSettings

Optional settings when you set Codec to the value Passthrough.



14801
14802
14803
14804
14805
14806
14807
14808
14809
14810
14811
14812
14813
14814
14815
14816
14817
14818
14819
# File 'lib/aws-sdk-mediaconvert/types.rb', line 14801

class VideoCodecSettings < Struct.new(
  :av_1_settings,
  :avc_intra_settings,
  :codec,
  :frame_capture_settings,
  :gif_settings,
  :h264_settings,
  :h265_settings,
  :mpeg_2_settings,
  :passthrough_settings,
  :prores_settings,
  :uncompressed_settings,
  :vc_3_settings,
  :vp_8_settings,
  :vp_9_settings,
  :xavc_settings)
  SENSITIVE = []
  include Aws::Structure
end

#prores_settingsTypes::ProresSettings

Required when you set Codec to the value PRORES.



14801
14802
14803
14804
14805
14806
14807
14808
14809
14810
14811
14812
14813
14814
14815
14816
14817
14818
14819
# File 'lib/aws-sdk-mediaconvert/types.rb', line 14801

class VideoCodecSettings < Struct.new(
  :av_1_settings,
  :avc_intra_settings,
  :codec,
  :frame_capture_settings,
  :gif_settings,
  :h264_settings,
  :h265_settings,
  :mpeg_2_settings,
  :passthrough_settings,
  :prores_settings,
  :uncompressed_settings,
  :vc_3_settings,
  :vp_8_settings,
  :vp_9_settings,
  :xavc_settings)
  SENSITIVE = []
  include Aws::Structure
end

#uncompressed_settingsTypes::UncompressedSettings

Required when you set Codec, under VideoDescription>CodecSettings to the value UNCOMPRESSED.



14801
14802
14803
14804
14805
14806
14807
14808
14809
14810
14811
14812
14813
14814
14815
14816
14817
14818
14819
# File 'lib/aws-sdk-mediaconvert/types.rb', line 14801

class VideoCodecSettings < Struct.new(
  :av_1_settings,
  :avc_intra_settings,
  :codec,
  :frame_capture_settings,
  :gif_settings,
  :h264_settings,
  :h265_settings,
  :mpeg_2_settings,
  :passthrough_settings,
  :prores_settings,
  :uncompressed_settings,
  :vc_3_settings,
  :vp_8_settings,
  :vp_9_settings,
  :xavc_settings)
  SENSITIVE = []
  include Aws::Structure
end

#vc_3_settingsTypes::Vc3Settings

Required when you set Codec to the value VC3

Returns:



14801
14802
14803
14804
14805
14806
14807
14808
14809
14810
14811
14812
14813
14814
14815
14816
14817
14818
14819
# File 'lib/aws-sdk-mediaconvert/types.rb', line 14801

class VideoCodecSettings < Struct.new(
  :av_1_settings,
  :avc_intra_settings,
  :codec,
  :frame_capture_settings,
  :gif_settings,
  :h264_settings,
  :h265_settings,
  :mpeg_2_settings,
  :passthrough_settings,
  :prores_settings,
  :uncompressed_settings,
  :vc_3_settings,
  :vp_8_settings,
  :vp_9_settings,
  :xavc_settings)
  SENSITIVE = []
  include Aws::Structure
end

#vp_8_settingsTypes::Vp8Settings

Required when you set Codec to the value VP8.

Returns:



14801
14802
14803
14804
14805
14806
14807
14808
14809
14810
14811
14812
14813
14814
14815
14816
14817
14818
14819
# File 'lib/aws-sdk-mediaconvert/types.rb', line 14801

class VideoCodecSettings < Struct.new(
  :av_1_settings,
  :avc_intra_settings,
  :codec,
  :frame_capture_settings,
  :gif_settings,
  :h264_settings,
  :h265_settings,
  :mpeg_2_settings,
  :passthrough_settings,
  :prores_settings,
  :uncompressed_settings,
  :vc_3_settings,
  :vp_8_settings,
  :vp_9_settings,
  :xavc_settings)
  SENSITIVE = []
  include Aws::Structure
end

#vp_9_settingsTypes::Vp9Settings

Required when you set Codec to the value VP9.

Returns:



14801
14802
14803
14804
14805
14806
14807
14808
14809
14810
14811
14812
14813
14814
14815
14816
14817
14818
14819
# File 'lib/aws-sdk-mediaconvert/types.rb', line 14801

class VideoCodecSettings < Struct.new(
  :av_1_settings,
  :avc_intra_settings,
  :codec,
  :frame_capture_settings,
  :gif_settings,
  :h264_settings,
  :h265_settings,
  :mpeg_2_settings,
  :passthrough_settings,
  :prores_settings,
  :uncompressed_settings,
  :vc_3_settings,
  :vp_8_settings,
  :vp_9_settings,
  :xavc_settings)
  SENSITIVE = []
  include Aws::Structure
end

#xavc_settingsTypes::XavcSettings

Required when you set Codec to the value XAVC.

Returns:



14801
14802
14803
14804
14805
14806
14807
14808
14809
14810
14811
14812
14813
14814
14815
14816
14817
14818
14819
# File 'lib/aws-sdk-mediaconvert/types.rb', line 14801

class VideoCodecSettings < Struct.new(
  :av_1_settings,
  :avc_intra_settings,
  :codec,
  :frame_capture_settings,
  :gif_settings,
  :h264_settings,
  :h265_settings,
  :mpeg_2_settings,
  :passthrough_settings,
  :prores_settings,
  :uncompressed_settings,
  :vc_3_settings,
  :vp_8_settings,
  :vp_9_settings,
  :xavc_settings)
  SENSITIVE = []
  include Aws::Structure
end