Class: Aws::MediaConvert::Types::VideoCodecSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::VideoCodecSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
Video codec settings contains the group of settings related to video encoding. The settings in this group vary depending on the value that you choose for Video codec. For each codec enum that you choose, define the corresponding settings object. The following lists the codec enum, settings object pairs. * AV1, Av1Settings * AVC_INTRA, AvcIntraSettings * FRAME_CAPTURE, FrameCaptureSettings * H_264, H264Settings * H_265, H265Settings * MPEG2, Mpeg2Settings * PRORES, ProresSettings * VC3, Vc3Settings * VP8, Vp8Settings * VP9, Vp9Settings * XAVC, XavcSettings
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#av_1_settings ⇒ Types::Av1Settings
Required when you set Codec, under VideoDescription>CodecSettings to the value AV1.
-
#avc_intra_settings ⇒ Types::AvcIntraSettings
Required when you choose AVC-Intra for your output video codec.
-
#codec ⇒ String
Specifies the video codec.
-
#frame_capture_settings ⇒ Types::FrameCaptureSettings
Required when you set Codec to the value FRAME_CAPTURE.
-
#h264_settings ⇒ Types::H264Settings
Required when you set Codec to the value H_264.
-
#h265_settings ⇒ Types::H265Settings
Settings for H265 codec.
-
#mpeg_2_settings ⇒ Types::Mpeg2Settings
Required when you set Codec to the value MPEG2.
-
#prores_settings ⇒ Types::ProresSettings
Required when you set Codec to the value PRORES.
-
#vc_3_settings ⇒ Types::Vc3Settings
Required when you set Codec to the value VC3.
-
#vp_8_settings ⇒ Types::Vp8Settings
Required when you set Codec to the value VP8.
-
#vp_9_settings ⇒ Types::Vp9Settings
Required when you set Codec to the value VP9.
-
#xavc_settings ⇒ Types::XavcSettings
Required when you set Codec to the value XAVC.
Instance Attribute Details
#av_1_settings ⇒ Types::Av1Settings
Required when you set Codec, under VideoDescription>CodecSettings to the value AV1.
12254 12255 12256 12257 12258 12259 12260 12261 12262 12263 12264 12265 12266 12267 12268 12269 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 12254 class VideoCodecSettings < Struct.new( :av_1_settings, :avc_intra_settings, :codec, :frame_capture_settings, :h264_settings, :h265_settings, :mpeg_2_settings, :prores_settings, :vc_3_settings, :vp_8_settings, :vp_9_settings, :xavc_settings) SENSITIVE = [] include Aws::Structure end |
#avc_intra_settings ⇒ Types::AvcIntraSettings
Required when you choose AVC-Intra for your output video codec. For more information about the AVC-Intra settings, see the relevant specification. For detailed information about SD and HD in AVC-Intra, see ieeexplore.ieee.org/document/7290936. For information about 4K/2K in AVC-Intra, see pro-av.panasonic.net/en/avc-ultra/AVC-ULTRAoverview.pdf.
12254 12255 12256 12257 12258 12259 12260 12261 12262 12263 12264 12265 12266 12267 12268 12269 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 12254 class VideoCodecSettings < Struct.new( :av_1_settings, :avc_intra_settings, :codec, :frame_capture_settings, :h264_settings, :h265_settings, :mpeg_2_settings, :prores_settings, :vc_3_settings, :vp_8_settings, :vp_9_settings, :xavc_settings) SENSITIVE = [] include Aws::Structure end |
#codec ⇒ String
Specifies the video codec. This must be equal to one of the enum values defined by the object VideoCodec. To passthrough the video stream of your input JPEG2000, VC-3, AVC-INTRA or Apple ProRes video without any video encoding: Choose Passthrough. If you have multiple input videos, note that they must have identical encoding attributes. When you choose Passthrough, your output container must be MXF or QuickTime MOV.
12254 12255 12256 12257 12258 12259 12260 12261 12262 12263 12264 12265 12266 12267 12268 12269 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 12254 class VideoCodecSettings < Struct.new( :av_1_settings, :avc_intra_settings, :codec, :frame_capture_settings, :h264_settings, :h265_settings, :mpeg_2_settings, :prores_settings, :vc_3_settings, :vp_8_settings, :vp_9_settings, :xavc_settings) SENSITIVE = [] include Aws::Structure end |
#frame_capture_settings ⇒ Types::FrameCaptureSettings
Required when you set Codec to the value FRAME_CAPTURE.
12254 12255 12256 12257 12258 12259 12260 12261 12262 12263 12264 12265 12266 12267 12268 12269 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 12254 class VideoCodecSettings < Struct.new( :av_1_settings, :avc_intra_settings, :codec, :frame_capture_settings, :h264_settings, :h265_settings, :mpeg_2_settings, :prores_settings, :vc_3_settings, :vp_8_settings, :vp_9_settings, :xavc_settings) SENSITIVE = [] include Aws::Structure end |
#h264_settings ⇒ Types::H264Settings
Required when you set Codec to the value H_264.
12254 12255 12256 12257 12258 12259 12260 12261 12262 12263 12264 12265 12266 12267 12268 12269 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 12254 class VideoCodecSettings < Struct.new( :av_1_settings, :avc_intra_settings, :codec, :frame_capture_settings, :h264_settings, :h265_settings, :mpeg_2_settings, :prores_settings, :vc_3_settings, :vp_8_settings, :vp_9_settings, :xavc_settings) SENSITIVE = [] include Aws::Structure end |
#h265_settings ⇒ Types::H265Settings
Settings for H265 codec
12254 12255 12256 12257 12258 12259 12260 12261 12262 12263 12264 12265 12266 12267 12268 12269 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 12254 class VideoCodecSettings < Struct.new( :av_1_settings, :avc_intra_settings, :codec, :frame_capture_settings, :h264_settings, :h265_settings, :mpeg_2_settings, :prores_settings, :vc_3_settings, :vp_8_settings, :vp_9_settings, :xavc_settings) SENSITIVE = [] include Aws::Structure end |
#mpeg_2_settings ⇒ Types::Mpeg2Settings
Required when you set Codec to the value MPEG2.
12254 12255 12256 12257 12258 12259 12260 12261 12262 12263 12264 12265 12266 12267 12268 12269 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 12254 class VideoCodecSettings < Struct.new( :av_1_settings, :avc_intra_settings, :codec, :frame_capture_settings, :h264_settings, :h265_settings, :mpeg_2_settings, :prores_settings, :vc_3_settings, :vp_8_settings, :vp_9_settings, :xavc_settings) SENSITIVE = [] include Aws::Structure end |
#prores_settings ⇒ Types::ProresSettings
Required when you set Codec to the value PRORES.
12254 12255 12256 12257 12258 12259 12260 12261 12262 12263 12264 12265 12266 12267 12268 12269 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 12254 class VideoCodecSettings < Struct.new( :av_1_settings, :avc_intra_settings, :codec, :frame_capture_settings, :h264_settings, :h265_settings, :mpeg_2_settings, :prores_settings, :vc_3_settings, :vp_8_settings, :vp_9_settings, :xavc_settings) SENSITIVE = [] include Aws::Structure end |
#vc_3_settings ⇒ Types::Vc3Settings
Required when you set Codec to the value VC3
12254 12255 12256 12257 12258 12259 12260 12261 12262 12263 12264 12265 12266 12267 12268 12269 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 12254 class VideoCodecSettings < Struct.new( :av_1_settings, :avc_intra_settings, :codec, :frame_capture_settings, :h264_settings, :h265_settings, :mpeg_2_settings, :prores_settings, :vc_3_settings, :vp_8_settings, :vp_9_settings, :xavc_settings) SENSITIVE = [] include Aws::Structure end |
#vp_8_settings ⇒ Types::Vp8Settings
Required when you set Codec to the value VP8.
12254 12255 12256 12257 12258 12259 12260 12261 12262 12263 12264 12265 12266 12267 12268 12269 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 12254 class VideoCodecSettings < Struct.new( :av_1_settings, :avc_intra_settings, :codec, :frame_capture_settings, :h264_settings, :h265_settings, :mpeg_2_settings, :prores_settings, :vc_3_settings, :vp_8_settings, :vp_9_settings, :xavc_settings) SENSITIVE = [] include Aws::Structure end |
#vp_9_settings ⇒ Types::Vp9Settings
Required when you set Codec to the value VP9.
12254 12255 12256 12257 12258 12259 12260 12261 12262 12263 12264 12265 12266 12267 12268 12269 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 12254 class VideoCodecSettings < Struct.new( :av_1_settings, :avc_intra_settings, :codec, :frame_capture_settings, :h264_settings, :h265_settings, :mpeg_2_settings, :prores_settings, :vc_3_settings, :vp_8_settings, :vp_9_settings, :xavc_settings) SENSITIVE = [] include Aws::Structure end |
#xavc_settings ⇒ Types::XavcSettings
Required when you set Codec to the value XAVC.
12254 12255 12256 12257 12258 12259 12260 12261 12262 12263 12264 12265 12266 12267 12268 12269 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 12254 class VideoCodecSettings < Struct.new( :av_1_settings, :avc_intra_settings, :codec, :frame_capture_settings, :h264_settings, :h265_settings, :mpeg_2_settings, :prores_settings, :vc_3_settings, :vp_8_settings, :vp_9_settings, :xavc_settings) SENSITIVE = [] include Aws::Structure end |