Class: Aws::MediaConvert::Types::VideoPreprocessor
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::VideoPreprocessor
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
Find additional transcoding features under Preprocessors (VideoPreprocessors). Enable the features at each output individually. These features are disabled by default.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#color_corrector ⇒ Types::ColorCorrector
Use these settings to convert the color space or to modify properties such as hue and contrast for this output.
-
#deinterlacer ⇒ Types::Deinterlacer
Use the deinterlacer to produce smoother motion and a clearer picture.
-
#dolby_vision ⇒ Types::DolbyVision
Enable Dolby Vision feature to produce Dolby Vision compatible video output.
-
#hdr_10_plus ⇒ Types::Hdr10Plus
Enable HDR10+ analyis and metadata injection.
-
#image_inserter ⇒ Types::ImageInserter
Enable the Image inserter (ImageInserter) feature to include a graphic overlay on your video.
-
#noise_reducer ⇒ Types::NoiseReducer
Enable the Noise reducer feature to remove noise from your video output if necessary.
-
#partner_watermarking ⇒ Types::PartnerWatermarking
If you work with a third party video watermarking partner, use the group of settings that correspond with your watermarking partner to include watermarks in your output.
-
#timecode_burnin ⇒ Types::TimecodeBurnin
Settings for burning the output timecode and specified prefix into the output.
Instance Attribute Details
#color_corrector ⇒ Types::ColorCorrector
Use these settings to convert the color space or to modify properties such as hue and contrast for this output. For more information, see docs.aws.amazon.com/mediaconvert/latest/ug/converting-the-color-space.html.
12769 12770 12771 12772 12773 12774 12775 12776 12777 12778 12779 12780 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 12769 class VideoPreprocessor < Struct.new( :color_corrector, :deinterlacer, :dolby_vision, :hdr_10_plus, :image_inserter, :noise_reducer, :partner_watermarking, :timecode_burnin) SENSITIVE = [] include Aws::Structure end |
#deinterlacer ⇒ Types::Deinterlacer
Use the deinterlacer to produce smoother motion and a clearer picture. For more information, see docs.aws.amazon.com/mediaconvert/latest/ug/working-with-scan-type.html.
12769 12770 12771 12772 12773 12774 12775 12776 12777 12778 12779 12780 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 12769 class VideoPreprocessor < Struct.new( :color_corrector, :deinterlacer, :dolby_vision, :hdr_10_plus, :image_inserter, :noise_reducer, :partner_watermarking, :timecode_burnin) SENSITIVE = [] include Aws::Structure end |
#dolby_vision ⇒ Types::DolbyVision
Enable Dolby Vision feature to produce Dolby Vision compatible video output.
12769 12770 12771 12772 12773 12774 12775 12776 12777 12778 12779 12780 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 12769 class VideoPreprocessor < Struct.new( :color_corrector, :deinterlacer, :dolby_vision, :hdr_10_plus, :image_inserter, :noise_reducer, :partner_watermarking, :timecode_burnin) SENSITIVE = [] include Aws::Structure end |
#hdr_10_plus ⇒ Types::Hdr10Plus
Enable HDR10+ analyis and metadata injection. Compatible with HEVC only.
12769 12770 12771 12772 12773 12774 12775 12776 12777 12778 12779 12780 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 12769 class VideoPreprocessor < Struct.new( :color_corrector, :deinterlacer, :dolby_vision, :hdr_10_plus, :image_inserter, :noise_reducer, :partner_watermarking, :timecode_burnin) SENSITIVE = [] include Aws::Structure end |
#image_inserter ⇒ Types::ImageInserter
Enable the Image inserter (ImageInserter) feature to include a graphic overlay on your video. Enable or disable this feature for each output individually. This setting is disabled by default.
12769 12770 12771 12772 12773 12774 12775 12776 12777 12778 12779 12780 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 12769 class VideoPreprocessor < Struct.new( :color_corrector, :deinterlacer, :dolby_vision, :hdr_10_plus, :image_inserter, :noise_reducer, :partner_watermarking, :timecode_burnin) SENSITIVE = [] include Aws::Structure end |
#noise_reducer ⇒ Types::NoiseReducer
Enable the Noise reducer feature to remove noise from your video output if necessary. Enable or disable this feature for each output individually. This setting is disabled by default. When you enable Noise reducer, you must also select a value for Noise reducer filter. For AVC outputs, when you include Noise reducer, you cannot include the Bandwidth reduction filter.
12769 12770 12771 12772 12773 12774 12775 12776 12777 12778 12779 12780 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 12769 class VideoPreprocessor < Struct.new( :color_corrector, :deinterlacer, :dolby_vision, :hdr_10_plus, :image_inserter, :noise_reducer, :partner_watermarking, :timecode_burnin) SENSITIVE = [] include Aws::Structure end |
#partner_watermarking ⇒ Types::PartnerWatermarking
If you work with a third party video watermarking partner, use the group of settings that correspond with your watermarking partner to include watermarks in your output.
12769 12770 12771 12772 12773 12774 12775 12776 12777 12778 12779 12780 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 12769 class VideoPreprocessor < Struct.new( :color_corrector, :deinterlacer, :dolby_vision, :hdr_10_plus, :image_inserter, :noise_reducer, :partner_watermarking, :timecode_burnin) SENSITIVE = [] include Aws::Structure end |
#timecode_burnin ⇒ Types::TimecodeBurnin
Settings for burning the output timecode and specified prefix into the output.
12769 12770 12771 12772 12773 12774 12775 12776 12777 12778 12779 12780 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 12769 class VideoPreprocessor < Struct.new( :color_corrector, :deinterlacer, :dolby_vision, :hdr_10_plus, :image_inserter, :noise_reducer, :partner_watermarking, :timecode_burnin) SENSITIVE = [] include Aws::Structure end |