Class: Aws::MediaConvert::Types::VideoPreprocessor
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::VideoPreprocessor
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
When making an API call, you may pass VideoPreprocessor data as a hash:
{
color_corrector: {
brightness: 1,
color_space_conversion: "NONE", # accepts NONE, FORCE_601, FORCE_709, FORCE_HDR10, FORCE_HLG_2020, FORCE_P3DCI, FORCE_P3D65_SDR
contrast: 1,
hdr_10_metadata: {
blue_primary_x: 1,
blue_primary_y: 1,
green_primary_x: 1,
green_primary_y: 1,
max_content_light_level: 1,
max_frame_average_light_level: 1,
max_luminance: 1,
min_luminance: 1,
red_primary_x: 1,
red_primary_y: 1,
white_point_x: 1,
white_point_y: 1,
},
hue: 1,
sample_range_conversion: "LIMITED_RANGE_SQUEEZE", # accepts LIMITED_RANGE_SQUEEZE, NONE
saturation: 1,
sdr_reference_white_level: 1,
},
deinterlacer: {
algorithm: "INTERPOLATE", # accepts INTERPOLATE, INTERPOLATE_TICKER, BLEND, BLEND_TICKER
control: "FORCE_ALL_FRAMES", # accepts FORCE_ALL_FRAMES, NORMAL
mode: "DEINTERLACE", # accepts DEINTERLACE, INVERSE_TELECINE, ADAPTIVE
},
dolby_vision: {
l6_metadata: {
max_cll: 1,
max_fall: 1,
},
l6_mode: "PASSTHROUGH", # accepts PASSTHROUGH, RECALCULATE, SPECIFY
mapping: "HDR10_NOMAP", # accepts HDR10_NOMAP, HDR10_1000
profile: "PROFILE_5", # accepts PROFILE_5, PROFILE_8_1
},
hdr_10_plus: {
mastering_monitor_nits: 1,
target_monitor_nits: 1,
},
image_inserter: {
insertable_images: [
{
duration: 1,
fade_in: 1,
fade_out: 1,
height: 1,
image_inserter_input: "__stringMin14PatternS3BmpBMPPngPNGTgaTGAHttpsBmpBMPPngPNGTgaTGA",
image_x: 1,
image_y: 1,
layer: 1,
opacity: 1,
start_time: "__stringPattern01D20305D205D",
width: 1,
},
],
sdr_reference_white_level: 1,
},
noise_reducer: {
filter: "BILATERAL", # accepts BILATERAL, MEAN, GAUSSIAN, LANCZOS, SHARPEN, CONSERVE, SPATIAL, TEMPORAL
filter_settings: {
strength: 1,
},
spatial_filter_settings: {
post_filter_sharpen_strength: 1,
speed: 1,
strength: 1,
},
temporal_filter_settings: {
aggressive_mode: 1,
post_temporal_sharpening: "DISABLED", # accepts DISABLED, ENABLED, AUTO
post_temporal_sharpening_strength: "LOW", # accepts LOW, MEDIUM, HIGH
speed: 1,
strength: 1,
},
},
partner_watermarking: {
nexguard_file_marker_settings: {
license: "__stringMin1Max100000",
payload: 1,
preset: "__stringMin1Max256",
strength: "LIGHTEST", # accepts LIGHTEST, LIGHTER, DEFAULT, STRONGER, STRONGEST
},
},
timecode_burnin: {
font_size: 1,
position: "TOP_CENTER", # accepts TOP_CENTER, TOP_LEFT, TOP_RIGHT, MIDDLE_LEFT, MIDDLE_CENTER, MIDDLE_RIGHT, BOTTOM_LEFT, BOTTOM_CENTER, BOTTOM_RIGHT
prefix: "__stringPattern",
},
}
Find additional transcoding features under Preprocessors (VideoPreprocessors). Enable the features at each output individually. These features are disabled by default.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#color_corrector ⇒ Types::ColorCorrector
Use these settings to convert the color space or to modify properties such as hue and contrast for this output.
-
#deinterlacer ⇒ Types::Deinterlacer
Use the deinterlacer to produce smoother motion and a clearer picture.
-
#dolby_vision ⇒ Types::DolbyVision
Enable Dolby Vision feature to produce Dolby Vision compatible video output.
-
#hdr_10_plus ⇒ Types::Hdr10Plus
Enable HDR10+ analyis and metadata injection.
-
#image_inserter ⇒ Types::ImageInserter
Enable the Image inserter (ImageInserter) feature to include a graphic overlay on your video.
-
#noise_reducer ⇒ Types::NoiseReducer
Enable the Noise reducer (NoiseReducer) feature to remove noise from your video output if necessary.
-
#partner_watermarking ⇒ Types::PartnerWatermarking
If you work with a third party video watermarking partner, use the group of settings that correspond with your watermarking partner to include watermarks in your output.
-
#timecode_burnin ⇒ Types::TimecodeBurnin
Settings for burning the output timecode and specified prefix into the output.
Instance Attribute Details
#color_corrector ⇒ Types::ColorCorrector
Use these settings to convert the color space or to modify properties such as hue and contrast for this output. For more information, see docs.aws.amazon.com/mediaconvert/latest/ug/converting-the-color-space.html.
26987 26988 26989 26990 26991 26992 26993 26994 26995 26996 26997 26998 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 26987 class VideoPreprocessor < Struct.new( :color_corrector, :deinterlacer, :dolby_vision, :hdr_10_plus, :image_inserter, :noise_reducer, :partner_watermarking, :timecode_burnin) SENSITIVE = [] include Aws::Structure end |
#deinterlacer ⇒ Types::Deinterlacer
Use the deinterlacer to produce smoother motion and a clearer picture. For more information, see docs.aws.amazon.com/mediaconvert/latest/ug/working-with-scan-type.html.
26987 26988 26989 26990 26991 26992 26993 26994 26995 26996 26997 26998 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 26987 class VideoPreprocessor < Struct.new( :color_corrector, :deinterlacer, :dolby_vision, :hdr_10_plus, :image_inserter, :noise_reducer, :partner_watermarking, :timecode_burnin) SENSITIVE = [] include Aws::Structure end |
#dolby_vision ⇒ Types::DolbyVision
Enable Dolby Vision feature to produce Dolby Vision compatible video output.
26987 26988 26989 26990 26991 26992 26993 26994 26995 26996 26997 26998 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 26987 class VideoPreprocessor < Struct.new( :color_corrector, :deinterlacer, :dolby_vision, :hdr_10_plus, :image_inserter, :noise_reducer, :partner_watermarking, :timecode_burnin) SENSITIVE = [] include Aws::Structure end |
#hdr_10_plus ⇒ Types::Hdr10Plus
Enable HDR10+ analyis and metadata injection. Compatible with HEVC only.
26987 26988 26989 26990 26991 26992 26993 26994 26995 26996 26997 26998 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 26987 class VideoPreprocessor < Struct.new( :color_corrector, :deinterlacer, :dolby_vision, :hdr_10_plus, :image_inserter, :noise_reducer, :partner_watermarking, :timecode_burnin) SENSITIVE = [] include Aws::Structure end |
#image_inserter ⇒ Types::ImageInserter
Enable the Image inserter (ImageInserter) feature to include a graphic overlay on your video. Enable or disable this feature for each output individually. This setting is disabled by default.
26987 26988 26989 26990 26991 26992 26993 26994 26995 26996 26997 26998 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 26987 class VideoPreprocessor < Struct.new( :color_corrector, :deinterlacer, :dolby_vision, :hdr_10_plus, :image_inserter, :noise_reducer, :partner_watermarking, :timecode_burnin) SENSITIVE = [] include Aws::Structure end |
#noise_reducer ⇒ Types::NoiseReducer
Enable the Noise reducer (NoiseReducer) feature to remove noise from your video output if necessary. Enable or disable this feature for each output individually. This setting is disabled by default.
26987 26988 26989 26990 26991 26992 26993 26994 26995 26996 26997 26998 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 26987 class VideoPreprocessor < Struct.new( :color_corrector, :deinterlacer, :dolby_vision, :hdr_10_plus, :image_inserter, :noise_reducer, :partner_watermarking, :timecode_burnin) SENSITIVE = [] include Aws::Structure end |
#partner_watermarking ⇒ Types::PartnerWatermarking
If you work with a third party video watermarking partner, use the group of settings that correspond with your watermarking partner to include watermarks in your output.
26987 26988 26989 26990 26991 26992 26993 26994 26995 26996 26997 26998 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 26987 class VideoPreprocessor < Struct.new( :color_corrector, :deinterlacer, :dolby_vision, :hdr_10_plus, :image_inserter, :noise_reducer, :partner_watermarking, :timecode_burnin) SENSITIVE = [] include Aws::Structure end |
#timecode_burnin ⇒ Types::TimecodeBurnin
Settings for burning the output timecode and specified prefix into the output.
26987 26988 26989 26990 26991 26992 26993 26994 26995 26996 26997 26998 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 26987 class VideoPreprocessor < Struct.new( :color_corrector, :deinterlacer, :dolby_vision, :hdr_10_plus, :image_inserter, :noise_reducer, :partner_watermarking, :timecode_burnin) SENSITIVE = [] include Aws::Structure end |