Class: Aws::MediaConvert::Types::WavSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::WavSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
When making an API call, you may pass WavSettings data as a hash:
{
bit_depth: 1,
channels: 1,
format: "RIFF", # accepts RIFF, RF64
sample_rate: 1,
}
Required when you set (Codec) under (AudioDescriptions)>(CodecSettings) to the value WAV.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bit_depth ⇒ Integer
Specify Bit depth (BitDepth), in bits per sample, to choose the encoding quality for this audio track.
-
#channels ⇒ Integer
Specify the number of channels in this output audio track.
-
#format ⇒ String
The service defaults to using RIFF for WAV outputs.
-
#sample_rate ⇒ Integer
Sample rate in Hz.
Instance Attribute Details
#bit_depth ⇒ Integer
Specify Bit depth (BitDepth), in bits per sample, to choose the encoding quality for this audio track.
27548 27549 27550 27551 27552 27553 27554 27555 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 27548 class WavSettings < Struct.new( :bit_depth, :channels, :format, :sample_rate) SENSITIVE = [] include Aws::Structure end |
#channels ⇒ Integer
Specify the number of channels in this output audio track. Valid values are 1 and even numbers up to 64. For example, 1, 2, 4, 6, and so on, up to 64.
27548 27549 27550 27551 27552 27553 27554 27555 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 27548 class WavSettings < Struct.new( :bit_depth, :channels, :format, :sample_rate) SENSITIVE = [] include Aws::Structure end |
#format ⇒ String
The service defaults to using RIFF for WAV outputs. If your output audio is likely to exceed 4 GB in file size, or if you otherwise need the extended support of the RF64 format, set your output WAV file format to RF64.
27548 27549 27550 27551 27552 27553 27554 27555 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 27548 class WavSettings < Struct.new( :bit_depth, :channels, :format, :sample_rate) SENSITIVE = [] include Aws::Structure end |
#sample_rate ⇒ Integer
Sample rate in Hz.
27548 27549 27550 27551 27552 27553 27554 27555 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 27548 class WavSettings < Struct.new( :bit_depth, :channels, :format, :sample_rate) SENSITIVE = [] include Aws::Structure end |