Class: Aws::MediaConvert::Types::WebvttDestinationSettings

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediaconvert/types.rb

Overview

Note:

When making an API call, you may pass WebvttDestinationSettings data as a hash:

{
  accessibility: "DISABLED", # accepts DISABLED, ENABLED
  style_passthrough: "ENABLED", # accepts ENABLED, DISABLED
}

Settings related to WebVTT captions. WebVTT is a sidecar format that holds captions in a file that is separate from the video container. Set up sidecar captions in the same output group, but different output from your video. For more information, see docs.aws.amazon.com/mediaconvert/latest/ug/ttml-and-webvtt-output-captions.html. When you work directly in your JSON job specification, include this object and any required children when you set destinationType to WebVTT.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#accessibilityString

Set Accessibility subtitles (Accessibility) to Enabled (ENABLED) if the ISMC or WebVTT captions track is intended to provide accessibility for people who are deaf or hard of hearing. When you enable this feature, MediaConvert adds the following attributes under EXT-X-MEDIA in the HLS or CMAF manifest for this track: CHARACTERISTICS=“public.accessibility.describes-spoken-dialog,public.accessibility.describes-music-and-sound” and AUTOSELECT=“YES”. Keep the default value, Disabled (DISABLED), if the captions track is not intended to provide such accessibility. MediaConvert will not add the above attributes.

Returns:

  • (String)


26779
26780
26781
26782
26783
26784
# File 'lib/aws-sdk-mediaconvert/types.rb', line 26779

class WebvttDestinationSettings < Struct.new(
  :accessibility,
  :style_passthrough)
  SENSITIVE = []
  include Aws::Structure
end

#style_passthroughString

Set Style passthrough (StylePassthrough) to ENABLED to use the available style, color, and position information from your input captions. MediaConvert uses default settings for any missing style and position information in your input captions. Set Style passthrough to DISABLED, or leave blank, to ignore the style and position information from your input captions and use simplified output captions.

Returns:

  • (String)


26779
26780
26781
26782
26783
26784
# File 'lib/aws-sdk-mediaconvert/types.rb', line 26779

class WebvttDestinationSettings < Struct.new(
  :accessibility,
  :style_passthrough)
  SENSITIVE = []
  include Aws::Structure
end