Class: Aws::MediaConvert::Types::WebvttDestinationSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::WebvttDestinationSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
When making an API call, you may pass WebvttDestinationSettings data as a hash:
{
accessibility: "DISABLED", # accepts DISABLED, ENABLED
style_passthrough: "ENABLED", # accepts ENABLED, DISABLED
}
Settings related to WebVTT captions. WebVTT is a sidecar format that holds captions in a file that is separate from the video container. Set up sidecar captions in the same output group, but different output from your video. For more information, see docs.aws.amazon.com/mediaconvert/latest/ug/ttml-and-webvtt-output-captions.html. When you work directly in your JSON job specification, include this object and any required children when you set destinationType to WebVTT.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#accessibility ⇒ String
Specify whether to flag this caption track as accessibility in your HLS/CMAF parent manifest.
-
#style_passthrough ⇒ String
Set Style passthrough (StylePassthrough) to ENABLED to use the available style, color, and position information from your input captions.
Instance Attribute Details
#accessibility ⇒ String
Specify whether to flag this caption track as accessibility in your HLS/CMAF parent manifest. When you choose ENABLED, MediaConvert includes the parameters CHARACTERISTICS=“public.accessibility.describes-spoken-dialog,public.accessibility.describes-music-and-sound” and AUTOSELECT=“YES” in the EXT-X-MEDIA entry for this track. When you keep the default choice, DISABLED, MediaConvert leaves this parameter out.
26718 26719 26720 26721 26722 26723 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 26718 class WebvttDestinationSettings < Struct.new( :accessibility, :style_passthrough) SENSITIVE = [] include Aws::Structure end |
#style_passthrough ⇒ String
Set Style passthrough (StylePassthrough) to ENABLED to use the available style, color, and position information from your input captions. MediaConvert uses default settings for any missing style and position information in your input captions. Set Style passthrough to DISABLED, or leave blank, to ignore the style and position information from your input captions and use simplified output captions.
26718 26719 26720 26721 26722 26723 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 26718 class WebvttDestinationSettings < Struct.new( :accessibility, :style_passthrough) SENSITIVE = [] include Aws::Structure end |