Class: Aws::MediaConvert::Types::WebvttHlsSourceSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::WebvttHlsSourceSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
Settings specific to WebVTT sources in HLS alternative rendition group. Specify the properties (renditionGroupId, renditionName or renditionLanguageCode) to identify the unique subtitle track among the alternative rendition groups present in the HLS manifest. If no unique track is found, or multiple tracks match the specified properties, the job fails. If there is only one subtitle track in the rendition group, the settings can be left empty and the default subtitle track will be chosen. If your caption source is a sidecar file, use FileSourceSettings instead of WebvttHlsSourceSettings.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#rendition_group_id ⇒ String
Optional.
-
#rendition_language_code ⇒ String
Optional.
-
#rendition_name ⇒ String
Optional.
Instance Attribute Details
#rendition_group_id ⇒ String
Optional. Specify alternative group ID
13573 13574 13575 13576 13577 13578 13579 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 13573 class WebvttHlsSourceSettings < Struct.new( :rendition_group_id, :rendition_language_code, :rendition_name) SENSITIVE = [] include Aws::Structure end |
#rendition_language_code ⇒ String
Optional. Specify ISO 639-2 or ISO 639-3 code in the language property
13573 13574 13575 13576 13577 13578 13579 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 13573 class WebvttHlsSourceSettings < Struct.new( :rendition_group_id, :rendition_language_code, :rendition_name) SENSITIVE = [] include Aws::Structure end |
#rendition_name ⇒ String
Optional. Specify media name
13573 13574 13575 13576 13577 13578 13579 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 13573 class WebvttHlsSourceSettings < Struct.new( :rendition_group_id, :rendition_language_code, :rendition_name) SENSITIVE = [] include Aws::Structure end |