Class: Aws::MediaConvert::Types::WebvttHlsSourceSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::WebvttHlsSourceSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
When making an API call, you may pass WebvttHlsSourceSettings data as a hash:
{
rendition_group_id: "__string",
rendition_language_code: "ENG", # accepts ENG, SPA, FRA, DEU, GER, ZHO, ARA, HIN, JPN, RUS, POR, ITA, URD, VIE, KOR, PAN, ABK, AAR, AFR, AKA, SQI, AMH, ARG, HYE, ASM, AVA, AVE, AYM, AZE, BAM, BAK, EUS, BEL, BEN, BIH, BIS, BOS, BRE, BUL, MYA, CAT, KHM, CHA, CHE, NYA, CHU, CHV, COR, COS, CRE, HRV, CES, DAN, DIV, NLD, DZO, ENM, EPO, EST, EWE, FAO, FIJ, FIN, FRM, FUL, GLA, GLG, LUG, KAT, ELL, GRN, GUJ, HAT, HAU, HEB, HER, HMO, HUN, ISL, IDO, IBO, IND, INA, ILE, IKU, IPK, GLE, JAV, KAL, KAN, KAU, KAS, KAZ, KIK, KIN, KIR, KOM, KON, KUA, KUR, LAO, LAT, LAV, LIM, LIN, LIT, LUB, LTZ, MKD, MLG, MSA, MAL, MLT, GLV, MRI, MAR, MAH, MON, NAU, NAV, NDE, NBL, NDO, NEP, SME, NOR, NOB, NNO, OCI, OJI, ORI, ORM, OSS, PLI, FAS, POL, PUS, QUE, QAA, RON, ROH, RUN, SMO, SAG, SAN, SRD, SRB, SNA, III, SND, SIN, SLK, SLV, SOM, SOT, SUN, SWA, SSW, SWE, TGL, TAH, TGK, TAM, TAT, TEL, THA, BOD, TIR, TON, TSO, TSN, TUR, TUK, TWI, UIG, UKR, UZB, VEN, VOL, WLN, CYM, FRY, WOL, XHO, YID, YOR, ZHA, ZUL, ORJ, QPC, TNG, SRP
rendition_name: "__string",
}
Settings specific to WebVTT sources in HLS alternative rendition group. Specify the properties (renditionGroupId, renditionName or renditionLanguageCode) to identify the unique subtitle track among the alternative rendition groups present in the HLS manifest. If no unique track is found, or multiple tracks match the specified properties, the job fails. If there is only one subtitle track in the rendition group, the settings can be left empty and the default subtitle track will be chosen. If your caption source is a sidecar file, use FileSourceSettings instead of WebvttHlsSourceSettings.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#rendition_group_id ⇒ String
Optional.
-
#rendition_language_code ⇒ String
Optional.
-
#rendition_name ⇒ String
Optional.
Instance Attribute Details
#rendition_group_id ⇒ String
Optional. Specify alternative group ID
26977 26978 26979 26980 26981 26982 26983 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 26977 class WebvttHlsSourceSettings < Struct.new( :rendition_group_id, :rendition_language_code, :rendition_name) SENSITIVE = [] include Aws::Structure end |
#rendition_language_code ⇒ String
Optional. Specify ISO 639-2 or ISO 639-3 code in the language property
26977 26978 26979 26980 26981 26982 26983 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 26977 class WebvttHlsSourceSettings < Struct.new( :rendition_group_id, :rendition_language_code, :rendition_name) SENSITIVE = [] include Aws::Structure end |
#rendition_name ⇒ String
Optional. Specify media name
26977 26978 26979 26980 26981 26982 26983 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 26977 class WebvttHlsSourceSettings < Struct.new( :rendition_group_id, :rendition_language_code, :rendition_name) SENSITIVE = [] include Aws::Structure end |