Class: Aws::MediaConvert::Types::Xavc4kIntraCbgProfileSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::Xavc4kIntraCbgProfileSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
Required when you set Profile to the value XAVC_4K_INTRA_CBG.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#xavc_class ⇒ String
Specify the XAVC Intra 4k (CBG) Class to set the bitrate of your output.
Instance Attribute Details
#xavc_class ⇒ String
Specify the XAVC Intra 4k (CBG) Class to set the bitrate of your output. Outputs of the same class have similar image quality over the operating points that are valid for that class.
13651 13652 13653 13654 13655 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 13651 class Xavc4kIntraCbgProfileSettings < Struct.new( :xavc_class) SENSITIVE = [] include Aws::Structure end |