Class: Aws::MediaConvert::Types::Xavc4kIntraCbgProfileSettings

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediaconvert/types.rb

Overview

Required when you set (Profile) under (VideoDescription)>(CodecSettings)>(XavcSettings) to the value XAVC_4K_INTRA_CBG.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#xavc_classString

Specify the XAVC Intra 4k (CBG) Class to set the bitrate of your output. Outputs of the same class have similar image quality over the operating points that are valid for that class.

Returns:

  • (String)


13406
13407
13408
13409
13410
# File 'lib/aws-sdk-mediaconvert/types.rb', line 13406

class Xavc4kIntraCbgProfileSettings < Struct.new(
  :xavc_class)
  SENSITIVE = []
  include Aws::Structure
end