Class: Aws::MediaConvert::Types::Xavc4kIntraCbgProfileSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::Xavc4kIntraCbgProfileSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
Note:
When making an API call, you may pass Xavc4kIntraCbgProfileSettings data as a hash:
{
xavc_class: "CLASS_100", # accepts CLASS_100, CLASS_300, CLASS_480
}
Required when you set (Profile) under (VideoDescription)>(CodecSettings)>(XavcSettings) to the value XAVC_4K_INTRA_CBG.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#xavc_class ⇒ String
Specify the XAVC Intra 4k (CBG) Class to set the bitrate of your output.
Instance Attribute Details
#xavc_class ⇒ String
Specify the XAVC Intra 4k (CBG) Class to set the bitrate of your output. Outputs of the same class have similar image quality over the operating points that are valid for that class.
27594 27595 27596 27597 27598 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 27594 class Xavc4kIntraCbgProfileSettings < Struct.new( :xavc_class) SENSITIVE = [] include Aws::Structure end |