Class: Aws::MediaConvert::Types::Xavc4kIntraVbrProfileSettings

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediaconvert/types.rb

Overview

Required when you set (Profile) under (VideoDescription)>(CodecSettings)>(XavcSettings) to the value XAVC_4K_INTRA_VBR.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#xavc_classString

Specify the XAVC Intra 4k (VBR) Class to set the bitrate of your output. Outputs of the same class have similar image quality over the operating points that are valid for that class.

Returns:

  • (String)


13423
13424
13425
13426
13427
# File 'lib/aws-sdk-mediaconvert/types.rb', line 13423

class Xavc4kIntraVbrProfileSettings < Struct.new(
  :xavc_class)
  SENSITIVE = []
  include Aws::Structure
end