Class: Aws::MediaConvert::Types::Xavc4kIntraVbrProfileSettings

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediaconvert/types.rb

Overview

Note:

When making an API call, you may pass Xavc4kIntraVbrProfileSettings data as a hash:

{
  xavc_class: "CLASS_100", # accepts CLASS_100, CLASS_300, CLASS_480
}

Required when you set (Profile) under (VideoDescription)>(CodecSettings)>(XavcSettings) to the value XAVC_4K_INTRA_VBR.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#xavc_classString

Specify the XAVC Intra 4k (VBR) Class to set the bitrate of your output. Outputs of the same class have similar image quality over the operating points that are valid for that class.

Returns:

  • (String)


26811
26812
26813
26814
26815
# File 'lib/aws-sdk-mediaconvert/types.rb', line 26811

class Xavc4kIntraVbrProfileSettings < Struct.new(
  :xavc_class)
  SENSITIVE = []
  include Aws::Structure
end