Class: Aws::MediaConvert::Types::XavcHdIntraCbgProfileSettings

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediaconvert/types.rb

Overview

Required when you set Profile to the value XAVC_HD_INTRA_CBG.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#xavc_classString

Specify the XAVC Intra HD (CBG) Class to set the bitrate of your output. Outputs of the same class have similar image quality over the operating points that are valid for that class.

Returns:

  • (String)


14041
14042
14043
14044
14045
# File 'lib/aws-sdk-mediaconvert/types.rb', line 14041

class XavcHdIntraCbgProfileSettings < Struct.new(
  :xavc_class)
  SENSITIVE = []
  include Aws::Structure
end