Class: Aws::MediaConvert::Types::XavcHdIntraCbgProfileSettings

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediaconvert/types.rb

Overview

Required when you set (Profile) under (VideoDescription)>(CodecSettings)>(XavcSettings) to the value XAVC_HD_INTRA_CBG.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#xavc_classString

Specify the XAVC Intra HD (CBG) Class to set the bitrate of your output. Outputs of the same class have similar image quality over the operating points that are valid for that class.

Returns:

  • (String)


13355
13356
13357
13358
13359
# File 'lib/aws-sdk-mediaconvert/types.rb', line 13355

class XavcHdIntraCbgProfileSettings < Struct.new(
  :xavc_class)
  SENSITIVE = []
  include Aws::Structure
end