Class: Aws::MediaConvert::Types::XavcHdIntraCbgProfileSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaConvert::Types::XavcHdIntraCbgProfileSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediaconvert/types.rb
Overview
Note:
When making an API call, you may pass XavcHdIntraCbgProfileSettings data as a hash:
{
xavc_class: "CLASS_50", # accepts CLASS_50, CLASS_100, CLASS_200
}
Required when you set (Profile) under (VideoDescription)>(CodecSettings)>(XavcSettings) to the value XAVC_HD_INTRA_CBG.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#xavc_class ⇒ String
Specify the XAVC Intra HD (CBG) Class to set the bitrate of your output.
Instance Attribute Details
#xavc_class ⇒ String
Specify the XAVC Intra HD (CBG) Class to set the bitrate of your output. Outputs of the same class have similar image quality over the operating points that are valid for that class.
27154 27155 27156 27157 27158 |
# File 'lib/aws-sdk-mediaconvert/types.rb', line 27154 class XavcHdIntraCbgProfileSettings < Struct.new( :xavc_class) SENSITIVE = [] include Aws::Structure end |