Class: Aws::MediaConvert::Types::XavcHdIntraCbgProfileSettings

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediaconvert/types.rb

Overview

Note:

When making an API call, you may pass XavcHdIntraCbgProfileSettings data as a hash:

{
  xavc_class: "CLASS_50", # accepts CLASS_50, CLASS_100, CLASS_200
}

Required when you set (Profile) under (VideoDescription)>(CodecSettings)>(XavcSettings) to the value XAVC_HD_INTRA_CBG.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#xavc_classString

Specify the XAVC Intra HD (CBG) Class to set the bitrate of your output. Outputs of the same class have similar image quality over the operating points that are valid for that class.

Returns:

  • (String)


26936
26937
26938
26939
26940
# File 'lib/aws-sdk-mediaconvert/types.rb', line 26936

class XavcHdIntraCbgProfileSettings < Struct.new(
  :xavc_class)
  SENSITIVE = []
  include Aws::Structure
end